import 'dart:math';
import 'dart:ui' as ui;

import 'package:collection/collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:simple_animations/simple_animations.dart';
import 'package:supercharged/supercharged.dart';

void main() {
  test('plasma', () {
    var random = Random(1);

    var values = <double>[];

    1000.times(() {
      var type = [PlasmaType.bubbles, PlasmaType.circle, PlasmaType.infinity]
          .pickOne(random);
      var circleSize = random.nextDouble() * 10;
      var offset = random.nextDouble() * pi * 2;
      var canvasSize = Size(1 + random.nextInt(800).toDouble(),
          1 + random.nextInt(600).toDouble());
      var value = random.nextDouble() * pi * 2;
      var blur = random.nextDouble() * 10.0;
      var particles = 1 + random.nextInt(30);
      var variation1 = random.nextDouble() * pi * 2;
      var variation2 = random.nextDouble() * pi * 2;
      var variation3 = random.nextDouble() * pi * 2;

      final compute = LiPlasmaComputeFactory.create(
        type: type,
        circleSize: circleSize,
        offset: offset,
        canvasSize: canvasSize,
        value: value,
        blur: blur,
        particles: particles,
        variation1: variation1,
        variation2: variation2,
        variation3: variation3,
      );

      1.until(10).forEach((n) {
        var position = compute.position(n);
        values.add(position.dx);
        values.add(position.dy);
        values.add(compute.radius(n));
      });
    });

    expect(values.length, equals(_expectedValues.length));
    values.forEachIndexed((index, value) {
      expect(value.toStringAsPrecision(3),
          equals(_expectedValues[index].toStringAsPrecision(3)));
    });
  });

  testWidgets('PlasmaRenderer renders atlas particles',
      (WidgetTester tester) async {
    // Render using atlas, check that atlas is generated.
    await tester.pumpWidget(Directionality(
      textDirection: TextDirection.ltr,
      child: PlasmaRenderer(
        particleType: ParticleType.atlas,
        blur: 0.5,
        variation1: 0.5,
      ),
    ));

    var customPaint = tester.widget<CustomPaint>(find.byType(CustomPaint));
    dynamic plasmaPainter = customPaint.painter;

    expect(plasmaPainter.atlasFuture, isNotNull);
    var atlas = plasmaPainter.atlas as ui.Image;
    expect(atlas, isNotNull);
    expect(atlas.width, 150);
    expect(atlas.height, 150);

    // Change blur level, check that atlas is updated.
    await tester.pumpWidget(Directionality(
      textDirection: TextDirection.ltr,
      child: PlasmaRenderer(
        particleType: ParticleType.atlas,
        blur: 1,
        variation1: 0.5,
      ),
    ));

    customPaint = tester.widget<CustomPaint>(find.byType(CustomPaint));
    plasmaPainter = customPaint.painter;

    expect(plasmaPainter.atlasFuture, isNotNull);
    atlas = plasmaPainter.atlas as ui.Image;
    expect(atlas, isNotNull);
    expect(atlas.width, 200);
    expect(atlas.height, 200);
  });
}

var _expectedValues = <double>[
  -377.3897087205196,
  564.111006770175,
  127.45681509176903,
  1069.3857101035937,
  567.8101690262133,
  444.2472107689569,
  1053.2962889411478,
  452.9110406119513,
  508.72291013296706,
  -385.11210045377743,
  559.7147567365082,
  300.1319617630467,
  977.8304001871958,
  295.0756221370148,
  -114.38918960147639,
  1009.6285112004339,
  532.5337465829236,
  -77.95014402733082,
  -364.48476248320094,
  568.4627107545471,
  324.8428475648708,
  664.6623652044227,
  14.986797083379088,
  513.7522660279618,
  645.0430867422888,
  149.12994687257807,
  427.9763036492984,
  502.76093313162033,
  149.02518696964026,
  -536.6198239045477,
  649.4788935446821,
  224.62773053303323,
  334.453491005948,
  -793.7539263569522,
  338.4421712168722,
  511.74125585792166,
  929.7206627207664,
  386.69046790659405,
  -61.8178271707902,
  270.1698869659842,
  54.963869062300034,
  -1201.619785647942,
  -385.9882330337209,
  571.7434551027497,
  -1101.4239443169756,
  1331.56484666507,
  573.7617636027423,
  6.129287083594361,
  7.608872169731626,
  2.1756969530729293,
  525.5703926344733,
  392.26551779435636,
  221.86358165538303,
  289.71364663338,
  1022.4670639861564,
  362.0748445968928,
  910.4280352153227,
  1076.2447610917795,
  306.73880440548464,
  1106.7694624372434,
  1019.8903160951268,
  364.2839472795219,
  1146.730430342221,
  672.7297685030364,
  524.981088056707,
  1017.4492240071095,
  1033.5600034703434,
  352.1943313669278,
  760.5358971412309,
  898.9965905956035,
  -152.62500958516966,
  783.1202125505997,
  989.041582718594,
  388.59776307987244,
  1032.7646207251084,
  -433.7322674154502,
  232.09707542316363,
  1149.8475416180202,
  1079.9557213621574,
  302.0136509197218,
  1096.6850243682168,
  -142.4049585374844,
  -512.937086339198,
  930.9562885459951,
  64.11851561458272,
  -796.9781323749105,
  1131.7248054459749,
  -74.22395678252997,
  -636.4270356553172,
  1172.5868098313354,
  182.96922660200963,
  1365.3332062873158,
  1040.3905819328616,
  -295.1722148498151,
  299.61565920342144,
  777.6843953856779,
  51.48298631630331,
  -786.1108664183594,
  800.7779400038263,
  891.7350250011975,
  525.3402254825928,
  1056.0513089038031,
  736.7325346233595,
  1048.6714011030008,
  1175.7742054651007,
  208.40958703448126,
  -878.3893604937114,
  1121.4129843314236,
  396.1178200634613,
  143.26403871077952,
  60.34838134260955,
  534.0722178081373,
  168.28673361711787,
  114.27498116824192,
  -235.6255152025485,
  3.4178475444491596,
  125.25055140498549,
  480.7505201378474,
  118.85189928861412,
  89.74252858141396,
  128.34782613914768,
  133.336767651634,
  19.179416334558923,
  -98.03115306954078,
  44.85366104483119,
  25.382362684950547,
  503.02761182136624,
  111.7232771360329,
  93.9490135890269,
  -157.50831401681899,
  19.341493525374162,
  126.10668866934385,
  235.01353300060705,
  160.4531432731157,
  111.50521696763792,
  192.1481882037196,
  285.1155031737277,
  114.28969593559685,
  64.50076154537523,
  42.930274973059,
  1057.4444811634116,
  436.38703179002164,
  339.61002660510314,
  1249.4028398001512,
  -105.73084522729604,
  0.8296615438773642,
  628.3816415730064,
  -141.0565799139195,
  333.13752991332683,
  -605.7391298344152,
  471.16750763076266,
  442.01459120201287,
  -497.25206497588715,
  -298.3153128869516,
  310.82577811573856,
  701.9513915062009,
  -296.49483179949027,
  592.4902328055223,
  1264.3763400820592,
  481.47218752423845,
  475.9434193352635,
  1009.0024067845508,
  101.83517434548395,
  -83.9134589157893,
  85325436.10969873,
  -339.92694312821556,
  1617.9526394848936,
  143188558.22526354,
  -139.4277191251056,
  -179.43514778928375,
  154965320.7682412,
  39.46960652653221,
  813.6463332304714,
  116865290.96168944,
  337.39427485461465,
  545.7582838306538,
  41151227.8834282,
  295.0532014711626,
  -343.84281687174405,
  47806975.57213015,
  174.86787989840784,
  363.1381800118331,
  121378840.05359988,
  -126.48273561954622,
  452.47437997321924,
  155883954.15576112,
  -122.84816627704345,
  -405.2600983819989,
  140216607.37560716,
  202.89497483739922,
  -226.9995784365591,
  257.0166064536097,
  -6.353195636305088,
  1645.2058050819398,
  344.9004273333079,
  -46.09790556085807,
  -332.0820054969461,
  362.7872411108759,
  31.298894637270422,
  760.3967134721495,
  304.92005260447723,
  211.24512872079765,
  465.69582675848324,
  189.92381814007067,
  293.9294936103599,
  -512.9451905836976,
  200.03271852961606,
  244.76759821659817,
  264.7973296149047,
  311.77533322920664,
  69.31705059999078,
  363.07516396861035,
  364.1824823134103,
  -32.34881678356365,
  -580.5097100207007,
  340.38656104706047,
  198.49947733208901,
  948.1534716218788,
  57921.87434713237,
  -335.1498246598652,
  -1432.8357405755178,
  98242.93971376822,
  -1357.3995972052826,
  779.1270361353666,
  106449.40343265247,
  253.75129875632246,
  2536.393106951584,
  79899.95818784581,
  2426.1894822559466,
  2062.3629402586344,
  27139.727233578666,
  2025.0017956215258,
  488.2062766787307,
  31777.687091396252,
  790.4853530142889,
  1739.2151236664035,
  83045.15846941664,
  -1454.4318397513441,
  1897.296284264215,
  107089.53959385352,
  -1362.7201914564525,
  379.527878156051,
  96171.9794873896,
  431.37596007807474,
  -568.3487520227994,
  297523868.58131486,
  -153.07006252220964,
  670.3085198449779,
  499288614.97749907,
  -107.97742059004645,
  -637.8716332033148,
  540353379.9085431,
  73.52321097410766,
  84.91589936361402,
  407501183.71607125,
  511.94596502135954,
  -110.05918166501914,
  143491427.9842628,
  629.5921187617271,
  -757.5313144503843,
  166699564.62448576,
  528.8103877490712,
  -242.97429161227222,
  423239620.4713025,
  100.85948959620578,
  -177.95335146474525,
  543556591.65529,
  -63.859053096347736,
  -802.2322239006079,
  488925625.778865,
  183.77209005674433,
  459.66176095585746,
  30627.367545835918,
  -342.6387339354103,
  -21.828143687457114,
  51532.883012211074,
  -871.9694316762482,
  425.4807903375574,
  55787.73968922091,
  65.3310198394565,
  -309.6368135970238,
  42022.48241880534,
  372.47169943728375,
  -405.4964414314488,
  14667.554809758829,
  1380.7701067662374,
  366.6500287314344,
  17072.226924902454,
  562.6896264797916,
  619.6323301036156,
  43653.19412082385,
  204.094667197127,
  -438.8766550197374,
  56119.63509666835,
  -898.4634672834686,
  344.67279696851904,
  50459.13928423332,
  342.5374836258234,
  184.11665323461324,
  33.73699448829474,
  750.0640304626063,
  315.4309142842509,
  37.186113908273065,
  -263.1100053663098,
  159.28363122112478,
  37.888106108250305,
  51.065129944639125,
  414.90484198785515,
  35.61703002554129,
  740.065642756229,
  350.1693060303429,
  31.103847262828804,
  -112.75590701122013,
  422.51035455404207,
  31.50058473167345,
  -193.80029681613934,
  348.62808058322247,
  35.886074785947436,
  742.815652865034,
  342.1367734234832,
  37.942864236413655,
  165.9901318624148,
  342.1299177054581,
  37.00896112052168,
  -13.038685548440728,
  223.79097622291383,
  218.6258979716615,
  -6.175421633351453,
  182.42084776078542,
  265.7744030429908,
  -12.120326870486206,
  264.4334011694991,
  275.37044155906773,
  15.876977846812515,
  309.5017655577415,
  244.32546190926078,
  -7.130908882961615,
  185.55020795585148,
  182.63150630336207,
  13.879933695025287,
  311.58504766679664,
  188.0547973768633,
  24.44132837426232,
  186.65210688380563,
  248.00322910309822,
  -7.122803981495608,
  185.52203199870266,
  276.11896997140735,
  29.260789586104117,
  213.92246542157656,
  263.35277360815127,
  -884.2341732146153,
  14.428118600835404,
  391.05897032757116,
  1335.742114864067,
  14.879672459348576,
  660.4354391117729,
  -724.4970616822955,
  10.291436381485692,
  715.2610792008345,
  -790.745842987671,
  11.075362174469054,
  537.8898777408808,
  1301.6184226956498,
  14.514451236095702,
  185.40998720555763,
  -222.85374599765612,
  1.6794519917825657,
  216.3952113682003,
  -208.381893272441,
  0.9659548498843851,
  558.9022924120885,
  1198.5225566782942,
  12.874442659008716,
  719.5376928537095,
  348.3405681761707,
  0.679765049211694,
  646.5997939545391,
  121.69652069046003,
  449.1870998284797,
  504.995031934542,
  104.02581506114697,
  361.4479432105906,
  613.9014380147956,
  156.30019648639527,
  512.150046486249,
  636.0669354322127,
  148.10025508845513,
  506.6015564532465,
  564.3574049735038,
  118.66091963425039,
  -236.82886014406256,
  421.85305681339975,
  224.95421449586922,
  -103.35227138976836,
  434.38009534937436,
  107.1998580521238,
  -180.83298177311195,
  572.8525291958888,
  169.70793606698467,
  510.09268766750444,
  637.7959306381804,
  90.61120924864417,
  -19.406869337319677,
  608.3078150948846,
  -1.4036426017829284,
  10.492659840829432,
  23.902756086670127,
  7.337471413032945,
  122.35280952110506,
  29.64500571374062,
  6.023964067995898,
  24.836875261263486,
  30.813714000608545,
  1.5384016258636564,
  32.90024902782864,
  27.032724072151225,
  7.146309401809981,
  89.26538435006398,
  19.5189737838966,
  7.055695630804645,
  80.86249746706858,
  20.179480221952133,
  2.144353339983403,
  49.7739716732469,
  27.480641927983882,
  6.265215334902129,
  33.93688289106587,
  30.904877802941325,
  7.33701081174868,
  118.74496494059152,
  29.350073759947538,
  437.8975469751849,
  601.5597251257605,
  2730642.5483752615,
  61.525986701992906,
  107.94104766678856,
  4582386.553863972,
  -181.68672221128998,
  566.5177328676461,
  4959268.21260801,
  64.89757674685009,
  -187.11754781349214,
  3739985.5464857556,
  407.4128883148459,
  -285.3918880582613,
  1316973.1456624912,
  749.3597508470119,
  506.20501923052154,
  1529971.3461395428,
  547.6946424547782,
  -352.3858068181099,
  3884428.7975383285,
  220.45437087349217,
  -319.6129521467213,
  4988666.451181871,
  -164.04542708892149,
  483.6741790770727,
  4487277.752796048,
  -40.04352894474113,
  8.7375516526659,
  581.9759819245636,
  334.124960112079,
  -6.202307782417918,
  707.4839742975389,
  333.25776554809795,
  202.25238416400117,
  733.0283585163916,
  139.41658488041077,
  -7.8482495186569565,
  650.3874971950745,
  511.1438995976787,
  182.02563903552863,
  486.1599252300765,
  632.9088627789356,
  148.2190831813529,
  500.5965732989741,
  -153.5800519070773,
  33.50636590738476,
  660.1776098659939,
  278.7028664536361,
  204.6076456251978,
  735.0209200647322,
  249.26906589498643,
  -9.248617686874482,
  701.0376649569097,
  340.0934011391646,
  -464.50503423657005,
  541.9458879297524,
  349.4022376381308,
  846.5484323838779,
  658.8210554305124,
  69.91119721330358,
  -385.0963083591397,
  682.6084185126186,
  151.6223978491003,
  -544.8871793603237,
  605.6518492398577,
  438.1995753998175,
  426.2846843146378,
  452.7203536534046,
  403.5445403039056,
  665.6996285795858,
  466.1640047651822,
  2.0880136999423087,
  -14.920675758570752,
  614.7685679175393,
  414.7204332294435,
  -205.19678690306876,
  684.4639255629253,
  46.4633668003961,
  -302.17260833909086,
  652.8181430286567,
  641.3453519030787,
  -399.85675993471364,
  1203.7754759062632,
  -613.5594439480639,
  322.63432789642496,
  2068.2900224706827,
  -104.26193865140323,
  -440.4084631330637,
  2244.2428946559276,
  122.31790107102177,
  -18.816823108516445,
  1675.0024391112402,
  862.3237850084404,
  -132.5430019246532,
  543.7826480338817,
  2060.9271118719375,
  783.5180085527649,
  643.2240622675179,
  780.6221555914267,
  -210.07048636769224,
  1742.4379438666879,
  65.88052594428092,
  -172.14470104682778,
  2257.967904600683,
  -1292.8963732523207,
  757.4446067900324,
  2023.8870478771066,
  250.76113142433334,
  -263.4319644547406,
  97478535.26850726,
  -423.20050582689953,
  188.0190223495231,
  163583338.0975963,
  -84.25405644244245,
  -288.770832620502,
  177037513.0091005,
  59.27222920628513,
  -25.33787805097461,
  133510740.41092728,
  445.9641898623771,
  -96.40006347688299,
  47012414.21999853,
  373.637435812629,
  -332.3829619855647,
  54616167.224599294,
  326.7168427413491,
  -144.84337294569448,
  138667172.72690654,
  -51.49601473755092,
  -121.14531839967816,
  178086991.1003957,
  -22.279670136397215,
  -348.67501479200496,
  160188080.15520757,
  -160.84791901028314,
  1176.8365138941742,
  657.9305192480517,
  201.78885189970677,
  1439.7794472760577,
  799.8187434298457,
  599.6312981480672,
  1226.6921558633808,
  828.6969626261147,
  803.965624899127,
  780.1142132193215,
  735.2705215203575,
  841.1244489926152,
  606.3764816710723,
  549.6093687345309,
  771.9927634092782,
  887.0145615627501,
  565.9301648759125,
  481.5731898493925,
  1349.0771669648873,
  746.338356127164,
  17.160205170896518,
  1367.4433709081154,
  830.9495762989301,
  -276.78862040828574,
  946.1001912234567,
  792.5311168207745,
  89.85802679394433,
  -349.8503564726537,
  23.607491330273305,
  128.40649842966465,
  -290.4127991383784,
  28.698644460041262,
  83.15812459046398,
  626.2820409103508,
  29.734836412481492,
  104.58462191279055,
  -363.95826551062817,
  26.382561614615014,
  91.90067714713412,
  652.4473987454674,
  19.720772981114216,
  135.53124897384006,
  536.0055634853807,
  20.306386571210588,
  90.11297479467166,
  -350.4727102130565,
  26.779691405498866,
  60.513215182510955,
  447.73954750666854,
  29.815663424142578,
  105.3466122358334,
  -363.51128057345386,
  28.437153957687695,
  331.3629051966489,
  -1520.3028286082488,
  14678939.505050866,
  -930.8351598206793,
  857.2247955341139,
  24633221.58103766,
  -152.42110856268567,
  -1653.7477889461443,
  26659196.19161231,
  97.99672213000531,
  -266.4008899348351,
  20104789.3443554,
  769.1508722453351,
  -640.6437508885904,
  7079582.382746697,
  527.6468637568275,
  -1883.4273008840894,
  8224580.915449699,
  459.1250925551572,
  -895.7662555092602,
  20881262.1509032,
  -199.6355040767143,
  -770.9624983607096,
  26817230.109062005,
  -35.02627091856283,
  -1969.227989626614,
  24121952.296010774,
  370.6755203854898,
  370.8739210339782,
  1154.683089467769,
  551.6888946365916,
  399.99997080226626,
  1236.6567399191701,
  -526.5451126822109,
  3.683579212168837,
  1253.3406688336718,
  633.8029275039564,
  392.8248362591197,
  1199.3650378728578,
  299.44741530750713,
  345.93114180929257,
  1092.1022785520433,
  -385.10764071534607,
  173.35323994206192,
  1101.5313572912912,
  879.3861322194091,
  258.13241476828273,
  1205.7593021646558,
  111.60719948908242,
  254.65991268469367,
  1254.6420803276997,
  69.32440728906101,
  398.7330462217419,
  1232.4464302918757,
  210.1131421052592,
  194.30360627777287,
  805.376358273123,
  -156.569383481542,
  -109.92766106285586,
  1332.4475802114441,
  -980.7128219952954,
  172.70622716378742,
  1439.7213047714083,
  194.75843059248828,
  397.2411729923376,
  1092.6707390255976,
  1829.0101536530276,
  336.6718946302657,
  402.9965167312632,
  1533.6188761524804,
  135.5337818239331,
  463.6232672234156,
  648.188547480489,
  295.3816320467191,
  1133.7843490102189,
  -1035.0109910446217,
  315.5804769574739,
  1448.0890734705542,
  -969.2607885219875,
  121.647382530009,
  1305.3762831815234,
  41.144992917120305,
  463.63315652466406,
  -968.9262640161338,
  -549.486494183328,
  69.43850364511701,
  620.8594675374937,
  968.321761279699,
  230.9157720349905,
  944.4252961723234,
  490.74809081643264,
  289.84054590330237,
  -102.37068620227255,
  -489.62244761409386,
  64.42339328950445,
  -2182.609925961382,
  1003.2746075899345,
  136.18142537050068,
  -1999.7436663913145,
  816.0173581683509,
  57.537276229012036,
  21.638798295555155,
  -67.5287427540407,
  399.37860253561826,
  969.6646921574072,
  1000.8568448714077,
  28.96218162258367,
  539.2053002040052,
  30.45125037681046,
  -56.4455265798436,
  38319.40160992598,
  -103.73394855100179,
  273.15618621266077,
  64326.01781827942,
  -35.1006650963981,
  -74.94528533943509,
  69619.09106483599,
  11.400865950518348,
  117.3855668904933,
  52495.00898148631,
  95.99679205147189,
  65.50348286414226,
  18465.276259515947,
  78.33978928598273,
  -106.78624472908729,
  21456.706196082498,
  50.096979124447174,
  30.135307268193174,
  54523.6264269197,
  -34.9333746303635,
  47.43711764524005,
  70031.97141197136,
  -28.00276127463718,
  -118.68097675286941,
  62990.272661239,
  123.89878643938862,
  44.39856742889297,
  -198.83527632269514,
  -163.37997954498272,
  29.53618169883067,
  86.63726183764608,
  248.86033175667353,
  14.401388821610766,
  144.73890190713547,
  220.01438604834914,
  58.0916258447121,
  -43.23077230329345,
  -167.02998687360156,
  33.94033151027365,
  -416.7724162922773,
  238.93215204861946,
  52.87744630971596,
  -383.93573004755984,
  255.6980966742507,
  26.633832441414295,
  -20.96280147369355,
  -165.16348847300705,
  31.54892569934984,
  149.2710563292628,
  155.68581948546668,
  52.52764828945544,
  71.97489449001581,
  1350.9937094121,
  483.5287677793656,
  1.099905436959979,
  -765.4499987532026,
  228.35235861314834,
  119.14499080039809,
  1153.2436150988797,
  85.03061399298218,
  143.1704648651096,
  1224.4136434657535,
  416.1264202968822,
  65.44356202219967,
  -647.6299840000671,
  502.83707532087374,
  -89.01877448006637,
  604.8827351708665,
  19.203264607422,
  -75.44055271558636,
  1145.8727336013135,
  368.3655475216213,
  74.65153885384244,
  -83.10604820716833,
  297.03121226482153,
  145.0445455002837,
  -92.79720267962426,
  302.04963731832515,
  113.08198937709152,
  -178.24031198237049,
  -134.65017555848075,
  120.09028198443377,
  -134.23322344009705,
  -191.3494027068512,
  145.98875660107947,
  92.4453861562026,
  -322.1812317505599,
  151.25982001131888,
  -64.77901532057524,
  435.24927900621856,
  134.2069438656503,
  552.2647794852984,
  336.51178941649687,
  100.31871473001578,
  -222.77826308890195,
  -43.54995532324244,
  103.29770560137561,
  -146.60404305912238,
  -177.30833786775634,
  136.22712584536382,
  332.74651477619557,
  -311.64714462372905,
  151.67098350542093,
  211.36532039630026,
  -333.2438637076704,
  144.65856578475913,
  296.45196153797986,
  2.7565964666640603,
  -247.67493564173608,
  242.8348089640061,
  25.16869470393916,
  105.63073018584976,
  346.1405790983677,
  26.849099283846705,
  177.5383075756439,
  284.27489929036784,
  7.697379883229659,
  -55.09615642666609,
  253.17318926312444,
  25.1257879430237,
  -517.3976446690586,
  355.14740641953574,
  10.810900887743209,
  -476.75840359871364,
  267.9535503100024,
  16.812665927000765,
  -27.536937206209426,
  269.80033665830234,
  15.70276773977685,
  183.1473789282226,
  355.64284062776886,
  13.152618287213237,
  87.48433511840706,
  577.3444700721866,
  -1576.7207511557406,
  6075.143897592542,
  -198.52927734620357,
  1109.9229653367006,
  10690.198162735694,
  -119.96438940212141,
  -1727.5156611911946,
  11629.490689934588,
  96.2765220830135,
  -159.79178241246922,
  8590.703658885155,
  661.4767618774054,
  -582.6921182965854,
  2551.891770325582,
  806.8209518186568,
  -1987.057132461261,
  3082.7417423874595,
  699.0779575173511,
  -870.984572615466,
  8950.69588235958,
  149.91196115504263,
  -729.9543584833898,
  11702.759168685347,
  -54.73806010206579,
  -2084.0132640914962,
  10453.160928258278,
  -724.2606585304422,
  275.4514288130328,
  52.34704599321472,
  808.6364058743096,
  -413.36734124670795,
  63.63612467226541,
  1245.1210384001429,
  -162.59207330926557,
  65.93376769724156,
  82.31468245351408,
  -458.7242421315706,
  58.500462710668074,
  1321.2205077038402,
  554.7206237007686,
  43.72867052334021,
  1112.7188073807883,
  -270.3677713425766,
  45.02720500572783,
  -718.2274303984839,
  324.4102284177502,
  59.3810548556714,
  482.24435213464255,
  -476.3024058145314,
  66.11299281005527,
  -598.8084511521606,
  580.3394015047625,
  63.056297906177065,
  384.5043154098011,
  -416.8100284998867,
  185849.7058593704,
  -2139.746197381717,
  4110.43165927355,
  313581.67650894437,
  -848.8620904002253,
  -670.9133168614095,
  339578.7024641336,
  211.45052306727183,
  1970.845564435676,
  255473.46045388127,
  1885.3552053823628,
  1258.2196145804664,
  88335.80646491704,
  1528.6427449913465,
  -1108.2645596878797,
  103028.26925194595,
  801.7139729777173,
  772.4203217859134,
  265437.0521000748,
  -901.8593674609281,
  1010.0691997279131,
  341606.5718324346,
  -769.2489229755754,
  -1271.6445561895064,
  307021.13976600615,
  194.07656017779735,
  51.86773133345947,
  17628.475946116985,
  -18.026988829563237,
  -354.07463906420674,
  29597.721248987742,
  -699.9419248304513,
  23.04988053020201,
  32033.797191606856,
  148.91013129514192,
  322.65172271922177,
  24152.63582097565,
  1376.1811004858823,
  241.8328225236475,
  8490.84363404895,
  1137.4326826637416,
  -26.550118531836745,
  9867.614776832817,
  515.4735158934628,
  186.7383307114694,
  25086.283614119773,
  -743.8043046552735,
  213.69008703171986,
  32223.820611647574,
  -674.9584150871444,
  -45.079041922715405,
  28982.95993907143,
  96.51897175502077,
  4.214492105044565,
  740.0435325707414,
  164.48946697448937,
  0.9888913678988427,
  899.6401154647717,
  158.3872556652302,
  11.867449167084917,
  932.1224805825719,
  111.68136957270235,
  10.008208702695493,
  827.0359532233663,
  104.03653114328463,
  3.526517340722254,
  618.2033617123195,
  332.64503555771813,
  2.084520541033906,
  636.5610746888188,
  89.07328361062142,
  5.302088684342278,
  839.4851088419427,
  314.3455428889351,
  11.57229417062366,
  934.6562316872521,
  138.38377586694583,
  1.732902825789684,
  891.4429566736012,
  41.131411953314654,
  249.55847617374013,
  -289.47367784892333,
  514.8473889607639,
  119.40218166660253,
  668.8622083009526,
  228.76208662307928,
  478.70505813436966,
  863.9103452656404,
  -193.09176145047428,
  0.0056258139502460836,
  232.89313616871195,
  540.3745900304215,
  78.73524257646142,
  -1021.0921498170063,
  465.3573729217316,
  512.7963494843589,
  -910.8588677880297,
  -261.15481744947783,
  269.7110272306898,
  307.64707115407367,
  586.0859016338069,
  17.179615772937836,
  879.1248603019623,
  599.5657750223456,
  258.84969617402385,
  619.6404061069572,
  115.39595430329699,
  296.32512706489797,
  618306.5266331924,
  13.32404182773459,
  -739.3783500099398,
  1037851.8206719032,
  -292.0275940537927,
  222.80053230647778,
  1123241.0137066247,
  66.54587992133906,
  987.1914713188911,
  846991.0012004101,
  600.5848592670422,
  780.9936904271763,
  298014.7673637314,
  513.3638710573283,
  96.25328019002814,
  346273.2698262661,
  253.65822659980782,
  640.4280316080534,
  879717.1696422328,
  -292.3895880086169,
  709.1915551269599,
  1129901.7036346775,
  -277.91471233155215,
  48.979401477681336,
  1016303.2427953512,
  242.08545444080568,
  -462.24844628457345,
  44342627.050003305,
  -961.4362196247523,
  442.20429200389856,
  74413913.8079103,
  -200.12297056254613,
  -513.0132233423979,
  80534261.11309652,
  90.8179126575984,
  14.757595816616657,
  60733792.69887262,
  747.9870812404832,
  -127.61087844943444,
  21385426.776180703,
  496.3418803859307,
  -600.3872926872153,
  24844398.39778621,
  375.99973650810233,
  -224.663903432231,
  63079470.29241229,
  -276.1444355158421,
  -177.1863899196744,
  81011672.06175444,
  -103.87718684629448,
  -633.0273626036296,
  72869400.08374707,
  412.07797222977837,
  -531.7791752787602,
  683.5908359113922,
  -8.858702854480896,
  -614.9364670955672,
  831.01292219076,
  -387.81149410270666,
  -139.73805160705228,
  861.0174369875075,
  -392.9868217637211,
  714.608607369352,
  763.9472189275477,
  93.90627992912184,
  1231.7832226794908,
  571.0449915400899,
  646.9619311447212,
  756.6728953071533,
  588.0023241924457,
  589.663543478685,
  -299.129300834235,
  775.4467163505325,
  -83.23921684629181,
  -576.7931907416535,
  863.3579061077808,
  -450.89411044304927,
  405.9111696343509,
  823.4410667747828,
  523.8312216740128,
  -177.44392765269072,
  1009.990063869084,
  1023.7770449718929,
  -158.93516167326055,
  1227.8028760295913,
  1102.7656402828525,
  -153.7279195059853,
  1272.1338708644255,
  -1285.6033981649994,
  77.55818639314681,
  1128.7148099470076,
  -1262.2388693855391,
  -0.028998138911568105,
  843.7061136267995,
  1481.0565777175311,
  -117.03291754050895,
  868.7601906987487,
  -1078.194473415382,
  161.46596080001487,
  1145.7050583917776,
  1805.179179447462,
  154.7947351836061,
  1275.5918612763608,
  33.59235681231138,
  -174.49707344152046,
  1216.6156301897693,
  60.563000655089674,
  104.09545416884109,
  292.52760996208224,
  32.071776231931615,
  103.59629586788965,
  355.61363787442434,
  -11.518611954716192,
  75.88086097867254,
  368.45340771987935,
  35.66497088213619,
  73.29744466217959,
  326.9143504419686,
  9.473344538452466,
  74.38858530395105,
  244.36609998337178,
  82.41223107027105,
  73.03589800927114,
  251.62261620847903,
  -45.671194267326484,
  80.29982650960022,
  331.835306546399,
  -65.07333631385995,
  88.6567477034106,
  369.45495982089716,
  107.33192805312822,
  103.25511835446561,
  352.37342947569533,
  755.5843277007592,
  -151.40969317792604,
  568.6326172596266,
  812.0409346432243,
  -139.91976546232945,
  691.2630013418634,
  1075.1862225537584,
  -50.594978382113084,
  716.2217118484672,
  -3.8242074493006726,
  -193.77096001074608,
  635.4756145433355,
  -775.0066471642475,
  22.730802850250555,
  475.01340137118586,
  387.50184863348056,
  -193.95350969172478,
  489.1190504543768,
  974.130255798893,
  -94.78897517379414,
  645.0412625498423,
  -668.9816265793784,
  192.64412094852486,
  718.1685885641299,
  184.43770642089925,
  331.1722854900288,
  684.9644909808253,
  160.2894698390225,
  971.2617505537357,
  1097.389343147019,
  51.29409975848692,
  150.63839787646634,
  1975.1396688300356,
  -13.695036941890365,
  913.0056948481957,
  2153.7863919872284,
  20.68730751512777,
  -339.88593784298075,
  1575.8308246322192,
  128.34069666612052,
  -503.26350489323124,
  427.2919781973942,
  203.08905542007955,
  812.7379709266775,
  528.2558475467571,
  183.7470889135826,
  -614.6384927780147,
  1644.2987717557464,
  80.42891142482529,
  -560.154796950935,
  2167.721532809193,
  -4.2090340773450095,
  775.2812570103049,
  1930.056881541271,
  -344.4616804850706,
  0.4491874923816397,
  572.51445817264,
  -151.03861038033557,
  273.4992413067683,
  578.5708725063572,
  567.3221506501684,
  247.88300343759724,
  579.8035220914871,
  -84.32856878617326,
  106.26131220944734,
  575.8156701021908,
  -103.03702072823205,
  266.92282866980213,
  567.8908343842819,
  179.65828147329094,
  229.85479791180393,
  568.587477846122,
  300.6432482544268,
  263.8957461827315,
  576.2880940298453,
  -111.6745010942895,
  268.4530721521817,
  579.8996735643458,
  -179.40105535077828,
  57.44514013000405,
  578.2598045054117,
  -34.82649694571717,
  1.1783299591345795,
  -50.302187513411965,
  233.82784731407412,
  9.157707893456951,
  22.75965295660974,
  -985.6436413889255,
  79.11275606587598,
  37.62977946741046,
  506.9927074572056,
  23.463357813696216,
  -10.477861424655579,
  -234.12917602441257,
  0.20399265810149814,
  -106.07949154258972,
  -245.25558021993174,
  76.00315373365919,
  -97.67550022546978,
  1130.1845075517665,
  68.47524744759795,
  -4.778753052173421,
  -530.8824698344729,
  8.476021770239917,
  38.78970730323257,
  773.0433174507812,
  10.644550625550785,
  19.007069429770773,
  254.39766636952845,
  174.94662800617078,
  985.4200852711416,
  349.24633924282904,
  373.09875851147933,
  1143.6602001846147,
  -413.8621757330068,
  303.14029275082555,
  1175.8664861570091,
  858.7529711410521,
  479.036379115529,
  1071.6731264769971,
  789.1040008664593,
  107.47084885052939,
  864.6154772519619,
  -471.38814637519397,
  217.90999563521174,
  882.817161512825,
  1198.3318372611884,
  313.6199453032971,
  1084.0164723051926,
  1138.6069654120997,
  12.989595942315077,
  1178.3787020121126,
  -486.5719201824728,
  188.22498426713463,
  1135.5327119542428,
  -43.295256916119584,
  -299.4843736369477,
  122.143107317501,
  -72.71874425054882,
  -8.690251821435112,
  148.48429090195262,
  -61.49834328683666,
  379.87093976718256,
  153.84545796023033,
  2.266334507166807,
  635.3629230874625,
  136.5010796582255,
  84.31058501062792,
  501.2036187142125,
  102.0335645544605,
  113.29058867961777,
  8.025763516331764,
  105.06347834669826,
  52.050921041897794,
  -406.02596078583656,
  138.55579466323329,
  -42.880879650656745,
  -301.59592182060453,
  154.263649890129,
  -72.47480190866958,
  222.07902421757979,
  147.13136178107982,
  -24.582274820644898,
  589.7104847527785,
  -403.7212700905083,
  -40.10142126862394,
  238.8045668072421,
  690.7406511235154,
  865.9680804251395,
  598.9171695286135,
  913.4942407539916,
  140.59027231540352,
  359.135196835873,
  192.84470965699214,
  2.589762991412897,
  129.90467661160835,
  -1239.2618879450597,
  790.6410733767849,
  312.5907344357868,
  -1113.3706097671568,
  404.7405039331991,
  35.74587569258341,
  278.2170060353327,
  24.84234055709618,
  90.60267192686473,
  930.8698891019739,
  542.8399924564005,
  3.5085649727874966,
  634.5271784012467,
  257.4345396993874,
  43.70366773540334,
  59.047771317369595,
  -59.96114240664667,
  239.54507438065812,
  89.7542221116019,
  205.68059852112054,
  197.29968659250034,
  96.00384305011721,
  201.0970479640997,
  211.36270920327823,
  75.78515024994135,
  -60.295946737521206,
  210.17718775201308,
  35.60567034388484,
  261.52289639091657,
  33.828075122839834,
  39.13770217054247,
  148.6087093575713,
  354.24150878197486,
  78.18037311436433,
  -13.38064609735656,
  1.4545132340908538,
  96.49133784612013,
  297.4971241951075,
  29.864922560782475,
  88.1770852549769,
  -57.62480198769819,
  108.81093476723436,
  274.0521819644771,
  -17.18805418733237,
  181.2395833463126,
  333.15382916656597,
  88.41539022012934,
  234.00974003162457,
  345.18266617967646,
  223.2153230364061,
  227.58607740121434,
  306.2671283087917,
  318.16468697275803,
  165.96774310284928,
  228.93245156336937,
  346.14807269944504,
  94.3318709864247,
  235.7306615005751,
  338.8743964520748,
  50.04969314984168,
  310.87728718557383,
  336.2302697013585,
  43.57687760272296,
  346.1209623585247,
  345.4102068258521,
  76.53169833785353,
  330.1182655088093,
  1463.2973913742628,
  81.72584016146895,
  -406.8371213219477,
  426.5518838121752,
  47.45438970852375,
  154.5337431731582,
  301.8097603621712,
  14.03568880535731,
  268.7884036199471,
  1301.3714411442297,
  94.81333209829153,
  -100.84679558476282,
  954.3922752330384,
  87.65675677323779,
  -835.4021996259021,
  1150.1114368928186,
  16.217702742010218,
  -770.8301078123,
  974.5814981883316,
  88.74708699557762,
  -57.05767977095692,
  1290.1530979734462,
  95.12909763747669,
  277.7007125319376,
  345.19959508959585,
  11.551557198199404,
  125.70075669212297,
  16.740042717694628,
  -503.869757025976,
  200.15046997405628,
  9.581457692379866,
  -104.57801578653203,
  243.31459433513243,
  15.194542882017094,
  -481.52980419994617,
  252.0997000188648,
  14.293457928314032,
  887.3125670359632,
  223.6782397760838,
  25.773839338956364,
  467.4527401148805,
  167.19785788335966,
  24.224827718160725,
  682.756572300975,
  172.16284266895934,
  23.26195212673698,
  -331.84758674847933,
  227.04520974227302,
  24.878067792040433,
  -181.62208167870625,
  252.7849725090349,
  14.179812328323708,
  883.6207154200343,
  241.09760964126525,
  -24.59364020272136,
  189.47727912617412,
  564.526966593492,
  -37.129665828519734,
  183.5043865993522,
  686.2719327401171,
  8.551371582369406,
  197.6527964860804,
  711.0504359506443,
  -8.624063096020507,
  194.34579281144147,
  630.8873429581852,
  -11.98714509293174,
  139.50798642332038,
  471.58370172229644,
  82.67388197552143,
  135.38064675170492,
  485.5875049637315,
  -47.113398927629405,
  158.0786407586076,
  640.3839249141033,
  21.148193976209125,
  199.16212139718874,
  712.9832557947138,
  -19.285037262418726,
  141.65515853203502,
  680.018898988184,
  248.8263201575065,
  101.38127610312081,
  -815.8073029196588,
  157.2244632765524,
  6.692027489352419,
  360.44146983895075,
  248.32349531737995,
  137.86695090340066,
  599.840969585626,
  239.87177147994925,
  114.02521481163478,
  -174.66119454782225,
  149.8715683124929,
  20.922738099103675,
  -1713.7861245594459,
  303.2534005340161,
  65.00059180405069,
  -1578.487254322357,
  221.81841158786634,
  132.25726703570496,
  -82.90920492061072,
  166.00174743264682,
  90.0892109463831,
  618.5150638131607,
  325.9341572723122,
  0.3790173743155236,
  300.02728180696914,
  66.17924395960748,
  328.3417724822377,
  827.2886092260993,
  57.356251651570155,
  44.83452998956909,
  1005.7003232518807,
  25.207445947526733,
  48.1258610895479,
  1042.012093411308,
  15.445066903065747,
  264.04666944976975,
  924.5367244078132,
  16.825023897936184,
  328.46042838130626,
  691.0844792512199,
  16.188918848956156,
  182.94873748123428,
  711.6064163650319,
  40.11815336211842,
  -6.632703519125698,
  938.4535336013951,
  67.4187387296953,
  213.7965203653351,
  1044.8445530373442,
  56.202843354980764,
  454.20721170660374,
  996.5367865172296,
  13.570241034342757,
  1520.7960580289207,
  2132.112998918213,
  -846.1033003642342,
  118.33711967534174,
  3915.3629874281332,
  -1553.0372929343882,
  1421.2354913317777,
  4278.304199406043,
  92.52354465468275,
  -719.9771165272941,
  3104.1214862944553,
  630.2609088468696,
  -999.1920919341399,
  770.733705305189,
  2110.245098013722,
  1249.876285938307,
  975.8533316830756,
  507.8898426782458,
  -1189.5337959064402,
  3243.2219370135363,
  6.512607052025885,
  -1096.4202548916319,
  4306.615028788323,
  -1642.1185356931207,
  1185.8621397871082,
  3823.772158507476,
  -293.28530669533677,
  118.01152055020849,
  692.8285499101949,
  -395.50442130920294,
  -0.5260529656214814,
  842.2428265446893,
  782.3611219667748,
  -52.62534954001022,
  872.652807757609,
  -408.714925087801,
  16.934560136205103,
  774.2708299941363,
  88.2331448126856,
  -110.75598677821017,
  578.761815750091,
  859.2302619460058,
  -20.440005147574716,
  595.9483015463977,
  690.0494572884095,
  142.16228434944094,
  785.925726030945,
  867.7160435571639,
  -15.219057707523724,
  875.0249048389669,
  -359.44418530789414,
  -25.289738475198263,
  834.5686487582259,
  59.33267654916157,
  294.72447157125475,
  342.82183062222975,
  57.735550841165065,
  85.80719885991216,
  416.7542282458166,
  5.172477696267279,
  244.60684668081922,
  431.80153746820946,
  5.439511475089901,
  134.840187903941,
  383.1206773600615,
  42.464313122304326,
  287.0172208001322,
  286.3799206822673,
  43.089091173250964,
  287.39081184502265,
  294.8840484688842,
  72.55134446201843,
  297.6861871437158,
  388.887692584201,
  19.505330110014228,
  112.92188683711433,
  432.97528624624437,
  67.77999641307969,
  296.9063373509922,
  412.95693138555174,
  12.868884833007426,
  124.64667085432546,
  124.19593265056825,
  8.463837942989283,
  131.8552611794969,
  150.97982520282577,
  9.51959786535436,
  129.58363425722985,
  156.43109590914176,
  14.975426164243565,
  122.58224156648349,
  138.79521545080073,
  23.3562023001988,
  118.92887433449637,
  103.74841437890522,
  29.039776730528146,
  119.67290635282419,
  106.82925109202093,
  27.096603557431013,
  119.13618386778992,
  140.88446348110273,
  13.924183833042703,
  123.53630997773423,
  156.85631627483704,
  9.19315855238029,
  159.76736921468628,
  149.60415777740047,
  -125.25628936499089,
  46.91409025537813,
  44.29856673754219,
  742.1914487155732,
  42.29983646657958,
  99.07455226811265,
  -339.81568454615865,
  48.375594510785795,
  110.22299623494075,
  -348.7538355656237,
  46.94792481270783,
  74.15569455650953,
  742.1760594065514,
  42.14561482409035,
  2.481158651715437,
  -107.18664138716065,
  45.46368380569936,
  8.781806210333727,
  -362.08795300451857,
  11.329114503710514,
  78.42843496025455,
  738.2304720865187,
  36.66019932313161,
  111.09261832415666,
  197.71432072090798,
  15.304886752679597,
  96.26116213660165,
  472.59655075839225,
  690.9834511009492,
  529.6289359313489,
  910.935027084412,
  664.6995986212104,
  643.8478496252735,
  1350.19330621649,
  595.7791221271692,
  667.09459081915,
  1730.953664361297,
  479.38111824635854,
  591.8870344844064,
  1980.1117783127988,
  318.9041701341861,
  442.4312547067363,
  2024.2452285568218,
  129.07662544115726,
  455.56936829324627,
  1810.4109819590287,
  -63.0839697085772,
  600.7965550103224,
  1330.3412266507673,
  -221.0665810863324,
  668.9079272546769,
  640.0052071965356,
  -306.2849103409044,
  637.9813670507326,
  46.45754979225959,
  25.622339578817233,
  -37.44451529720764,
  39.87969055334456,
  77.77886236083854,
  37.35064321398474,
  36.85830171500251,
  5.256945863781333,
  52.573548389952514,
  48.22212150987632,
  5.005522237270924,
  3.324602524730289,
  38.7794005876886,
  57.699549230032474,
  -94.54507927630831,
  36.98614667119337,
  6.873439426044541,
  -85.94171179135446,
  47.05660093164844,
  69.07806812150588,
  9.158916461390136,
  37.56520859562178,
  25.459005364498072,
  53.76099433688913,
  38.0020148990158,
  38.23232519992722,
  33.509033450108404,
  -37.40970266079046,
  330.3703672116128,
  5233.662293441986,
  -888.9401703545348,
  45.93446191658977,
  8734.458440779883,
  -1599.190377907176,
  310.17826094329513,
  9446.968299066277,
  88.75379445749545,
  -124.08596590137367,
  7141.865624277199,
  607.6154612261553,
  -180.71419374454578,
  2561.063713963824,
  2113.6566961016015,
  275.42450852759384,
  2963.7453359427595,
  465.32709729349057,
  -219.3178301178932,
  7414.941370867966,
  -17.16600653202488,
  -200.4332598752419,
  9502.54684557856,
  -1694.0055448081632,
  262.44165311966356,
  8554.651446200929,
  1353.724392923316,
  59.85464935451452,
  -15.435446416033574,
  1082.1156509996085,
  87.4713608608163,
  231.6867604144899,
  -592.9313469854965,
  24.086885563880273,
  281.9830362208179,
  1137.6301027032605,
  215.21942458751164,
  119.26517548562741,
  947.9287280991563,
  142.06279087663836,
  -204.09494875095152,
  -198.9567080524672,
  62.432918566884936,
  -175.66953724871345,
  655.179401993907,
  287.6863053292226,
  138.54167097100975,
  887.5412287940151,
  165.0437342153692,
  285.90634180289015,
  427.37395780233436,
  254.6596724393506,
  218.99413295667458,
  -322.5785781841984,
  109.17772708460762,
  -0.44574353881170503,
  677.9932483611143,
  173.4040091628558,
  241.83030476411892,
  704.438260236992,
  0.34205223050491895,
  291.14025186680203,
  -334.63961724447216,
  88.07781216910541,
  131.61334899212596,
  693.1654678940747,
  7.627137237277964,
  -185.4055627583275,
  657.43118404998,
  226.521473367058,
  -157.53758416395584,
  -318.6098524075126,
  116.10755965763408,
  150.5118252206527,
  514.6542128087684,
  265.86974844960713,
  294.98661996500044,
  380.1466121364281,
  543.9458168342587,
  229.3865844586844,
  152.53555155280895,
  1419.537028323561,
  31831.52678429746,
  -33.336389537817155,
  342.42277712681476,
  53465.975386491446,
  -156.31521581141686,
  1343.0726825134732,
  57869.19032929106,
  28.520864515916273,
  -301.4179700789382,
  43623.96631691135,
  185.55192574170513,
  -515.8602050233317,
  15315.227585903669,
  386.88458487360197,
  1211.4656620471656,
  17803.7457649402,
  220.77311883483043,
  -662.0461334229867,
  45311.53764511227,
  70.51371997663985,
  -590.5332218762348,
  58212.65825981279,
  -156.24131208160384,
  1162.3016207964483,
  52354.79238159371,
  293.69640844351596,
  582.752914605605,
  1946.6554894899389,
  30.849210869815067,
  -3490.234430210348,
  3379.2800101800362,
  -519.530284486126,
  293.6115236453711,
  3670.859139970478,
  126.79330856962815,
  3299.640459536041,
  2727.5461118404737,
  1110.7350049194442,
  2488.7510778830333,
  852.9527722284706,
  1017.7047634601862,
  -204.04573810995464,
  1017.7414492603991,
  548.0296139365937,
  1935.965302650343,
  2839.296409231877,
  -454.6558747032866,
  2206.3833974784875,
  3693.603448752455,
  -493.312786492638,
  -389.95407384284476,
  3305.6979166835945,
  -359.99130065145744,
  249.3520766713318,
  1129.076970412665,
  1325.6376755948484,
  125.574789314412,
  1351.5121415015342,
  1317.8128680235347,
  134.6178754574481,
  1396.7839155666873,
  -393.845874144399,
  230.02058216501797,
  1250.3212578555215,
  1379.1194489662068,
  9.936837919178515,
  959.2641914737508,
  1164.2194552078554,
  262.58992755681726,
  984.8499587419591,
  -671.8272720105961,
  1.940712961307014,
  1267.6720683159729,
  1222.2905648623494,
  52.345554149461464,
  1400.315290426012,
  1015.5696958214245,
  335.276951773257,
  1340.0874832469945,
  -298.66001210601723,
  -315.739985968381,
  67.74323599121905,
  -414.199315562509,
  111.10493736403309,
  82.35263192881405,
  -297.3203315278449,
  637.1382947461423,
  85.32605231407733,
  92.41950635441215,
  930.7324463129445,
  75.70648115498221,
  531.8406739608796,
  703.0272252610771,
  56.59004420667557,
  688.7180940347904,
  85.08216325967427,
  58.270500595647775,
  474.3764901231554,
  -454.9189397489678,
  76.84607098969241,
  105.1204944636439,
  -612.995290210742,
  85.55799069536566,
  -181.15787756585058,
  -472.63298759480676,
  81.60226787858208,
  107.88824876380477,
  106.78177523356052,
  -433.14334302393115,
  111.90383049430928,
  85.26279240772064,
  501.46190821084247,
  108.94683867327866,
  507.97032529915396,
  691.6801977326097,
  107.68519361042294,
  8.708706727123797,
  76.28844859250937,
  112.30712780435417,
  88.9497473153597,
  -1146.6452327932916,
  108.4318368370502,
  369.62941426927625,
  -1039.1415842979527,
  107.99526923577166,
  185.42219902216343,
  149.19130154573293,
  111.70850379032751,
  448.66547268710383,
  706.5179658402656,
  107.9218198789852,
  147.7894156615892,
  453.45895280596346,
  -265.7742877254068,
  511.92713935258536,
  -739.1076835735086,
  -221.62874881502648,
  487.01752082689757,
  931.7329935502266,
  596.845436948038,
  72.66176492252708,
  1271.7957689797115,
  -305.3880991464434,
  412.7209880573084,
  171.62907777917718,
  -130.68832027953346,
  379.05432380160266,
  -2014.6707932995364,
  610.4214563984204,
  441.7223162656119,
  -1822.481129687104,
  -242.40560320523753,
  143.02374133540945,
  301.9611640066893,
  -58.49600532745427,
  280.85619800418596,
  1298.3219911245656,
  404.4553099848819,
  435.53124352199177,
  845.9157028741223,
  821.570075661682,
  116.10560246250279,
  179.62221664338384,
  838.3326652905603,
  130.92905383585813,
  218.3592513264009,
  815.2910383780611,
  153.7762029734755,
  226.2433205297505,
  186.63581546406465,
  63.282308352493914,
  200.73688185033163,
  -125.03485892265945,
  83.40907989590107,
  150.0493596389125,
  836.3847286721134,
  139.93902252319396,
  154.50511521573276,
  586.7889418758336,
  74.26880636335248,
  203.75852156357834,
  326.41518664215073,
  204.30029278827783,
  226.8583086619544,
  -255.27077072478403,
  109.38012314940609,
  216.36964967805855,
  376.1907344999312,
  693.4343566996754,
  12585.960172541205,
  -192.37393987761072,
  -136.29817043811903,
  21356.308363470544,
  -830.2474306756089,
  634.5316406559039,
  23141.319339157682,
  79.66347565673374,
  -632.2674788561947,
  17366.47492580445,
  1601.3885700243088,
  1081.716602346479,
  5890.448885935508,
  1540.3075805644276,
  533.1509138116928,
  6899.264562772054,
  761.961583554772,
  969.1053174542192,
  18050.596274006977,
  -697.4247420986583,
  1024.1937992515227,
  23280.557153741414,
  -831.7403590041454,
  495.27841872035344,
  20905.847987244088,
  -9.418205858927646,
  31.988225798759302,
  73.28124675286705,
  19.307564059098063,
  8.40175601367281,
  81.14451140749208,
  -9.000937518686033,
  225.37387890025423,
  82.74490553183881,
  11.21750089782534,
  43.360372612981266,
  77.56733116729497,
  31.499977154086004,
  34.357803778776955,
  67.27822656501854,
  -12.919792941153162,
  243.2287591756986,
  68.18270429862832,
  29.634794804651122,
  214.47522728373082,
  78.18069646359632,
  37.71069899327802,
  180.6254909973253,
  82.86974251232904,
  -14.28928035536645,
  245.72939357143127,
  80.74064042340116,
  356.3825917448829,
  -99.10886826965398,
  560760.2837059501,
  -1800.9237760432225,
  439.0233754023047,
  941035.350165112,
  -517.528496444582,
  -129.31294883811893,
  1018431.954340052,
  167.6387335154632,
  184.70068950419056,
  768039.4619016738,
  1443.7176231307396,
  99.99414460509396,
  270448.4347276657,
  1032.2161071967034,
  -181.29886472384152,
  314189.8507128172,
  643.9585197605636,
  42.24943349064175,
  797702.3995057828,
  -638.9046246085339,
  70.49765452961552,
  1024469.1911796586,
  -390.29655592189545,
  -200.71908793082378,
  921503.7596538138,
  -213.1957557822738,
  8.785138777791019,
  -3.0797544667586996,
  289.59938658639487,
  77.13170017412637,
  15.593650744905174,
  11.38824606082359,
  88.25609860270107,
  19.394210600755244,
  -271.96892580058426,
  7.500440631590685,
  7.0986885282807854,
  462.0580014862065,
  12.533020384820354,
  -17.335516339858124,
  -67.80021723188034,
  90.53529963922315,
  -15.187594329540355,
  -231.38478401061093,
  48.17826903461766,
  8.555286929031611,
  454.24095579163793,
  15.93208708497156,
  19.690669085174104,
  -165.38927138943444,
  75.51375400827135,
  14.634552091812365,
  255.94640118940205,
  -128.7290705010429,
  8093515.871010287,
  28.974326087638644,
  300.68465450536354,
  13582344.248447664,
  -41.77983567133509,
  -152.83103967277557,
  14699474.22824959,
  36.60275665194497,
  97.74262085217345,
  11085349.771471307,
  237.95293942369545,
  30.14928593259356,
  3903201.9232262634,
  349.2642592081968,
  -194.31427367494808,
  4534558.397801692,
  301.816412077343,
  -15.929297520940537,
  11513499.781924522,
  107.06918844534921,
  6.611953191666387,
  14786614.72156432,
  -24.47549162636369,
  -209.8110414041306,
  13300428.451934583,
  1.231596449769497,
  29.321724296476802,
  261.7352299660736,
  1.3406362742766484,
  -35.076324986695596,
  318.18062336132704,
  1.7937423499315657,
  157.82230691299588,
  329.66883848620785,
  1.5977660767226167,
  -51.230351521994805,
  292.5023135533404,
  1.2910008796315326,
  -13.855914483733983,
  218.64335261670107,
  1.6457759757170225,
  -39.47272196740428,
  225.13602502863915,
  1.376197581670501,
  267.5397582563503,
  296.905274278357,
  1.5377913511855341,
  -58.926882857963164,
  330.5649640502764,
  1.772962292377347,
  187.78087401974489,
  315.2814895308853,
  1434.5421965333999,
  244.67707250814118,
  398.30333087797726,
  -933.1382634823947,
  3.599795865574805,
  650.4913779399383,
  1500.9000969518513,
  18.907765829549703,
  701.8186938164365,
  1244.6146196568284,
  285.72091727364534,
  535.7652255862423,
  -593.9212308897304,
  182.01158068456456,
  205.77643471702967,
  929.9513981313547,
  177.0719541736073,
  234.78454817483077,
  1137.1560940513582,
  296.4300374412487,
  555.4368763577618,
  180.96622886041786,
  298.77079189172684,
  705.8224245432693,
  108.87175015533387,
  299.9961752212905,
  637.5385600943665,
  22.05112156066636,
  323.6386148415262,
  319.21433929195643,
  72.11606186437754,
  465.19648131326744,
  388.0555837857753,
  41.42769177021145,
  428.29712538187243,
  402.066701055728,
  31.27076313226212,
  106.02119352011874,
  356.7381157454465,
  20.339918783539567,
  196.0022672332605,
  266.6591477011531,
  108.09628918075462,
  102.96056413449074,
  274.57766189767364,
  102.00457100924444,
  417.56113334492295,
  362.10800117870207,
  111.4426549796845,
  375.3893368934301,
  403.1596228221018,
  107.2788669213067,
  99.17290022554084,
  384.519777427864,
  1186.5996359135468,
  911.4403950354022,
  1090.0502518587066,
  408.8710972779093,
  -723.5641222994476,
  1325.1287137636443,
  709.6063015741115,
  -676.0310656562938,
  1372.9737508719716,
  1521.331748082784,
  214.024917425795,
  1218.1861058574411,
  -383.7189369993258,
  -528.8650212135249,
  910.5852567801434,
  1392.9333281770237,
  676.6402380326147,
  937.6253277663325,
  -444.5451379763738,
  -488.6636492201246,
  1236.5231422886868,
  1507.069237130858,
  390.75716257796245,
  1376.7058502799746,
  236.20900986729276,
  -722.146607606864,
  1313.0546740462753,
  234.00124276126508,
  -417.21430278404557,
  119004353.43089798,
  -295.1399179321036,
  677.4000139369526,
  199706505.79422024,
  -109.95058687945942,
  -478.6523961196883,
  216131649.31122372,
  53.207699126759906,
  160.08246546328246,
  162993237.5201259,
  404.5189542048796,
  -12.219041939130719,
  57394237.13462128,
  402.1374948696123,
  -584.3969012399839,
  66677060.88188964,
  312.0959217716512,
  -129.67750729607516,
  169288320.00439286,
  -35.243991184745795,
  -72.21782608431528,
  217412874.5354279,
  -73.69999774522967,
  -623.8995599382055,
  195561502.52588195,
  1.9047743917036943,
  301.238171505565,
  486.4734700659954,
  3.523328619302762,
  309.7184473738385,
  851.7952879136642,
  3.0159485917037316,
  49.23179038574156,
  926.1484880740067,
  2.1732157767781883,
  570.2276151372091,
  685.6019769268697,
  3.8975443601120707,
  540.1690701274789,
  207.57731892205925,
  2.7499875235466473,
  0.5086024008181198,
  249.59872661443742,
  2.8595659327595917,
  248.60358562723323,
  714.0985028472691,
  4.092940616773197,
  503.52555613847073,
  931.948327536421,
  2.600862524686119,
  9.080904796268612,
  833.0317223255166,
  12.16474372302104,
  156.35052803694447,
  -21.967458243517672,
  5.237226792897458,
  239.58931147346985,
  85.61406873166533,
  13.779458670653943,
  30.47550898755776,
  107.50991622270257,
  13.617342957856462,
  47.17982142742002,
  36.67275371697847,
  6.4316943437974885,
  208.31875915248912,
  -104.09798629228894,
  12.62537768403024,
  127.36474320989458,
  -91.7233429385821,
  13.97961154080054,
  2.1146647018089624,
  45.064532204412714,
  1.8821058593851454,
  223.28949222242233,
  109.21787768324042,
  10.087038200161762,
  238.6496628806736,
  80.08849391282533,
  354.06266060919415,
  365.6673505087844,
  42059.52437955833,
  56.09458933862993,
  -267.2701452865469,
  72485.86543897465,
  -173.0581619879652,
  320.7351146750352,
  78678.4762177838,
  51.41865436708204,
  -645.6060087055143,
  58644.221948668885,
  506.347446253317,
  661.8572480764163,
  18831.266442874366,
  639.0550925374257,
  243.3997550597685,
  22331.0784436408,
  464.28119164531563,
  575.9549815907678,
  61017.59516182887,
  27.926054389303232,
  617.9776389840285,
  79161.52399908786,
  -156.57998868038953,
  214.50981593044142,
  70923.11550676622,
  216.6749590828607,
  946.384485716475,
  44154458.73283956,
  40.39625492109285,
  252.7297436959442,
  74097549.06161268,
  -71.32990497888133,
  897.1419322847158,
  80191804.81056122,
  31.05357864727651,
  -161.89961146216945,
  60475747.46149447,
  194.5635436420011,
  -299.99904983965894,
  21295126.938065033,
  345.76587202559074,
  812.3878463293781,
  24739352.67220869,
  265.1402957497311,
  -394.1418599811369,
  62811425.23381558,
  108.71607115660515,
  -348.08799879139735,
  80667180.51612027,
  -61.5656526795554,
  780.7265157764122,
  72559619.72959004,
  115.17353211419629,
  1210.9202581239656,
  4737.446055168095,
  37.34816384609091,
  -1834.050878766789,
  8320.765449982056,
  -4.8044783168871135,
  994.7577426486976,
  9050.07109553793,
  13.638243510270733,
  3242.0692542092947,
  6690.63090708528,
  79.46534734849328,
  2635.8471981827056,
  2001.8470881506082,
  139.36666306920523,
  622.7084653442187,
  2414.02100666612,
  129.575807237121,
  2222.583765726993,
  6970.143788678256,
  67.41152386989832,
  2424.74871836126,
  9106.959778931985,
  1.894230421180879,
  483.7231289093904,
  8136.719917514273,
  1062.1489375453439,
  305.56843989632773,
  526.549697931748,
  1081.3821618157724,
  255.16312704802016,
  640.1045481739638,
  356.30947477866835,
  675.496746023375,
  663.2161338957828,
  985.4977574810262,
  -141.86307452780096,
  588.4458307955435,
  302.62616739708164,
  674.6582557356221,
  439.85897997006924,
  -404.82172765745247,
  101.02279801737996,
  452.9207091752623,
  467.0164132452818,
  668.5896422448752,
  597.3035517835182,
  84.79619088472475,
  -361.3132520515503,
  665.0189276776149,
  -406.6484595605019,
  127.41009558654086,
  634.2721730562516,
  318.23758559387215,
  -658.935800898217,
  847641.7290022159,
  -335.5643672618554,
  5075.581897480798,
  1423697.3436996536,
  -189.43073322574207,
  -980.8006150212968,
  1540940.761230625,
  72.41768264288777,
  2365.4340471486125,
  1161636.373776909,
  559.1010364865133,
  1462.7726909401924,
  407865.9315135446,
  610.5888146810646,
  -1534.7799727325757,
  474127.14739520376,
  435.82069247302263,
  847.425679554884,
  1206570.957351827,
  -49.70606405653547,
  1148.4481984627591,
  1550086.2048462061,
  -159.83907536623423,
  -1741.7283855001017,
  1394110.122841952,
  26.023026698827138,
  -690.168446246288,
  204.25612064019077,
  124.28492825555996,
  34.7375148771946,
  248.30566293687875,
  -7.267434762519251,
  -513.9676791234351,
  257.2709759166877,
  25.79307970025648,
  -689.6062316435097,
  228.26651136123425,
  25.507459724340404,
  -688.8968967914134,
  170.62755753224909,
  -39.748795970460236,
  424.4904434151621,
  175.69438815960467,
  17.692503846698674,
  -664.6427012963735,
  231.70254737801196,
  33.89341421545945,
  1248.7368983743695,
  257.970305278451,
  -40.28991841426958,
  376.3583935347824,
  246.0432016339066,
  304.8906972868771,
  129.24473715754425,
  -108.071445526139,
  304.77190946609585,
  9.793256281121039,
  294.09992656648,
  302.0635507762721,
  85.97728627153563,
  375.9530409086154,
  304.9415537819178,
  40.825889011577125,
  111.14290443744714,
  304.9952464281268,
  95.10630293495564,
  -415.09950215230293,
  302.07700942532097,
  90.30780437323895,
  -368.83944769271983,
  304.43975455977,
  1.3224637816784792,
  142.51383923898857,
  304.57062598186434,
  135.4671973015491,
  382.3379029140068,
  302.1538625395167,
  108.67627330744617,
  273.4437036165498,
  613.2804125772391,
  -1596.2033429613725,
  -1441.9170865402602,
  -464.32750934783496,
  1340.083348324094,
  -1292.5497744679467,
  -169.11221890982586,
  -1761.0101183192928,
  -1262.149351856024,
  116.71139396096481,
  -47.61331300033669,
  -1360.5004057572244,
  837.1221416508695,
  -509.8095544944863,
  -1555.9479667354692,
  900.3486741153065,
  -2044.6681870273746,
  -1538.7668830720713,
  765.9715115938959,
  -824.8901480313614,
  -1348.8491731393467,
  62.236012001337144,
  -670.7554042679269,
  -1259.7780003828057,
  -79.50020264927184,
  -2150.6334838759035,
  -1300.2215400726027,
  571.7291606161176,
  -285.2134165150759,
  746868.4849921551,
  142.12694666967715,
  666.9979075655208,
  1253281.6010911807,
  -71.42452950638102,
  -338.6587691935981,
  1356350.8237479953,
  76.66337982754084,
  216.9803805905032,
  1022902.6081597185,
  482.5296864997297,
  67.09430291136962,
  360259.5772599645,
  753.403189350769,
  -430.6465256999013,
  418510.11410919856,
  663.8970091117276,
  -35.083495344597736,
  1062404.8053577065,
  273.6736191167231,
  14.901013620885237,
  1364390.6249083518,
  -36.36875877250128,
  -465.0101169385239,
  1227271.340399375,
  -379.3434472321694,
  72.86110801175415,
  459.9977000976777,
  -347.3704944839684,
  33.58864874951426,
  775.5413940328104,
  199.592818875779,
  219.51174064221817,
  839.7633547487612,
  -290.52848523060317,
  6.264782126625661,
  631.99329837007,
  -391.23137998267487,
  112.62537451160578,
  219.10345985018057,
  617.0268899298442,
  43.303599645754346,
  255.3991026500754,
  -83.86081407578632,
  28.911678168581318,
  656.606936576016,
  -381.265519628423,
  174.29418840371122,
  844.7729180400621,
  822.5932460121173,
  30.02198920224511,
  759.3345196885384,
  252.42413840362474,
  43.923522880964484,
  -121.37023560581395,
  -143.8892488692603,
  51.011059549362386,
  179.09859750098622,
  56.74358102782996,
  33.69773438161641,
  240.25240271732306,
  487.6507747516732,
  14.628468371190264,
  42.40840331395346,
  -233.7225959293179,
  41.14963033615181,
  -350.7559360983556,
  426.9087699609664,
  56.54057287034601,
  -316.1942901248901,
  650.0268013141311,
  0.46225800417740004,
  65.84614360919727,
  -272.90985393398006,
  35.15514325748648,
  245.02263791911173,
  645.208969229603,
  25.82243717418773,
  163.66599429538053,
  287.2389190687522,
  -4.192282477578889,
  964.8279065416046,
  435.97177076993705,
  -13.985233985060422,
  1172.901121410382,
  368.7787135980902,
  -17.583852738814425,
  1215.2498359883741,
  279.0304503902069,
  28.407013263860538,
  1078.2438225103529,
  270.9484901697814,
  22.718153350712402,
  805.9794174890158,
  456.06652372527236,
  38.18746217727532,
  829.9131903016502,
  496.1269833028224,
  16.42501936228915,
  1094.4743443986495,
  412.1286628258067,
  44.63039474389343,
  1218.5532008127836,
  276.32492865766926,
  26.830971966858783,
  1162.2141182707146,
  406.19783675098745,
  509.8841177894974,
  -2099.4441526290925,
  -79.20894010257484,
  486.4960920173321,
  858.1085366321051,
  -480.6763064289436,
  457.87176657744317,
  1460.053168313236,
  445.5772356864044,
  514.9036737069678,
  -487.3503158998615,
  -537.6196511178294,
  414.2182484864094,
  -4357.316586035985,
  21.65118127226944,
  448.51036891137176,
  -4017.121937768477,
  390.1162862743816,
  507.1814865247054,
  -256.64967675648273,
  -682.7901019099644,
  100.91671221489139,
  1507.0071961356289,
  648.3938564811843,
  88.54867046607279,
  706.2034733311901,
  139.63427433473697,
  201.2027347686534,
  -838.5358431398927,
  -211.2097262450095,
  -233.19468203206787,
  -724.3895728923088,
  -826.9803753426884,
  170.36486008604322,
  -701.1576166700444,
  155.83210838920235,
  490.967674195232,
  -776.3173408559228,
  1482.3637263874245,
  404.48367047016933,
  -925.6780664734061,
  1256.669582221436,
  117.28808604848506,
  -912.5483087521245,
  501.6306607682688,
  345.52726022968756,
  -767.4134868020061,
  -868.6569880373652,
  374.3682341647141,
  -699.3454335199392,
  -831.5260882853479,
  97.46035422239038,
  -730.252324372775,
  120.60755633970882,
  130.8586807037292,
  151.2660566657698,
  -315.8447529660231,
  321.6230080861652,
  257.14330236770866,
  -139.84520644667387,
  120.15153356359136,
  278.6922809873886,
  40.975379721712066,
  231.46729509190155,
  208.97730416635085,
  344.03097859167565,
  201.43938419716488,
  70.43662114515587,
  318.3423495690329,
  101.72286961728986,
  82.6152283063697,
  195.31066491529504,
  180.96926536452224,
  217.23614207069926,
  -110.7380974591544,
  190.9830732149494,
  280.3731853237671,
  -124.03169313822264,
  94.838528711757,
  251.70526240687298,
  303.90398801536895,
  4428.949703408754,
  3632.3142862891305,
  -182.3223565119153,
  389.4569255780413,
  7472.69380749311,
  -532.6470424791303,
  4142.1860919179435,
  8254.318373236472,
  69.09757470600914,
  -2025.1337694398435,
  5725.61669111649,
  448.8357372599867,
  -2829.354731475502,
  700.46895138391,
  1068.6185097716548,
  3648.6213580981084,
  1142.2113978240072,
  509.3646794809344,
  -3377.594624629625,
  6025.181264661324,
  149.24167825206422,
  -3109.4003366106954,
  8315.288136359171,
  -544.3526652185334,
  3464.2418557931546,
  7275.445218689863,
  408.64801766279,
  35.37014811875423,
  89517.57366064146,
  -805.1845647289774,
  337.684620740723,
  150248.6527142989,
  -233.91676541633865,
  18.401957129527347,
  162609.1246495203,
  108.99999281761913,
  194.81002148151234,
  122620.68576944839,
  855.2033145019506,
  147.2231787492081,
  43153.89272126264,
  743.2933627341458,
  -10.802936146376624,
  50139.52924181647,
  569.7823163895174,
  114.78308229976497,
  127357.94668264138,
  -169.40217596191007,
  130.6525012879942,
  163573.28964510036,
  -145.7356484370885,
  -21.71292083147776,
  147129.39859535263,
  -348.16921821393873,
  62.982673672703584,
  590.1872832568326,
  -796.0480411558123,
  204.46299730518962,
  717.4661115010315,
  382.52824875127413,
  30.488063833872474,
  743.3709103120373,
  1115.6515489823532,
  349.3123189921332,
  659.5640403653754,
  -803.8133875295607,
  274.5364287493442,
  493.01932452785536,
  -813.308706522904,
  250.66495677607574,
  507.65966428026474,
  -470.2442718644678,
  406.2810742357818,
  669.4922851374718,
  -719.6168054283141,
  153.86717301997749,
  745.3915856035644,
  1142.5901133252173,
  338.28726295783224,
  710.9288489421924,
  182.61245675240662,
  65.10973629259871,
  -95.32461326658765,
  156.75990742772257,
  158.19114369340988,
  476.95873310669685,
  248.2088809376764,
  162.23822798280293,
  593.4343886041362,
  166.89840762213748,
  27.002964456690563,
  216.61385494768868,
  205.28546958670708,
  127.16593142534472,
  -532.2205632747911,
  265.57558877610916,
  80.06743153738859,
  -466.39325529961326,
  158.69977179923688,
  11.639134891112576,
  261.25418688794866,
  247.81737377047327,
  13.80227591962013,
  602.5199437881475,
  261.0255762877359,
  1.2147954795115794,
  447.5652625279499,
  105.96752226906654,
  215.75075046883697,
  100.58844132029495,
  145.19095792470853,
  226.79746631113628,
  122.2811807427845,
  97.62075672010842,
  212.21839197122654,
  126.69625949666028,
  64.56520565039293,
  191.2771365201569,
  112.41265383618571,
  159.78862855989297,
  229.04577663492512,
  84.027641397791,
  336.4940044749005,
  170.09861606879204,
  86.52286452081033,
  342.267809267566,
  137.86585750920537,
  114.10477207560388,
  231.02313119805632,
  228.10746859694768,
  127.04065285069446,
  65.17269360000878,
  191.81602199295406,
  121.16700381971279,
  295.62144256605404,
  -182.51673751469698,
  1937594.0519108064,
  -1091.1781726966926,
  231.86855816620118,
  3251594.769065457,
  -289.86221883974963,
  -205.7751967583376,
  3519030.639468828,
  110.61567817265141,
  36.028998962063085,
  2653825.5717326747,
  920.5713839842858,
  -29.19873467940365,
  934451.8230291639,
  679.271631107966,
  -245.80661910640907,
  1085595.71081814,
  471.83782617143413,
  -73.66468049579485,
  2756322.7500190106,
  -336.9191494186166,
  -51.91231838528569,
  3539891.6799013265,
  -195.79451468987668,
  -260.7610378955583,
  3184105.400966766,
  168.8853471579312,
  92.98852718066816,
  180.00474551296082,
  184.11861523217914,
  85.29903201296781,
  247.15468074792173,
  28.728008125204333,
  21.050662694465274,
  260.8215693139941,
  127.65264647664354,
  74.28087651854325,
  216.6066282527368,
  191.49685361046664,
  63.84601324536871,
  128.7407432780757,
  -47.845456132775254,
  86.29402097694762,
  136.46471339748885,
  63.36955411199536,
  24.590562268691173,
  221.84458497059728,
  191.04936445034673,
  46.414162017374316,
  261.8876398995639,
  -68.88614052525676,
  71.53500140316012,
  243.7057429827362,
  215.61300086938147,
  227.56351868659493,
  -17.9360637671871,
  294.10023200661476,
  501.32423234047735,
  740.1216877286033,
  104.1592699493939,
  504.5126439416506,
  894.4076268004607,
  132.14423653336405,
  495.87363347369416,
  395.26375292870955,
  292.51798938454533,
  503.667711931458,
  -596.6570131005759,
  186.59349827931018,
  344.1824987217875,
  -509.4608691153984,
  64.35939857543326,
  358.98189147772837,
  454.3952126699586,
  299.498079123956,
  489.3865566586891,
  906.4425314985083,
  261.37588663492886,
  54.38911822497957,
  701.1865197619146,
  505.7573118567033,
  211.0448604722704,
  2.4247424274626885,
  409.76552327861776,
  542.8180360144045,
  8.160183003094716,
  32.756620569626534,
  192.42322268273517,
  9.32750545769155,
  47.9368221121743,
  386.02117779779064,
  5.550998955867202,
  233.55325527110807,
  333.79728725629116,
  -1.953841668835468,
  545.207859569996,
  160.37249054450908,
  -1.2941184468719273,
  544.1542198508396,
  298.19610111201007,
  5.998385679144045,
  376.9847785245944,
  315.61189826544614,
  9.418561159704817,
  54.99119522682142,
  148.3993943420691,
  7.865600774056679,
  94.30665318664383,
  101.09113982940306,
  125.22234531710188,
  -12.756958569407075,
  94.0831317439137,
  152.22759235326234,
  -78.76312739136043,
  71.24903700959032,
  157.72391488359747,
  -88.3942452633683,
  55.68212994870044,
  139.94228334708833,
  -87.11645516947237,
  61.633880385844904,
  104.60583929112758,
  -48.46021200945849,
  85.54509093781145,
  107.71213746468226,
  64.01062289085557,
  101.19999571684592,
  142.04879789003746,
  154.94488753243905,
  95.98975611283169,
  158.15264946719105,
  146.23701512148722,
  97.17632614564059,
  150.84055577556083,
  2.74461012222731,
  533.0189979694057,
  -2.0923934890244684,
  2.4873715837330788,
  390.10392340421197,
  2.8368501254737275,
  5.1689949251228855,
  530.9494234449921,
  3.8400889664145073,
  2.490119185531788,
  351.3121125153077,
  0.5944236485104462,
  2.8134733645843717,
  521.4942702783991,
  -5.855505914758676,
  5.110489963373209,
  536.0571516760499,
  -5.288516084366856,
  2.8015906538365383,
  44.10130918445333,
  0.9789238660339485,
  3.6999794543786573,
  187.19454599783688,
  3.9183455069180404,
  4.928573231970086,
  526.9872938991181,
  2.5836755781512863,
  425.2000329925163,
  364.05356641325506,
  661.0097572476525,
  999.6331152443588,
  329.5549730227657,
  803.5620448811553,
  1458.257971933312,
  224.8655768063764,
  832.5754195494818,
  1460.9976124111895,
  74.48368652637213,
  738.7117252092204,
  890.7189830090228,
  -43.079271134127794,
  552.1816434711981,
  54.77288275943363,
  -59.00872603083826,
  568.5788239938965,
  -578.7548890088232,
  19.536080658915125,
  749.8313593539683,
  -808.5185438073763,
  127.30009551151963,
  834.8385758759922,
  -769.0108308052224,
  208.371365888881,
  796.2403108152555,
  288.7037344591357,
  160.32038815271102,
  647.971593816257,
  463.91457927142005,
  242.14562922848862,
  678.7396784267561,
  654.692562919853,
  5.249640334644511,
  685.0018435694598,
  268.74537962461676,
  136.4573654585829,
  664.7425679221958,
  629.5683133777555,
  28.770954370575595,
  624.4824399888299,
  513.7261400024597,
  183.10800391228895,
  628.0215612900124,
  280.66503768400486,
  150.72377992432956,
  667.1425984645538,
  686.1717859915254,
  42.35727181416097,
  685.4903168622902,
  300.303994615315,
  331.75456237919735,
  677.1593759498547,
  66.31321964996528,
  -1105.2731308147172,
  477803.95054187614,
  -187.27172406376434,
  628.8649065965363,
  801896.3896684884,
  -26.24872352578609,
  -1202.6061667268689,
  867858.2589562479,
  19.33630216126147,
  -190.69320124537762,
  654459.2728776783,
  150.62848504309517,
  -463.66112549552236,
  230383.37648529885,
  99.23790594758916,
  -1370.131445516981,
  267662.34491590975,
  90.4533536332542,
  -649.7441955595033,
  679739.7465339983,
  -37.98232226706291,
  -558.7139419946433,
  873003.5418988077,
  -320.6465857611107,
  1672.5055222203223,
  785250.4368644579,
  438.42987651707796,
  72.418786748204,
  -81.69160272583774,
  -161.86479006323674,
  21.0398512486758,
  166.44693709106764,
  -140.63594220052084,
  13.791340321013138,
  216.95006506519445,
  466.17813375222295,
  86.2006562739015,
  53.562998873077625,
  -226.42861038538206,
  61.94378599997872,
  -271.1270000233191,
  -56.682722167633585,
  0.4093127003750183,
  -242.58468408043314,
  454.3508207579588,
  71.14898250128857,
  72.91877229335265,
  -225.0328923244719,
  93.43261348435144,
  220.88950592272366,
  8.6764437484386,
  2.1523124619926435,
  153.702108998859,
  16.073171949446866,
  -15.011738913695233,
  65.6904106581518,
  -3.765380525938447,
  -13.660254250389023,
  79.8570976279409,
  110.31817620698732,
  -8.630435477722664,
  82.74041436516589,
  -9.531178625853478,
  -13.084989882180778,
  73.412345362407,
  -24.9763160282549,
  82.1044660437855,
  54.87519438223086,
  -32.34718617831348,
  80.91531339313283,
  56.50472785032512,
  40.35196232439974,
  -15.415357768272692,
  74.51740217182294,
  -6.169922023353344,
  -13.430726592200898,
  82.9653243106576,
  184.4827780527747,
  40.72196697575952,
  79.12947188226141,
  -50.05177935017069,
  246.0227331541283,
  677.4323599121905,
  -44.93869013204197,
  519.1595331889959,
  823.5263192881406,
  -26.512707951140378,
  797.2755170006188,
  853.2605231407732,
  5.220142804164929,
  972.8233210200451,
  757.0648115498221,
  41.92010488703794,
  964.1780916138395,
  565.9004420667558,
  71.82002999309412,
  784.5204518091339,
  582.7050059564777,
  88.38848015446548,
  533.1831252572954,
  768.4607098969241,
  93.65409732881238,
  319.698713280326,
  855.5799069536565,
  93.98542790620027,
  207.72286739196852,
  816.0226787858209,
  -255.9400808018545,
  252.7032890250157,
  689.749311910594,
  -35.06264027382127,
  278.44243329725117,
  838.4995250933795,
  796.619353738362,
  218.2097253806333,
  868.7743508342419,
  118.48207041101583,
  284.84328732506185,
  770.8296263052735,
  73.38875604136507,
  283.48036468057205,
  576.189541013424,
  -170.41012095692162,
  204.9526199211913,
  593.2996424284138,
  563.8497675670474,
  279.3752682210917,
  782.4327228041409,
  -256.3841140001948,
  252.58701996061504,
  871.1359052619049,
  -145.20826432981568,
  202.1953579804187,
  830.8594547637448,
  134.8269324116504,
  162.4350200779973,
  86.21866398882425,
  19.737261025144164,
  132.80920623600102,
  104.81244063667243,
  591.1979865973344,
  98.2977835396853,
  108.59679385428024,
  28.9339568702448,
  137.27631406051626,
  96.35370328815918,
  426.71315511556963,
  55.339888916094395,
  72.023692626678,
  597.5668150902861,
  112.17124294101151,
  74.16245530355172,
  501.60057833851613,
  156.23603648789293,
  97.80409035051761,
  284.6306590422917,
  172.50423614115877,
  108.89198815773811,
  8.70676553988676,
  125.44023859562493,
  103.8574318454681,
  297.0868715372044,
  4.341384081280168,
  39.337596303584924,
  313.00965683323983,
  21.17884909429256,
  132.10884002935248,
  245.52075743990437,
  140.90903455488416,
  150.99038095265465,
  250.09688743932614,
  17.142179302154503,
  89.90506405455662,
  332.79614444567187,
  69.07092772298968,
  -31.486377376359123,
  158.2810681944677,
  12.564400468130216,
  -20.815297620714734,
  188.22576021766503,
  106.36993002543703,
  97.14158271384282,
  340.86915505048717,
  106.2377083481499,
  152.46321475028543,
  104.96857795922652,
  43.932826327812585,
  127.34394718337327,
  1108.1367200254113,
  32.25208285840971,
  766.7302619006156,
  -335.46876969175344,
  46.984747079627695,
  932.0820613761227,
  -383.42822344434273,
  46.35371692733729,
  965.7357739184206,
  1109.5070438763378,
  32.29388193344928,
  856.8597185268442,
  1119.2866738178145,
  32.60466188882002,
  640.4964094301008,
  1188.9491035180395,
  36.760727814935784,
  659.5161203780135,
  1075.9949761107941,
  31.36937817739546,
  869.7578034742459,
  -316.8271684010018,
  47.20678206124325,
  968.3608946884567,
  201.58268477379147,
  24.866205233052703,
  923.58930462577,
  141.51520501010344,
  -193.43883335155,
  31742271.465752978,
  -1174.3326411677863,
  1552.6931332858433,
  53267993.69124255,
  -444.7421863832262,
  -291.4450599318457,
  57649079.777634285,
  105.02221384286848,
  727.4666635661162,
  43475446.75519327,
  958.5773173654259,
  452.610793896478,
  15308976.803385371,
  730.2118677117311,
  -460.1290044648522,
  17784988.651895765,
  354.38481316463185,
  265.2407056572747,
  45154537.00216494,
  -516.5092828837567,
  356.9005575557752,
  57990821.57109164,
  -403.96459425847877,
  -523.1437614130177,
  52162395.06264207,
  203.14142502866372,
  1442.1218600986847,
  302.79173662741846,
  220.11514413586676,
  1491.9484446636068,
  368.0913093787901,
  263.62574035366083,
  1481.2601551333503,
  381.38159746443654,
  128.93716693791103,
  244.9625078346371,
  338.3850294048448,
  176.08665079560095,
  -748.6525879476076,
  252.94034910559537,
  210.10064314051385,
  1466.4797680830832,
  260.4514799350923,
  180.93693269753473,
  1322.692225935311,
  343.47865063574636,
  344.36992280917684,
  -125.11891671292284,
  382.4182917444374,
  292.47692956684205,
  -821.3610236409397,
  364.7374094572987,
  340.62670778810525,
  -153.58054838919642,
  206894817.94013506,
  -1859.7874979531302,
  886.5130625729439,
  347200633.18815327,
  -704.5494704914138,
  -211.95852442326856,
  375756787.9403065,
  182.1627414173814,
  394.9621402189888,
  283372285.55715394,
  1615.2657302203772,
  231.24265083277893,
  99781719.449803,
  1286.69000886603,
  -312.4360921746567,
  115920497.85314189,
  692.6301113705424,
  119.63457344426146,
  294316686.0984462,
  -763.152002785848,
  174.2322946720319,
  377984279.3309821,
  -625.0683356663121,
  -349.97119682331834,
  339994281.8612187,
  478.4649470617362,
  -441.680718294243,
  78486.97954505449,
  -1801.129866197759,
  744.1956222506554,
  131700.02262587275,
  -365.0381561754,
  -508.24113156672706,
  142530.3641221444,
  172.7836894174379,
  183.7474060046588,
  107492.18344071975,
  1413.4905692886018,
  -2.9195121485853406,
  37862.76226360811,
  943.0818515475706,
  -622.8019452243016,
  43983.63123066101,
  729.1136629353944,
  -130.17092201574872,
  111643.0082405902,
  -500.3082984243322,
  -67.92061572668302,
  143375.17297860305,
  -178.72301125263834,
  -665.598085950078,
  128966.90794393442,
  528.534768660168,
  2484.955870908737,
  21139.403654142017,
  229.67374190069313,
  -1456.3135233767775,
  36323.558227112466,
  111.91131084808029,
  2205.1651378825154,
  39413.95805836595,
  62.21771685963566,
  -3812.191582678777,
  29415.936509130424,
  147.62487873991267,
  4329.315204863225,
  9547.426219764206,
  460.4325730323285,
  1723.6018113731338,
  11293.994638628632,
  539.2544611112028,
  3794.406187703136,
  30600.35975797243,
  457.5005009505301,
  4056.0791246847743,
  39655.02129246064,
  147.6826783050894,
  1543.7056389238608,
  35543.67357114236,
  146.7274899914916,
  -540.3320444396908,
  1936124.8520567832,
  -83.83727907760877,
  293.8263100919024,
  3249334.442816709,
  -17.19166863845865,
  -587.1513652356523,
  3516609.29688789,
  24.96027852339388,
  -100.39907908240627,
  2651925.1471063457,
  169.56782057581233,
  -231.70262563993305,
  933586.5895844203,
  386.87164581352647,
  825.9435626947621,
  1084639.4774846828,
  174.28272667881663,
  -321.21265551187827,
  2754360.6144498573,
  35.309415691023304,
  -277.4251109865331,
  3537457.77741879,
  -210.22696389626037,
  795.8402904499349,
  3181885.7083491636,
  -7.739681620162287,
  97.17173281363746,
  347.95389395489786,
  159.63750514850895,
  58.64227106558786,
  422.99306399799946,
  -42.79023903194724,
  188.61236137859174,
  438.2656323404881,
  -45.171959196829164,
  186.2530701690277,
  388.8560168414996,
  277.89643348157813,
  250.08485396283214,
  290.6670452433791,
  371.7454825263137,
  73.21811498985736,
  299.2984803321909,
  128.63573427473045,
  247.36539538746263,
  394.7093646288746,
  -11.183855676264358,
  210.1015925933215,
  439.4569522080145,
  422.580847635082,
  88.79548349849203,
  419.13892137635344,
  75.69822693931981,
  226.61207119429798,
  -432.16579062405054,
  -160.25750109537978,
  196.89521212014762,
  348.7321141052606,
  286.7829586550139,
  222.92815316575394,
  507.6666627101323,
  279.87657077450007,
  227.25890216716743,
  -6.5163325772478045,
  -159.87473488498313,
  197.34635153200793,
  -1028.3235053439041,
  82.9802409506635,
  230.37010805137325,
  -938.5001561279064,
  426.66611512578265,
  55.85961470815268,
  54.396748153624955,
  -179.13563132973968,
  171.38130425865893,
  520.0641770733566,
  -93.18183574173091,
  88.43875944294444,
  308.62383604138284,
  88.50334280816352,
  941.9526528240906,
  747.2284212364768,
  52.00617814186165,
  539.2637080673946,
  908.3744855178278,
  47.53689226207766,
  21.90568927304932,
  941.172213403762,
  71.17645573016647,
  -357.0238611516211,
  835.0654284973796,
  87.36988698404441,
  -489.2755532995002,
  624.205336097876,
  74.34254295158276,
  -386.8159208370904,
  642.7412792974482,
  48.50966087168425,
  -8.772013461256705,
  847.635449704486,
  53.07996910266914,
  560.8584720969504,
  943.7305640337303,
  96.06745528598016,
  989.1179522244843,
  900.0977426607236,
  312.53364731069973,
  56.490019537209875,
  -498.42654805469766,
  289.1469656900416,
  168.86368367944218,
  229.2829435754429,
  -165.9152822932289,
  142.99247316026225,
  377.3921635736814,
  337.42624140598014,
  170.71319649834857,
  -101.76886866797369,
  342.1339727618195,
  148.87470813292765,
  -1053.9788486599257,
  -164.80935802054643,
  140.65969582370573,
  -970.2735353294355,
  261.097099478989,
  148.27761238809782,
  -45.00469150238797,
  285.7649615821232,
  25.6030824646011,
  388.94526010538056,
  -153.6004984335041,
  119.44866699058261,
  191.90651515469816,
  472.6406873649373,
  46.458770275019475,
  -331.391232221192,
  148.34073125747554,
  77.56838190387853,
  817.0121301856149,
  244.64431916344407,
  93.33005629700553,
  1050.744310685845,
  286.6938354786824,
  100.27089081315127,
  294.5769844524409,
  314.0197039849487,
  97.37977509967465,
  -1208.1121453684193,
  242.53122469953883,
  92.86925367061394,
  -1076.0162137010784,
  129.64905738125384,
  68.91440511970303,
  384.15692352288795,
  497.1711203674587,
  35.33191461546716,
  1068.976331919336,
  212.38132353937948,
  84.83777740200097,
  758.0281309842462,
  408.9354761175212,
  110.682545527117,
  97.17513732324312,
  942.9578010126072,
  45.07920123814834,
  123.73313050567168,
  -406.9908281257482,
  69.76553927703392,
  129.1384243766595,
  -76.16562421663417,
  75.95267181709507,
  111.65128758110549,
  1121.9401545252224,
  0.6783517365439806,
  76.90007648968856,
  -475.4756445878669,
  49.84440802343557,
  79.95492896355745,
  -406.2369293250812,
  16.87273563367279,
  113.7229145799409,
  887.5707624028198,
  65.84119456154905,
  129.56005836996837,
  -541.6364493240428,
  20.35702068865165,
  122.36906566578888,
  424.8716128852942,
  -50.04857522896883,
  345.9010686218306,
  105.42456616579861,
  -57.43128907417818,
  420.4975296971263,
  -212.06990406301833,
  -39.18066596063416,
  435.67999439157666,
  -371.070413105695,
  -11.28011303564439,
  386.5618810489243,
  -400.3996846383641,
  -1.107305929355178,
  288.95219541893437,
  -343.0642588776893,
  -18.413322819475823,
  297.5327075868682,
  -111.87930718711863,
  -48.33441571873375,
  392.3806958110051,
  270.85622238653286,
  -56.70160702465256,
  436.8642858233065,
  547.4874850920173,
  -39.47049318626501,
  416.6661253800327,
  256.12462455823203,
  -1348.1024360492183,
  7796836.729889609,
  -758.0230935904385,
  805.7959867327813,
  13084828.915035434,
  -110.6140686944724,
  -1468.995622181465,
  14161083.116618382,
  76.92613361527289,
  -212.1419615600102,
  10679199.448666876,
  603.2468698417813,
  -551.1837038137902,
  3759846.3404151374,
  394.4281906779193,
  -1677.0715803680419,
  4368101.485961299,
  353.7765866986929,
  -782.3094979954152,
  11091683.453204792,
  -161.86147621839848,
  -669.2447272857587,
  14245035.13988663,
  -1288.3308265535507,
  2102.057199766894,
  12813228.415563025,
  114.40226681180191,
  -329.2798452605938,
  -73.68182761206398,
  -184.17154928176097,
  580.0888884238556,
  348.63276407641155,
  -70.23094395159558,
  -380.3205454260885,
  434.5855865808147,
  29.029875882349835,
  150.31888013687072,
  156.51212730675135,
  227.5078474711892,
  7.176586814946006,
  -396.0877405349853,
  218.07009684991502,
  -468.1695213132207,
  -347.51069759696543,
  159.67288243163787,
  -90.40395298845291,
  189.45431176076508,
  -37.767712516392294,
  -42.66838371692785,
  441.29024180469037,
  -52.13133917053602,
  -500.987000647116,
  326.9419502436537,
  39.92390360615849,
  -19.182392071335613,
  360.2708459533013,
  415.0831025180306,
  -16.80526967966511,
  437.9662698032384,
  -274.9380364168238,
  24.45143112695362,
  453.7794600339567,
  191.5074479550256,
  -19.584457963459883,
  402.6208315969509,
  -194.1068306011589,
  27.636096864342633,
  300.9561441900474,
  185.76811219478424,
  32.601476478206564,
  309.8931168041268,
  15.949723154231606,
  -18.95319633360313,
  408.6813775360914,
  -294.6875637156731,
  -10.466486044158135,
  455.01295051626283,
  220.52803950971395,
  -19.459356013669904,
  433.97569735427743,
  508.97019251713186,
  109.67863126007018,
  -1849.9832907553803,
  228.07616992772827,
  55.90009780961273,
  836.9632614169038,
  504.24301624186546,
  102.01552118515434,
  1383.8319811414744,
  398.715059045174,
  214.99690867745846,
  -385.39062530405437,
  250.99363349311184,
  94.04000102113733,
  -3901.2679803623773,
  424.8439921205636,
  202.64047242693613,
  -3592.199999748249,
  268.668830277231,
  104.70272434092304,
  -175.7983197532466,
  294.0658817234248,
  156.24217987343013,
  1426.489873129696,
  344.8295290169362,
  203.05085772794092,
  698.957001181566,
  -136.72097458708845,
  491.74030888726793,
  -323.86753991495425,
  1063.7305956191412,
  2.9624337972147714,
  270.700282264208,
  -336.397691836598,
  156.1817976997861,
  391.71145140773825,
  20.14841018168073,
  527.1357489812342,
  0.2176826857575196,
  985.1238537373022,
  234.1726552667277,
  -777.776036748683,
  -283.4006085150784,
  0.07756500114282971,
  -709.3854407427855,
  135.52376551753775,
  499.151420535552,
  46.596290610096496,
  607.4403985493364,
  525.5716628876814,
  401.1507943368657,
  -20.146294776665854,
  182.74153514100763,
  240.1622421499088,
  444.17711095049225,
  60.603062699273856,
  447.5159226086592,
  162.74796513467865,
  60.97463528093084,
  544.0264775903474,
  122.56711110782015,
  49.70985220431176,
  563.6690728626926,
  505.37636798705495,
  52.412362029511414,
  500.12160278139766,
  325.47783901689564,
  62.781259427680894,
  373.83726172894774,
  390.91518403261847,
  62.023575078139814,
  384.9384584803399,
  501.1385672156441,
  51.853758608754134,
  507.64980229554374,
  86.18094250479749,
  53.26411878320405,
  565.201271866355,
  102.11762094296023,
  51.12307307427152,
  539.0695271979059,
  265.0993490023437,
  507.0946314043736,
  404.68257788572697,
  77.66705919879935,
  -760.9761630811435,
  612.4350709922526,
  -43.385157685442806,
  417.0742796789352,
  654.7185097279067,
  36.989420672662305,
  1352.9616709896454,
  517.9236758104523,
  238.4638305388658,
  1100.5019760825735,
  246.07893614504272,
  363.4212616665322,
  262.1352666474381,
  269.9758177038046,
  311.90411094429476,
  928.3994287786155,
  534.1291801510289,
  116.9955059832484,
  1012.5905296393817,
  658.01678278215,
  -28.140823569444564,
  204.25516267551149,
  601.7645406815474,
  172.9949306254547,
  386.31695795437884,
  1044.4003669985636,
  419.2458460484373,
  255.08388535486853,
  1471.2715345731892,
  459.1014741476913,
  116.39068162385648,
  1558.151747620278,
  161.03657156087797,
  386.3939454554636,
  1277.0780064614696,
  482.487788206732,
  381.98447367265544,
  718.5158458596601,
  486.57421738721007,
  351.68145693233396,
  767.6170122516834,
  159.79313556709062,
  385.56013885631046,
  1310.3756215974308,
  471.9668700975043,
  180.08348704833273,
  1564.9287429217152,
  442.46486575227027,
  321.5520102573874,
  1449.3466870574696,
  428.5095136416428,
  185.69099537763952,
  391.06322594931,
  500.36846361168534,
  106.91990534764601,
  475.3992843163357,
  468.35820404874744,
  89.61141972097761,
  492.5640292676282,
  -308.5599995921836,
  119.89483316674104,
  437.0328684855791,
  515.7877770061905,
  131.39108023408227,
  326.6788915567181,
  299.51014632693625,
  209.23233344972485,
  336.37970798396674,
  -239.3916720646011,
  181.3088511698652,
  443.6114098041334,
  399.5605009533466,
  69.13394186167483,
  493.90294628688355,
  478.10688476529634,
  93.87915297536247,
  471.0676372990875,
  -306.04326383931533,
  190.00105333356979,
  79.03377532308889,
  -307.78027911448305,
  191.28825200707476,
  96.0780705836164,
  -162.989387370624,
  148.60743847711763,
  99.54706103309022,
  -297.9549670442919,
  233.05560898750363,
  88.32422801414592,
  422.1002531192885,
  277.09662868973965,
  66.0217182411215,
  -55.08279993954332,
  282.0390191639126,
  67.98225069492241,
  -166.0169513179237,
  149.08254995793027,
  89.65374948797447,
  31.865150337749782,
  287.7352202511189,
  99.81765581125994,
  243.93504131164485,
  128.65954840185748,
  95.20264585834576,
  13.730760480486936,
  38.83031067497663,
  63.63758532508456,
  10.6591029601333,
  148.8524837156496,
  77.36156332706776,
  14.88485013751155,
  97.5271398194204,
  80.15477641625445,
  11.039800131042545,
  104.23741331203149,
  71.11820956983178,
  10.410765025550766,
  345.89579311115784,
  53.160344557786146,
  15.715210466031717,
  284.8008446355166,
  54.73895510500246,
  12.538070294700917,
  33.44268515852772,
  72.18873335395347,
  13.911270988186224,
  43.924008298706184,
  80.37265792594955,
  15.049238065898084,
  112.89444008811671,
  76.65667588594074,
  -68.84813216980595,
  -23.18016453985645,
  141.64494798163983,
  -169.59953970278397,
  -2.664905739022508,
  172.19186676024756,
  -233.19314582571047,
  32.01510508893142,
  178.40901847488894,
  -230.1345478667771,
  67.48547032807033,
  158.29536968769008,
  -194.31477455304406,
  89.66612681762089,
  118.3246378866853,
  -180.97324377300248,
  94.85325844466651,
  121.83831942726354,
  -208.73821915453703,
  82.80744737843827,
  160.6781484329932,
  -238.99811115455725,
  52.030762160754676,
  178.89398054485545,
  -204.75024800070628,
  11.128574587694594,
  170.62292374612616,
  -33.46566285425723,
  55.98128229301314,
  -515.7542023382871,
  110.78991379357592,
  138.19411585800054,
  463.8447732292756,
  -9.162499920227958,
  38.91692856910804,
  663.2205431637518,
  77.54263378188492,
  122.51910919142713,
  18.202631875620167,
  -13.889158011011205,
  68.93811587520565,
  -1263.6054682713198,
  199.6785024705706,
  144.92620935083565,
  -1150.9263839234884,
  248.90801554230225,
  176.55122515092603,
  94.61517072512733,
  -81.99564492905586,
  23.458305235128606,
  678.7726304420601,
  489.2731679620675,
  157.84578190473897,
  413.53086168564965,
  395.51380282290705,
  127.91715619793202,
  -368.61820232495853,
  365.71057673830967,
  0.008308834434956225,
  228.1751302623183,
  426.72453121285525,
  408.72254533995977,
  349.63925297376954,
  360.06403089698483,
  399.8538830163872,
  -43.31990527065359,
  376.68902721458505,
  25.830273638657644,
  -824.2257115275918,
  407.48073462177035,
  264.74296080906447,
  -755.5791245690215,
  337.7544126842123,
  274.93367161282606,
  3.2323011411905145,
  393.2050598713338,
  135.17430499036107,
  359.1139280469366,
  388.0563195386871,
  94.30363581641966,
  197.52278405276374,
  122.80680611451561,
  62.858557902228,
  -206.7936003692907,
  147.8441505054314,
  20.071699269678824,
  82.69062666001874,
  137.8213870939028,
  3.0216856903473364,
  141.60875753537553,
  128.04427416267697,
  32.988329885286134,
  -49.00241716610945,
  151.64583060210992,
  51.95781117283218,
  -427.79336767313396,
  134.76455525737765,
  11.793120291118633,
  -394.49523399970536,
  137.8764081433563,
  0.03952077812821031,
  -26.421518966026454,
  151.8418699937128,
  60.7863094666595,
  146.20460142327377,
  133.27047880888136,
  17.82543467389405,
  67.82221197676641,
  392.2874956850788,
  -2138.362778154276,
  8902762.837791078,
  -1260.5721274407065,
  1292.9578389238509,
  14940542.247380015,
  -189.8690580327155,
  -2330.954628193336,
  16169399.104630064,
  123.80162195962447,
  -328.69313214272483,
  12193817.299498882,
  980.3024044594275,
  -868.8118805203219,
  4293365.433848956,
  627.1511654736105,
  -2662.4351277805517,
  4987865.399993264,
  552.4406550925635,
  -1237.0124856768227,
  12664787.630427072,
  -288.18696255193936,
  -1056.8918844926372,
  16265254.729928873,
  -33.432045630793425,
  -2786.265307187189,
  14630431.368631927,
  -65.66818759087123,
  13.813782056599088,
  -0.0,
  176.07789850086363,
  38.517886400823535,
  0.0,
  -73.68558153387787,
  84.94883227267098,
  0.0,
  -92.76372103075605,
  57.85329805074554,
  -0.0,
  130.93160655922244,
  0.6553173119708404,
  -0.0,
  -90.35191657535424,
  86.0579271502944,
  -0.0,
  -91.26402181709707,
  85.19706245048957,
  0.0,
  124.91541097802869,
  1.952015655841258,
  0.0,
  -93.50783762476297,
  60.97221351973124,
  0.0,
  -48.87230396805762,
  200.0327856459119,
  516.2855712664118,
  571.5539434298113,
  135.7123904161645,
  627.626876669598,
  566.6885282764104,
  138.43875011872075,
  650.2879441512257,
  -122.71691018855472,
  183.9785932709971,
  576.9751518326675,
  -318.84570575580585,
  15.448796894702149,
  431.28473084784565,
  237.5559262116212,
  215.4362036509526,
  444.091845448649,
  -314.47645107496436,
  74.90289985724255,
  585.6602076941709,
  236.826446839203,
  -134.47787670282057,
  652.0555957540746,
  169.62719534887998,
  -136.56996193187453,
  621.9081930746482,
  -683.411861900391,
  16.245350778135474,
  99.56202865376133,
  -771.8370338237784,
  50.6999176640231,
  121.03341359234793,
  -619.89192748132,
  90.04771192266693,
  125.40344052220455,
  -246.4428200243907,
  117.62017294045992,
  111.2655859398981,
  137.38636541909827,
  127.02794104920703,
  83.17021648556864,
  339.18821692767835,
  127.15469931375736,
  85.63997814814901,
  286.9168460678962,
  127.42010546499463,
  112.94043766666914,
  -18.005269689347585,
  124.77359538195812,
  125.74431965834043,
  -456.6821913861578,
  105.6491255532147,
  119.93060582155245,
  -438.07783893475516,
  27.90831080911559,
  -112.55355887456233,
  -128.13570129101885,
  360.1740861186703,
  506.0326757167556,
  556.104404017434,
  262.4060045053806,
  631.9322630668305,
  -179.8575574947156,
  230.3138641290285,
  224.62354701135627,
  -71.22489872624902,
  369.07400684993115,
  -584.7983347123857,
  113.44363747129647,
  360.9321626454181,
  -513.6450033570333,
  238.43308027328433,
  370.58112003847157,
  272.8756847344416,
  -80.55541844041,
  368.1238808245263,
  641.7529216725121,
  -271.17021217344893,
  163.38373646244858,
  474.26100805928377,
  545.3146541999403,
  421.6396928115918,
  380.19148689656174,
  194.49654790961398,
  19.286841529212666,
  702.1137743955957,
  22.07060849235205,
  393.0766619873831,
  767.6339571744729,
  57.20275849161999,
  690.0292942935832,
  555.6639095747212,
  302.6180340679729,
  609.9250299879368,
  134.42766287997986,
  600.1207326109677,
  343.9152477042059,
  171.45700804189573,
  594.8864319908944,
  555.3177076508568,
  580.7751029442222,
  369.5099982709917,
  582.0311448116483,
  772.7447868475205,
  55.13922830135215,
  325.5501651181998,
  685.5792843633213,
  389.3394995507547,
  15.162309015950058,
  218.0700033589475,
  -96.67598066514603,
  202.37407428657033,
  239.04948713607527,
  246.51159686155262,
  0.18383599875284062,
  243.31939843163298,
  711.0496921477261,
  24.09140180598098,
  229.50543665407403,
  -210.2548426855342,
  250.48363101554924,
  202.05372129591623,
  726.4913583407576,
  131.34450754033566,
  204.46690166978027,
  960.3942558576364,
  174.48302104826993,
  231.14191817268073,
  -259.6987085658443,
  266.44609476275906,
  243.65246815801433,
  993.2391444427043,
  275.78886549222216,
  237.9719442666763,
  561.8040905662468,
  -1603.5496750373143,
  10776.500700133716,
  -819.2716156743079,
  1530.7569292056107,
  20289.549194692667,
  -245.7058867073606,
  -1779.4708362649903,
  22225.72043959194,
  131.31409826548978,
  49.47554643609959,
  15961.844279055964,
  998.3642272954318,
  -443.89069619641316,
  3513.9927382237734,
  930.5073365594592,
  -2082.2584900513793,
  4608.238057439595,
  746.9635435171797,
  -780.2199749832417,
  16703.89914619848,
  -107.58936427564498,
  -615.6905553067244,
  22376.74934443991,
  -139.4212355390764,
  -2195.3699688176034,
  19800.942435801207,
  -74.49274785609168,
  93.53914222022894,
  540.9194752632187,
  600.3479277903194,
  104.96468386405829,
  657.5732882800759,
  179.42955011558382,
  416.6633246365516,
  681.3155995381629,
  -667.7531077099825,
  249.40240715104167,
  604.5047813435701,
  258.6839405168592,
  416.2102565633237,
  451.8629287411822,
  958.7062440308061,
  174.95119526914218,
  465.2811183925209,
  -227.63275117042298,
  106.47101168717919,
  613.6042335086045,
  765.4280835469344,
  374.88336835453697,
  683.1675923705712,
  -633.2975205634567,
  297.42086703788453,
  651.5817450304963,
  -483.70958273714473,
  30.921027386054348,
  7.335899647782785,
  466.8980599400659,
  108.13711243537156,
  11.109537532460322,
  -652.809389255264,
  129.91411605859932,
  11.877578309836165,
  -652.1111527266371,
  129.1082581604042,
  9.39282272409026,
  461.1485008117704,
  109.80101217887386,
  4.4550066092882705,
  -485.85093420345686,
  31.586870411117957,
  4.889072050464741,
  -680.5644975919837,
  206.92360432951637,
  9.687181189808161,
  1045.0860513329353,
  1.8273893253145843,
  11.93748848451273,
  -124.60775729383403,
  7.242079052001969,
  10.915716910488626,
  240.82683765912384,
  56.15776292292111,
  554.2628399281558,
  240.0158673570086,
  45.05097667819999,
  673.7942612357514,
  243.44661617326116,
  60.36423745005584,
  698.1222462060872,
  241.16827542360122,
  11.481169136717781,
  619.416663995309,
  244.97873568756467,
  45.18704666521642,
  463.00945260007285,
  244.28790507385338,
  55.169791475267424,
  476.7586412371182,
  242.68442288328666,
  7.944931146561206,
  628.7405808247561,
  239.8254449029562,
  35.1601542909719,
  700.0199238711735,
  243.4940632891996,
  60.176924736159194,
  667.6549190065807,
  80.6672832611633,
  93.75912888789026,
  384.9047499501082,
  81.81482520414048,
  606.9601861423344,
  467.9126814137162,
  80.42709347803645,
  310.3783869912977,
  484.80711542089387,
  131.52172493436953,
  -583.8738102288494,
  430.1504611078535,
  94.6620549057478,
  -740.9476932628526,
  321.53434208338393,
  82.06298554488808,
  635.8075804244569,
  331.0823897479987,
  132.50864949556401,
  1048.7676136342761,
  436.625403350525,
  138.02849732017512,
  725.0222613649569,
  486.1249471327594,
  85.20878652836288,
  885.5708371211672,
  463.64924931012547,
  233.60218027177507,
  824.7600420207259,
  81.08660065615614,
  -414.9304554909338,
  -395.552947079599,
  98.57360488448955,
  -555.0045201249598,
  -319.89890516740684,
  102.13269898200164,
  1056.2826344685163,
  635.5882888365352,
  90.61836380672113,
  -38.21396885189381,
  -508.35110365389835,
  67.73656806556622,
  -489.04999474588135,
  649.6880530480673,
  69.74802344024506,
  15.327958919978187,
  -516.6142352023013,
  91.98241830584394,
  -484.75434029100825,
  -361.004315632056,
  102.41032219596798,
  1399.4625165445475,
  81.76238383414116,
  97.67544185466643,
  387.21000867748404,
  428.1199924885866,
  442.1707161510102,
  120.81462025642756,
  381.23909589811166,
  1369.2401332680683,
  245.23646174035014,
  18.467280715589084,
  1557.9246699309706,
  366.9898142455664,
  344.0951258856874,
  947.494898195559,
  179.43093247360113,
  76.11428105252926,
  -265.5781223949866,
  364.88721367895846,
  187.86280602256056,
  -158.94128869770253,
  328.51909938943106,
  192.25643509109136,
  1019.8099267107776,
  251.8728963678278,
  8.940939230254173,
  1572.6427993366306,
  440.3496986083313,
  553.7916965348734,
  1321.6242314439535,
  0.9610633486917841,
  59.652268297554954,
  2.052825333067244,
  1.2557690207410408,
  -20.032459668609235,
  2.495534300873153,
  1.0981372670019045,
  9.113839242477198,
  2.585637948911434,
  4.469527457646808,
  347.48655282311574,
  2.2941357925752186,
  7.313959187520326,
  -197.06176406692333,
  1.7148498244447143,
  9.269076709555012,
  293.2959288035751,
  1.76577274532266,
  1.6662858193504526,
  -68.58895016353173,
  2.328668817869467,
  2.0181149840805235,
  251.48466448614772,
  2.59266638470805,
  4.204454171609282,
  -188.28456621196642,
  2.472795996320669,
  286.31294128187716,
  -151.72079470639858,
  259.4839937806374,
  -1726.564237094603,
  1683.691561558585,
  367.1485767828588,
  -675.0317606192107,
  -254.73811681798333,
  389.061328496697,
  166.62360045742318,
  816.2709494971991,
  318.1694776680812,
  1492.7846936103545,
  527.3615949797049,
  177.2900586065901,
  1192.1099486321064,
  -432.0469354037957,
  189.67425554019002,
  616.5056073422265,
  330.41120307376036,
  326.5677348494004,
  -733.7335086113542,
  426.75765795937866,
  390.77060855251074,
  -611.0458075711573,
  -498.28366077134365,
  361.61873606164266,
  10.188547246365857,
  32.74154349747673,
  -556.2781678370638,
  280.97375417714215,
  3.3346203199384377,
  621.9697363201244,
  299.6349316534798,
  21.30655143057993,
  861.7761151793067,
  9.337007728392535,
  35.270475799934644,
  85.95762100544104,
  178.33066825094159,
  102.5388964511588,
  -1455.783178238254,
  349.16985687161275,
  240.7909720068301,
  -1320.2543564586454,
  1.8071793153669375,
  65.78356209903946,
  177.86555067492463,
  82.92284003913915,
  292.95296806436215,
  880.4819475637479,
  315.03483949540924,
  322.9058252202833,
  561.4528694135615,
  0.27936013013678007,
  3.004691099056373,
  -19.533056530351256,
  105.02148965541295,
  85.1543306324452,
  18.925066012441498,
  -90.23458691323988,
  317.35860293177655,
  26.75236880005542,
  18.0654778877804,
  18.672572868076514,
  1.4295800943578563,
  9.045128271685417,
  22.31051376711585,
  -48.89298477279523,
  -25.089263639357725,
  90.75858977024521,
  -44.46931126767762,
  20.938494853139872,
  22.357560234399443,
  4.429463573388276,
  -70.72108090902623,
  242.00053924741223,
  27.362928930540317,
  69.58259526288282,
  16.40428348600389,
  16.94978977796921,
  11.251706808056447,
  670.6972472463983,
  75413884.5855376,
  -80.20255453320738,
  -228.1577891407137,
  126555604.01646045,
  -192.44734627287286,
  606.8875239425996,
  136964373.25941068,
  10.01179045294274,
  -765.4448017432638,
  103290057.6774602,
  318.63035528601773,
  1091.3261133259966,
  36370969.50260954,
  270.3543958273721,
  497.06107513402776,
  42253582.96094982,
  91.99730560946631,
  969.3335226189649,
  107279311.15803048,
  -205.58784410588962,
  1029.0112593484578,
  137776297.83670178,
  -199.06155521717906,
  456.0335369334627,
  123928876.12901494,
  462.13608379924005,
  103.58451347370476,
  361.2972586198349,
  270.37389873380727,
  48.031899491982415,
  439.21403695367496,
  481.5025102663078,
  116.13457186635024,
  455.0722790084124,
  9.13374133842342,
  343.7444159595371,
  403.7678994932385,
  506.0675745174995,
  136.75337911750512,
  301.81356910226975,
  518.4616017717747,
  150.65473725708102,
  310.77600317678815,
  329.61177730762313,
  56.45299555183868,
  409.84571194502615,
  297.3353875215139,
  371.8743944624416,
  456.3092837086168,
  463.64786479114923,
  104.47947828008036,
  435.21209535243776,
  451.24365888096804,
  23.89216106946173,
  -177.33201336226375,
  683.1123208479298,
  26.02286201566585,
  378.7756878244217,
  -189.68779300118155,
  44.712195960984765,
  491.9591474399732,
  211.39371378930315,
  1.7177042147032502,
  125.78948330485514,
  667.3432890891684,
  20.117306079067333,
  -601.8790562852256,
  -85.15848276278871,
  16.991114104572965,
  -537.9123636575733,
  -37.894502801034434,
  10.06112224751983,
  169.16805186329785,
  665.3648990690635,
  19.50564987725552,
  500.78789851128187,
  150.6981510941014,
  0.08262344589918058,
  350.2130265884553,
  93.0686155257415,
  519.6520509514569,
  416.7597904872919,
  139.41827001998624,
  555.8322449759914,
  666.1512795973283,
  -157.54297277059032,
  129.42088496837587,
  716.9094177707686,
  -24.543592303435602,
  514.3879198918158,
  552.6973458812572,
  -36.68610607984054,
  274.07848364943646,
  226.36785920152727,
  -110.3721277342168,
  309.90252266305856,
  255.05429654776862,
  -109.0899855356904,
  314.1865449777276,
  572.1508542307489,
  -40.01489778667525,
  265.10193628727984,
  720.8687504179466,
  -26.583238313800535,
  511.50792711849306,
  653.3420978446162,
  -17.31160647173163,
  58.056896151343516,
  151.90907464697605,
  3.0705050672527427,
  54.38346907484555,
  184.66953826461332,
  55.25183129383691,
  58.95293370342649,
  191.33720821944613,
  44.19675533860515,
  56.13535266991081,
  169.76604865056618,
  55.825058914664986,
  88.85726571595306,
  126.89888700890886,
  64.85770594401788,
  63.045183436266036,
  130.66718315387683,
  -33.78146754669588,
  82.34471746788554,
  172.32149252234055,
  71.32920761758675,
  68.10252414707786,
  191.85731246839572,
  24.35171714488883,
  53.855591310431194,
  182.98690372772953,
  169.331643426406,
  281.23727516650916,
  160.120375979245,
  164.47474698457484,
  -46.171495004184294,
  194.65167546810596,
  133.92105584122388,
  639.1190866117527,
  201.67976001509186,
  102.78540244949278,
  663.0454193412567,
  178.94259182086705,
  165.27411283072612,
  -31.9020874889396,
  133.75828630668772,
  65.66940883187016,
  -93.4170000593827,
  137.73027413516746,
  77.94841584620355,
  564.2742038061326,
  181.6361677938184,
  169.314422245879,
  281.9272913599166,
  202.2279780072279,
  169.28134672175645,
  283.23940092586935,
  192.8780877130122,
  89.59789000643451,
  1962.8417421198533,
  7625.499652384036,
  -353.55194179478224,
  321.08611568848465,
  13011.21051966095,
  -678.870639551838,
  1846.293502399112,
  14107.353204156592,
  52.62252651109455,
  -660.2667612940743,
  10561.126573611129,
  364.35299930712716,
  -987.1232162832405,
  3513.9082864286484,
  1020.2775958988802,
  1645.6958721213898,
  4133.40359442989,
  317.4706674258416,
  -1209.9422628129569,
  10981.233016290464,
  21.046186512666935,
  -1100.9410823310013,
  14192.85660662299,
  -715.0397384228435,
  1570.7592149823874,
  12734.591018279054,
  1955.2818164156124,
  236.7447150004495,
  235.04850063619944,
  1922.3925369618296,
  242.89098893775667,
  285.738677449976,
  1941.6283764531904,
  197.4686691679562,
  296.0555451503592,
  1850.8904240678812,
  252.35014895317744,
  262.6785482498625,
  -532.8323444975671,
  287.616358962076,
  196.3503048989198,
  -170.522372168787,
  296.404085879734,
  202.18097933944458,
  1995.278668957527,
  215.88302599119453,
  266.63257964605396,
  1730.8469108451784,
  263.3648775515621,
  296.8603010490717,
  -1007.4470300752132,
  172.84306415746897,
  283.1351415787166,
  341.7701416715115,
  2.220696838740608,
  -215.0610895551512,
  339.3486486473913,
  0.17217789505050973,
  310.08231046861596,
  74.30129968854438,
  1.386929527510219,
  416.96366938907124,
  331.5828968727544,
  103.78187059095828,
  71.18247988361541,
  281.55840213817925,
  89.06543326673275,
  -615.969181845275,
  85.04035998349603,
  8.421591537916882,
  -555.5641804703997,
  277.58949352398685,
  200.3497886412352,
  112.14571224370353,
  179.38130429863568,
  205.0769668368858,
  425.3008320387827,
  109.44457378864695,
  37.05824682452054,
  283.1100297338324,
  122.26695801618959,
  -570.9861131963031,
  1304.9451685687661,
  -107.04444976150069,
  363.52073280033676,
  2389.4852196102956,
  -22.62260386960304,
  -623.4377557064496,
  2610.2194313584246,
  23.081851282345752,
  -78.12961218237402,
  1896.1029654588713,
  162.9163204975335,
  -225.22885598308966,
  476.97916374872057,
  377.2169214995389,
  959.6512069829212,
  601.7291715966836,
  149.40924505394406,
  -325.5068610480475,
  1980.7013172854874,
  14.03081625211069,
  -276.4517147367638,
  2627.4375603594754,
  -229.43347092730937,
  925.926538463017,
  2333.7813514411732,
  244.32055873692673,
  4918.419571113379,
  399559740.4604126,
  29.474913183810884,
  681.5367975452637,
  670518590.5519576,
  -106.86517020959604,
  4617.643242887321,
  725666289.462384,
  36.760485706509,
  -1851.042980065588,
  547253167.4704773,
  232.66783460283938,
  -2694.5622354758707,
  192702726.40594563,
  425.69734081527434,
  4099.960446215756,
  223869965.12888044,
  307.5565654210234,
  -3269.5918955945367,
  568389014.0522299,
  119.95561125490977,
  -2988.2922816645123,
  729968024.9588021,
  -97.67273166352544,
  3906.571231262297,
  656601671.5315291,
  361.4254399266308,
  291.89483282843116,
  -15.617830648517746,
  539.660165335077,
  221.38128075847075,
  10.772656724407078,
  195.1977773205706,
  17.724056964362802,
  16.14385848161028,
  492.53173142448986,
  21.268350921239204,
  -1.2329839485253031,
  530.5710611672012,
  7.968172688531723,
  -35.7650132024774,
  190.34152405990605,
  13.089130941928374,
  -32.72942820612592,
  545.5687023564034,
  89.11168841435747,
  0.8255769441835543,
  435.41320782116566,
  131.95976262580115,
  16.56283315714324,
  204.8767206166602,
  28.598249677364635,
  9.417195274985684,
  46.90119960553567,
  0.045058561421280174,
  136.51288464897172,
  -24.190200361641345,
  0.7704803206631201,
  165.9530310080647,
  -32.31508035678158,
  0.9544313833851721,
  171.94492360261037,
  35.31597264311258,
  0.07247061816157885,
  152.56003020625204,
  105.1967962449749,
  0.40658644067030103,
  114.0375133255735,
  55.461596470191715,
  0.04542900190260113,
  117.42388756395688,
  -91.24008697137282,
  4.189463324195904,
  154.85647638831955,
  49.73438460550819,
  9.956753878707609,
  172.41231458308533,
  143.65074476991492,
  8.798012643996358,
  164.4409337553245,
  435.873279516924,
  31.958208076420362,
  329.47846595729266,
  246.56344219225787,
  87.53491261354495,
  400.5332552901411,
  -330.9307382050369,
  52.053110393052144,
  414.9948908002852,
  -246.76145055945653,
  39.89153099617991,
  368.20879470832256,
  296.49957428824837,
  86.8583180693214,
  275.23339682337667,
  -325.5510953984761,
  64.51097552685641,
  283.4065256242869,
  622.9602299028013,
  69.57192483484532,
  373.7513452680494,
  89.25340873221477,
  87.6392681768015,
  416.12295474564206,
  -261.2417367416663,
  41.20446011445883,
  396.8837574094674,
  173.25987197216102,
  99.31618252604372,
  145.84956036476254,
  -764.2592718505192,
  373.5537861626264,
  256.29218556328044,
  -281.49769140957574,
  83.92387929102219,
  278.77034650641696,
  78.77542752190358,
  243.94838758027964,
  206.0492910546671,
  684.5347447650969,
  200.78108036420502,
  61.534795723624335,
  554.0096949224292,
  57.43133370766506,
  74.23853898053164,
  319.38055071945826,
  171.3537948132436,
  214.66424635689557,
  -293.6411378539061,
  185.74937236099098,
  280.52373068624183,
  -242.27748826461584,
  47.53459264262257,
  250.61965975070035,
  502.83314841808783,
  -555.0276812945395,
  9777.872803295146,
  21.55566958195783,
  386.5823892006847,
  17035.56579992363,
  -67.48465309811724,
  -607.8780108701318,
  18512.709166996352,
  72.39331556276497,
  -58.42495799525631,
  13733.87405771756,
  468.5880044277184,
  -206.64230912366537,
  4237.161725951257,
  662.0534128609881,
  -698.8416401592808,
  5071.983139340296,
  589.1908849178901,
  -307.6825313786824,
  14300.002404004732,
  207.6638985775239,
  -258.25451490753574,
  18627.932107952714,
  -229.7362510597078,
  953.2630642386324,
  16662.79803214234,
  109.87942793312813,
  222.95634947188768,
  -157.3675224468609,
  75.85335845947785,
  78.39024861623912,
  67.85452451658692,
  39.43063816470899,
  37.44011183461146,
  113.69350571145762,
  96.88011092506612,
  10.933578258577029,
  -34.604173167016455,
  97.42794017358705,
  13.608753959922495,
  -329.30787471198704,
  39.404568593245784,
  37.80384421386978,
  -303.4015450202046,
  75.20307884593439,
  84.00641752958683,
  -17.03597552431387,
  110.02707694304848,
  230.41812449258578,
  117.26912493803498,
  37.77713007856295,
  66.872620152799,
  56.28672745756298,
  1248.823514295518,
  1.7448733238425973,
  261.1860354195307,
  -166.67478724332864,
  170.49034855889124,
  1244.8787716360218,
  -858.8038570630731,
  153.46955581884936,
  1445.0877362773774,
  1570.267982165283,
  263.86600048034717,
  797.3742842537574,
  -421.1240858879296,
  63.70948411751036,
  -489.7905135732909,
  -750.9699346221739,
  5.898805321134233,
  -376.6405414305909,
  1262.9898602438618,
  456.2062822922305,
  874.1061523925234,
  -692.0684449517869,
  0.0017660156436818397,
  1460.7048159908522,
  -494.2962942552414,
  38.22121295655592,
  1194.3545974070437,
  23.157219598701445,
  339.44422111428867,
  50.294220660147474,
  28.58859257515591,
  249.1272645739711,
  61.14059037139225,
  28.882289989077005,
  149.17739928298892,
  63.34812974833014,
  26.95564015549621,
  98.08278743237382,
  56.206326918092856,
  27.818352172450748,
  116.12601426767995,
  42.0138206988955,
  29.355869679741147,
  204.0415136659701,
  43.261432260405165,
  25.176220691948632,
  316.4970576645488,
  57.05238603780194,
  18.242678330887195,
  376.1857019031562,
  63.52032642534723,
  18.927364234659166,
  372.22445010253875,
  60.583501909856395,
  214.16933030165893,
  41.05375583341197,
  -393.6272405589708,
  105.08854585215752,
  71.09769366068619,
  150.58309917628205,
  218.94515309106862,
  44.719521211839904,
  261.3451132220341,
  274.3925406221426,
  74.96393620934296,
  -96.99072153530531,
  102.03883695191709,
  72.69041007308086,
  -809.0915291665134,
  154.7931198837628,
  3.710821825467143,
  -746.4933391893727,
  300.9985932623218,
  40.69202030176832,
  -54.54019354937088,
  93.92296626548217,
  74.99520941947291,
  269.9849820994153,
  108.36534485638211,
  9.229551233197355,
  122.63150717027581,
  32.13039256121209,
  277.15065555601166,
  959.6958432089365,
  27.763632454809567,
  86.87940840995445,
  1166.6622856581992,
  602.5568360058355,
  229.22847271026149,
  1208.7857411160953,
  255.65267659239012,
  -294.66802229497216,
  1072.5084830289147,
  245.1860314026046,
  620.8505078309297,
  801.692292927904,
  478.0779407972593,
  -223.07386394587525,
  825.4987584383435,
  550.9106320511595,
  -108.31043605684147,
  1088.6526723539757,
  200.82112388962594,
  -267.02709147676643,
  1212.0715348510134,
  30.10986608464941,
  67.05039238991398,
  1156.0321282799127,
  311.24144429146037,
  -29.426282630156038,
  42365.33722909823,
  -551.3084350935115,
  724.9090301941424,
  71130.0792699975,
  -216.90092514563315,
  -71.76532629851863,
  76984.50820919492,
  83.16041912160486,
  368.40821634918296,
  58044.335452059255,
  660.8174790147469,
  249.66948846935574,
  20405.587080257857,
  627.8179762125471,
  -144.6373992568884,
  23714.272445911916,
  445.08259756116917,
  168.72493397612573,
  60288.097464389655,
  -131.3249802102244,
  208.3223208726287,
  77441.17648868031,
  -168.6263129967379,
  -171.8600017309567,
  69652.67196076416,
  -133.7520439622122,
  -32.01452015611957,
  99.56202865376133,
  -323.5017377303302,
  0.9612558322779137,
  121.03341359234793,
  -358.73442319486753,
  14.204892295142159,
  125.40344052220455,
  -258.4474100642694,
  -14.427717642432718,
  111.2655859398981,
  1.390885887637097,
  -42.49024365848952,
  83.17021648556864,
  27.069046544153565,
  -43.78005790730627,
  85.63997814814901,
  -348.7489791527238,
  9.760629602615516,
  112.94043766666914,
  21.53654161223068,
  123.51888474253549,
  125.74431965834043,
  706.012803235855,
  83.66513142317157,
  119.93060582155245,
  134.7492055677982,
  146.42922018829475,
  357.19160795370044,
  126.42352597506851,
  157.19241406030758,
  434.22296835192867,
  93.69177108494087,
  167.603097662002,
  449.9010031105895,
  38.92849122689891,
  172.54124656709243,
  399.17962790808804,
  -18.523085431926518,
  168.8239730539764,
  298.38386945338027,
  -56.10863891416366,
  158.44959046455656,
  307.2444576861428,
  -66.77340158296488,
  146.89129521614356,
  405.1883743092872,
  -61.0956958545931,
  138.53713374195908,
  451.1239509392007,
  -54.458345195961996,
  134.74976141324726,
  430.26650335979645,
  722.2208486452339,
  808.3367199410767,
  357.19160795370044,
  783.3820370580419,
  376.1963081533345,
  434.22296835192867,
  710.3015613702366,
  854.0371299324826,
  449.9010031105895,
  545.7384926321637,
  1205.0629019947119,
  399.17962790808804,
  783.0239433263,
  382.88629834510004,
  298.38386945338027,
  203.45356245830155,
  -736.723782277959,
  307.2444576861428,
  -12.844828577558815,
  -114.22882213420678,
  405.1883743092872,
  589.8968363787519,
  -679.4176424266195,
  451.1239509392007,
  585.5454423533024,
  1151.2078066893757,
  430.26650335979645,
  -449.34858885161646,
  48.8323360615443,
  540.9194752632187,
  -473.2465517006267,
  7.124171190392659,
  657.5732882800759,
  676.399745947152,
  -12.822994164733203,
  681.3155995381629,
  -234.92067471308263,
  64.14510247368392,
  604.5047813435701,
  265.3560691823727,
  -20.876595400809173,
  451.8629287411822,
  -406.4511071117422,
  -0.1371502339653503,
  465.2811183925209,
  999.1165957988695,
  37.76791578979467,
  613.6042335086045,
  976.7558062413408,
  42.311953609602654,
  683.1675923705712,
  575.2757865056832,
  69.31790547820277,
  651.5817450304963,
  373.28062011317184,
  5.528967969112178,
  415.6971299461169,
  527.2615155020646,
  9.060080792148966,
  505.3456959268135,
  413.7144562053986,
  17.298425460654222,
  523.5916846545654,
  383.42544852199524,
  5.539334850573309,
  464.56249799648174,
  335.76234365265515,
  17.319302067299752,
  347.25708945005465,
  424.9548685685308,
  5.814286532636858,
  357.56898092783865,
  496.064424463665,
  7.40336144321026,
  471.555435618567,
  539.2830137077888,
  10.4381171733189,
  525.0149429033802,
  223.09003522567266,
  8.810419304481023,
  500.7411892549355,
  217.860527346291,
  -10.33239689893665,
  1095.1823151913745,
  1514.6192758575116,
  56.9998148831218,
  1331.3675495158272,
  -846.42445998841,
  217.96638645030788,
  1379.4378457442501,
  -1000.8257607825799,
  177.2041143411761,
  1223.921445338879,
  852.1219007001841,
  -0.9192439291396113,
  914.872381341255,
  60.69978060729852,
  -7.695905736542045,
  942.0397596296391,
  -814.778063517145,
  57.52219389799386,
  1242.3448143333605,
  -10.055948695392317,
  286.8437343351885,
  1383.1875162417448,
  542.2689654240701,
  290.6045239517845,
  1319.236664037077,
  23.973643270461757,
  -99.23502413600977,
  147.80342398084156,
  24.145149200344697,
  -165.9398320338983,
  179.67846966286703,
  29.269465577856813,
  -938.2819507707677,
  186.16593232162325,
  26.187710914157893,
  1178.9358165244262,
  165.17777706541574,
  47.08190187166118,
  948.5390542379781,
  123.46918736001943,
  27.142239797084812,
  1304.9377949098168,
  127.13563766323152,
  28.63411224756482,
  -887.5539678895962,
  167.6641548866016,
  47.342749448915455,
  885.994523620392,
  186.6719796989796,
  27.123167277656137,
  -735.6913202938204,
  178.0413117350882,
  323.356995536689,
  -204.24831523576955,
  77445.44210852681,
  -302.9452331218682,
  1163.4046422054926,
  130032.88323462234,
  -160.63329096209793,
  -281.01141687484727,
  140735.89724841775,
  69.49550989456083,
  517.0483281151728,
  106109.64479088616,
  525.7815548035503,
  301.76824035202185,
  37298.8255856342,
  576.1066230211345,
  -413.13264254468925,
  43347.7342330231,
  430.52139775843114,
  155.01114511947083,
  110211.67019951402,
  -22.347674707640977,
  226.80346661796372,
  141570.7740648845,
  -126.33422904799266,
  -462.48877389628285,
  127331.900559961,
  120.17947598604559,
  5.884523064699087,
  146.13136818417703,
  171.62726092719944,
  8.740083206119658,
  426.7764039206408,
  119.39135161356343,
  3.2849228215389186,
  483.89551232500327,
  134.0610762471934,
  27.579052448383802,
  299.1045118452035,
  169.10336931217526,
  12.406102060982802,
  -68.12033122346506,
  129.07004253731577,
  20.895173167069277,
  -35.838931954721,
  155.7365683678295,
  27.017090274306096,
  320.9959186667644,
  163.57260942891716,
  19.8614114418128,
  488.3510254470629,
  142.56260203019608,
  31.696385293507355,
  412.36198551537336,
  138.8722113919,
  996.333121245495,
  2652.7148770679178,
  -360.01418428863667,
  -756.280986451736,
  4588.963369521148,
  -1107.2889034760353,
  871.9150374129741,
  4983.044053143409,
  57.52369488860569,
  -1803.8990784131213,
  3708.1193242630256,
  1921.3910094655412,
  1816.4877123116205,
  1174.532557202675,
  1633.3293752371765,
  657.7721825719243,
  1397.2509477288518,
  615.3062363244669,
  1578.6229545337046,
  3859.1542547213394,
  -1167.9840235303056,
  1694.9843688591604,
  5013.783882704459,
  -1127.20155756578,
  577.7754763806606,
  4489.5142706495135,
  458.04568002030015,
  2626.6681370050524,
  20065237.34015256,
  12.073700286650137,
  -682.0208903543756,
  33673275.32087155,
  -326.30627784356284,
  2391.7842872324236,
  36442891.37537131,
  73.05604088534307,
  -2659.7765585945294,
  27482665.350259926,
  442.09410210265236,
  -3318.5021013813102,
  9676508.192238502,
  965.3238287048165,
  1987.51268460853,
  11241782.654218761,
  642.1637281868447,
  3725.9494754823777,
  28544145.36075586,
  -70.46180711615966,
  3945.6234659494035,
  36658932.22437287,
  -311.70829746077527,
  1836.490150419471,
  32974342.76140505,
  26.401783687735307,
  963.765836079436,
  4813098.799875263,
  -17.5360143116596,
  -3268.9077389867603,
  8077352.212326997,
  -132.8055745869757,
  663.2883188750641,
  8741719.013029026,
  26.421573683130347,
  3787.1721333001387,
  6592368.13524265,
  248.81200288066006,
  2944.4908854949063,
  2321083.0794485686,
  204.86389515335478,
  146.11982240218055,
  2696556.2013771012,
  85.7250429298131,
  2370.0324977275377,
  6846992.626401484,
  -143.28572324816585,
  2651.0526500871183,
  8793542.213374402,
  -130.5895439343828,
  -47.07726696339557,
  7909694.465079029,
  28.8159159462708,
  -36.106885531178506,
  54.47631619244204,
  -68.2460494457606,
  89.33618919772385,
  101.29999560266637,
  -16.477837373225995,
  -43.14770640824429,
  110.82992301829043,
  8.196861737652947,
  30.051468634092043,
  79.99882514529662,
  64.74341716859067,
  10.305672750725613,
  18.72990485887523,
  51.56200360751512,
  -55.266053167778836,
  24.115832624554685,
  40.58176165978879,
  -3.1550967844758446,
  83.65125467130511,
  -15.323310000563502,
  3.4297970672121068,
  111.57329450707485,
  -8.798650247950796,
  -59.79306774394064,
  98.89504978019022,
  297.22357987092886,
  113.5790425547548,
  -715.9371605789753,
  134.41917572842044,
  216.52451759199457,
  269.47341450278583,
  290.0207865608216,
  0.3622081375896471,
  470.03200736439146,
  288.6538561002503,
  231.72185567335,
  -178.81255735375146,
  97.9075948214156,
  1.0771702701509867,
  -1468.2251523173518,
  259.1469359019531,
  114.08760984791904,
  -1354.8775845102798,
  278.72152067320934,
  302.9559390316215,
  -101.94669108687003,
  111.70262520302028,
  166.0003633684081,
  485.67635944199594,
  205.65640575972904,
  330.94894144274423,
  218.86100907423616,
  479.6519454409607,
  449.7682401838593,
  2144.212467477306,
  -70.9943774400133,
  -289.0458197899428,
  3419.8178966660807,
  -623.0859301225736,
  397.31982655604077,
  3679.4392528743783,
  84.14330603348685,
  -730.6689771208676,
  2839.5156003548004,
  1327.8280400759038,
  795.5042128492126,
  1170.3821972923402,
  1383.1497310852342,
  307.0479570642615,
  1317.1096391690905,
  790.7333863538445,
  695.2323808202626,
  2939.0177965040516,
  -401.2409183766209,
  744.2845073348766,
  3699.690730736464,
  -611.3728550899256,
  273.3253646087185,
  3354.300577508425,
  228.2832773085602,
  190.17582134162012,
  209867.9051473047,
  -253.95438137091207,
  -455.99328485757303,
  352415.63726731815,
  -1520.1808693658259,
  144.3042734224332,
  381428.0847613294,
  292.41445222316264,
  621.2031356753823,
  287567.3900034165,
  2786.666400851309,
  492.5575930772583,
  101043.26916800498,
  2262.5302250585437,
  65.35221175416726,
  117439.9256894524,
  897.9525539515776,
  404.85953264592246,
  298686.66880035354,
  -1675.1205982198453,
  447.7606771480267,
  383691.16876462876,
  -1504.263137742917,
  35.85832607136535,
  345094.1371805348,
  -282.58592356598126,
  141.77258639546685,
  141.64494798163983,
  -260.7323665404537,
  77.28628303399354,
  172.19186676024756,
  -1.9391917941887584,
  -64.1185475785006,
  178.40901847488894,
  369.70850282040084,
  289.9379075248438,
  158.29536968769008,
  -36.521254106372496,
  -58.05107187761172,
  118.3246378866853,
  -274.55496131932796,
  204.59391479347335,
  121.83831942726354,
  -279.8942541152304,
  124.86254745917076,
  160.6781484329932,
  254.9062057871058,
  352.46796444670065,
  178.89398054485545,
  267.2039385524363,
  348.0205956479578,
  170.62292374612616,
  247.7943915701576,
  256.4987993965706,
  296588078.065036,
  -140.07203160247082,
  -618.8777183780865,
  497717611.3783232,
  -991.5107136596057,
  194.355816240629,
  538653092.6936902,
  201.2393960620122,
  840.4189928372946,
  406219153.18193364,
  1874.5292572256924,
  666.1406405818389,
  143040575.61107096,
  1590.703337582976,
  87.39808621106785,
  166175646.40462428,
  694.815571929063,
  547.3345540334851,
  421908040.8404578,
  -1026.6366056615109,
  605.4534800584285,
  541846219.81443,
  -976.7183110912636,
  47.442206709920455,
  487387247.83126837,
  140.69851352293483,
  212.1358603389402,
  -66.89441607786371,
  129.79846525082374,
  10.019211055087084,
  725.1110672206842,
  141.12913816070824,
  349.99330536861294,
  886.3063185055134,
  141.27490627213658,
  334.7731151104988,
  364.80952715781495,
  132.11820518957526,
  26.041005745923627,
  -671.5319443761684,
  141.17654463642535,
  294.2029506281176,
  -580.4309378598676,
  140.86622256716552,
  341.2390568429977,
  426.58904231758646,
  128.4534513422855,
  91.76991366783946,
  898.8801764906358,
  139.9452228514352,
  128.062608547891,
  684.4322845528459,
  283.9606171238318,
  475.26807357305734,
  894.0054325507847,
  -18.975135176260153,
  108.14857593949517,
  1086.8051880302583,
  414.26801542411124,
  466.2065158382436,
  1126.0453267509295,
  657.2464717391108,
  403.1970246949571,
  999.0961376665077,
  -175.0054186788322,
  166.80729168233063,
  746.817098545673,
  574.8346516395336,
  119.13101144680184,
  768.9940305880184,
  762.4809728967641,
  321.38858371451425,
  1014.1352701821528,
  601.6892648498792,
  425.3146682023172,
  1129.106210540356,
  -158.8512633624527,
  395.0504678808241,
  1076.9026563976515,
  -44.72717464016,
  24.762014189908232,
  134.65641352429265,
  216.49146143623003,
  25.130696763297195,
  164.06134147027612,
  -17.31139784766171,
  3.0584930706367643,
  170.0460661334492,
  -109.40130561767168,
  50.04251554034594,
  150.68436233592604,
  283.78798641175706,
  51.9877816933316,
  112.20792885092673,
  -52.86003749909142,
  11.140393731075669,
  115.59025206573789,
  -118.16859741859128,
  46.339419646086775,
  152.9780613444796,
  249.00864272369654,
  25.487323221314885,
  170.51289798733447,
  -93.04909603420467,
  28.090734712241318,
  162.55105309664475,
  -358.95883136637224,
  3.310412020817182,
  328.14747771651054,
  -643.7726565529568,
  99.03464532096864,
  653.2789688134621,
  594.6100646178031,
  36.065995123496364,
  719.4523142172192,
  17.999905523062665,
  31.701431765919267,
  505.369163344337,
  -687.201709815941,
  153.09567736500304,
  79.93366443575152,
  1028.0043617816852,
  28.69346707233602,
  117.33215057465715,
  500.9992443910821,
  152.19736763638076,
  530.7306871048633,
  -690.4914459124911,
  179.2244156649097,
  724.6140931212209,
  1056.9940885547303,
  177.05834682132183,
  636.5796484884063,
  116.88842586156215,
  295.3921884642991,
  -1086.0709818497971,
  444.2358245511062,
  18.964858658812744,
  440.72347161834085,
  -240.07106556508472,
  149.71976727777002,
  751.4688146456031,
  246.46507999759913,
  182.6837168374432,
  -253.85049856799043,
  284.3617944903285,
  146.91043254582448,
  -2251.665468291692,
  -258.7483548020357,
  224.17940588430528,
  -2076.0448262790133,
  404.83090205694145,
  43.53160821354308,
  -134.75457931873694,
  145.15799012869655,
  273.25927791408697,
  775.7081627753995,
  -104.3259881027509,
  2.468639675274602,
  362.3046461672556,
  -4.850232108503729,
  27.00797211376854,
  23.770132658673013,
  22.192807743601904,
  29.09637205625625,
  90.30080721925077,
  -19.78480478115511,
  43.19503765530884,
  103.8416589306258,
  16.221544635089142,
  0.3081750870986468,
  60.034470670969895,
  18.025427874675884,
  21.85064324710809,
  -27.021109915544137,
  -15.515308621615382,
  16.665166452178813,
  -19.368370705413724,
  36.05137186668464,
  21.014539222423643,
  65.22412264217432,
  10.494305475554098,
  10.075184164250777,
  104.89789815020173,
  -5.384413048444948,
  0.599416177515689,
  86.88367576212647,
  577.3232955094907,
  707.3843510512145,
  1085.944601192572,
  466.88445511970383,
  1170.0374143523266,
  1320.137645161898,
  276.62293675479566,
  1312.4371872199704,
  1367.8024749741487,
  89.11029392337224,
  870.5564719776147,
  1213.5978342722906,
  42.69239764038775,
  -36.13939626424411,
  907.1555571312539,
  204.71371035397596,
  -784.0479621289455,
  934.0937822756871,
  462.5539908852696,
  -732.7930673770915,
  1231.8658046529479,
  604.1549846813966,
  87.0436651399244,
  1371.5205175105586,
  527.8859138318404,
  981.9258519606116,
  1308.109082053634,
  655.2829110449657,
  523.4243237333151,
  73.80433670832258,
  144.88663225741013,
  461.84783152333785,
  559.4116183226517,
  662.679775977241,
  496.5561586446935,
  658.2462721681704,
  548.633100307374,
  310.3042569140653,
  338.4976788096437,
  161.201495196842,
  434.5041551347505,
  -296.9208573346428,
  617.3626394014027,
  214.63495714078414,
  -241.06352672316524,
  345.34491569375655,
  5.893895221322282,
  376.3769398107687,
  206.309218725139,
  349.70568091319626,
  665.9557604536931,
  501.9226042292256,
  8.345930645667522,
  534.4699815697875,
  627.3623177801733,
  935.9450502971456,
  12967948.228889694,
  272.5472486234764,
  17.00023328617405,
  21762117.90790296,
  95.18086926345643,
  870.7091533714073,
  23551977.222192094,
  73.48437525093993,
  -532.2953655491792,
  17761447.526523445,
  459.6759934606629,
  -715.2477126483413,
  6254251.000419726,
  595.2088845694136,
  758.4280381550786,
  7265806.761241705,
  673.2037202278726,
  -839.9668880501561,
  18447427.043659452,
  298.71020200566693,
  -778.9553293020991,
  23691593.22608698,
  139.1679913468871,
  716.4835175617803,
  21310434.01851021,
  378.0464893884626,
  -1679.5083994682916,
  21205.611294563336,
  -670.9780801811705,
  1241.0556442483153,
  36376.37596751205,
  -150.6043907715669,
  -1843.4327000823114,
  39464.05057988234,
  92.60004066187113,
  -139.2104532952631,
  29474.84562351776,
  705.5370915283349,
  -598.9318177161912,
  9623.856057157676,
  595.7584442789628,
  -2125.5718926337813,
  11368.884293037443,
  501.84519110816194,
  -912.3252799716847,
  30658.22440796043,
  -99.90814860402645,
  -759.0158664668563,
  39704.901236280464,
  -59.69512202456394,
  -2230.969787456531,
  35597.17904015547,
  181.35240740450377,
  302.3639840155626,
  -55.79917522059663,
  191.03164944189865,
  273.5852681681583,
  520.9135386258474,
  100.76711058060985,
  74.58166495632398,
  638.2906941986338,
  146.3540857971984,
  291.7183645638762,
  258.55363916239423,
  202.75300411547073,
  188.61722078894044,
  -496.07661924288453,
  29.82451185833817,
  293.9060490415494,
  -429.7398200538899,
  94.53763096996222,
  145.042785209038,
  303.5394790324941,
  205.84355524570512,
  123.94109651648171,
  647.4465699028252,
  -4.197519817110475,
  235.84967376991102,
  491.2925680100476,
  621.1749838731245,
  79.70692327037132,
  536.5914852938378,
  105.2594357657739,
  240.09532251916968,
  680.1294543774771,
  126.67460299561887,
  201.109328872523,
  709.3434427693094,
  656.8759605415113,
  162.62643851741444,
  614.8307255063829,
  59.70196125361008,
  323.85588348051533,
  427.0108767326025,
  194.44245949752212,
  97.9734026282794,
  443.52143598070825,
  657.0738922495611,
  325.86232856331503,
  626.027246646708,
  74.98150015319521,
  259.71553963931876,
  711.6222477483025,
  247.9224544360065,
  41.83179419680609,
  672.7570939935335,
  85.77467266228403,
  3038.722584472626,
  21515.20200410919,
  -79.12351970159807,
  -1011.6702137619889,
  36603.074564042996,
  -242.78451632310373,
  2751.1851804815583,
  39673.878314697366,
  22.035948613685377,
  -3432.776352497662,
  29739.2537518741,
  124.0828802314567,
  -4239.1673951294515,
  9996.728755762526,
  423.9434958326205,
  2256.288629533894,
  11732.222266078941,
  195.23272172609427,
  4384.428143316158,
  30916.166628364594,
  -213.13482672816116,
  4653.346117048218,
  39913.41297811424,
  -247.29586305806657,
  2071.4116042854157,
  35828.13512015252,
  594.1126612667067,
  49.357002315137095,
  832.3285660393482,
  -527.4901556705091,
  460.4788648509166,
  1259.2578264506176,
  902.9805879256244,
  390.5857379084448,
  1346.149863013576,
  908.3828679032069,
  318.13899376616826,
  1065.0378705692033,
  -552.1396005187936,
  465.64864702879277,
  506.3996953221894,
  974.4596117456701,
  421.23901869402414,
  555.5075438849822,
  975.3416499862813,
  460.59274495400246,
  1098.3400171728852,
  -542.3326510110738,
  464.23618372337,
  1352.9277805953425,
  742.5061439626531,
  142.62506280949805,
  1237.3299951855095,
  90.76785293333268,
  -3287.3632407217633,
  29359.603767942153,
  -104.0338535236547,
  1994.3269969207988,
  50307.59784104245,
  -27.067718357072522,
  -3583.81192847715,
  54571.10010173786,
  19.003101270502682,
  -501.81342788140876,
  40777.87275084277,
  139.3724388078313,
  -1333.195930080474,
  13367.361761718003,
  133.72133916590602,
  -4094.046183453159,
  15776.920009482776,
  115.32791188325649,
  -1899.9519283599816,
  42411.89794977952,
  -2.3009213128764046,
  -1622.699719359754,
  54903.66989841572,
  -9.900697563628114,
  -4284.652868949801,
  49231.67233775197,
  10.98226262545085,
  73.10034638377563,
  -52.42651701847939,
  128.25964904838548,
  187.2306104188095,
  89.50785415843224,
  73.11858535414041,
  80.42524472721185,
  118.39546555795106,
  72.73976379514511,
  3.3304402499936714,
  24.938638917760567,
  113.5319089510231,
  175.81335770794846,
  -160.78289734499342,
  105.3039458308331,
  159.70125164134294,
  -144.45679311194888,
  94.14169522485764,
  32.223910096975295,
  36.010073170080354,
  86.22229592825606,
  113.32839057936667,
  120.6488118592334,
  124.19921514773661,
  187.71202688234558,
  82.21785735922393,
  1774.6204614871037,
  202.78778246204402,
  -84.87345891560469,
  -884.1535178985887,
  189.15993703151207,
  882.685780606119,
  -525.0639834002197,
  8.251489957443283,
  1079.6111277616653,
  1244.5210342976256,
  60.78151297988047,
  442.5207925433719,
  -222.06839999001602,
  66.09326429378443,
  -823.5332780750599,
  -419.66683995876144,
  2.343784694720341,
  -712.2390731189702,
  327.49956853806935,
  6.275617418674344,
  517.9941850469903,
  705.4341716633432,
  2.6395134479898843,
  1094.9720725107727,
  -446.1340904027775,
  3.470132437272838,
  832.9902508998849,
  8.157933449147436,
  1388.0465382080904,
  3814284.228357453,
  -156.01495299407824,
  -310.4216732820938,
  6401462.771895529,
  -339.1673025058373,
  1267.4722718045823,
  6928025.913488245,
  17.4942964845279,
  -1325.674271765536,
  5224495.650693164,
  95.49676169527908,
  -1663.8216120771942,
  1839165.0242374942,
  464.08931404363966,
  1059.9452240261267,
  2136757.117125632,
  148.66422614674488,
  1952.346898093594,
  5426305.662646448,
  48.41952673536359,
  -1781.5711871476426,
  6969099.891225264,
  -353.44527078402257,
  982.4199651039974,
  6268580.770552355,
  52.23837440972491,
  -862.5994485858826,
  185.89261241437325,
  -105.29157371240515,
  402.6184389747542,
  547.662307543079,
  -182.36780488028214,
  1331.9380671112535,
  621.2925514533044,
  12.213520670549904,
  -195.32679696785527,
  383.08493901264785,
  89.19375779617245,
  -394.4827424813649,
  -90.29175611404234,
  252.65531409095826,
  1209.7125148361627,
  -48.67893391985943,
  64.55343063883333,
  -530.2479605539751,
  411.3043855137841,
  -9.419749599753658,
  -463.8327717773311,
  627.0359975099205,
  -193.90599705883918,
  1164.0530806156062,
  529.0811851717289,
  -237.50182022539417,
  277.87095651728794,
  150.07488857811688,
  172.46880357192896,
  200.18738562616633,
  173.47766468439173,
  -795.0154477795345,
  115.24820806236295,
  178.24078369652557,
  142.68798423435453,
  207.7188802358387,
  162.83120269561928,
  -216.6566788184531,
  275.72517903602,
  132.20860229776963,
  -293.67042547579126,
  1.5151175893267919,
  134.90052363356372,
  630.6278912761575,
  74.46082635523716,
  164.6567104625817,
  -467.0377644549786,
  281.61499647940593,
  178.6123255474637,
  496.99087358730065,
  167.49759914633242,
  172.27565729539444,
  117.89998188463926,
  1177.8794533502878,
  8644.65025898538,
  -343.797186198596,
  -875.2436768068461,
  15798.40782465777,
  -1012.3306343517002,
  1032.1282325855636,
  17254.397426682568,
  52.88227952813608,
  -2102.489838258207,
  12543.998704390899,
  1744.6063371452892,
  2138.6604683079377,
  3183.28618542003,
  1483.9806290879653,
  781.267734258461,
  4006.152350300723,
  551.9137888015878,
  1860.0106309602713,
  13102.019681893646,
  -1068.698201027983,
  1996.3237589672292,
  17367.970291501802,
  -1033.1602673377934,
  687.5545277423424,
  15430.978361845962,
  289.7338339029858,
  89.7544670015616,
  87.95210368413488,
  192.68043452208457,
  190.37670037364592,
  145.43565097460794,
  375.72604460733476,
  66.22898757514845,
  157.13515943209964,
  179.23293111093255,
  202.7772566091202,
  119.28506104336752,
  298.40012469715816,
  80.49878067168474,
  44.06767272442054,
  174.9051674066933,
  272.8851734814541,
  50.67975954290969,
  27.975350549069574,
  289.57293714032943,
  123.76900181923024,
  359.9955854230502,
  20.975665329365867,
  158.0477666997933,
  -64.39856824863938,
  214.86916933458366,
  142.48319574984515,
  -641.6585195157313,
  126.95872876385832,
  -25.369382523761573,
  17.52307133542695,
  199.96890218500022,
  12.147232764669951,
  1018.8130044625077,
  68.83860856010536,
  19.78291251222463,
  -661.5919849852652,
  66.40849035143903,
  -4.9199398135692505,
  -379.67285909167185,
  46.283374048577244,
  -54.01053970823129,
  462.14675411060387,
  282.0055087191365,
  -49.6951637595365,
  -623.577742908014,
  7.805473996262975,
  -1.9934975706418916,
  -593.5689475380191,
  0.8754568627760762,
  20.37852529858384,
  274.69863380918434,
  302.4435546757378,
  10.220313984518366,
  495.8057266088669,
  241.0088087249112,
  1715181.5381138884,
  145.65245455407856,
  -885.1919147311594,
  2878121.9063289384,
  -90.94978493949617,
  161.05981401591197,
  3114812.773799907,
  71.06300057154527,
  992.2413708746246,
  2349073.5417594514,
  464.4520848352266,
  768.026530280336,
  827362.6976844568,
  692.3315149522145,
  23.45517133629187,
  961130.7590135124,
  587.6334254630102,
  615.1785866755883,
  2439787.4239523225,
  206.01058841111657,
  689.9504993403035,
  3133275.5841509183,
  -61.966586792978035,
  -27.9493837172314,
  2818391.2611606107,
  36.60827766368564,
  57.20451035701503,
  6867176.810156941,
  -25.788043898700266,
  -61.1775218027782,
  11524130.699274361,
  -142.46623626860406,
  48.80056933153057,
  12471950.970987275,
  28.64666936825794,
  136.17128375685513,
  9405575.091221474,
  266.6570097657778,
  112.60265347886984,
  3311937.4231920824,
  230.3350334560895,
  34.3360809896609,
  3847606.929963256,
  100.64288429191402,
  96.53584602748818,
  9768835.648702538,
  -144.36113958937256,
  104.39559143997518,
  12545884.6470537,
  -141.36370499923586,
  28.932625315407428,
  11284941.427047897,
  -317.62047098944595,
  312.50248091482945,
  533.7345865974834,
  -145.8924344457962,
  -461.94415321325766,
  648.8389182270198,
  -293.9159059716762,
  454.5542995878782,
  672.2658667169728,
  621.7988865657505,
  -349.3475042801556,
  596.4753060695568,
  -317.2307055205781,
  21.969366223697705,
  445.8609543556257,
  699.7253405245392,
  -130.21318127177307,
  459.1009137838916,
  726.7663794729348,
  311.15850310346104,
  605.4538926460614,
  371.4929132932736,
  -629.2193307598997,
  674.0932600240931,
  210.21084545729198,
  1010.0292246098636,
  642.9269590433739,
  103.6945595503357,
  1587.0939955320719,
  33421.939956752394,
  -62.142284466739255,
  153.24761632878673,
  56165.862145126615,
  -191.17038217197762,
  1485.3052342598787,
  60794.885970932126,
  23.47408044003474,
  -703.8283374419699,
  45819.127981857826,
  147.92105947870425,
  -989.2922255872186,
  16058.63984610936,
  376.79995015235403,
  1310.1109597772167,
  18674.776031000238,
  176.12920425745781,
  -1183.8938325137158,
  47593.242574824195,
  59.57018072276454,
  -1088.6963832424988,
  61155.96787459554,
  -194.7667153398025,
  1244.664158329726,
  54997.69464221762,
  192.69918548535867,
  136.45400601621856,
  896.058257883852,
  289.59500064913055,
  -44.09029190498023,
  1089.3007223311313,
  212.2089554064287,
  175.237063158836,
  1128.630964699841,
  530.6757833705565,
  88.04447712368183,
  1001.3902734590829,
  492.2000222790911,
  190.76302263704497,
  748.5319483701178,
  530.7588294504799,
  89.88062980045287,
  770.7598033333411,
  289.883408554749,
  -44.200762059508946,
  1016.4639390000223,
  235.96436718950628,
  -11.714288776135263,
  1131.6988769250638,
  527.3896815823343,
  64.71618428612749,
  1079.3754523939722,
  1243.3270768204543,
  60.57673714429822,
  -1022.0249610471561,
  -862.7997227572162,
  66.97004715729994,
  587.2585834221823,
  1238.3585066414998,
  12.730506349489954,
  914.7927619216656,
  1485.4720301981904,
  66.42020494313144,
  -144.8415745909515,
  -620.7468053132563,
  44.777416091314876,
  -2250.5937590895423,
  1414.2807993617607,
  33.02429880278212,
  -2065.4847494136425,
  1465.7405530019487,
  43.37639578922972,
  -19.31118467768154,
  -376.87326447457315,
  23.38789805738267,
  940.3417046659473,
  1502.6583961220506,
  59.33000601967012,
  504.60297441837474,
  20.78238090484517,
  309.34379239560667,
  2202.190932108079,
  7.14473404428632,
  -570.917182488164,
  3844.046815235394,
  1.3092032633515664,
  246.85406160628858,
  4178.2103750025935,
  2.0744033993255844,
  896.5221645538354,
  3097.1287499862633,
  10.514740382666385,
  721.271367733821,
  948.7555659012506,
  22.293434687181485,
  139.29952502067943,
  1137.6112325118643,
  22.4542374132312,
  601.8023627472268,
  3225.1999092910905,
  14.797633343759525,
  660.2455828280788,
  4204.276435328969,
  2.5020630503233647,
  99.12069827828859,
  3759.718234120671,
  360.49086759638806,
  441.7356443763907,
  -301.63396068862374,
  364.5876917813187,
  167.54684788384543,
  1086.4539493873835,
  306.2183657299709,
  15.24018380372786,
  1368.9686341825534,
  342.05229724917234,
  552.406842210599,
  454.98078122181676,
  362.3724049678115,
  221.97140002979214,
  -1361.3362742554912,
  325.0377041077305,
  347.83427524772003,
  -1201.6704532382337,
  319.8288731734858,
  251.41508680413054,
  563.2570493689539,
  362.68823725441894,
  214.3487481340179,
  1391.0058809191169,
  347.0890281781168,
  563.9004089385517,
  1015.1593338720123,
  338.49852526458653,
  1072.0704090953418,
  -243.82744329917543,
  175.49944509805556,
  68.97129587450752,
  -17.566376306578647,
  99.24728271257695,
  1000.8603982818287,
  28.48407450336481,
  36.57303020467478,
  -530.627197841434,
  -120.49774813771369,
  225.13041301577817,
  -730.3337892924515,
  -416.5610104037502,
  256.3322651683857,
  878.2969047836104,
  -390.53516667773175,
  347.7612797040451,
  -866.4743843872932,
  -102.848502882342,
  164.81525210754643,
  -799.8755643673244,
  32.076189184286434,
  126.15132366846663,
  832.5112268704737,
  -29.187539246072557,
  153.4571373821369,
  -557.008549493314,
  108.79974265256392,
  -6.82645095528693,
  -444.16943920302333,
  132.2633179462771,
  -107.33753455783753,
  -184.39909873601363,
  137.038811292306,
  -125.35044296427776,
  -96.20908153638692,
  121.58919700648659,
  -72.59912381338725,
  -303.9560929211151,
  90.88704069556987,
  83.48362291006674,
  -538.5273593303034,
  93.58595550210097,
  239.2233552096888,
  -520.4976509759248,
  123.41944734708174,
  242.53736611952002,
  -517.701883319255,
  137.41131838952666,
  16.7971512625366,
  -477.73741430358746,
  131.05818780499547,
  188.64603706893166,
  22.561656198189123,
  -774.9515318164384,
  302.70445955676126,
  89.14463873392125,
  412.7410766197338,
  183.83305105405196,
  91.85069689966599,
  654.4697167658225,
  198.33323277680105,
  5.514001040434273,
  -127.56765225245104,
  300.0250621076296,
  61.038917845398096,
  -1681.6668744327162,
  204.03904544480753,
  66.94086874388769,
  -1545.0516686769756,
  205.3240691801091,
  0.71456272910536,
  -34.9229988310653,
  270.0582349936789,
  3.3034257710925203,
  673.3254930241625,
  239.38833089981253,
  11.305312438586562,
  351.7391132323655,
  68.98672295034538,
  3126.1740301806435,
  115660.73190620811,
  -625.142806944897,
  297.4431140254023,
  195084.19102863906,
  -1197.054621510303,
  2925.362409002797,
  211249.08473345276,
  77.88323489225627,
  -1393.4195077233198,
  158952.6297675345,
  521.129298527449,
  -1956.590386803848,
  55026.80319565906,
  1693.3831286013256,
  2579.7344060657883,
  64162.54432326471,
  456.2777612779987,
  -2340.5057000693782,
  165147.96919430225,
  43.559844165812024,
  -2152.697597473168,
  212510.00945777842,
  -1260.962929233512,
  2450.619186120914,
  191004.86367485177,
  267.4728353325566,
  -931.7312124581317,
  21428944.092649523,
  205.46469724125956,
  511.9905320170708,
  35960846.84952405,
  150.61162207185663,
  1572.423654168895,
  38918495.20668586,
  29.50448457694452,
  -170.31608696387428,
  29349949.50883976,
  169.96913392633093,
  -397.57004211758124,
  10334912.61221868,
  160.0102252227928,
  1432.953852733937,
  12006455.2917398,
  304.91327727646916,
  -552.4897594263126,
  30483494.57336331,
  170.1873247413431,
  -476.70435270467203,
  39149203.308298424,
  180.86388495167319,
  1380.8525358993043,
  35214462.984181255,
  -1365.0818323074304,
  68.54446750739669,
  91.35072732149236,
  -1261.058826849674,
  767.8796127555913,
  111.05127638885531,
  -628.1548474107203,
  1389.1679644124833,
  115.06088872655882,
  226.49132016564948,
  1621.3003906020786,
  102.08904276959723,
  791.3056340282938,
  1577.4620924492376,
  76.3108171877898,
  849.5362927490443,
  1564.2232457668233,
  78.57688716685837,
  364.94578812513515,
  1624.229004525696,
  103.62576239519127,
  -532.4219285981007,
  1436.8962654684944,
  115.37365411950823,
  -1262.085806281636,
  765.8420420860684,
  110.03942183626978,
  451.1441957107231,
  -1206.0734378769414,
  -1009.8281251509368,
  -1773.1595625234904,
  2610.348053302569,
  -45.673511577747014,
  -571.9304813551787,
  -1420.2800823557006,
  150.55889904279073,
  183.35196518811728,
  806.6974161783023,
  -484.2896568629341,
  1558.8863796319768,
  205.96054861839553,
  -1745.8887645550599,
  1220.2726246236884,
  -1788.9630017643851,
  -1634.9861791739143,
  768.487075029865,
  -203.56361405840926,
  -409.0818384555006,
  -614.931376712754,
  -3.2278803638813542,
  165.865792040904,
  -451.53061050464714,
  -1926.6907779424446,
  -95.19417375850725,
  720.9594090189805,
  100.91122245901776,
  258.65599196647275,
  834.937735873163,
  37.2396309689745,
  314.4373219100173,
  679.5585916879518,
  108.66290240302641,
  325.7903815628407,
  230.92821187431514,
  135.4669686006343,
  289.06110986447754,
  830.7506602339569,
  31.688228090919907,
  216.071077880034,
  -116.17184636612006,
  108.05373923535181,
  222.48736591065514,
  538.6524737554029,
  125.70985825575153,
  293.4122710515528,
  77.05239201868545,
  -38.35968395018837,
  326.6759644732143,
  303.24034395740205,
  135.81772383649792,
  311.57229553640434,
  322.44758154388774,
  -2529.237503577581,
  2174.7339620670045,
  -297.24173941614254,
  1872.1292503502148,
  3439.1539192417977,
  -94.13938003751076,
  -2776.275731838854,
  3696.4987192771214,
  64.126970593142,
  -207.96802619195273,
  2863.940151833351,
  465.28062674543673,
  -900.7802019036283,
  1209.44297133654,
  477.2709709050418,
  -3201.466908436305,
  1354.883796162876,
  406.4209109939333,
  -1373.072384174807,
  2962.5698375613633,
  14.259986708967944,
  -1142.031069701335,
  3716.5726168830515,
  -41.7657319499161,
  -3360.3043053442575,
  3374.2111054312504,
  551.8406212868316,
  1049.4339752156347,
  2626157.4337255294,
  104.13886907096128,
  -259.1384903611446,
  4407288.105443407,
  -217.3289512806174,
  956.5384096669941,
  4769797.977222229,
  78.57611857535909,
  -1041.3324619604964,
  3597010.7303418797,
  700.93681435472,
  1661.7945117832876,
  1266396.081520543,
  926.5860064641366,
  796.6507068838712,
  1471271.9319436497,
  701.6590027309683,
  1484.1950783471161,
  3735945.8660894823,
  104.02661319894571,
  1571.0752091032864,
  4798075.160387493,
  -190.7759547105561,
  736.9219356734966,
  4315806.12832871,
  122.67637496152602,
  -807.2509003778557,
  498.83655593534024,
  42.181797262411436,
  -775.2482753541433,
  606.4148351121762,
  405.5488152635555,
  -787.6373684289626,
  628.3100215854785,
  115.07395170148325,
  -804.9725672412571,
  557.4749975957782,
  -399.4730434821686,
  607.7073290431647,
  416.7085073400656,
  -320.66012312553266,
  887.5483392762551,
  429.08277711340634,
  23.560427601053902,
  -765.276420953817,
  565.8665227422804,
  255.08621962595984,
  -823.2805179015447,
  630.0179314840562,
  -17.087209384451455,
  1305.924199042343,
  600.8894271059226,
  154.41660962607403,
  53.588775305418736,
  445.44095131556764,
  245.9977463586508,
  263.6930952409996,
  855.288568773684,
  221.52916010745088,
  7.34344281975288,
  938.704013587904,
  158.61407011221297,
  30.140904720969075,
  668.8394457875078,
  229.6129087157291,
  253.11797181764547,
  132.5526498776186,
  184.00556292667596,
  187.57051165549007,
  179.69567004111377,
  167.99118628329094,
  2.888744849907937,
  700.8091576517443,
  206.16077033322654,
  116.49018800252202,
  945.2107434605261,
  150.66000945641534,
  275.3320116133308,
  834.2380804764641,
  -236.89204589624904,
  51.117617130562564,
  -198.19166853039903,
  927.1166862647423,
  98.36774904114372,
  872.3783947149838,
  868.588980197098,
  65.10690539475686,
  1090.2693235051881,
  -229.68746732538182,
  48.81449595985556,
  385.3514098435749,
  1024.9114312581396,
  234.29433818154342,
  -1015.4926223254934,
  415.25301450673993,
  10.201709960169751,
  -892.3495224801732,
  -148.32234061356985,
  26.631012442081726,
  468.86004816310856,
  853.5042266027259,
  205.106395589569,
  1107.265665351595,
  -152.5879530435153,
  171.37510769561686,
  817.3920494789917,
  44.66529580941113,
  158.1782109755125,
  -33.61347515867399,
  87.94601712652718,
  163.12823952446797,
  135.1718539860506,
  10.003533132091079,
  57.31129337320616,
  169.52438577833445,
  95.04110112817864,
  118.23891071817476,
  58.38751939080794,
  79.58090911676403,
  163.62998460177573,
  -162.46857323457036,
  4.826774206256147,
  0.045317830170660045,
  -143.05391804022835,
  140.4251799233434,
  8.399247395234752,
  71.55343303728323,
  63.4754884872127,
  151.38737286481782,
  172.2040171740655,
  19.21529807479091,
  40.075164118137415,
  126.50274516472989,
  248.29789381045757,
  31.935448720527756,
  -16.398717040884243,
  216.99092793715033,
  1.7437765903449503,
  54.31397882572758,
  -9.445285583736464,
  20.908863067347717,
  68.70598875446379,
  256.0667011422885,
  17.410974129544044,
  22.145144442628276,
  250.5037741922288,
  4.22980741947724,
  -70.38262314975286,
  87.54630785193098,
  48.59587625993562,
  -62.248843898503566,
  247.75004478210954,
  2.6356698668900265,
  27.66101037841109,
  255.59174235230392,
  19.772018719211047,
  69.82862163305055,
  -22.56460506558409,
  15.33514484661422,
  50.68205146199929,
  352.6999831307927,
  -456.82977757118454,
  3367.688202925617,
  -1101.6885211125884,
  1189.6986172687741,
  5937.881323144156,
  -331.0468719443909,
  -549.2454930032497,
  6460.987456372776,
  121.92777515743126,
  411.5450524017946,
  4768.641262309051,
  1007.7984124662522,
  152.36762334929867,
  1405.5361115209055,
  803.0157925485005,
  -708.3072991747902,
  1701.1744437430552,
  550.7128668879116,
  -24.314423898060966,
  4969.126345029405,
  -334.9965019700139,
  62.116929345154745,
  6501.791773980997,
  -240.03033283181338,
  -767.7275426566623,
  5805.871722760706,
  43.056506101558426,
  170.55557703532926,
  829.3414345591665,
  60.39164059824515,
  557.0986492737325,
  1008.1958575527539,
  44.48262347494679,
  88.49438284245039,
  1044.5977313602193,
  82.9115320059056,
  -336.6309502024087,
  926.8308602003883,
  70.99327591295554,
  648.796728839802,
  692.7993290756646,
  497.06946375389225,
  770.163007584433,
  713.3721891103546,
  543.812621497927,
  237.54211997700304,
  940.7822024192645,
  211.4786572701103,
  1126.4369822030985,
  1047.4372194220523,
  79.352357798647,
  -314.2835271396898,
  999.0095825135503,
  -217.07335974010584,
  34.09588244566825,
  396.1952892819781,
  910.7863034561396,
  198.1495489208063,
  481.63812006851856,
  -380.32453163676644,
  189.3430436364066,
  499.02812413990677,
  -56.83651200213876,
  232.23664809755758,
  442.7682079670172,
  843.7357056236375,
  41.5055840670434,
  330.9660161178299,
  -368.56087719884806,
  192.01464670472924,
  340.79413984727336,
  -281.8951082033043,
  207.95454527448345,
  449.4330818488071,
  957.1010420549911,
  188.2116774593467,
  500.3846122486537,
  -432.29346977723253,
  175.13017909850976,
  477.24962728988913,
  24.360931760285496,
  47.99738463754404,
  33.78821061005143,
  -1.0823461764462365,
  18.899477700190406,
  104.34966674938568,
  41.99424870693216,
  14.392027021234721,
  118.71089516668431,
  5.595250830820401,
  25.116374826387556,
  72.24963480238799,
  -4.438271179508337,
  0.03942994838843816,
  -20.080235168289217,
  43.392202835139436,
  11.519721008234955,
  -11.96385237662358,
  -3.9814743673006276,
  0.3547571241363201,
  77.75370344986771,
  3.219164978070207,
  19.197914833350286,
  119.83112696738384,
  42.39983083460055,
  13.552942576204654,
  100.72550732177197,
  193.80498007202218,
  68.32466681191639,
  111.8789806521648,
  170.99633933172834,
  76.05084137201793,
  136.00661939758686,
  -114.98389956492545,
  68.24658906340494,
  140.91726821567315,
  127.63154268047182,
  84.50922264482531,
  125.03040069534941,
  152.50275649120942,
  15.65648030151619,
  93.45931543223693,
  158.45838930377195,
  79.09493799746267,
  96.23461462008497,
  -79.72295266970387,
  79.03678789961303,
  126.91245057388593,
  206.31353833052805,
  61.51996231963884,
  141.30031796658875,
  180.2373942972938,
  22.650279957235412,
  134.76738179947648,
  18.619327502623612,
  195.51340352146852,
  89.29790198842511,
  42.89840072336043,
  113.00853386303679,
  108.55574208798217,
  43.482917198947455,
  -33.017233875953465,
  112.47525077764737,
  21.973635019516436,
  -116.07834809398926,
  99.79490697702201,
  6.881122838372439,
  -125.51438603706421,
  74.59596736334507,
  11.189594438918464,
  -125.49734388300922,
  76.8111144215357,
  33.03054463707845,
  -89.48570799060853,
  101.2970935773218,
  47.12442946781119,
  49.80044967253501,
  112.78098773480018,
  26.821424963509234,
  181.94383932789506,
  107.56662583994911,
  172.91497483652182,
  259.9892839956303,
  169.5556878724156,
  44.87515112220344,
  71.62377936232485,
  313.2971601097754,
  -35.69823361781391,
  246.61721592674323,
  342.5525670810153,
  23.41478459964796,
  -40.970949670504865,
  247.90585296587972,
  145.07078421206924,
  -78.47256080889147,
  59.81971972534252,
  247.20392243951275,
  223.60180897629357,
  76.3536870716547,
  206.3727799715912,
  322.57198135522935,
  259.1182481455081,
  88.42531979824635,
  -91.53136166159626,
  344.8346028706636,
  -26.495295033682396,
  215.0040121968753,
  305.9143474490018,
  229.71201737957267,
  134.440597554558,
  409.53865394691513,
  230.61987883958855,
  137.80228930028684,
  497.85909302419407,
  236.35958117241768,
  176.40482386720922,
  515.8347708078311,
  215.23276082169772,
  122.56336280776023,
  457.68009061875614,
  202.52320132966088,
  232.4679078707458,
  342.1125399767205,
  218.8142839193039,
  119.31391701552268,
  352.27166269187063,
  235.3268494456172,
  165.60933733942946,
  464.56942916495865,
  205.50715860305937,
  269.20082730250147,
  517.236943749256,
  232.48867314615606,
  281.6836235487566,
  493.3228012659735,
  310.7661405376516,
  166.94065865158512,
  539.8930625966851,
  326.76399938657414,
  165.86038508824475,
  656.3255211296392,
  204.30096790525033,
  160.47240256650917,
  680.0227805637071,
  358.6256596490831,
  162.01686760751096,
  603.3577134472825,
  430.8011625808159,
  33.75163238016078,
  451.0055038289599,
  467.59205066643585,
  56.335824355782435,
  464.39823201985956,
  246.5352216200423,
  165.96846502587198,
  612.4398990996698,
  398.5926384133194,
  153.44007706248777,
  681.8712591782172,
  115.09631753097776,
  47.858020947516216,
  650.345347032336,
  72.34441647569312,
  316.31438235321195,
  3251.0620171938012,
  20.086006038186007,
  -173.3007880994832,
  5440.1408364883055,
  -26.938616325546377,
  281.5565990764952,
  5885.679557872966,
  12.884248863933635,
  642.9123424733214,
  4444.27845100845,
  92.55019298782904,
  545.4350587980746,
  1579.86246812519,
  118.80698182041952,
  221.73305325785122,
  1831.6628508077301,
  91.63515082291786,
  478.9844959430587,
  4615.03513256486,
  12.939579838410765,
  511.4915455319289,
  5920.43331497754,
  -22.36096989966603,
  199.38495006418702,
  5327.7059311616695,
  354.4563449758924,
  113.6478813567052,
  -1620.5183643535413,
  404.7748348779549,
  146.81206619135162,
  642.9023353720061,
  420.5924820786077,
  463.737473285449,
  1103.5717071748425,
  355.30265034408575,
  182.83121639575586,
  -386.7798841561157,
  385.5949297428074,
  415.34816561671903,
  -3348.472433158134,
  399.6279109508972,
  348.52359894885365,
  -3088.1208216313494,
  358.3916166442832,
  311.6962774784716,
  -210.2242461203057,
  370.089967998288,
  483.29683504094567,
  1139.5057139956107,
  373.4893907869051,
  17.58999723073356,
  526.6491014340854,
  45.49514157176425,
  448.5678918284532,
  -640.5465707025187,
  80.80363653286071,
  157.56852750811285,
  411.701760030206,
  -16.159725168750235,
  310.9772418442208,
  625.8637041875625,
  16.185557436358536,
  228.2875219787109,
  -66.99024663696426,
  78.94614402443419,
  10.302066391447028,
  -1443.8602386843152,
  -18.490397258483092,
  219.96178544979557,
  -1322.824609441438,
  -5.52011831456479,
  22.83422140684084,
  15.08922512326083,
  53.23609823380467,
  306.045370149594,
  642.5691706959657,
  -18.70448105039643,
  87.74269016294642,
  357.6564509242628,
  39.32944259467905,
  1343.3584773991106,
  543.9987132628196,
  44.99292050910615,
  1161.298945381423,
  661.3165897313856,
  41.98401542297895,
  -759.6067480183394,
  685.1940564615301,
  43.62077962031132,
  -702.4548793774072,
  607.9459850324329,
  33.34003671093795,
  -865.8032219380027,
  454.4352034778493,
  17.036828980520994,
  297.842724922866,
  467.9297775105049,
  51.91136846737162,
  164.65150248082074,
  617.0972367354087,
  29.928995368893013,
  1348.017326601469,
  687.0565919476334,
  51.71179524310217,
  453.8759362629528,
  655.2909390249773,
  433.0544368205369,
  645.8350662073735,
  811.8924192280949,
  699.767767108375,
  325.233284739778,
  986.9838159953321,
  60.11775024582272,
  31.17421357628585,
  1022.6198087944722,
  93.79428839416647,
  367.31905548978966,
  907.330705963499,
  720.6913316970845,
  212.55774129906808,
  678.2231055678845,
  646.7021616292882,
  462.25853554350886,
  698.363120775112,
  725.0771729431269,
  154.4703303132975,
  920.9885174673741,
  368.7939732148511,
  649.0047846691615,
  1025.3995551520338,
  513.4833629964661,
  613.2267550056549,
  977.9908165448246,
  431.5317327372649,
  36.70185082146833,
  387.09579976214087,
  -328.34051605174255,
  137.63628803851697,
  391.06369805207197,
  551.2310139558928,
  108.3070569463102,
  391.8712762512206,
  578.9453786401646,
  134.56271611371395,
  389.2586097101064,
  -327.6964138152128,
  139.22863628840807,
  384.06660329171865,
  365.4849163451015,
  14.846080073111224,
  384.52301367723965,
  540.5101526971713,
  131.98496333630177,
  389.5681212447164,
  -318.95906415857013,
  148.92946816475788,
  391.9342704989236,
  121.8585751488933,
  12.773425750485472,
  390.8598998769483,
  338.76697714500125,
  153.0671833462465,
  668.9119786264207,
  306.3982569492407,
  109.97343524964779,
  767.6911531571843,
  339.5292084185262,
  154.94353162887464,
  787.7954759124755,
  366.6454970557961,
  219.34904087642747,
  722.7542310523695,
  208.20530894621567,
  0.3474303211630456,
  593.5013947414681,
  288.1237042707167,
  47.54864857375675,
  604.863541105813,
  376.9312733547798,
  230.12617393658016,
  730.4593917350672,
  126.27855750428108,
  127.8162853679603,
  789.3636914597525,
  216.27763587610184,
  2.563870102528327,
  762.6176825088369,
  190.67529399150416,
  -45.93276081825519,
  697.9606132428629,
  188.73977471297937,
  266.7433578097792,
  848.4816622968721,
  207.45171030792258,
  47.06889983775568,
  879.1169026298876,
  190.40448306890636,
  -27.618360234881834,
  780.0061694755743,
  206.09646840870738,
  -60.04815456801691,
  583.0489403112028,
  202.50096743553667,
  667.3798580345376,
  600.3627334097043,
  188.84429580693475,
  162.13406285602883,
  791.7473980756187,
  195.4072362679929,
  -210.45048475211473,
  881.5065708007371,
  195.58256795336604,
  -213.181052672136,
  840.7506387490275,
  362.6902443871048,
  -125.69490313022533,
  54967.75251019606,
  -309.00416183647394,
  791.1609166521656,
  92151.56116146523,
  -181.93737781852133,
  -177.15583559807226,
  99719.50545688238,
  76.7068107215512,
  357.85249217032384,
  75235.78998945536,
  579.3081631089176,
  213.5316684738009,
  26580.668544584645,
  651.0106569750769,
  -265.7280965748704,
  30857.76316788441,
  482.39840360435926,
  115.14772090419115,
  78136.27201730921,
  -16.910815374001402,
  163.27631041474734,
  100309.83461392281,
  -147.87814216825177,
  -298.81577135774444,
  90241.73591052403,
  559.4795904287474,
  -120.75279131041813,
  26361.095034093283,
  325.90249881620196,
  95.84614634268567,
  44252.71246824295,
  -55.09006657103515,
  -132.90997356598453,
  47894.15666150574,
  65.56972436661766,
  -6.51907007834361,
  36113.403521931235,
  386.84041069967077,
  -40.613566093332594,
  12702.170227678442,
  494.9574727658448,
  234.01659203148654,
  14760.166530516182,
  637.9142010278395,
  -63.855888458425326,
  37509.01942840499,
  330.8532264524912,
  -52.485942242453646,
  48178.20350396471,
  209.38816138418815,
  226.19992658338515,
  43333.767798631954,
  228.41217332990126,
  146.4462693687669,
  30.79237999600866,
  305.58173671707897,
  129.92792709185707,
  37.4330145130973,
  190.58434930502096,
  114.35516078699004,
  38.78456923367151,
  40.772113698485775,
  113.34787644113467,
  34.41203688862828,
  5.661272527296219,
  114.7218739261854,
  25.722747366670717,
  100.1380713795843,
  112.47391855641015,
  26.4865911798399,
  274.1635211922003,
  121.25866636963877,
  34.930032268042,
  270.01055343698226,
  142.32315679060946,
  38.88999577062075,
  129.31552221109578,
  150.35600476949702,
  37.091939944810036,
  59.631910603957095,
  126.10986272967341,
  -976.438955665928,
  -195.69594518705907,
  101.97327141290529,
  632.3704626182445,
  598.947373790668,
  95.28265720954248,
  959.8081431878898,
  -4.164321333785949,
  122.19064758174284,
  -99.51400447064447,
  -529.1229220328242,
  24.85267048288864,
  -2204.645793481086,
  1074.085125492973,
  8.522879005912642,
  -2019.5913205143315,
  -149.75673198504683,
  106.82917710243711,
  25.979401751903787,
  -597.2516879076322,
  1.5094404400048944,
  985.3495587174688,
  1170.3383859670007,
  34.537088217935896,
  549.7392055620567,
  37.38662998837228,
  2675.335216490685,
  3142788.688279997,
  8.582263779250113,
  192.31879713783428,
  5273858.891144301,
  -9.320534344238325,
  2499.0658690834143,
  5707591.237826595,
  5.186602843108638,
  -1291.894363150499,
  4304385.9616435515,
  32.42206722251653,
  -1786.2370847123502,
  1515874.421571154,
  55.634506042114076,
  2195.6789327794195,
  1761002.3209756748,
  44.80464229127143,
  -2123.23203217627,
  4470617.744984332,
  18.717848551434223,
  -1958.3769730504214,
  5741424.051679781,
  -7.467234448000394,
  2082.343581834403,
  5164403.409509024,
  50.39171858076901,
  461.0521249734031,
  819.0773078938303,
  37.2633895318871,
  506.43598475988324,
  995.7181860483881,
  21.12596540662051,
  491.1870770844028,
  1031.6695416156622,
  7.157574682192163,
  395.6847539086532,
  915.3601812375123,
  2.470004038843136,
  236.18832731709338,
  684.225079953441,
  12.013915765669257,
  77.64005066190097,
  704.5433253837413,
  33.36762961187969,
  11.54403201011769,
  929.1388583299173,
  55.054853353707024,
  95.05701020946015,
  1034.473887498512,
  62.45467464814679,
  290.4812498981691,
  986.645602531947,
  342.744587999847,
  0.9603969632920553,
  -26.635476781440953,
  -65.48609694028826,
  20.81435887199796,
  261.9117337353119,
  -122.18762113109304,
  10.361942562810889,
  320.6391555620767,
  329.04203868365585,
  34.35491981147675,
  130.6449603071265,
  -103.068879889487,
  7.495194609918226,
  -246.9199013760805,
  -128.3909272710541,
  0.04028326707618746,
  -213.7295487082339,
  214.81336260835616,
  52.36300410059222,
  153.1527675664733,
  -129.63584942512563,
  0.006598535541254336,
  325.22012340074656,
  -99.88145143023678,
  8.630193342035863,
  247.09144585405062,
  330.29394523255513,
  237.0473367372899,
  316.13510129235556,
  333.7293444003296,
  228.33676935090398,
  384.3122823344656,
  333.18240060637316,
  230.65238934323736,
  398.18824413236086,
  284.52345228838453,
  240.718016282877,
  353.29691205658366,
  303.99313295043385,
  249.8239815151742,
  264.086872964486,
  334.07069605748705,
  222.36623926278773,
  271.92900277968965,
  278.68153288256264,
  217.83792899429517,
  358.61499795189786,
  294.60823131314527,
  200.3285472196786,
  399.27062324503976,
  333.7956066834705,
  227.96109455018788,
  380.81058343338304,
  345.00787297890366,
  103.56062768955408,
  -199.64916098748733,
  270.596738001077,
  69.89580979725436,
  137.4540185729743,
  -116.26636621678884,
  112.50850558964649,
  206.0639371708235,
  302.8307332624971,
  93.023728000273,
  -15.901983774221751,
  341.51672409522354,
  112.79353093388983,
  -457.002471752515,
  -116.19264753584227,
  112.9141037011584,
  -418.22693344449686,
  192.61485392381402,
  23.168137751669583,
  10.39337835550269,
  315.5923494819496,
  54.63676269498511,
  211.41577828241927,
  -113.07305480814816,
  111.22114763649398,
  120.13981145301162,
  731.2043918681309,
  13.15944892229129,
  7.184888665735354,
  631.8729179705887,
  -519.0623270683334,
  8.734370053056036,
  496.70125036327613,
  -784.919887281539,
  9.04973282119002,
  496.70044889511087,
  -784.9208775960258,
  8.029475274013265,
  640.8501616177907,
  -491.5919298706657,
  6.0019743855565,
  736.5815091646839,
  111.73614298245889,
  6.180204608629309,
  731.1039282882646,
  430.231607092055,
  8.150340862543134,
  726.060539755597,
  -48.66857932517041,
  9.074332346478176,
  351.022129939243,
  -885.8677718686829,
  8.654785987122342,
  -1255.0894464042449,
  327.0901972773237,
  16.459391208337316,
  -1452.4289994719124,
  341.7300846309147,
  69.48709336819202,
  1157.7129859697775,
  23.732849864855098,
  80.27971280703089,
  -1459.8861722625,
  338.8520210537397,
  45.36357003774969,
  -1236.0400116777464,
  323.1587784872832,
  -24.02333200683415,
  2084.512255083383,
  95.18263237925035,
  -17.923782013960714,
  -1383.540171168952,
  221.02442668128762,
  49.49993752327339,
  -949.3487643440519,
  252.66183551198432,
  81.12157919595847,
  2113.3553573270087,
  330.3826249635088,
  66.76349811913937,
  24.111997572566118,
  54.13512125533373,
  25.66031666334055,
  1.6803316328329352,
  52.50388498359983,
  31.194178760914415,
  36.840659585225666,
  54.021230467852085,
  32.320474361392925,
  56.396617105321454,
  52.361690527701754,
  28.676697407190233,
  -25.12468000961684,
  46.62397725933606,
  21.43562280555893,
  -23.197841882989174,
  7.747883790885279,
  22.07215931653325,
  -28.473492208488615,
  9.57906829300575,
  29.108360223368337,
  -3.5726814567258387,
  51.748069547572555,
  32.40832980885063,
  53.36011246010702,
  52.746385006108916,
  30.909949954008365,
  -0.08834786956663243,
  24.892713135686193,
  18.475427997605195,
  0.9835615846126331,
  105.59862126313253,
  22.45980870785838,
  0.21531438546840864,
  81.32970415796072,
  23.270741540202906,
  -0.029390696067620903,
  52.22851082722234,
  20.647222133176967,
  1.6444347248414135,
  -37.25586437232797,
  15.433648420002429,
  -0.07559238024663606,
  38.67998925791369,
  15.89195470790394,
  1.5970820838171855,
  92.64589717787251,
  20.9580193608252,
  -0.05794963918725338,
  7.868312822396685,
  23.33399746237245,
  0.6271178571703262,
  100.82181993120048,
  22.255163966886023,
  209.73946953529503,
  48.02589272841958,
  74647.58302073868,
  67.7311365724846,
  686.7147605274374,
  125374.341492742,
  -22.49742893247148,
  12.177808455400339,
  135698.65458297994,
  27.14995711727299,
  384.8687547882113,
  102297.57045355656,
  167.75700762296205,
  284.33375081296055,
  35921.459896745604,
  272.03752896611866,
  -49.52231479309174,
  41756.34216910331,
  241.7206671191276,
  215.79873066361327,
  106254.45536169538,
  106.97171984831525,
  249.32547901380644,
  136503.9912511254,
  -10.563175125939011,
  -72.57144540797444,
  122768.92672372746,
  549.657791726867,
  -1613.988997317386,
  6496068.295462815,
  -24.230910754780837,
  518.8719294570178,
  10902351.417170865,
  -63.87321236977499,
  -1733.7013989271456,
  11799153.181822404,
  80.52563127458083,
  -489.1236439787589,
  8897831.716003606,
  522.2204879759015,
  -824.8539072771597,
  3132197.4740182394,
  1008.3251195532323,
  1879.443444893658,
  3639033.3935267366,
  642.3588857258799,
  -1053.7222561118192,
  9241538.976440838,
  218.1484536685668,
  -941.7618084460435,
  11869107.2154534,
  -331.49219697203546,
  1802.4723364821166,
  10676037.032661283,
  383.4222800645322,
  380.61553302946646,
  376.69344861783924,
  620.8529300679297,
  327.703237181258,
  457.9305442102236,
  -310.5407724148055,
  272.8112271043956,
  474.46456362524816,
  401.30973662243514,
  378.5609569437004,
  420.97391793755264,
  -278.7582914715556,
  304.36720720878054,
  314.6749427856051,
  16.838794615442964,
  122.99931672860089,
  324.0192987667081,
  561.4946732708537,
  348.00367777755866,
  427.3107280790472,
  521.2531361175636,
  358.21711706484166,
  475.7542815939272,
  104.5044532060456,
  388.44089101558734,
  453.7580653248428,
  112.91294079783452,
  250.40567203295427,
  351.0331319544987,
  113.32101458332676,
  236.36752707509743,
  426.7363654493092,
  82.93103651479778,
  -68.91139631815179,
  442.1440892638552,
  114.470150498359,
  181.32088160748646,
  392.2972205303624,
  97.30141929410816,
  411.51188697586394,
  293.23931998004616,
  113.65549814160511,
  -17.330186490673356,
  301.94713945017486,
  111.97067201914086,
  -71.45978060813005,
  398.2023678556788,
  112.94890169525665,
  -43.23689126749102,
  443.3459517850766,
  84.4337945153101,
  308.90305075966376,
  422.8481153708344,
  320.84968940857374,
  212.0351749044944,
  385.80768127628824,
  476.81533517133334,
  58.519112830750956,
  650.5329736736385,
  304.678138077977,
  1.6728179237045282,
  704.4119693741711,
  280.1135612718583,
  243.1075613390472,
  530.1033395919201,
  483.1267657976125,
  81.90390508881404,
  183.709526846158,
  272.0791694015732,
  135.78037863135194,
  214.15974606342797,
  274.8667511832714,
  97.24579205513626,
  550.7529443733458,
  482.4178216673722,
  78.99267310623506,
  708.6147410744518,
  286.5447896778486,
  252.79025299096676,
  636.9362210460401,
  32.59103460344589,
  -9.922680773116845,
  -8.51729003224409,
  -41.43158728764489,
  79.72613978943969,
  0.03947517801268674,
  -12.841504334315076,
  -14.954455454861545,
  1.7810160477905974,
  7.239608840104204,
  37.35787603796357,
  -3.8531944413588093,
  54.32777116885318,
  23.246397059643133,
  -15.049746531675076,
  52.33305209710021,
  -23.61492153884572,
  -14.06549839246843,
  42.62911892730117,
  13.626558616563528,
  -3.185733398255909,
  -3.69043907766374,
  18.33250167965535,
  1.91686302465458,
  -7.048069705055436,
  -26.850185966950008,
  -0.40001520389486434,
  367.1524892605986,
  700.3119135248853,
  335.63694195649435,
  773.7533394805114,
  91.33242929847167,
  408.0198581927605,
  -60.46762895074346,
  -238.09228780033538,
  422.75180464701947,
  -63.66988513781439,
  646.3943895931377,
  375.09120208604827,
  787.5401433819336,
  188.49635765395848,
  280.3779462967108,
  -33.551772603660595,
  -251.3844274076519,
  288.7038438602549,
  -240.779106343337,
  497.4063262825381,
  380.73735172165783,
  378.6371384650163,
  697.4447555604575,
  423.9009538997662,
  675.8211460395356,
  511.20794057982556,
  404.3021453984294,
  846.2894232688359,
  321.90832095469807,
  -27.42714013499221,
  -296.54128963066876,
  368.96580795698355,
  222.1155911063852,
  521.1047331604407,
  10.605001165352917,
  272.9045112805572,
  537.8764032731535,
  63.629253892048354,
  108.59285386054854,
  -243.01379046991417,
  352.26485600769445,
  -217.9345335866093,
  211.11630923396945,
  52.1509490593925,
  -189.2306995042551,
  90.15651140993606,
  50.086841715256554,
  128.0581596858696,
  -125.99054982287197,
  274.91854788244905,
  276.8662450437892,
  -38.10783563719906,
  208.59197437612485,
  209.2986412940816,
  1168.6707666572856,
  220.11775334560093,
  485.95384194630304,
  -351.61330182700283,
  205.18194994565326,
  1064.4845483111062,
  1196.361680935116,
  308.53388705793554,
  1182.2317161716992,
  1034.2574861111286,
  68.75165519471946,
  801.2976021693153,
  -764.7611996805662,
  455.78651006185856,
  44.28849528199381,
  1119.2220655861424,
  451.91939535012807,
  110.83441038212064,
  880.3322141019323,
  8.403223010575374,
  846.4252525428984,
  -675.7798016243773,
  233.97666092255227,
  1191.416454276753,
  785.6922623779558,
  350.9675348596501,
  1034.770202429471,
  89.25807404389803,
  250.92595969953788,
  595.3193465895007,
  102.85283424632289,
  393.82348369749786,
  723.7049472532144,
  128.88045970207244,
  458.9801824424982,
  749.8350051843158,
  106.15144037980187,
  404.73906669384985,
  665.2993798468134,
  89.36622995273757,
  249.62179849753488,
  497.30644908896716,
  111.13321949414328,
  149.7684261257615,
  512.0740961435714,
  89.46081669615035,
  248.5205601003059,
  675.3139571821454,
  197.4316444482765,
  539.6751833467357,
  751.8732515653346,
  460.2685316086912,
  382.15800744676864,
  717.110838932994,
  614.2802989384215,
  -4270.428953493969,
  2281187.6812754683,
  -1305.1723276360385,
  1306.1696473957609,
  3828970.4293271066,
  -98.06174049073798,
  -4583.430144966792,
  4143987.476895273,
  149.05177086956564,
  -1329.3452302789553,
  3124848.400419977,
  1102.983490322286,
  -2207.148791253582,
  1099570.1863724298,
  3066.1913541899266,
  4863.532958874795,
  1277605.022228381,
  772.6629673079385,
  -2805.550167488417,
  3245581.488465082,
  -147.83815325306523,
  -2512.817309021052,
  4168560.0346315783,
  -2368.911653529741,
  4662.283561838012,
  3749473.6084682434,
  506.1180011013,
  -268.13589840155066,
  673.326709246056,
  527.9317600886773,
  274.85226698614053,
  818.5352506863942,
  526.6530430659197,
  117.86771122025391,
  848.0892472429504,
  473.855775202033,
  -537.3878551429539,
  752.4765399646717,
  459.1332193705095,
  -623.7253163159672,
  562.4707424178663,
  515.9624230117277,
  634.4822079392629,
  579.1734604658325,
  174.14865173349992,
  1451.757031472608,
  763.8033722611851,
  33.766414937158544,
  826.0089107695746,
  850.3945741842405,
  241.20570014509997,
  1529.7209472180905,
  811.0770867931794,
  166.77720389944096,
  -110.52603128106182,
  455.7272239409281,
  -30.922923225519185,
  -72.06112354333187,
  554.00861479384,
  -128.55081092613295,
  -20.653619361858134,
  574.0116246583384,
  -124.24784735690378,
  -24.08272370945913,
  509.29814595169853,
  -2.8494858826943243,
  -81.1516930244569,
  380.6966610267266,
  222.99070316655622,
  -113.01557620608739,
  392.00154946163053,
  319.21014579445807,
  -109.99249464622216,
  516.9644775670216,
  107.26542807409953,
  -104.30745219160664,
  575.5719374051871,
  -169.08769795621947,
  67.26143906443646,
  548.9607111831886,
  481.4568999717176,
  155.8685829117357,
  174.76251493075677,
  478.81649649868837,
  64.36474051561075,
  763.9660815721129,
  -418.8146958790103,
  136.26591042391993,
  883.8854747903406,
  1014.2415918051997,
  110.40830452990399,
  495.92380541606207,
  264.59319911244006,
  107.2616615565567,
  -275.0507700920239,
  -132.62335454136138,
  160.5329362214602,
  -207.27720147925695,
  1196.4460393611603,
  3.944364990702468,
  541.8839804970593,
  -25.888541118487808,
  152.43751023870306,
  893.2396549412417,
  172.67331876925127,
  124.12283428232826,
  733.7035589760616,
  102.71733172935159,
  660.9498949137995,
  2137641.251568357,
  -472.8196033093326,
  59.64876062156568,
  3587403.972816235,
  -947.7582886333064,
  618.2635245334666,
  3882471.205408662,
  67.06977715741601,
  -299.77659390163853,
  2927873.5122241518,
  441.7623803054198,
  -419.4893903565747,
  1030854.7874853634,
  1395.6608915734766,
  544.7936483348292,
  1197614.79849618,
  414.5202185417064,
  -501.0979703810349,
  3040960.656068639,
  66.04100533048981,
  -461.17574784815986,
  3905487.5998068103,
  -994.4633623078716,
  517.3477262911849,
  3512941.6314547104,
  -889.4881802978352,
  341.40099104323264,
  -816.3756656025195,
  -947.2465408510475,
  351.46025921143723,
  401.5961217516753,
  1428.2522705182278,
  350.0988926596028,
  649.487421067825,
  -459.835378180867,
  148.57312468737052,
  -152.48730316246935,
  -725.690367149877,
  158.51735573921007,
  -1746.2069187597774,
  1385.7474670006557,
  333.5873448321288,
  -1606.1088284355733,
  154.89385378105402,
  3.545535040637361,
  -57.48075574863197,
  -18.47563618601572,
  1.167703357653437,
  668.8239087652273,
  1263.490487341699,
  274.9218781269401,
  339.03896693629224,
  74.79152453587332,
  11.550268044581458,
  -2240.3551529175156,
  -135.0303471878696,
  444.297966950272,
  934.7684850074518,
  769.1950173238215,
  443.0543534286634,
  1580.99488554209,
  332.57387151204887,
  91.64251312426615,
  -509.6684043305372,
  116.8350296824247,
  104.73201840500809,
  -4664.326891700038,
  735.7788031950305,
  484.72196485212817,
  -4299.105986885132,
  548.6120528188478,
  330.34640430622983,
  -261.9963830379865,
  466.94034492893377,
  50.95186362843759,
  1631.403063957976,
  648.8891774185838,
  441.720543740621,
  771.688598397654,
  142.54232017149934,
  -44.0275955763816,
  210.4145966393925,
  111.62352052096023,
  -110.85199420345546,
  255.7922658394982,
  128.20329946200079,
  -82.14714614516814,
  265.02788976342197,
  158.06450170502512,
  31.948526383822568,
  235.1489187389599,
  153.1058880810136,
  -0.25045076764692453,
  175.77210700558322,
  42.79923481828675,
  -134.99564417027224,
  180.99170639557263,
  -31.01067634656323,
  156.60605492067808,
  238.68855383162034,
  -27.385974930609933,
  187.55198243701597,
  265.74830443257514,
  34.283906181928444,
  -129.1320775165,
  253.4615896228686,
  245.5914730200655,
  330.37609488921987,
  -311.74657057638785,
  246.25750838662617,
  331.99080581072906,
  853.1259220317197,
  321.8500979293324,
  35.43023042418119,
  1090.2100308168203,
  288.0878195701699,
  350.4709288091167,
  323.1985895647985,
  224.72506321568875,
  237.98471629543286,
  -1201.0404448812383,
  421.13313807724,
  293.5711899821864,
  -1067.0501395391877,
  352.8695664125882,
  214.0317005311079,
  414.06318499229747,
  217.11819810726857,
  155.3997072802918,
  1108.7035155233007,
  484.2804498237459,
  317.9713325401299,
  793.2960395854562,
  269.0662950521218,
  19.120610989361126,
  681.5105853144613,
  267.16235151686794,
  51.29912340481653,
  1122.8560464963516,
  329.6815910667787,
  327.9475539651761,
  1212.6821828285624,
  265.4833109557169,
  141.11432386217467,
  922.0778287732675,
  272.91981593853075,
  0.05485249732731745,
  344.5760130141549,
  344.0846809245641,
  326.7925444005865,
  395.3420955513829,
  269.02645735429894,
  327.6488757652959,
  956.5044952355058,
  279.07340503960654,
  22.1190202285338,
  1219.6889716302853,
  338.3334466594986,
  50.98270554401958,
  1100.187774021668,
  -109.27218663559017,
  -66.39428503845232,
  361.2972586198349,
  -158.0517519875151,
  23.70130687081317,
  439.21403695367496,
  -148.7745552858346,
  -5.138875656704414,
  455.0722790084124,
  -58.77914230236536,
  -108.50119449784177,
  403.7678994932385,
  -43.2453059627224,
  -117.74914694476368,
  301.81356910226975,
  -159.44702789098022,
  97.7623327662811,
  310.77600317678815,
  189.69126233715485,
  277.5779641448007,
  409.84571194502615,
  347.2939301836234,
  187.5587678314438,
  456.3092837086168,
  79.97390870160376,
  283.60142877429195,
  435.21209535243776,
  62.962071883965585,
  825.5525616878554,
  333.5841166234271,
  -128.37475950378425,
  635.5422658725957,
  405.5243238918874,
  323.10248447621774,
  459.97339195925053,
  420.16616669810804,
  345.72295723298487,
  152.24842439158647,
  372.797066293473,
  -113.3768962367675,
  668.0067298173406,
  278.6630964722661,
  -154.3596738943552,
  -146.0914629224019,
  286.93807111493226,
  318.2184774200491,
  -64.18698522045821,
  378.40868290378836,
  127.36520399356797,
  812.8171088050302,
  421.30828751505817,
  294.9153061257076,
  569.6152836761771,
  401.82934940210873,
  414.0691574756479,
  154.13054132026164,
  489.59884193653767,
  554.7770113993439,
  84.75356941408478,
  595.184930758247,
  530.9852226802589,
  13.91726600212349,
  616.674650815377,
  520.1710593455207,
  6.615829890947666,
  547.1513865291896,
  560.4608696439803,
  69.88602005905567,
  408.99168313006436,
  423.9390575263152,
  152.20128074536723,
  421.1367997594544,
  262.6598751823778,
  161.820601249388,
  555.3875130618678,
  368.0475806412953,
  160.56634588004414,
  618.35093275287,
  535.5769723442271,
  17.50480862219996,
  589.7618451224796,
  3.2679304800160747,
  445.9514253986463,
  -879.2532664145714,
  2.603579583469113,
  451.95255676105637,
  365.31918357817176,
  2.4496851589167576,
  332.59496481476737,
  618.6244611921808,
  3.28505959654554,
  439.8162878527877,
  -200.86549557911903,
  2.3825119538596233,
  196.80286197510966,
  -1829.3921553749092,
  2.7675434697239765,
  449.69029512021166,
  -1686.2343044916245,
  3.2409206118334493,
  453.6515666648644,
  -103.78399278253158,
  2.3958037847369447,
  2.275832132601977,
  638.3832603020419,
  3.2098493194491313,
  158.8224632145459,
  301.3957723452349,
  177.68056478084017,
  -310.1524467445841,
  45772.58602947792,
  -823.8624833933216,
  2186.7970164144403,
  77146.38436421096,
  -324.7799294175384,
  -450.3002703464856,
  83531.82917863845,
  85.2849782236393,
  1006.7322619048499,
  62873.72073245537,
  748.8055571034797,
  613.6913982527728,
  21821.014634495838,
  618.5855173009608,
  -691.5164514787484,
  25429.80859717125,
  341.3777882641359,
  345.75423761424435,
  65320.99930654781,
  -332.16965670090804,
  476.8268153827915,
  84029.91876644261,
  -289.73597016692975,
  -781.6268592480984,
  75534.9713742303,
  63.505078098665905,
  152.52693066456078,
  -12.939289303804493,
  442.32200232444194,
  69.4768887449135,
  6.429549749186184,
  -98.80662419009309,
  367.99918477851,
  10.371649828138974,
  306.15058699031056,
  363.60585697529785,
  -2.381781342813059,
  422.4679556908984,
  295.86274383486085,
  -27.725963408929893,
  -112.44988100959634,
  367.17784527350386,
  -25.498048615422647,
  438.2085770794471,
  249.7670502462675,
  -0.870936391439975,
  262.0040187332113,
  342.74199608146114,
  10.679149001723857,
  -91.48759130101823,
  367.8111050302969,
  5.4347324013523135,
  910.046899137342,
  1.9838810424791902,
  16.83845546836624,
  -423.0474913562615,
  9.941557941159722,
  366.49241948954636,
  120.779917019121,
  11.939279194364776,
  437.6567735018339,
  878.5534647887373,
  0.7502118770956443,
  207.42677615431015,
  55.45981033699789,
  7.801344067627138,
  -250.0964496852864,
  -374.0153437058234,
  5.88527981136879,
  -209.8772482700651,
  903.3673749446124,
  1.665159109886126,
  234.70114839849572,
  560.5885642292733,
  50.11672475472927,
  443.2078705336712,
  -627.7846355312436,
  53.77019541650155,
  348.5335821944716,
  96.43587058636632,
  -983.8999580844738,
  875.6605358574596,
  -189.78454974234484,
  4744.182114734355,
  1521.4080226914662,
  -84.25691524311117,
  -1305.4035558797566,
  1652.8356839915298,
  27.893056023793605,
  2037.0757576357546,
  1227.6426146174958,
  226.86667048306583,
  1135.4274230625908,
  382.6801555726711,
  218.34861135524247,
  -1858.7612041636999,
  456.95772971387726,
  144.44762423394212,
  520.7709916289256,
  1278.0134358977925,
  -55.35683968729708,
  821.4556847040526,
  1663.0875539153142,
  -71.741796242985,
  -2065.477366798798,
  1488.2413057568544,
  -768.6420229941398,
  197.8234352509196,
  -88.22844221866511,
  1012.122467373159,
  183.58523324152824,
  102.89964930512492,
  1172.2345203006057,
  188.3914115401847,
  141.79955769017045,
  -766.3182630865132,
  195.67769054948138,
  15.95107738552846,
  558.3276271187883,
  66.76004779309557,
  -234.14058460184452,
  1012.1559528317368,
  57.63111069258955,
  -212.15593692132654,
  -744.9989763589589,
  181.91367579737044,
  30.859813596009033,
  42.53360042194268,
  0.13273412793937212,
  144.83390218710332,
  447.2404021605216,
  10.310138981288247,
  93.08297724821666,
  1566.8023609861232,
  7.869921646535723,
  580.94956925803,
  -88.19337482020251,
  5.155163809330232,
  706.2362071471024,
  1608.4146934270923,
  11.7297781592546,
  731.7355395419359,
  -350.3830310963707,
  5.657078364520313,
  649.2404292987869,
  859.6716189802673,
  5.227509889969825,
  485.30250031785414,
  -502.2408512462566,
  13.90358684088362,
  499.71368692631273,
  1308.7533947164065,
  13.598324780590055,
  659.0132754570591,
  1004.9111208864136,
  14.501790322948908,
  733.7245868723783,
  -683.0152727292236,
  6.835409334731793,
  699.8012669587494,
  541.4494911285252,
  2834.8134205142487,
  4269264.624994338,
  28.38300054045817,
  -1211.664626333065,
  7166613.106115887,
  -377.56754153862164,
  2547.5539247427605,
  7756304.498818096,
  84.67672294403695,
  -3630.430738042433,
  5848542.534812277,
  952.723358891184,
  4728.406273153515,
  2057353.6456055497,
  1129.1108196421221,
  2053.135697023453,
  2390623.261062431,
  756.2573781031833,
  4179.218339403653,
  6074547.011027648,
  -78.70340718425479,
  4447.876400810404,
  7802302.726233524,
  -358.1005124044276,
  1868.437357553642,
  7017800.235925054,
  677.2953776587856,
  98.89599074959692,
  -24.94723102695851,
  1401.5066053201417,
  217.68895840178044,
  173.23507229993683,
  -1125.857600055764,
  102.62554194405173,
  213.5707099421614,
  -105.09307512928456,
  203.12863705177472,
  83.07737692073621,
  395.6557132413629,
  97.0513073310675,
  -176.24474166662836,
  -952.6665213548938,
  165.11623989363247,
  -153.44867814494023,
  -682.5727331689229,
  208.1250706140073,
  98.53636915118156,
  -438.6250496548904,
  2.4042357955553086,
  216.717046918035,
  -570.5833391083268,
  215.33006502411786,
  163.05608362416342,
  945.8908426798641,
  161.43828906683552,
  11.29053933186984,
  469.1475819153486,
  262.0285065593936,
  13.725438654802343,
  284.45939587147336,
  266.2256445761661,
  14.221008719012888,
  632.331377106963,
  250.52714913311635,
  12.617746859163702,
  945.7122445844676,
  159.06745886837254,
  9.43167403444593,
  260.4636804378845,
  266.1624035984473,
  9.71175009927463,
  -72.75783302417909,
  73.21101958699181,
  12.807678498282067,
  353.68549652589945,
  57.36378600282947,
  14.259665115894276,
  284.701774434675,
  266.2255820619924,
  13.60037797976368,
  125.79049009850033,
  292.6455294172846,
  205.11774886714437,
  1133.618862782806,
  64.58484790678376,
  354.7025807517647,
  -802.2985158361284,
  0.13284510496714574,
  385.1472747248633,
  429.0960230757871,
  273.70138057681754,
  286.6529946887879,
  758.8264778184715,
  199.9314093365345,
  90.92080840538115,
  -887.4150783169082,
  129.42966873846703,
  108.12691244332973,
  812.6121445849146,
  183.23554422742666,
  298.3211946999793,
  381.9589799899834,
  279.8601876783815,
  387.5220795368353,
  -748.6970341891073,
  2.2901827419320853,
  347.0196429502522,
  201.53523323846434,
  -573.1234989580313,
  508.0742699341429,
  223.84110310633378,
  -490.003365778643,
  617.6447394661054,
  272.4794605368128,
  -185.3067075368475,
  639.9453923555799,
  272.1727212106723,
  -188.33036778641195,
  567.7986086623666,
  101.08258073892887,
  -761.3719669679745,
  424.4253315500668,
  -130.11577184814522,
  742.4586725687814,
  437.02875446735834,
  152.8032141755698,
  -695.1353315315929,
  576.345532422693,
  264.85108599010067,
  645.413807614152,
  641.6849302152424,
  -26.017839026898088,
  1097.4168063807656,
  612.0170090893656,
  576.8580105641801,
  -167.88771405456725,
  402.3537652811798,
  276.8129611327054,
  -541.3808368947739,
  489.124722971138,
  58.75760326844778,
  -247.95976582346492,
  506.7850379866411,
  71.58900930238985,
  -287.5243753940423,
  449.65061534474285,
  350.2475970368001,
  -538.0429692029486,
  336.110565591164,
  605.7180293588578,
  57.67772874704262,
  346.0914580832413,
  586.166695226807,
  375.6899531256608,
  456.4190883024155,
  498.6956967030001,
  -390.47001896282677,
  508.1626114027778,
  99.25660181111738,
  611.2838921131349,
  484.66801527885116,
  857.3309240503437,
  361.44765882227114,
  -327.92338778701685,
  672.420460962165,
  4.0814211155791895,
  468.96002572941177,
  388.3951713391309,
  213.18654286932696,
  631.1480721448336,
  1083.4474018629774,
  367.77763989953553,
  106.43940283582577,
  -99.54849566239648,
  157.05561372220936,
  -936.2848545331556,
  -136.18974615728717,
  35.13400735419859,
  -844.6227605472145,
  1192.0038427621898,
  328.2665076512996,
  168.59941556815053,
  -694.6948192323579,
  372.3295420351706,
  643.7993720203399,
  -627.5616915882534,
  35.52689328682234,
  428.0307040597784,
  30.77740530723213,
  16.749670063093234,
  -80.22513666480515,
  456.012051975737,
  97.5902920401366,
  37.27385266660173,
  11.14048807760048,
  32.61748269068862,
  61.188180926182746,
  -101.05256467616431,
  85.67763255561438,
  -16.179144446018306,
  481.8542243359726,
  109.18167742231617,
  -169.92691270681576,
  -126.87632487426902,
  113.61523352851333,
  -156.41150603544017,
  -139.02600208707128,
  121.84600202954847,
  -7.013765233711555,
  484.5411085608774,
  110.30573934354338,
  63.05359175527875,
  -122.24579522930537,
  102.87229938719874,
  31.238899687745594,
  1.648070794292115,
  -2451.3339804726356,
  156292.32162579786,
  0.4731750986450707,
  628.6825357638031,
  262130.8643309504,
  -0.2278152604168986,
  2890.9962697576925,
  283671.96580909024,
  0.2168016105898214,
  -826.941211430378,
  213982.47301444534,
  1.3506744118552487,
  -1311.7617372221466,
  75492.43297677522,
  2.1934839375455315,
  2593.4532746620266,
  87666.58829764604,
  1.9052791943467362,
  -1642.2653746630465,
  222238.2919341691,
  0.8172392887236217,
  -1480.5858091334915,
  285352.25569772127,
  -0.13647934040577048,
  2482.3010273661357,
  256694.8122235173,
  72.92123754783728,
  482.4149710297768,
  -1305.99835611499,
  136.69637230209526,
  29.160789233024076,
  463.46182422605847,
  509.3987654295056,
  10.290470174875992,
  823.5964248359608,
  60.220384105874814,
  408.4363631457138,
  -341.5063754909126,
  73.82665113707895,
  222.4719533985646,
  -2656.850152503867,
  322.9908510206564,
  330.6682248049988,
  -2453.316708836003,
  72.42034801560283,
  231.48234810221373,
  -203.48158356559588,
  60.06343818047662,
  403.144259004093,
  851.6883275905665,
  503.0036872632795,
  15.56036848277165,
  372.57926389868936,
  1955.0901080130536,
  8.311466787292886,
  41.66192223777598,
  36.70315203948735,
  89.13306861197461,
  767.6816709332568,
  308.4683721725173,
  81.70117525876984,
  915.446981018366,
  2094.4091488246977,
  8.408941802387062,
  437.3985616780226,
  -162.71983864196557,
  82.88730822799113,
  -512.6003847840531,
  1418.2181400806396,
  79.28097922856938,
  -429.08943536309044,
  1642.6729714147023,
  64.61201742746596,
  494.0309323076064,
  -185.77391080692405,
  81.9780602512462,
  926.9732512361824,
  2036.832046006878,
  19.82490767559861,
  730.3920306560958,
  645.9301047792201,
  206.78506958543568,
  391.06322594931,
  640.9973837056486,
  210.65122763396613,
  475.3992843163357,
  130.93735207048297,
  329.89553288046136,
  492.5640292676282,
  565.5186845655288,
  -54.01097165517376,
  437.0328684855791,
  -162.12548649464594,
  286.60745029582245,
  326.6788915567181,
  125.97777259528623,
  -128.77787868481542,
  336.37970798396674,
  134.39361062061494,
  329.9663810009198,
  443.6114098041334,
  -385.88293776779517,
  125.71525208502989,
  493.90294628688355,
  -230.12847605952823,
  -61.237941967503986,
  471.0676372990875,
  457.6789516230683,
  188.8076448269376,
  -1320.9996750916537,
  523.9945876721844,
  126.7884725784064,
  868.3749349543449,
  91.49334461207005,
  7.004161328903876,
  1313.9738580238686,
  337.1578559392558,
  325.89917339592125,
  -127.62201255260007,
  402.2640280502322,
  324.72169768935737,
  -2992.425038491918,
  110.00909886476649,
  45.85733012964688,
  -2740.590632263142,
  226.24986550168282,
  270.7454042757583,
  43.15774183550158,
  233.339737448456,
  193.6606542061226,
  1348.7323110945445,
  153.82339218198297,
  145.32014364312727,
  755.9248372989322,
  1117.1556892296455,
  -41.44937090602909,
  707.1983272416655,
  961.4888225389736,
  -124.9055755284019,
  859.7115666508013,
  1212.1241398243358,
  75.58195145783995,
  890.752273399989,
  1215.58665002331,
  88.11701908550464,
  790.3297805421628,
  0.846133749556941,
  -235.26764676830413,
  590.7657645212041,
  -761.3010396593482,
  179.9299011349915,
  608.3087107636563,
  -368.07918894432885,
  -174.19291291283741,
  802.2264077560313,
  1216.1024656391055,
  90.47348136290887,
  893.1735695319232,
  834.3448857257508,
  -167.80988629650045,
  851.8782207324705,
  529.4739056295888,
  -444.7119562109409,
  28341444.945605233,
  249.8017376568782,
  598.6453452730511,
  47561373.59658185,
  -46.470996657163596,
  -503.27311541724464,
  51473166.246889584,
  64.24500949426721,
  105.5519943632471,
  38817785.27696038,
  383.95579743759356,
  -58.68122738331908,
  13668452.903685631,
  677.1731008860933,
  -604.0659698717446,
  15879239.169941101,
  603.8453373048326,
  -170.63951769545753,
  40317014.63648131,
  298.808247422164,
  -115.87047528715726,
  51778301.32289317,
  -23.415997125383,
  -641.7188552316622,
  46574204.54665532,
  117.23210540850789,
  2504.0287588990655,
  496080.14510412904,
  49.2990965946559,
  -921.8838955809906,
  833645.2316546856,
  18.026300579297256,
  2260.823203280185,
  902349.1612346665,
  13.937800993766203,
  -2969.7095193450436,
  680079.0971765807,
  44.47954324604483,
  4107.221372620028,
  238374.20256232168,
  111.07998664319409,
  1842.2286518359053,
  277202.8720576889,
  122.48560703979774,
  3642.2565636827653,
  706410.4898521773,
  93.40957960239854,
  3869.7133895065367,
  907708.33556935,
  25.94212448740486,
  1685.8555364685603,
  816307.3001862695,
  112.43243176178026,
  176.3783515279771,
  29.451145002041663,
  166.6707891387398,
  69.08120832869038,
  485.40816746961974,
  121.0641334323545,
  120.984451386508,
  578.208164895949,
  120.56612872332633,
  124.75279062239471,
  277.98281390597253,
  166.47884171943207,
  60.99218890861484,
  -318.63827216570496,
  112.83591780776035,
  174.82375140005058,
  -266.19148416876624,
  128.82133049933893,
  64.21741245062711,
  313.5492391085134,
  162.34023353067,
  176.54280546839237,
  585.446926455969,
  108.19464788799564,
  157.4394571451289,
  461.9894197286504,
  109.21566765587872,
  -1079.7152995847275,
  -1416.3350102104184,
  -166.77220876725318,
  2950.731343823035,
  -1171.8449199115482,
  -71.53027233458766,
  -1305.9346658760091,
  -1122.084353383348,
  27.6462475733938,
  1045.9318679058583,
  -1283.0690943931625,
  217.5583646018574,
  411.5056398217586,
  -1602.9850865155267,
  215.4591637995043,
  -1695.2933461074363,
  -1574.8624361309305,
  153.65309703965954,
  -20.984663115136755,
  -1263.9979142579875,
  -35.76651640315555,
  190.58591086100782,
  -1118.2028352133166,
  -56.675780504072435,
  -1840.7449044543914,
  -1184.4023572745912,
  54.72954633151318,
  23.83858391998824,
  131.42852214397283,
  39.43860512732384,
  2.0691264600995396,
  165.06324093491008,
  47.26587770130974,
  92.03197436767434,
  171.90884625170557,
  65.66559041289176,
  21.342807620660594,
  149.76203250200322,
  38.22355775346186,
  0.038336146476240174,
  105.75090543093948,
  37.837745267846145,
  172.2160798118,
  109.61976341281292,
  70.48351822326228,
  143.80845405214222,
  152.38567168539015,
  35.89990801115146,
  6.444651706764432,
  172.44283015253086,
  33.16104361922109,
  144.97498445773647,
  163.33570312785852,
  131.66241310480513,
  34.46456196139022,
  27.05897050774965,
  23.237874053935528,
  47.543614845216155,
  819.1021678632815,
  53.80591292060867,
  128.76337854651035,
  980.3050950127619,
  129.49471013783622,
  39.05724145022165,
  458.78347080705845,
  120.5758113682591,
  366.512566698153,
  -577.6073496798513,
  -43.52435289382605,
  22.674001851104748,
  -486.50200507672713,
  141.49549696894167,
  16.679600803345124,
  520.5659278102949,
  187.12387195816964,
  510.72494130661585,
  992.8795517452497,
  -99.34455219284831,
  359.15762571565983,
  778.4214481357136,
  84.34066483865318,
  94.8763455992194,
  -3.688514378588099,
  109.834058630446,
  144.60340879302308,
  136.83967080096488,
  65.4988153397886,
  158.89834348617023,
  165.44108404911051,
  73.3998852599257,
  187.7293085417031,
  72.91016196529566,
  92.4896057732916,
  7.330650726080833,
  -110.97137584229125,
  67.52593684820162,
  199.55661121842263,
  -94.80701917591126,
  67.46211963635153,
  199.1437769704171,
  83.87190822810884,
  92.82598944110025,
  8.439681065190271,
  167.67210577890407,
  73.54609277484985,
  186.78134337251782,
  129.62189816659296,
  206.77799991231362,
  21.683398477501278,
  -235.85294184453406,
  492.89324184389943,
  28.832039240584898,
  78.76082760733426,
  206.21365836767686,
  19.959479208891462,
  142.79352270086625,
  250.30993266128218,
  27.917607963398623,
  -64.3642239849701,
  485.9737510021476,
  28.995280292888438,
  -476.03725362193603,
  232.52978836618652,
  2.9793391455696376,
  -439.8485760617978,
  352.2814940328694,
  9.469895202594895,
  -39.82312351382868,
  464.62010271893405,
  28.216294026425302,
  147.78832253580705,
  296.73064077726895,
  1.7694319108216963,
  62.60171580606202,
  554.6872267429803,
  -460.08168551267124,
  52626.14459155308,
  -979.7729552554067,
  303.41683242731267,
  88347.33208585442,
  -71.88029282518704,
  -502.9350380499674,
  95617.59209763505,
  124.46690501268594,
  -57.41453578204141,
  72096.94097306997,
  904.3721980906543,
  -177.59562927864596,
  25355.663553364197,
  2469.741950833196,
  790.4595282481959,
  29464.519114736184,
  684.8782949992694,
  -259.5234488308094,
  74883.33284896733,
  -65.92959670991979,
  -219.44505703899546,
  96184.70072009385,
  -1834.751277434685,
  762.9062422093891,
  86512.629607955,
  65.49302732090166,
  -32.980351850064096,
  3591144.977449596,
  -78.35227297878643,
  44.88325082549181,
  6026516.859891597,
  -24.665644213902652,
  -37.35065033378928,
  6522183.103169696,
  14.24372011239852,
  8.084711434824543,
  4918610.086045565,
  106.28260261812883,
  -4.171675045638768,
  1731918.915839295,
  103.83507765574188,
  -44.87261309823998,
  2012049.3371691331,
  85.09781566748906,
  -12.526891250767935,
  5108578.586647842,
  -5.361139868038343,
  -8.43959061949323,
  6560847.002393287,
  -13.322239438530119,
  -47.68257024435201,
  5901431.913372511,
  -124.20600048140375,
  92.38248379611315,
  -327.0542914884179,
  551.9655527337738,
  183.358624914494,
  350.190953543887,
  186.76116402786565,
  419.4026463942538,
  488.02928895511656,
  -42.076959524869494,
  313.4965861169168,
  42.09648964051828,
  640.4994113881426,
  4.870408126903243,
  -844.0808773431972,
  72.51620055978916,
  428.35190105235284,
  -766.1802506658884,
  78.84922600734691,
  430.6375422360942,
  94.92425884749605,
  640.9334867935584,
  1.7744984639091967,
  498.78121645020167,
  -47.733450020813905,
  303.46317140652656,
  315.4064568245491,
  -173.44237848677443,
  8.341548930778721,
  324.361149318233,
  1438.604211920406,
  5.995572201295424,
  502.8759888131895,
  463.01998185528066,
  33.8224829202401,
  539.2087478878049,
  -68.2040465212047,
  12.62519215662184,
  421.66547581745624,
  1448.9749168164728,
  38.86244949836531,
  188.07829068540696,
  -393.6304508494726,
  57.656437076142126,
  208.61208988128462,
  168.40606686880682,
  23.81450214811587,
  435.5903291996463,
  1135.9124771226666,
  57.791159550438934,
  542.0428447310466,
  -949.6970896074963,
  23.347075712976,
  493.7071553746184,
  -801.1202134542166,
  29.07685659901597,
  104.69409198642944,
  -867.2282480179483,
  134.09099153267053,
  127.27224934453082,
  -661.3544434320563,
  231.9036806249223,
  131.86753539448313,
  -430.79006147713915,
  277.8959671331045,
  117.00092542133615,
  -476.12089252403257,
  270.6818776041931,
  87.45734104668043,
  -752.224756578265,
  203.6358036339322,
  90.05441001145566,
  -871.2196358589545,
  84.30515278590367,
  118.7621097113428,
  -688.0530428850866,
  -12.529208983189008,
  132.22598562011055,
  -627.7938192153092,
  -28.36454351421372,
  126.11259581235413,
  33.142310569697614,
  48.03057441285168,
  -436.7722957021696,
  32.886215464166604,
  413.58907863063695,
  395.588463414616,
  36.83378912263626,
  405.76302358261523,
  564.9971412013643,
  34.90886728658895,
  294.4518579312521,
  16.928378703272536,
  33.01176390890182,
  410.755269578131,
  -1072.218088260102,
  34.8834040411293,
  291.128590187104,
  -976.4751868039166,
  36.85614627834017,
  404.624892857632,
  81.8557626932019,
  32.883039975249034,
  413.6267436509012,
  578.2116784719076,
  33.12381824350061,
  45.947125011895935,
  352.83696341195116,
  346.4888208432818,
  -343.2027924858243,
  595.3193465895007,
  201.03251887611387,
  -526.7603854576234,
  723.7049472532144,
  400.31759537368197,
  279.38461259223516,
  749.8350051843158,
  248.7550181794962,
  776.1941652821097,
  665.2993798468134,
  192.16793116232463,
  -524.2579486655006,
  497.30644908896716,
  23.04573690544177,
  253.00174870636374,
  512.0740961435714,
  37.24687657906469,
  404.604459714122,
  675.3139571821454,
  232.01296258964592,
  -524.5481714213568,
  751.8732515653346,
  405.1216202901504,
  97.673416968622,
  717.110838932994,
  222.82748398693363,
  129.6006803283201,
  1064.389935195366,
  239.0870908178071,
  829.7661724044503,
  1293.93453500273,
  259.97570812717134,
  1052.9307920999493,
  1340.6532765105785,
  370.0632227447633,
  1088.9393680110497,
  1189.509408450251,
  339.22584496645413,
  1225.3597011320674,
  889.1496339745844,
  387.90133069863737,
  -399.63473027858004,
  915.5531684497992,
  393.4966141996359,
  863.8653015832822,
  1207.4147820653186,
  232.90840678296004,
  -192.23179086897278,
  1344.297520471124,
  412.154502259191,
  404.7142971978934,
  1282.1447240922669,
  1327.0036396480823,
  63.84116115771068,
  -21.698003278197206,
  116.98345634533828,
  102.38069418267531,
  87.28367588301299,
  -509.4330419982757,
  112.7539982024376,
  109.46449347618096,
  1541.152550797557,
  0.002708072496361069,
  37.705399383101415,
  -257.78206968221934,
  119.86302346089695,
  -104.8974438217092,
  -114.9594393298857,
  116.32160347024976,
  -92.3617469448729,
  1538.2500286222692,
  10.520806795139151,
  46.20639519923693,
  -640.1735688041592,
  99.52884503397969,
  111.19468371557946,
  231.64835087852504,
  92.69246516429283,
  81.68618680640793,
  161.45777515215414,
  8.693665732104144,
  167.30526464498038,
  452.83114476586866,
  28.596290060401035,
  203.38604552116198,
  454.63018571796914,
  66.04625853638257,
  210.72949283628188,
  301.1878729701747,
  82.25645469415834,
  186.97206709488032,
  321.1092415936083,
  81.07942735041195,
  139.76026069224423,
  483.014750739357,
  58.56936596294795,
  143.91047874379677,
  373.0025023566592,
  17.9436217367534,
  189.78650865636155,
  32.8191011287532,
  10.511070926996197,
  211.3023103537061,
  -57.67493271509994,
  15.334711897549134,
  201.53287370013453,
  58.41507007498715,
  -132.77287252720322,
  404.406590614247,
  57.933949297126496,
  162.71876400811223,
  491.6202572720112,
  58.03899965102139,
  15.47794823775385,
  509.3706759355525,
  59.48881225109785,
  -317.27103825260275,
  451.94475113731806,
  59.026330995469316,
  -257.2204653919055,
  337.82541541560875,
  59.35561352778824,
  608.0216797674263,
  347.857230828564,
  65.00193042751967,
  260.9228303493471,
  458.747757120285,
  65.06600901818366,
  142.89886086826866,
  510.7552777874859,
  59.938934099704284,
  665.000283559215,
  487.1408112751718,
  522.0658813679254,
  273.1208101133112,
  1061.310697195765,
  484.2309489425417,
  293.7716655742105,
  1290.1912335514203,
  553.5019151386011,
  245.8251720316733,
  1336.7748195872114,
  559.1433923401125,
  238.83779006671435,
  1186.068204761388,
  314.67398713918675,
  324.51561970826066,
  886.5773592379173,
  87.25365471822727,
  236.63707437204945,
  912.9045093318152,
  206.00891434227816,
  308.8632622500378,
  1203.9217788385142,
  552.0754581988608,
  247.43853389649922,
  1340.408520894062,
  485.55273545857494,
  293.1850708164925,
  1278.4355300977859,
  70.48617315135525,
  160.47742035794138,
  90.32431465495873,
  58.73223385399464,
  82.58742144224472,
  109.80350923841874,
  58.354772471935696,
  0.28979946135471124,
  113.7680697521031,
  61.23147997942047,
  -32.48602563117551,
  100.94197487330962,
  58.350723089775535,
  0.35806139996552844,
  75.45339227556744,
  59.30041350797807,
  90.1115855010558,
  77.69400079419704,
  73.70406705834847,
  171.5454403892125,
  102.46142798625654,
  83.68769377070241,
  195.00077684337353,
  114.0773209271542,
  70.26971252528821,
  159.65086940775313,
  108.80302383810944,
  896.9450743289448,
  420.6411848936197,
  999.7259372037478,
  1113.5073139891547,
  383.0624887814682,
  1215.3252045252257,
  1285.5393231366697,
  326.00802642675154,
  1259.2056811198684,
  1354.6733783593354,
  252.0353103276077,
  1117.2441309841315,
  1266.599287255811,
  171.0071670243926,
  835.1318645045759,
  996.1420853760237,
  99.86853380962569,
  859.9313269721354,
  571.2533186607493,
  58.583625035898876,
  1134.0617143024303,
  80.36920046984801,
  62.672688289251255,
  1262.6285293528204,
  -348.53800286089324,
  115.44458516022317,
  1204.251650208166,
  861.0579180762363,
  304.78377136180194,
  887.8469565515829,
  1431.7284295369755,
  69.98889854155433,
  1079.3185851276387,
  1432.4792964914232,
  95.5821342516029,
  1118.2884129041952,
  565.5146635495169,
  327.63428525734423,
  992.213730288782,
  -146.26395441867658,
  294.7317940989806,
  741.6725490723389,
  1403.972956018307,
  142.89450625114046,
  763.6967123520504,
  -420.2023967274089,
  236.92657225800963,
  1007.1492637285444,
  1196.1435488990853,
  -72.3631016223072,
  1121.3282113862317,
  1433.204521710456,
  90.66375612496381,
  1069.4842684086893,
  1670.865049980059,
  39.798812686209,
  137.53929731550534,
  1297.150110379962,
  294.66177841426213,
  167.20079815850127,
  -1101.672715779376,
  53.32817280679178,
  173.2377425770661,
  -1100.7420326278632,
  49.12428578115343,
  153.70709810253965,
  -1075.3987364726077,
  134.019643511533,
  114.89493823779586,
  1668.9830313130929,
  35.085296913575185,
  118.30677393661821,
  1241.023261126114,
  307.98035172532127,
  156.02081079725428,
  -967.7882284301834,
  -73.35249572057597,
  173.70864777543937,
  1164.3753288099551,
  -186.93644755169265,
  165.67733175348482,
  327.7750194860315,
  24.271324588672208,
  15459.174797514512,
  44.11008994458456,
  -130.04625807384448,
  27076.219506947553,
  -417.73140743499016,
  13.316318662261116,
  29440.612785293422,
  111.41507437499786,
  127.20891874378371,
  21791.358242659884,
  943.4638947135751,
  96.48589444009549,
  6590.4215535489675,
  925.2895944520706,
  -5.538948768479997,
  7926.68056701754,
  541.5394008279017,
  75.54191466743339,
  22697.533016537844,
  -302.65060405534985,
  85.78753125526688,
  29625.04467808143,
  -393.3547688602458,
  -12.582654662541046,
  26479.54783365379,
  -273.9252679695752,
  186.06328505253074,
  -135.25583560589948,
  600.7639362139109,
  92.5813167369642,
  261.4011517479835,
  647.7404842824328,
  59.06591760365072,
  342.13193467652866,
  -239.25390425227556,
  258.85796071447317,
  80.9527502734326,
  738.6765045035866,
  6.868923671607007,
  -438.0740678952054,
  503.0975813263981,
  163.1435553878887,
  -392.44830954923594,
  -246.59126535747401,
  32.763496898954216,
  111.89354156871372,
  809.6289850739967,
  41.339535559334436,
  348.42925045649304,
  385.98946644168456,
  237.23999341399104,
  241.02815721384619,
  416.9727816090295,
  -102.11157441729742,
  111.8789806521648,
  -303.3384071466581,
  143.3755912015879,
  136.00661939758686,
  106.02805167273448,
  328.0241139285328,
  140.91726821567315,
  -321.36113880065096,
  70.66079510103042,
  125.03040069534941,
  -246.8570671800374,
  215.8310388898487,
  93.45931543223693,
  498.1924265682742,
  -13.52604097241597,
  96.23461462008497,
  -276.63990752418704,
  -48.749639116278686,
  126.91245057388593,
  79.51657161932029,
  -191.78100082980745,
  141.30031796658875,
  248.9542464143451,
  310.95257296705034,
  134.76738179947648,
  496.3072548015682,
  -53.35567912480286,
  711.3039779078,
  606.8032319077804,
  256.3132316493377,
  864.7026352525476,
  152.92432972819716,
  468.46277314876096,
  895.9235492978119,
  207.52122366570015,
  516.0217876399013,
  794.9180521273132,
  433.5136285154741,
  533.5065317566664,
  594.1954641700935,
  132.78997305648394,
  443.3833277813159,
  611.8402562543017,
  572.2127653945782,
  386.8967661296573,
  806.8837453917703,
  197.4301911659968,
  509.0076405915339,
  898.3589023013394,
  477.4873465429023,
  -68.84714547003125,
  856.8238127251119,
  -417.73389344638474,
  304.3922838433665,
  -1068.5879295930224,
  -253.61597558447863,
  268.7129420948379,
  452.9612054306099,
  145.46309372737792,
  30.40648137852409,
  762.6389795551804,
  -315.89528350922785,
  295.0083944553837,
  -239.2265485570606,
  -395.4778229592348,
  310.689670366264,
  -2230.1780038858824,
  522.1546808593084,
  15.299204599782826,
  -2055.160708440708,
  -82.00601399384385,
  181.11872237816817,
  -120.53978459421992,
  -436.46221914701596,
  277.0416682780054,
  786.7950531488798,
  972.2149025070579,
  227.83823149821765,
  374.811788681266,
  3.4832680502140447,
  5.179585533135935,
  -174.61056166736526,
  2.1410442176359403,
  153.2484774710052,
  96.92577639702097,
  0.7515621467893085,
  177.338989070105,
  152.19101024989288,
  4.226512166356795,
  288.5475491243285,
  -26.60235926709939,
  1.7208186764470987,
  50.97425425006895,
  -381.9084450186791,
  1.0951893992750164,
  11.959033779542523,
  -350.67478032182584,
  4.081668892121788,
  459.1038443295758,
  -5.421466372252993,
  1.2217636049213207,
  0.8546901400912361,
  156.50191393000634,
  1.5905091753333118,
  27.666309400680973,
  82.97919658732269,
  -111.2722087431535,
  497.7205328215882,
  623.0324885859085,
  -196.79862714547005,
  352.7523268786184,
  757.3946603150019,
  -191.93780902488436,
  364.5581642890851,
  784.7411174946202,
  419.5959905303637,
  634.1227754292204,
  696.2702130465789,
  -50.61409573635217,
  -284.4734425112728,
  520.4569217189708,
  626.0517094351092,
  -187.40752971545976,
  535.9120282054273,
  413.289174727251,
  636.7988923967602,
  706.7509862233832,
  477.31471919761924,
  -329.09905292749835,
  786.8742477588933,
  725.783236791938,
  139.11282109528855,
  750.4935848833231,
  452.67581044261976,
  1736.8645352216192,
  9508.522535534785,
  89.6845656292287,
  -390.4977903113826,
  16382.951966727982,
  -158.26594316600676,
  1585.8430736244181,
  17782.090486559802,
  64.12371249927762,
  -1662.120134669702,
  13255.615649816697,
  392.3875497274446,
  -2085.655828415225,
  4260.404804800638,
  733.7794013011095,
  1325.9116719141489,
  5051.1410479371125,
  567.075809330226,
  2443.6609991082523,
  13791.847943929604,
  109.32640095784754,
  2584.9030944985248,
  17891.228745346307,
  -136.5347733325127,
  1228.8098751349285,
  16029.869283976546,
  1129.5857792540385,
  96.59707139082909,
  655.8776939149844,
  1231.3484494866666,
  55.59371700539891,
  797.3232091289724,
  1116.2694199014466,
  5.808262308713083,
  826.1113246772031,
  740.1198293627865,
  -32.04554138244127,
  732.9763857277824,
  247.42432348974813,
  -40.92175640550697,
  547.8945189100863,
  -150.56907274313068,
  -24.46310014175927,
  564.1643921305898,
  -362.5858457084644,
  -1.7285947328084674,
  744.0096873092947,
  -429.48189554831504,
  10.25186756625768,
  828.356909914222,
  -399.15220018834873,
  4.315878827203008,
  790.0583208244537,
  96.76918256973312,
  -373.03893651363495,
  47693.08569142886,
  -466.6934756400776,
  1239.3039891039014,
  80416.10360490973,
  -166.85492537888263,
  -463.5359030158579,
  87076.15231239221,
  46.499122194619765,
  477.3065651364217,
  65529.648904333255,
  406.1302085817322,
  223.51021669680122,
  22711.485075148743,
  320.7848000855767,
  -619.2952441364566,
  26475.47400077253,
  183.11551171126314,
  50.49646858552504,
  68082.17186520943,
  -180.89129380937726,
  135.13332112326157,
  87595.66207433867,
  -142.6309782963235,
  -677.4817956206005,
  78735.3923446867,
  142.1316526796315,
  -1785.1749771119057,
  -48.781926805545396,
  -205.95434465512523,
  612.1295858985112,
  563.464318320003,
  -19.518577742062234,
  -1919.7299699037071,
  688.0735406200515,
  29.962290588652195,
  -520.8427318730055,
  284.93939687916117,
  215.1734440843772,
  -898.1986494776042,
  -516.1865902440775,
  563.9783219419661,
  2141.392118355823,
  -445.76252078629284,
  174.26059845137073,
  -1155.4433343524688,
  332.69699070883576,
  -4.159427820934198,
  -1029.6014246917998,
  697.7935457216212,
  -398.5572446126146,
  2054.87771551851,
  532.0182835767386,
  93.12035113935363,
  11.29251908684581,
  448.5423352751928,
  196.04951815211157,
  14.276689231040113,
  545.274244740784,
  331.58425925047777,
  12.78822303706321,
  564.9618918371483,
  383.9929347821656,
  8.282230405605224,
  501.26867067768524,
  371.39675260585693,
  5.468218935523193,
  374.6946866411701,
  373.9379112463573,
  5.7250068842432125,
  385.8213448530012,
  381.3638476764039,
  9.201978467501387,
  508.81413670447847,
  296.61337109517535,
  13.749806296376882,
  566.4976050587089,
  142.44506759845925,
  13.380385810040519,
  540.3059251960663,
  -344.8803785803183,
  79.63012291072151,
  -334.7455007844983,
  -387.1033349567356,
  9.523784900053755,
  110.04348144767312,
  593.1005156717263,
  28.65917457854823,
  200.5704705551612,
  -382.54947536730344,
  15.846930432957322,
  -92.30127333079581,
  -333.4714785643006,
  95.54756362444537,
  -674.308946369638,
  577.5101197254126,
  41.55882930184879,
  -623.14677032011,
  -229.66581385313123,
  201.68205313099784,
  -57.60599880281183,
  -63.63910410599951,
  324.84226428279817,
  207.63192860547898,
  525.5177711945908,
  88.54769981747532,
  87.19834372726778,
  341.7209434069336,
  395.88916039655953,
  365.2579170427711,
  155.57570983286067,
  171.7426395529912,
  1377.2103519778766,
  402.5076187975452,
  113.60470353997407,
  1583.1709551270978,
  224.2208282302476,
  210.3560328810583,
  916.8498766198426,
  145.93637532072376,
  2.035634670007454,
  -407.29281892728517,
  412.2147946739832,
  88.90467398371123,
  -290.892254394251,
  153.01060336269836,
  3.349850926270449,
  995.7861114229986,
  201.65838937517907,
  141.05949165085036,
  1599.236685065708,
  406.2787560808728,
  103.89274464021503,
  1325.234710345358,
  2.534379891356364,
  2126.09088930749,
  1321366.353009274,
  -31.96663722793035,
  -580.0984802187955,
  2217476.2230201694,
  -70.69942772122008,
  1933.9784931070574,
  2399859.6265713945,
  3.7190498398362806,
  -2197.712381269897,
  1809815.1991522866,
  20.11825104441766,
  -2736.4865140410548,
  637252.8357258813,
  97.67437953339069,
  1603.3232080755554,
  740328.5250092229,
  31.92645022400586,
  3025.197286949251,
  1879715.2623041107,
  -75.71676222752313,
  3204.86948123755,
  2414086.2430307358,
  -73.57733298964835,
  1479.801301603879,
  2171450.4575205925,
  100.13065309826617,
  -196.1076706853912,
  4.350114617937889,
  50.75266706640295,
  421.25649731523083,
  23.615750639994705,
  -7.397250383575042,
  -230.75885037151585,
  27.536846017773648,
  11.888425436064068,
  129.48859968506645,
  14.851368984291987,
  70.04408471875526,
  32.31028295941549,
  -10.357771616582305,
  126.26067545159368,
  -290.39891484627043,
  -8.141727826738387,
  113.59150494532358,
  -33.9364732103229,
  16.35416369693749,
  58.2853424186164,
  -1.5291241166772807,
  27.84270674278467,
  -3.08746625861901,
  -312.6784754627397,
  22.626233979788072,
  443.7389952296998,
  47.19818758552903,
  -230.42837448600184,
  -712.1932753817857,
  38.84007371214996,
  623.4993281267143,
  1174.3766163380599,
  9.439977793753478,
  797.2974816804657,
  171.33080641700212,
  81.00341933139241,
  235.0279439737692,
  -133.01724665326196,
  4.910047387624019,
  -882.3389310933177,
  1310.474020758514,
  71.15201709860133,
  -784.115276282021,
  8.615669715933478,
  99.08074562273572,
  301.63763363045695,
  602.6390156048901,
  83.17494366309995,
  810.8544151722591,
  1107.1890923610968,
  122.71667864717523,
  579.6401122991202,
  -8.318618078271498,
  232.3524109637726,
  377.7198612843729,
  -306.49046981125633,
  209.68353140618888,
  459.1783113606602,
  -34.99761229449521,
  180.24670236826208,
  475.7573825997039,
  470.50903734307013,
  189.81175728129287,
  422.1209858338402,
  514.0038260219239,
  217.38476976741265,
  315.53236769782745,
  354.75727816010885,
  229.21508156129914,
  324.9021851393694,
  369.0391406378226,
  228.599130004213,
  428.47506248798186,
  535.0192645393317,
  213.74976618366648,
  477.05061478628124,
  384.8293453226552,
  184.14654134259814,
  454.9944633230031,
  81.2755107185044,
  -64.10628665555058,
  367603.12334407517,
  -265.19300342853523,
  586.5214051395153,
  617003.2526047066,
  -103.91647833103448,
  -100.62446867147548,
  667763.1492902731,
  30.67594138464522,
  279.0330803962813,
  503545.3882850835,
  260.5369998309459,
  176.61880502862527,
  177204.59594324543,
  225.04858213365276,
  -163.47793425789905,
  205892.02712909048,
  136.81336589177553,
  106.80267981485372,
  522999.5706000034,
  -95.22975886715466,
  140.95613385524018,
  671722.619108252,
  -89.36523329353193,
  -186.9579155225219,
  604193.6270787938,
  1261.1610236583674,
  553.2999923364739,
  -407.224501182472,
  144.88753112376554,
  181.00292677457423,
  387.4752927785761,
  -870.8706777885648,
  190.90931409809312,
  549.2189115853985,
  1287.542338532958,
  306.09551965425266,
  25.948048725548347,
  786.2409733304355,
  1.0378966562601022,
  -1013.918936123212,
  -853.5454446748258,
  157.97651231558007,
  -922.5080145641526,
  850.2608242008312,
  7.55538140474647,
  87.93773062018363,
  1259.2708833642575,
  262.0049933716147,
  561.8355443749285,
  -867.8148556402555,
  184.42347313391306,
  346.65812561695503,
  361.7915036690127,
  -390.2517795673334,
  520.3912219325464,
  396.69837522522283,
  492.16270801167747,
  632.6179452713443,
  289.25226435486616,
  988.7334969993382,
  655.4592200490486,
  215.1505208147863,
  705.8378239426538,
  581.563423417818,
  216.5253663892966,
  717.9127448210028,
  434.7144304967351,
  300.6256936330718,
  990.7331289669853,
  447.62339093929427,
  402.98675878129114,
  294.8133217815001,
  590.3175453299099,
  330.08377161129965,
  -510.78470713511115,
  657.2409285234908,
  276.26310855397577,
  -532.455516703482,
  626.8537850672897,
  361.8830706089249,
  48.922868557052425,
  847.8168625567718,
  410.11949325396296,
  178.9820232287831,
  1030.6556662606122,
  197.91972605453964,
  425.2832528940123,
  1067.8684729004224,
  413.57045450717817,
  199.92410339006005,
  947.4780823335652,
  338.0453825086454,
  565.6098646473954,
  708.232977495667,
  195.94334992883154,
  173.37400847610343,
  729.2641438182585,
  188.83995005075883,
  369.0104039120215,
  961.7402217800898,
  326.55487995086474,
  16.124140533159107,
  1070.7712168844248,
  396.7464765508986,
  123.96359316191425,
  1021.2647464804363,
  286.82483569972794,
  325.90768909809486,
  -230.6114635133541,
  279.8718937070692,
  76.62149943371378,
  777.1898815130479,
  -111.32959732485804,
  592.3737998817418,
  982.3056218487534,
  251.57870542318338,
  560.9267819277482,
  318.717832584609,
  257.6831120781027,
  4.8747994789730456,
  -999.9931497797528,
  -145.71989653274846,
  320.94442120693236,
  -884.0700673813719,
  164.13561892268729,
  525.3752718750272,
  397.33026619275785,
  238.63656234817017,
  3.291038727271541,
  998.3054491943941,
  -75.45113257299786,
  2.2950700071965002,
  725.4274470966305,
  153.51933906006656,
  853.6669627340104,
  3857749.231080465,
  -369.4194924471036,
  53.37382862314311,
  6474143.665456656,
  -880.6480363916862,
  796.8541493411,
  7006653.057377772,
  63.45077281721399,
  -424.9982000424118,
  5283885.562455226,
  371.51009229716954,
  -584.3282322081828,
  1860325.8581183674,
  1358.749017117095,
  699.0704696962042,
  2161278.530090551,
  532.1220579969042,
  1119.556957340642,
  5487974.52778573,
  170.85339573760763,
  -639.8100927669234,
  7048190.865820583,
  -911.5551914468736,
  662.5417127752179,
  6339761.085015341,
  -1062.9836215064208,
  42.991132649186135,
  176.542978643783,
  -656.8214950325208,
  12.670321204332087,
  214.6159498750912,
  -1068.022688005032,
  40.86638504116091,
  222.36486360638332,
  -213.92926662355478,
  74.3094967444936,
  197.2956781614688,
  -996.7465598214408,
  27.485754743266707,
  147.47708490224542,
  780.9395751116538,
  74.88930164017852,
  151.85645609774875,
  -962.6224475063741,
  25.01285119415655,
  200.26551833677414,
  1116.1735051283858,
  70.06759361371158,
  222.96930908489233,
  -969.6878094742367,
  53.51608650507873,
  212.66045568357754,
  1010.2892252975655,
  434.7417463239451,
  112.76513018121258,
  944.0443244945112,
  258.0450048354881,
  257.78076962428156,
  166.45681887558686,
  150.7137054120159,
  287.29550523305534,
  984.922107132042,
  329.1996083318942,
  191.80981446506834,
  1011.8084932476476,
  408.88854057551964,
  2.0564297410623444,
  -179.4403295702803,
  5.825470235255949,
  18.73695909654994,
  828.4643546437159,
  126.0947349390866,
  203.12159965380792,
  990.2686352271794,
  446.9432260661016,
  289.597769667368,
  -533.8359933772203,
  181.00300674875697,
  250.33251351401606,
  111.75875581421526,
  553.1609952828212,
  25058726.765589714,
  -114.30807772250287,
  -316.2830202937537,
  42052572.913411334,
  -375.1318480506567,
  491.43916048610214,
  45511295.55846813,
  29.525654497242797,
  -835.9897125229433,
  34321680.80752481,
  683.2160355842794,
  960.0266583619592,
  12085183.844767138,
  629.5246273757409,
  385.2062922224425,
  14039913.352701781,
  279.4085002463972,
  842.0257309140421,
  35647267.05389733,
  -348.75270866296836,
  899.7507799621864,
  45781089.4078665,
  -380.6274366967585,
  345.5211971645144,
  41179739.342539035,
  282.57382513291776,
  74.48705789229696,
  106.90777045949216,
  263.42746042741646,
  0.17137259130004168,
  131.2548403878847,
  465.6789551659998,
  193.11336686329685,
  136.2101495844969,
  266.50385226521786,
  16.14100807129992,
  120.17879738540026,
  272.21029896865133,
  38.816747353869175,
  88.3205857830698,
  495.66556877661804,
  141.90341087948286,
  91.12112520226877,
  266.11123964505083,
  6.42874063038596,
  122.07796375161361,
  290.76887233691707,
  98.99234447834331,
  136.5966830190363,
  523.2779803321821,
  6.3215033865439665,
  130.00433242158772,
  103.15326106234093,
  -684.7588962025483,
  620.9796632528413,
  -166.4273585628427,
  -548.3515403304348,
  754.8991260141288,
  -386.7035925012432,
  -147.51617664606778,
  782.1554795457088,
  -445.56290535367066,
  354.5002932953079,
  693.9760772540036,
  -389.8967355214968,
  706.53105599528,
  518.7420718945261,
  -353.75797722760734,
  814.6102194986294,
  534.1462554601046,
  -398.66471096203463,
  674.3960814089306,
  704.4223174055137,
  -446.93724540212304,
  266.5615154656664,
  784.2815813741852,
  -338.5297828250617,
  -282.08285053324346,
  748.0207888870024,
  281.4172258031977,
  837.1635857339911,
  3237.400152226663,
  122.48685591202363,
  146.43508029066214,
  5650.039183535555,
  34.174180040742286,
  788.1287658507559,
  6141.078656257016,
  32.84923519220331,
  -266.4451286257422,
  4552.474107374703,
  201.18471099481943,
  -403.9619837620444,
  1395.528938796266,
  277.9854821579538,
  703.7322216108652,
  1673.0444973973938,
  304.06507101631405,
  -497.70764512354845,
  4740.6693569694835,
  142.08880581855232,
  -451.848065735654,
  6179.381649340721,
  54.29550458847963,
  672.2044568478099,
  5526.121835890674,
  -102.42862137032552,
  116.22501113773905,
  63.63758532508456,
  -381.25937955968686,
  142.49510143978335,
  77.36156332706776,
  -613.744107664186,
  188.84199875282718,
  80.15477641625445,
  -717.6841400822705,
  253.12002736341668,
  71.11820956983178,
  -616.204464608579,
  324.3939386682782,
  53.160344557786146,
  -280.459103379357,
  383.37112223859526,
  54.73895510500246,
  231.4385650520245,
  408.3318468993773,
  72.18873335395347,
  770.2101212834189,
  385.489251369906,
  80.37265792594955,
  1145.3359293712163,
  318.3975620850984,
  76.65667588594074,
  -256.0752032834779,
  118.10250113593233,
  79.76971144244072,
  1416.7602317760904,
  182.66902033540043,
  234.4906237520512,
  -562.9696255650192,
  172.02142294120495,
  265.9806536378221,
  -730.9647212267548,
  182.2561004476261,
  164.10451638204557,
  1420.5606474582455,
  182.1642877537565,
  -38.348246030939286,
  14.111078875587964,
  66.80459039903758,
  -20.551360608098587,
  -781.784164542624,
  85.56480316512042,
  176.17335068828754,
  1430.9528975417143,
  175.20562600005215,
  268.4369987259991,
  627.0837154699097,
  0.3911850749706929,
  226.5438879039613,
  22.893132681863165,
  -166.35666318684503,
  222.73154863779595,
  -342.68415777696646,
  -56.11194660861963,
  270.76547164473715,
  -581.9448544426239,
  179.62402952906388,
  280.5417174568906,
  -571.4683343259278,
  426.96585904088704,
  248.91373349441122,
  -451.61940177341637,
  568.9450730879512,
  186.0612059522515,
  -427.51469078044806,
  587.3867204315334,
  191.5863428675086,
  -538.377898123887,
  480.0481549738673,
  252.66056673883713,
  -599.4505096525887,
  236.12857719378263,
  281.30430274082346,
  -375.62507423585396,
  -37.54794251804071,
  268.2983656007926,
  165.77975847644,
  344.22388535906384,
  -281.7121197236743,
  195.54101480021893,
  332.90951539660125,
  767.4338271862351,
  325.81377815236533,
  378.09183521002285,
  980.9643495284067,
  197.40455190856954,
  324.9193373275498,
  290.1531663907767,
  165.06789778092752,
  336.4457880050054,
  -1082.6573474282043,
  326.75331555223215,
  372.0946898145106,
  -961.9785721400267,
  243.95063137130884,
  94.29643550558747,
  371.9906401188482,
  169.3019322336445,
  72.6126314440928,
  997.6205626737634,
  328.0629497682565,
  340.3093426869427,
  713.5478619231586,
  243.60303848981275,
  676.1102614786048,
  5300204.330765157,
  -117.5475970945867,
  -2010.094697383316,
  8894896.890285447,
  -948.058510664539,
  485.41655868618585,
  9626517.292722937,
  194.0588058369983,
  2467.9441607789,
  7259588.4327561455,
  1804.3055625594293,
  1933.1487161386933,
  2555922.794823622,
  1527.2453340969814,
  157.2030654519698,
  2969404.9198779403,
  672.4672916089424,
  1568.5770234452837,
  7539988.465532042,
  -983.3487153121118,
  1746.9223915491125,
  9683586.536177335,
  -930.973135135655,
  34.59333184327747,
  8710267.212246591,
  -56.16596787195678,
  75.13000672576979,
  699.1206181708673,
  254.77831299956108,
  10.520223293093636,
  779.9311905654802,
  -49.7774395201576,
  192.84090537974788,
  796.3784005890378,
  -14.725912252679478,
  21.44079531282904,
  743.1685995214411,
  246.66265145354012,
  2.6225153425490078,
  637.4277312105992,
  2.9442066429311353,
  346.70746428090695,
  646.7230260507898,
  88.93630450179629,
  256.072699966879,
  749.4721391908008,
  224.8628550097165,
  4.595056811782939,
  797.6613470867746,
  80.15009563381236,
  280.671236878148,
  775.7806186552792,
  33.10969177842482,
  433.14613398692336,
  -88.41451293505766,
  319.6675367977394,
  0.2649981418993548,
  407.8878970082325,
  -135.2842615732967,
  134.31349414642398,
  508.8993083824117,
  -88.56159516455503,
  259.4720581817871,
  182.10849723092718,
  304.9237456701184,
  208.78868080046902,
  -467.30464534527255,
  -157.2163700423256,
  49.75460186817932,
  -410.21709982223723,
  -153.61622430778934,
  52.8595301654569,
  220.8220199343612,
  173.80936331790912,
  435.9886955905565,
  516.7785922407893,
  -168.01234231367155,
  0.021330159887611444,
  382.3969398149511,
  916.5842324298894,
  362.25825312954424,
  555.9378539291951,
  403.02960042167985,
  22.529401856078437,
  755.02221452972,
  -286.3324942004673,
  50.149548230095576,
  795.5414460383538,
  1107.1523447601871,
  484.532809338583,
  664.454152515733,
  -382.2837852523219,
  178.40167850232416,
  403.9516893700609,
  -735.898467485952,
  357.5236045321172,
  426.85151268545735,
  1192.9800848952268,
  532.8159591249371,
  679.983508729997,
  -839.4717076259108,
  546.1616195072411,
  798.7021040515083,
  -882.897879774029,
  575.861679209462,
  744.7968946194266,
  40.69431270623616,
  350.8458647676631,
  123.16951998403464,
  47.219730247005614,
  294.9034587317485,
  149.7320580523892,
  37.34808273969244,
  369.3269077130233,
  155.13827693468605,
  29.13089290429742,
  395.4429598792194,
  137.64814755451312,
  51.745125180149394,
  224.28511278125498,
  102.89098946668287,
  35.74019063612356,
  -149.42202500982603,
  105.9463647193596,
  33.30158314546394,
  -158.24309260521454,
  139.720129072168,
  51.250616887490104,
  234.75587816407682,
  155.559983082483,
  28.979953770273127,
  395.70379824372407,
  148.36775977924015,
  -27.90521176695779,
  214.83854218256334,
  722.5945172396698,
  255.22915199403775,
  209.4518449854621,
  878.4280739073499,
  573.8527860992393,
  219.0330917726803,
  910.1445580168248,
  730.6811426562188,
  244.75097893302998,
  807.535798986477,
  548.4704247410087,
  272.560405625638,
  603.6271382045395,
  103.07031905205005,
  279.29454241537303,
  621.5520063535763,
  -236.9238010641966,
  255.88497955569835,
  819.6914238900523,
  -147.59483744867373,
  222.3789477089804,
  912.6185674172336,
  284.17261664705734,
  209.59769207789924,
  870.4241907048755,
  1083.336365094603,
  -510.7034080655508,
  571.7118552592274,
  533.4616585120641,
  -577.701377876214,
  695.0063027931732,
  -147.2488398294347,
  -545.8639456113854,
  720.1001687718344,
  -824.5064515959355,
  -366.84183910062427,
  638.9168182321984,
  -1297.3666321181972,
  -40.37562545049735,
  477.5856761078529,
  -1389.9056253368553,
  366.43031767832787,
  491.7677095723608,
  -1058.414361996669,
  742.3449504320781,
  648.5342657766465,
  -425.6650351578577,
  990.1601998972575,
  722.057588141192,
  292.8572170371158,
  1076.665883162736,
  688.6736849753064,
  561.1795992329676,
  694.6837594188269,
  703.0926765755311,
  1030.405720848907,
  501.16209133399707,
  854.720498049055,
  1034.3985981531246,
  497.62098367172314,
  885.5809975021662,
  517.2153677893733,
  701.1860311667971,
  785.7415089570123,
  41.48131798310004,
  691.388359927595,
  587.3360648723146,
  736.0541588545107,
  654.1481798100868,
  604.7771652730111,
  538.6007540959338,
  -142.19213192922285,
  797.5690701202924,
  -457.8609890820926,
  450.5371068485615,
  887.9882367625072,
  -356.5579537438591,
  541.3878688570269,
  846.9326287398292,
  79.67966902410203,
  360.32748598715057,
  429.30156112933815,
  602.866136625234,
  51.75549511679671,
  965.4786898761864,
  445.6914041914241,
  192.93779010442356,
  1074.6057209689081,
  260.56460461617655,
  254.34044966589659,
  721.5593619071464,
  459.8846200292969,
  27.059973940109273,
  19.970034148771433,
  430.17190539202954,
  171.95803140047232,
  81.64419819170567,
  463.9678012636822,
  24.171331683362496,
  763.3832681202455,
  255.89866341509236,
  260.02006476063593,
  1083.1180548023244,
  446.39124538171865,
  193.8926773233728,
  937.9396975943151,
  592.1635093990395,
  -295.03599026263856,
  766.7302619006156,
  352.7931401750029,
  -347.863820619527,
  932.0820613761227,
  68.6961779755045,
  -277.4962548145102,
  965.7357739184206,
  -143.57050405427816,
  -72.4017752564148,
  856.8597185268442,
  -211.3341846928372,
  174.87209914840312,
  640.4964094301008,
  -178.72791716627114,
  356.30673482027817,
  659.5161203780135,
  -144.31053576129005,
  429.1136208886155,
  869.7578034742459,
  -164.19775699115382,
  390.7352046066111,
  968.3608946884567,
  -208.35700320134322,
  233.44476604460178,
  923.58930462577,
  48.97440352617659,
  -52.43980364560798,
  65893.44890532862,
  0.1997234630325444,
  1047.1279730134786,
  110583.47855169974,
  -10.171060040909765,
  -114.15592288439706,
  119679.14860788514,
  7.405746385718661,
  527.469406600906,
  90252.95452555084,
  49.489845360464386,
  354.3881829083312,
  31775.921142236017,
  69.66080886729009,
  -220.3789537847647,
  36916.42429263282,
  58.690866646040945,
  236.39818256810764,
  93738.95105240557,
  17.751734403230323,
  294.11788616818785,
  120388.64632977474,
  -6.800479605816562,
  -260.0603739282998,
  108288.12070160931,
  -318.44446456815496,
  162.23779910839156,
  189.88634330872006,
  -47.84664039637602,
  217.27099043377945,
  230.83692283076667,
  -318.8616848331993,
  162.39416868059257,
  239.17151027430765,
  361.7171078151416,
  137.6099042305308,
  212.20756081320772,
  -233.029385423395,
  145.32403877164444,
  158.62360876113607,
  -283.0519773300765,
  195.94535794996585,
  163.33397894234605,
  -314.7807029211687,
  160.9478529174902,
  215.40186565292566,
  191.6587377322411,
  219.17051157468234,
  239.82164058549463,
  267.2907263566369,
  216.81303176326855,
  228.7336296596619,
  248.4184734273964,
  795.2236636485237,
  606721.8502846352,
  9.176481111580898,
  -739.1237577836413,
  1018143.6418273858,
  -243.03828949105258,
  686.300332910999,
  1101879.4750637691,
  68.96869955553868,
  1818.7106146185506,
  830978.3907853042,
  564.8452750313801,
  1513.2380151542773,
  292631.7835209204,
  608.6703962279765,
  498.8263557813748,
  339955.8742029488,
  377.17306797518665,
  1304.9964084347794,
  863070.8943647204,
  -124.4364651898137,
  1406.8664294738355,
  1108411.1964822852,
  -231.94521319448125,
  428.7922625211613,
  997012.3012042409,
  -868.3324293536209,
  76.62684827162927,
  -285.74893106290494,
  468.64607942238,
  301.8630940002066,
  745.6270035102843,
  145.37052128462,
  220.32310769261196,
  955.540831695211,
  -736.6809744137684,
  273.0004630642899,
  276.43033070085727,
  556.9007640888453,
  315.3565048195849,
  -1073.1280704464853,
  -539.9930322710197,
  325.5938973412375,
  -954.4933037464044,
  -200.0027506611338,
  305.4191333061865,
  356.88167419410576,
  523.8650412879205,
  310.76188212478786,
  971.914928597401,
  -858.3905664962203,
  164.576739717459,
  692.6537370669685,
  477.23343450183467,
  -2943.288738982438,
  -1727.385681562889,
  -307.8140464302145,
  1114.3211364603872,
  -1479.2925232226412,
  -79.5253041476451,
  -3171.0327127629275,
  -1428.7986316473623,
  84.52393634809303,
  -803.3157529551745,
  -1592.1558163614307,
  585.5899022902353,
  -1442.0177024089571,
  -1916.7864334640246,
  1306.8051372504124,
  3702.707630853633,
  -1888.2493375584843,
  576.2317321102558,
  -1877.4227777001279,
  -1572.8035828732445,
  91.9170789183249,
  -1664.4263219046056,
  -1424.8599112649495,
  -726.873960461904,
  3556.275800398198,
  -1492.0350204430754,
  1217.1905326430651,
  9.674714003104247,
  -174.2441791959446,
  900.2832056233601,
  0.13852094115757474,
  426.29194626792577,
  -591.6567466442757,
  0.6663531990791762,
  548.517831935533,
  1274.2515593022183,
  7.300026735874252,
  153.09422803134862,
  1193.4236357485374,
  1.6396292606417342,
  -632.70903355787,
  98.90272308116923,
  8.396652464476675,
  -563.6319291276028,
  1250.2531785350961,
  3.316454702902554,
  199.93838687803725,
  1279.4959996212212,
  5.7672357904446585,
  558.0519274888487,
  -338.1488369286269,
  3.379096629531016,
  395.44736368980006,
  -581.0301101544318,
  2.2902472986051237,
  -509.5921520121114,
  1336.0682246146057,
  34.155562504290145,
  462.5939770038667,
  395.4601379856515,
  153.93666644089066,
  660.4610254865139,
  -540.8032844959869,
  10.526389046175353,
  20.324110318894117,
  1084.5341882760117,
  15.901753532226166,
  -1251.784258619709,
  958.1358706149789,
  40.66583430649237,
  -1139.9578423357243,
  -535.1573089916548,
  11.882159041492173,
  96.15841823999465,
  551.7893585523925,
  127.77737809230342,
  675.8954266101548,
  1309.8041005647055,
  10.524248899729699,
  412.66080218515066,
  -443.1248168609678,
  78.02312134974851,
  239.77108381754286,
  249.1926890164634,
  58.72148747831008,
  322.4826212809801,
  628.7660488822025,
  233.93147134573846,
  339.3167308253297,
  -440.5370829645508,
  115.6313501311824,
  284.85523743392844,
  -52.439576649416836,
  188.49661092641622,
  176.62695081815838,
  320.64725778860867,
  130.6125928391373,
  186.14090554742066,
  -407.87162712445354,
  177.28816896581085,
  291.3070597891586,
  -272.95699353747546,
  234.64381914433045,
  340.6298569939327,
  -94.41141553454943,
  0.16134183172383132,
  318.23441249006993,
  761.5032340580079,
  157.6241025540364,
  682.5644232448586,
  361.1883286563625,
  168.18766543736507,
  829.7651550403234,
  347.8031283854649,
  168.22357601216447,
  859.7246180130518,
  -309.79071030807336,
  125.56167912809337,
  762.8001510312602,
  35.676740519381156,
  93.13282520549615,
  570.1875666278676,
  -41.91668658465272,
  160.94009392656852,
  587.1194378197845,
  48.13957967979701,
  164.25426791831552,
  774.2823819415977,
  227.97914394895383,
  89.23612461093819,
  862.0615729154267,
  812.9431464305371,
  154.28328978039997,
  822.2046687766225,
  1732.7353548579445,
  -38.80791741776255,
  737.9907072376742,
  1899.0337326317483,
  -19.978313051582724,
  897.1445811638986,
  2069.4739049486375,
  39.70841115587938,
  929.5368426336605,
  -606.2105695412147,
  -66.42565281567913,
  824.7418174307911,
  -1294.7127865766258,
  66.03884018514185,
  616.4885118878748,
  1729.170860416125,
  -39.136773610336846,
  634.7953019434963,
  1558.6191897452825,
  -52.57432487965437,
  837.1564400240733,
  1681.6307189123354,
  107.30913054130319,
  932.063565302544,
  863.0187849916829,
  145.2416353611548,
  888.9701606772805,
  76.93907683328352,
  547.6031647127515,
  -18.141286545696868,
  167.72901863376745,
  5.843074507619633,
  213.37037009477433,
  -100.98429349769643,
  199.6641128888869,
  260.4894626446179,
  2.4951588327754735,
  353.53440010099257,
  108.05038407313103,
  164.9203273250191,
  0.31469800205320553,
  -194.88328997267863,
  -79.63904461520886,
  5.558253887363264,
  -168.25349335515588,
  -68.46936666738476,
  33.74983308856781,
  126.10919578932763,
  164.56083868143807,
  0.7118447042004163,
  264.16493554712105,
  -13.674864356871616,
  279.70227515646326,
  201.47952771534224,
  -701.6400040413546,
  1.7138081123198816,
  522.3940747055044,
  380.2367220985726,
  76.31338013476544,
  897.4891093611432,
  131.11041625799677,
  60.65730405184001,
  973.8314322895003,
  -837.7974735213024,
  1.3538948682224685,
  726.8497368993518,
  1141.7858334017646,
  26.688977879109757,
  236.03679636118147,
  747.5874295483545,
  77.3585228422073,
  279.1823754221719,
  -884.9299129223382,
  6.890923226066356,
  756.1086118295497,
  1463.5612800343424,
  1.5264372611228438,
  979.7864310819856,
  1281.2091840187418,
  41.91424305617184,
  878.2235743158633,
  93.33882946737,
  637.5760887257466,
  1880468.459334632,
  -289.52637569917607,
  131.01441999317868,
  3155865.5835268707,
  -590.3033220851942,
  601.6152734556242,
  3415444.5438465434,
  46.142111740921834,
  -171.78079689324488,
  2575658.0499573103,
  307.6266875681231,
  -272.6319519675381,
  906797.214586855,
  903.6887280608635,
  539.7211226445445,
  1053500.696029938,
  291.776920600125,
  -341.38249328947563,
  2675143.9975048006,
  46.27190184838224,
  -307.7503138165899,
  3435692.714664045,
  -618.557078474097,
  516.5995097330774,
  3090358.963277065,
  17.828682985957812,
  2315.7148073464673,
  27787344.93411653,
  -1058.0982845621377,
  43.63167323332942,
  46631126.55786574,
  -2025.6101695559692,
  2154.419614860558,
  50466362.77535504,
  115.01821761257952,
  -1314.496957184183,
  38058656.18636209,
  744.1433938648374,
  -1766.845057413387,
  13401513.28895622,
  2747.870597522333,
  1876.805525918601,
  15569032.969940316,
  656.8445452493206,
  -2075.2121428850824,
  39528544.611431256,
  83.62061499102259,
  -1924.3615901083544,
  50765526.15116007,
  -2133.5998757670595,
  1773.0980605253276,
  45663277.075157374,
  111.74825233399496,
  0.18862005928562553,
  0.989218976256719,
  43.72864668837442,
  258.58791315451384,
  41.452022874503754,
  18.52964326340208,
  214.14718387459644,
  49.68733434596243,
  132.48508742962457,
  75.69046564054054,
  23.044561225270748,
  7.75276406592527,
  185.6246267381689,
  -29.90113500861948,
  52.18736093365134,
  265.15937399786446,
  -25.24687157315728,
  97.46674597078186,
  16.77349326031566,
  26.200817664844312,
  -31.00825799500693,
  57.684525753182896,
  50.329720744321044,
  75.39719368793047,
  257.61020513071946,
  39.37378270998751,
  801.7269153290863,
  -5.918168633896471,
  692.8285499101949,
  506.95408248401844,
  -117.27701432976528,
  842.2428265446893,
  528.3596833776099,
  -112.34578276455227,
  872.652807757609,
  851.1267286244491,
  26.371287152835635,
  774.2708299941363,
  964.0062283659208,
  139.11185155067008,
  578.761815750091,
  625.3495274109982,
  -84.7970360746574,
  595.9483015463977,
  -477.15297057424084,
  37.57205411715793,
  785.925726030945,
  -458.235438103314,
  551.4118683514557,
  875.0249048389669,
  -531.9339119315875,
  488.7424048614166,
  834.5686487582259,
  673.7529985360172,
  -39.28672365288634,
  269.94653129834256,
  217.25964619280765,
  298.5965340035095,
  328.1627605648196,
  -202.91112584779927,
  -5.42138225131643,
  340.01139028185355,
  -118.05913169447075,
  -47.14630048191299,
  301.6788567236413,
  264.85884148904097,
  299.4828634776108,
  225.50275191447994,
  -254.8055719707187,
  40.77830301927278,
  232.19911600992978,
  788.1631457247454,
  154.61906901737447,
  306.2199495498349,
  -37.90383350745219,
  264.1501926402122,
  340.9356295891086,
  74.73401949296161,
  -94.1706993420946,
  325.172673516168,
  1051.4947512769186,
  180.53797343500574,
  415.98755634801563,
  -689.7151181426036,
  140.93927859739307,
  993.6819033865481,
  707.8176352937483,
  221.71751570642132,
  1111.2588487491844,
  1159.1376810598595,
  29.417536483687698,
  730.8754363697832,
  -690.8904090543186,
  117.2756369057138,
  -25.039291913858904,
  198.2626403756812,
  121.32963801203603,
  41.41042034671781,
  835.3917711110616,
  36.07957422440758,
  775.9378474555508,
  -665.5230159266279,
  68.95349749154946,
  1120.4303088358215,
  -240.53878811367946,
  17.232414880736115,
  964.0105143782969,
  36.31412792871531,
  515.1799911557043,
  1793.88684917175,
  -148.82902658201056,
  38.24540522631894,
  3020.39272534851,
  -309.14262413123083,
  481.3224026345455,
  3270.0209502557695,
  21.680005604992587,
  -246.8403410924886,
  2462.4269468261587,
  138.75100422609566,
  -341.7930523906103,
  857.5404512575844,
  458.02986195171184,
  423.0482318659759,
  998.6201813530151,
  137.80257626812931,
  -406.5226065233572,
  2558.09918643646,
  30.166960475512838,
  -374.85745974875624,
  3289.492924920308,
  -323.4095666190944,
  401.27892407855035,
  2957.3972448500326,
  12.75382884330034,
  481.28386218127105,
  85.19225132229062,
  6.924219713433359,
  266.9579255626565,
  103.56467348623586,
  17.540342344359896,
  -288.7759540433382,
  107.30397487982451,
  10.856511069053226,
  -150.88818167343135,
  95.20663539187157,
  72.57187500244231,
  -214.27174344534,
  71.16626771445564,
  22.42968827462133,
  -351.8233999832037,
  73.27956893089039,
  52.823293651319055,
  713.0993214825895,
  96.63975594158288,
  29.73954112300384,
  -412.88710276127745,
  107.59565496538409,
  8.099405604072864,
  -52.451425262876285,
  102.62103384730777,
  160.25529306277355,
  -96.46028093980397,
  176534.664100132,
  -675.5714905385053,
  1213.2316357544792,
  296385.8255874483,
  -246.84766022770378,
  -169.97016747211148,
  320778.8866206434,
  70.4495418198227,
  594.2678589699294,
  241862.77117328343,
  609.2933403959754,
  388.11132690924103,
  85037.17882570803,
  494.7092032328851,
  -296.49210444599817,
  98823.14580938162,
  289.6397514503761,
  247.57378754457417,
  251211.6289831868,
  -255.16155405789317,
  316.32355526577743,
  322681.64047231764,
  -210.70243107677084,
  -343.75652625620285,
  290230.060945106,
  741.1372570813863,
  172.611463978039,
  143.69777331470706,
  611.2883718923804,
  367.0933121052341,
  174.68740106112074,
  731.146729140622,
  213.1414472497167,
  180.9946564238004,
  -409.8599334649522,
  -41.37337702243872,
  160.5895054802653,
  619.5218099012884,
  -81.72327925186264,
  120.03948771113001,
  697.7267970797585,
  278.7150386256809,
  123.60409217258619,
  232.52903748547746,
  501.73372458093337,
  163.00681725086267,
  -487.6676650437835,
  168.9053813310282,
  181.4866469295635,
  524.4376096558319,
  420.60695144882885,
  173.09571974244685,
  484.32422066698655,
  1.0921658735170736,
  73.90171199042078,
  440.9694887756391,
  3.220468944011737,
  89.83923483143352,
  473.8241277828736,
  0.5549718661339573,
  93.08296616081162,
  -1.9136113089005846,
  1.941984893358348,
  82.58888853270787,
  481.18031864909375,
  0.8776726520712156,
  61.734593680009716,
  415.25631981069387,
  -0.5877640530802597,
  63.56781883161576,
  482.6005854929261,
  0.9635052121805715,
  83.8320774433008,
  194.08992215311423,
  -1.4073738046496809,
  93.3359898494898,
  436.2391697114412,
  -0.29771001330251234,
  89.0206558675441,
  170.47632098854695,
  8.084738554504073,
  60.51643647940799,
  226.89776199168853,
  0.06608011630321364,
  185.5062488414352,
  127.4105678049393,
  1.4216525677768033,
  210.9451689456612,
  91.0699899978721,
  0.1658233861323435,
  128.64550376344718,
  229.24321336731634,
  0.14955200307379535,
  -34.904028154619624,
  203.3076913193476,
  15.182961141859275,
  -20.526984118206038,
  30.845362115323184,
  13.256003501244303,
  138.3951963734996,
  240.90951689372827,
  1.1499418990140278,
  212.92950388193185,
  254.01047397872378,
  23.94091837752474,
  179.0865541297356,
  183.73319560685366,
  332.9533694926165,
  472.1498266054661,
  44.12655775983173,
  276.2461729789046,
  573.9728892008252,
  245.21898946843493,
  299.3287941740487,
  594.6967282496298,
  45.4400837011937,
  279.7301571922783,
  527.6512322923003,
  49.449963477194984,
  227.18293122425473,
  394.4154596222843,
  143.38415723554996,
  336.168559738489,
  406.1277314242118,
  219.9226083644025,
  195.54617697064677,
  535.5938281099774,
  111.39554114060901,
  183.99309589427742,
  596.3132684828515,
  122.86011654609547,
  181.31209789179528,
  568.7430791537539,
  432.82447392381164,
  205.72029087739307,
  21.55466599720606,
  615.2409417035003,
  178.38513827088428,
  26.20311015916811,
  749.3778663904322,
  138.03166805043384,
  27.14919846357006,
  811.5952050619452,
  88.39741805397793,
  24.088425822039795,
  784.6693150076289,
  35.42037688426423,
  18.0059231566695,
  662.6961336432169,
  -13.261242988920642,
  18.54061382588793,
  455.17187933405745,
  -49.336215395831516,
  24.451022587629403,
  188.94557390240203,
  -65.32179231729168,
  27.222997039434528,
  -93.22686845832149,
  -56.33422689723545,
  25.964357961367025,
  90.68575380733814,
  -1604.4526261146468,
  22975.17117458783,
  5.236158671303805,
  820.4574438448575,
  38781.15275778951,
  -12.520274544421113,
  -1740.557050232721,
  41998.11176481089,
  13.022126828001305,
  -325.5613076898062,
  31590.64760760458,
  84.28832579341662,
  -707.2625644584117,
  10908.474872192277,
  120.0145077208416,
  -1974.8139125741695,
  12726.569394986125,
  106.33241324448933,
  -967.4694803511827,
  32823.575787303045,
  37.66458629665678,
  -840.1784724969756,
  42249.04710797912,
  -39.12894766496352,
  2279.819146113247,
  37969.32998227402,
  772.3393740742949,
  170.83981638684318,
  -588.6956465827142,
  56.196764626351325,
  41.071974823882215,
  432.9281970159274,
  124.96536823813352,
  69.62345469524448,
  640.8572021303771,
  756.7737466720398,
  109.53658029862218,
  -31.83202494681027,
  -115.68820008711208,
  0.00042139481512037946,
  -1368.6297867750857,
  271.5754441068056,
  134.26555744739971,
  -1251.1167614292688,
  543.6175465175652,
  0.02390481215309137,
  47.85861743400142,
  -232.1654774106865,
  56.41500041588881,
  657.0764750956657,
  368.32249191006207,
  171.52022085476733,
  380.4558149701007,
  402.1007124740878,
  142.09641317413707,
  395.16887661544445,
  377.019446125172,
  -170.59638686229675,
  480.390352918082,
  295.4093146437244,
  -397.1542161252401,
  497.73530516545105,
  219.0977966854918,
  -450.8983678729844,
  441.62114007072955,
  204.1474109742937,
  -449.8333131785221,
  330.1085912056075,
  262.28277610384356,
  -433.2874663164165,
  339.911253474612,
  357.6019818668418,
  -253.42432162607804,
  448.26874743987236,
  402.24741044788027,
  95.7093632012726,
  499.08827905629965,
  387.56881923085143,
  333.75878877502316,
  476.0132292917288,
  48.52483943215253,
  1931.3765995934868,
  379.5827266341041,
  -773.121187791083,
  385.1174788378003,
  626.3799764801835,
  -1393.8218502333386,
  1821.607657264402,
  676.6101144580888,
  90.9327242739046,
  -539.1527427983181,
  514.1062219696936,
  640.0357814137486,
  -846.9968376003242,
  191.17130488956184,
  1938.5407104865913,
  1632.678251191268,
  219.55933797841558,
  499.92246913144436,
  -1056.855099955463,
  533.3573695435148,
  -20.69178659706222,
  -954.1942247436746,
  680.52826103172,
  -1476.3250038757835,
  1562.1004576910211,
  613.7040393797273,
  40.4414011177046,
  48.540157394690844,
  62.1315382358569,
  835.2973963731625,
  16.32731261950592,
  196.33266255103274,
  214.56587675875627,
  92.8766706255312,
  223.64634208087125,
  124.03852298460822,
  65.01005193042344,
  135.28147946130696,
  683.8469044286724,
  68.21157554229191,
  -40.32108085818847,
  -137.5058109833297,
  29.693547602916844,
  -24.884498967601765,
  268.8392508886444,
  86.62855524037636,
  145.74969031201712,
  469.52452658000306,
  95.41693123202955,
  225.77691556068476,
  -269.28043985191243,
  4.834426236228197,
  189.43985879535626,
  89.14471503151336,
  323.458673559324,
  4654.203053559559,
  18.56528584652567,
  -47.68300047754252,
  7915.384469491332,
  -31.093867388768246,
  297.1113243560627,
  8579.126033043587,
  12.515567520132606,
  -269.5314557046445,
  6431.797914394586,
  106.72490550348313,
  497.13840520158936,
  2164.532574954971,
  144.31487379480143,
  251.7634424237606,
  2539.652338250408,
  111.68725385205447,
  446.7670633252747,
  6686.182777849346,
  21.24472185501625,
  471.4082949097847,
  8630.900462453934,
  -26.65439492066703,
  234.8229697190927,
  7747.884505341369,
  213.87766018556056,
  88.71990714820575,
  -498.75153157578615,
  -160.05167175265873,
  0.15020490506825013,
  447.67293656747165,
  -73.28070900616524,
  162.41072897500743,
  640.2967670605191,
  203.67999387608617,
  107.50003311711698,
  17.12264289398987,
  -171.00626941535168,
  168.86395980856423,
  -1221.2765180896342,
  96.74804478928513,
  455.04856695159503,
  -1112.4133555766487,
  168.04567394870458,
  177.87708650087194,
  90.94744084074227,
  -105.29786393467398,
  417.0979705162871,
  655.3221767414173,
  265.69529132793025,
  312.3101793918806,
  399.0629255726214,
  185.3330085945086,
  365.35775575591344,
  24.36553610606007,
  -155.34274269645888,
  364.07219436071193,
  92.03264392564951,
  190.51291598439394,
  45.14859408657341,
  105.80479156693636,
  227.95945462138533,
  365.67142974201874,
  61.24931770742939,
  -115.18977474576766,
  296.6347507391828,
  -27.29328909390235,
  218.39681013099062,
  149.4291861687825,
  -19.509830821950075,
  227.20498173124,
  215.85166056431783,
  66.5276159029766,
  -69.67835537467558,
  162.27589657541344,
  106.87907277070268,
  231.90091065537246,
  308.32529067120316,
  88.55714327470686,
  381.0116888682933,
  -1376.0996241238909,
  68106.53718002506,
  -921.0285330863192,
  1847.8398253560892,
  114185.52981861713,
  -260.9121227544945,
  -1557.051663376339,
  123563.89266327152,
  112.44416798013035,
  324.19772881515587,
  93223.13452927535,
  900.5362349699377,
  -183.27747814497445,
  32928.63904295901,
  744.0018355573948,
  -1868.4982399607698,
  38228.90867133299,
  552.052447017598,
  -529.2248811297948,
  96817.47558409584,
  -231.00146161991518,
  -359.99035698432624,
  124295.44152467852,
  -169.24924034667526,
  -1984.8444066343986,
  111818.83240726647,
  341.9046031357226,
  861.5648466830412,
  346.9274812883642,
  613.1798456421004,
  668.6249077704006,
  421.7452968475629,
  784.7237045312042,
  273.49063005150026,
  436.97281336603237,
  733.1562193080463,
  -174.44045232837692,
  387.70894894521194,
  519.059809972774,
  -470.85931889657047,
  289.80962033115674,
  319.2160474238432,
  -577.9852538282298,
  298.41559395952953,
  255.85887413261034,
  -593.1790142419852,
  393.54503021993986,
  362.12902052750775,
  -563.0300947870329,
  438.1606190156605,
  593.6232297161239,
  -400.1839069871438,
  417.9025233781931,
  105.71286276053308,
  320.35052745607265,
  -354.02446244073195,
  514.8936280339325,
  261.7438007928341,
  578.0573598285927,
  551.2585012963599,
  421.42379514146694,
  767.7620610296188,
  199.45642427088586,
  23.587469440563268,
  154.03186617976758,
  545.0042060065117,
  387.7896518183485,
  -1065.5999010873666,
  530.9002608668955,
  324.4914519984586,
  -958.3865118433494,
  137.03824069385163,
  163.66888001513198,
  226.73788183664263,
  547.6559692791413,
  413.24072710430335,
  782.5597672461437,
  496.01799393910653,
  197.69496045236707,
  530.184012135564,
  131.0336161131051,
  1232.3475684600319,
  264500.1632494879,
  49.494506152580755,
  188.23173556201195,
  444170.12733153213,
  3.5118733607079804,
  1158.22578052177,
  480737.98654371913,
  16.11335708247954,
  -435.8843387314125,
  362434.1215501191,
  99.8999136443469,
  -643.7569320971835,
  127335.45254626381,
  146.23629493719358,
  1030.6506661485905,
  148002.12078756417,
  145.60666827614506,
  -785.464315709806,
  376449.079153106,
  64.93018664461192,
  -716.14227014256,
  483590.42211417854,
  12.028687096391792,
  982.9928120053511,
  434941.96467994014,
  24.69398133604555,
  317.3919010827175,
  640.48150391698,
  29.902459629969343,
  424.34128833840646,
  778.6067018724239,
  40.173637996094335,
  475.9430395906299,
  806.7190400603674,
  51.333328266175684,
  408.39517349224127,
  715.7703672834682,
  56.23552153579533,
  240.40915613801405,
  535.0331452267509,
  51.95396436505122,
  76.9716287626581,
  550.9210965406699,
  42.757932729493184,
  3.5013549008234577,
  726.5446711752736,
  34.7060763083266,
  13.047388455028567,
  808.9119120289116,
  30.386137037825833,
  46.24260930182706,
  771.5123508520488,
  327.6733372440728,
  596.9643789224513,
  243.34001179118312,
  -282.43581641458354,
  4.842137124928939,
  535.5514372826758,
  -912.4569883262361,
  554.929618163929,
  595.0246292664286,
  81.85315448248184,
  -349.09657102278607,
  402.6177280486653,
  1683.613277170147,
  874.0543401122986,
  20.258230445611414,
  1598.0892549700873,
  482.5812633740627,
  53.87006210486684,
  740.2862025527618,
  793.6915192257652,
  425.41135836019333,
  -803.1747376113101,
  833.0043269947537,
  599.6637700845677,
  -926.7297825368196,
  455.5543047307675,
  520.5429489309016,
  437.5633672912741,
  -2534.970594010303,
  5642.064435372828,
  -72.82951945283071,
  1752.6885507554537,
  10504.045499238202,
  -77.22470790299133,
  -2775.6266851133796,
  11493.594531232007,
  68.47342730342655,
  -273.6702165091368,
  8292.218306108953,
  459.33243128481627,
  -948.5838574013258,
  1930.3019853891528,
  596.8449267989342,
  -3189.8332119802567,
  2489.5548919935463,
  522.3430165587519,
  -1408.6745536627188,
  8671.471782474557,
  143.8248595637411,
  -1183.6021022618067,
  11570.783213270906,
  -33.75268748314454,
  -3344.567106122411,
  10254.325673804153,
  239.35246845477377,
  90.36172983313823,
  937.1147645451969,
  253.42111575599088,
  56.28517215034398,
  1139.2114083485944,
  279.97764737413456,
  33.22850284920504,
  1180.3437236780696,
  309.07557736150073,
  33.249475764836774,
  1047.2729893105873,
  328.66359955259884,
  47.32088220897906,
  782.8289448590122,
  335.5640808468702,
  56.26275281900015,
  806.0752582397943,
  330.8524800710249,
  49.860469216819084,
  1063.0373153574117,
  312.4709978702387,
  34.75931397250562,
  1183.552204619225,
  281.4556876757144,
  32.678547891198434,
  1128.8313723203855,
  177.11053664530263,
  179.87860810114248,
  140.61853531510621,
  164.23895994380294,
  177.59231439528654,
  170.944099609811,
  161.18179477484136,
  175.72045733190365,
  177.11619950043323,
  161.44640369212485,
  176.16006019005272,
  157.14830179140247,
  168.51854952810254,
  178.64838283456763,
  117.46721297446294,
  185.49838234078902,
  180.58208047179284,
  120.95543305460221,
  188.63658220885642,
  180.76421394741308,
  159.51381402405846,
  166.20895985224672,
  178.14606094213036,
  177.59764735250144,
  178.60420005086706,
  170.96902174992698,
  169.38652574796583,
  238.24020857130745,
  -315.7150101192127,
  16658.205762347847,
  -441.2802661609147,
  1135.070423820679,
  27991.01049303071,
  -166.56445651635943,
  -397.14413957496083,
  30297.552991595352,
  64.5563056013129,
  449.4254869854606,
  22835.456543213386,
  513.7751784989323,
  221.05964765118327,
  8006.448690529112,
  479.96829478778193,
  -537.2963241428242,
  9310.01279379521,
  341.56191910606606,
  65.3819554908469,
  23719.459490700607,
  -106.50252426176445,
  141.5381570564977,
  30477.472298041634,
  -127.31714861861718,
  -589.6525568047135,
  27408.93788068401,
  63.24800637740465,
  101.61642830118836,
  26.27806064454759,
  101.28224673952793,
  512.192906190836,
  172.4968607224518,
  44.32802999137917,
  578.7606931127642,
  202.25647314705327,
  188.49148283708618,
  82.18607017721598,
  105.97856007281506,
  181.24633661082123,
  253.11786680791488,
  -85.3491638307682,
  19.691607050123707,
  508.498837749779,
  -68.53024004854284,
  311.3141151138544,
  499.6816849923276,
  117.38419648133392,
  275.7250017996316,
  10.872744080973405,
  204.57783892760006,
  10.064585350894276,
  431.7280269259104,
  164.98680818399097,
  175.56496275830094,
  71.12559637703549,
  498.83655593534024,
  178.70799859513858,
  61.78805606732034,
  606.4148351121762,
  168.19040990345906,
  130.2600723989827,
  628.3100215854785,
  177.30343005092928,
  65.47649875079854,
  557.4749975957782,
  201.11301956676172,
  210.01318454673577,
  416.7085073400656,
  197.60099176179114,
  222.7976177005704,
  429.08277711340634,
  176.13649367272848,
  69.12225863432032,
  565.8665227422804,
  173.82044727800553,
  78.293259070639,
  630.0179314840562,
  169.95506926408896,
  184.42848140259952,
  600.8894271059226,
  49.82311538700985,
  450.84634607219175,
  509.41270342518106,
  236.1892500260328,
  503.99513366444944,
  550.3419554614084,
  166.54380853196596,
  225.13371496232796,
  558.6722021655121,
  -88.94959273295513,
  188.10548535181908,
  531.7222958084775,
  294.05137538931774,
  412.7404502806578,
  478.16625083344536,
  -53.42246206550965,
  535.7154673973389,
  482.8741678050936,
  -199.13798761905122,
  0.36151985947685716,
  534.9149370211609,
  321.32350148935586,
  346.6612442840991,
  559.3219938821014,
  -199.3651234720151,
  329.13711590593215,
  548.2397577071647,
  36.02555051745162,
  0.003876283125300972,
  58.388597323447165,
  84.25508125391917,
  30.703438872681488,
  103.38276128060471,
  -11.441089008365253,
  17.922775419323077,
  112.54033116915917,
  3.6733967883169214,
  14.956496030601095,
  82.9138795500294,
  94.40305204480052,
  38.48202442725895,
  24.038885539129424,
  -16.91392339780422,
  26.00924153679479,
  29.214371959734653,
  -16.185873622723655,
  35.85540496314897,
  86.42359973872745,
  75.30962830999599,
  9.978601750531611,
  113.2546573192767,
  -21.90538833152715,
  36.4328806337017,
  101.07178256198344,
  137.96315767620348,
  122.76604897190637,
  223.5097856317834,
  -283.347033725699,
  -167.98185260529058,
  452.1886849706215,
  -1201.330661236734,
  102.12585405752988,
  498.73123223802094,
  222.02446438806038,
  316.70953212933915,
  348.1573855047226,
  2138.1999604298217,
  258.82465153256555,
  48.93038260245908,
  1745.9625807415412,
  66.60087145620246,
  75.2343392519044,
  659.1455856287764,
  219.36435112795203,
  365.9952311084989,
  -1322.0003044476834,
  238.66799412106042,
  502.36173236095607,
  -1203.5708585299813,
  53.32990989309978,
  440.4433379457721,
  138.56595934253892,
  3.0176193579317823,
  135.4864719824381,
  69.06110670467214,
  5.0958052649273995,
  164.7052638576281,
  167.79218166228662,
  3.510371341426874,
  170.65210462815466,
  87.47073217449243,
  5.158660174864745,
  151.41296230996443,
  163.50175509992133,
  3.3921893415430056,
  113.18008841335114,
  125.32511971895096,
  2.917571064238796,
  116.54100119129555,
  115.24608386398953,
  5.130439999467154,
  153.69214197938481,
  172.39988797469613,
  3.6974283083486332,
  171.11598139073132,
  174.94809758144288,
  4.0751024384648336,
  163.20453575716417,
  266.17331271038955,
  246.4187863241275,
  93.4035526545596,
  235.05490577540263,
  255.54760613896818,
  113.54681068972847,
  287.69392845799007,
  244.57414560817205,
  117.64652667547026,
  365.7681211029636,
  275.64386991191736,
  104.38317856217245,
  247.53435509169665,
  250.63817741172744,
  78.0256670122345,
  340.41266569875114,
  252.31986726092288,
  80.34265991218102,
  263.97603296996806,
  305.2267635658154,
  105.95443121306074,
  269.0830763980555,
  246.00026154109065,
  117.96632050421628,
  363.86887458795553,
  268.9206971705278,
  112.51221783259045,
  1132.9344418004334,
  -195.48279588549536,
  552.2100145950886,
  785.5950519804074,
  -291.87709362347726,
  671.2987269348782,
  339.33612432242654,
  -335.1253215771787,
  695.5366082571758,
  -150.6066330787097,
  -302.2825920620387,
  617.1225282027337,
  -593.6279231550193,
  -181.14794694193722,
  461.29460277562816,
  -877.2126299843205,
  20.05908199061213,
  474.99286849179555,
  -897.3312495752355,
  266.0054391417504,
  626.4119120068866,
  -601.4938392092824,
  495.73040876734603,
  697.4272574864655,
  -30.117099740071637,
  636.3868828390512,
  665.18212301026,
  915.4664051917861,
  -205.61467031339072,
  804.7075305623596,
  -100.48746147917399,
  -220.16947378621103,
  978.249445942276,
  -840.2940984269326,
  -45.68004901785716,
  1013.5700759732822,
  -978.0851592946565,
  96.0992080531326,
  899.3012306894857,
  -957.8365297525243,
  48.240601241377874,
  672.221131182328,
  -531.1199550834739,
  -152.69899239619212,
  692.1829161664826,
  592.2124423780419,
  -234.12422370865914,
  912.838176604831,
  1358.8517249794304,
  -113.27571000435626,
  1016.3252228055557,
  1341.9103498454206,
  -118.6058194211455,
  969.3360305577023,
  618.9944698818213,
  864.171119262903,
  428.01408194452034,
  -356.29204729197113,
  -68.21008776729127,
  520.3189017320525,
  813.6855356696136,
  305.7188049278401,
  539.105512348034,
  -334.6160587449531,
  -114.52344058408795,
  478.32731275193305,
  -430.7020704368075,
  299.1862927345967,
  357.5461883967229,
  330.2551668879402,
  -456.9057971984936,
  368.1636173997746,
  -207.59971353491147,
  895.684901974658,
  485.5274485257838,
  812.2794821695898,
  352.4821021305171,
  540.5709412116285,
  -397.59080134907185,
  549.9204874050843,
  515.5779652328595,
  696.1586392074954,
  212.90723646111297,
  279.1842452971452,
  732.1828971653558,
  170.5889749839637,
  339.39266491874884,
  583.7982503391479,
  279.67844839513236,
  351.646761051955,
  639.8288748977302,
  252.68955636368383,
  312.00246779022973,
  526.3719985258022,
  -80.98037905455871,
  233.21957612448114,
  64.95674737322139,
  -104.17274011160325,
  240.14509336388176,
  696.8737787462285,
  6.7377386894771405,
  316.6989592302475,
  533.0116536896975,
  297.92998087494027,
  352.60262832029485,
  586.8893973241002,
  -59.40211308101169,
  336.300255499611,
  1370.6335777004372,
  285.21319676596136,
  607.6362985879042,
  755.2821018203522,
  491.7073483547574,
  738.6781530584533,
  144.20188539193697,
  -84.73738125681808,
  765.3488328777845,
  1020.9117052836792,
  -4.7231952485948625,
  679.0641946022647,
  1385.7104098979244,
  263.81598623422707,
  507.59554803563543,
  731.3863644281978,
  494.7644111974671,
  522.6687326155073,
  1322.3293767488472,
  327.45138578082435,
  689.2859700893622,
  -738.9243593774924,
  391.96651520265385,
  767.4292498735829,
  1397.9531756772801,
  214.07259465077485,
  731.9476149109181,
  18.302591870384482,
  -10.219834488882075,
  30.79237999600866,
  12.870574004795355,
  -25.367721968409818,
  37.4330145130973,
  15.33101620188564,
  -20.470907037652893,
  38.78456923367151,
  20.337915596252856,
  5.275779617427155,
  34.41203688862828,
  20.188399965272193,
  3.2446737456663968,
  25.722747366670717,
  4.03125077204563,
  -28.609768716823304,
  26.4865911798399,
  -3.77076460396993,
  41.59594330211003,
  34.930032268042,
  1.6603694261993098,
  55.14307065958376,
  38.88999577062075,
  -4.6562788637037205,
  -8.432632696954911,
  37.091939944810036,
  -7.00983996757358,
  85.06619034539332,
  16.378678215736517,
  -9.523071386542881,
  3.848114545656351,
  16.881378253602882,
  28.455855931488273,
  61.87847952915648,
  16.983691761064062,
  -9.858946716815193,
  90.0960848355057,
  16.652688425498955,
  -16.93317676488951,
  12.693110266882421,
  15.994903968233732,
  30.49898264942027,
  2.7185373881009696,
  16.05272740555979,
  -13.899945194635674,
  88.38787766326354,
  16.69190098812016,
  -18.033863149574774,
  54.65631490463752,
  16.991672613493165,
  20.05227738426089,
  32.536343820854334,
  16.85555870308372,
  363.5407501066731,
  0.07341176685540063,
  170.94436475320725,
  205.5122678271825,
  50.28235703976137,
  187.1710106770226,
  338.2341267490344,
  91.06112187479877,
  190.47358663433246,
  354.8393410612289,
  2.0643936276238506,
  179.78913562729934,
  233.9752457510489,
  0.21279931812634345,
  158.55652238236206,
  288.95490946081645,
  40.578982020860465,
  160.42300412676428,
  351.4124810520357,
  4.096627606363711,
  181.05487726543484,
  285.7816426353545,
  36.8446825198951,
  190.73120043338238,
  236.593131709921,
  0.0016050710322303985,
  186.33758184744715,
  112.27919580279631,
  5.815883104007942,
  253.52392863380462,
  108.67312715716028,
  -9.41168674525997,
  308.1984861578344,
  106.67944911912359,
  -12.949348363334106,
  319.3262866905621,
  111.24815213026169,
  -1.9656481529752856,
  283.3257703830395,
  111.55992676872904,
  15.490774741874041,
  211.78395331892222,
  111.74829814731306,
  14.43478179696343,
  218.0729340473485,
  104.71300818551485,
  -15.554979165635025,
  287.59059900687913,
  74.23153772121702,
  -3.8305575086586643,
  320.1942985114442,
  81.48604629158027,
  31.83848392694667,
  305.39030554560264,
  100.49814957184586,
  61.50419148178055,
  -1065.6611362175572,
  109.76292706375938,
  75.51876315014201,
  494.78314686394987,
  174.85418865032275,
  182.492833333104,
  812.3771706826996,
  174.6553164204787,
  168.1628262372359,
  -215.09890601652552,
  64.98201258699396,
  12.87640133213533,
  -2256.9447753662616,
  340.36193171957757,
  239.53768628019174,
  -2077.4535372383734,
  282.36507354201285,
  252.69243912693474,
  -93.37816888082914,
  45.61908542304346,
  0.051440140208413254,
  837.1507426123359,
  464.0045671765357,
  66.03776415727262,
  414.63600748762394,
  -781.4893216754854,
  277.81033798281555,
  223.7579613043296,
  -539.9233908339282,
  389.57532150936214,
  272.0132387951737,
  -104.99210442944388,
  472.6868577943537,
  281.8345364313463,
  430.49733455711566,
  480.42254932004147,
  250.06080139069883,
  888.2715916456742,
  409.5572043762779,
  186.91863086447387,
  1154.7719291170463,
  306.7376165015037,
  192.46922924016994,
  1254.2842864318384,
  228.69530189237094,
  253.82490114777187,
  1269.5881467551662,
  208.97695487935266,
  282.6006359331775,
  1226.5695341769654,
  256.2866114308513,
  269.53476359895296,
  410.2651206637886,
  173.5556915294823,
  824.2093712264984,
  282.50163629862755,
  121.00072031415905,
  1001.957021800571,
  106.61300924456978,
  140.81378441025493,
  1038.1336364879407,
  87.42181056340647,
  151.7058663746459,
  921.0955207189503,
  193.75383973454245,
  122.01841779830131,
  688.5122045145528,
  405.24764388605917,
  155.0413131976614,
  708.957757247048,
  337.3100346737805,
  208.1136776577694,
  934.9605303745909,
  367.19457480178704,
  200.71542321487385,
  1040.955553460282,
  239.24461389320913,
  119.75644366975585,
  992.8275925227487,
  51.581991475058814,
  1630.2303986761708,
  56411331.49105513,
  0.12155943999431429,
  77.50763347493606,
  94666633.9366994,
  -34.92449259325721,
  1520.0026021971742,
  102452657.16600865,
  8.399977385898499,
  -850.6262058460142,
  77263415.55324692,
  52.89934132203601,
  -1159.7571449723337,
  27206241.371345278,
  106.47988079361394,
  1330.2834368335223,
  31606585.347335126,
  68.76964595040545,
  -1370.4926530449698,
  80247478.27404936,
  26.43636456840618,
  -1267.402636697036,
  103059997.33002631,
  -33.578331250198474,
  1259.4106153157818,
  92701774.89608064,
  51.451045251932975,
  47.91590020075978,
  215.6470890856741,
  45.558304679180914,
  42.77334755913838,
  318.6859889930923,
  80.42054666688074,
  17.118518017690747,
  339.65728491583496,
  66.15617623062994,
  5.641950362958006,
  271.8112196816376,
  68.35330518019722,
  100.74875592027476,
  136.98452036313762,
  73.67710105744762,
  0.4625365569793658,
  148.83664473581666,
  76.23709970720195,
  3.541632492652724,
  279.84865554933475,
  61.61101902735234,
  92.12731682983807,
  341.293127749881,
  62.057639849708046,
  14.54283484832498,
  313.3937314215787,
  98.69120951321565,
  275.70971762230187,
  330.24357781780463,
  179.65176745554206,
  168.43726397747332,
  457.88139997892426,
  220.5159334136132,
  154.57753789433718,
  483.8592640853958,
  47.165062901822296,
  460.00651777031305,
  399.81601424019107,
  194.2082529989621,
  252.21890881352888,
  232.80155382137886,
  237.19083635323761,
  398.523003185693,
  247.483187110076,
  38.7021588807944,
  187.18139576710465,
  409.77226193726756,
  214.0710418643465,
  376.4457657663852,
  485.88563875479855,
  230.2659806960571,
  458.23113137530595,
  451.32569886652277,
  11.571699434480783,
  738.7954167364562,
  14592948.372367729,
  -28.867668477613385,
  -836.016439617424,
  24489729.71516402,
  -101.66080539364425,
  626.9995155715812,
  26504001.31947021,
  18.46922074012866,
  1789.2741822996156,
  19987455.88667484,
  178.20096411849167,
  1475.745535066309,
  7037488.801185105,
  148.12717988456447,
  434.5813983853358,
  8175873.270248973,
  55.41887197209182,
  1262.0120959068888,
  20759443.411879584,
  -109.90166211014753,
  1366.568674618105,
  26661122.356809314,
  -102.73190530801988,
  362.7003375026372,
  23981413.76805969,
  868.9398045504482,
  96.26194965617826,
  377.7198612843729,
  662.4696026092056,
  -74.79203055901917,
  459.1783113606602,
  459.50658423543166,
  -110.13139681241049,
  475.7573825997039,
  822.3736321720079,
  -16.297445517002345,
  422.1209858338402,
  711.8367240209151,
  178.34591866608656,
  315.53236769782745,
  640.6358353706577,
  196.96025932439917,
  324.9021851393694,
  591.4236671036344,
  -90.19411720848083,
  428.47506248798186,
  -242.84990144823678,
  213.71051001710768,
  477.05061478628124,
  740.756255516224,
  -52.05398590870173,
  454.9944633230031,
  90.97647277165979,
  286.62709721126464,
  100785.54725229468,
  36.93028121158314,
  -181.322950126651,
  169196.99082351345,
  24.167237073140807,
  253.40732112740585,
  183120.63159338888,
  5.946788568887982,
  598.7733298481468,
  138075.04912435124,
  14.853107960191224,
  505.6093466569635,
  48558.47683360618,
  73.18147581930931,
  196.23092466919803,
  56427.5528665329,
  90.55453391793296,
  442.09917395360344,
  143411.4084101579,
  86.15926622374278,
  473.1678097147528,
  184206.72985174836,
  29.65455089646318,
  174.8717091495475,
  165683.25979044478,
  28.802646086113242,
  1798.0612780148192,
  4655.345316562364,
  -58.366332201846916,
  107.64595477611994,
  8367.795869132444,
  -132.8719003556435,
  1678.0586861865452,
  9123.38331432499,
  10.860073982575237,
  -902.7930618767602,
  6678.916587732268,
  68.44339944158583,
  -1239.3371559659424,
  1821.1642744223936,
  211.98408941261505,
  1471.5155791810848,
  2248.191598239094,
  73.90033750397143,
  -1468.7602957434462,
  6968.502203020176,
  20.8451809593098,
  -1356.52844907192,
  9182.322080544629,
  -138.0204988498898,
  1394.3578880724385,
  8177.1179352321205,
  -45.43819158985028,
  251.829484482131,
  492.67807993613854,
  -10.356302972247107,
  258.9466795839217,
  598.9282322095568,
  8.860252066294322,
  259.8621471762523,
  620.5531077387442,
  -40.61526719449601,
  255.23544845853993,
  550.5925902180525,
  -22.833526285941332,
  247.05865143236562,
  411.56395786673147,
  -32.59566036216562,
  248.23356723531037,
  423.7854588774384,
  49.76768727155541,
  260.10462569444036,
  558.880516288672,
  -11.741817912146068,
  246.14562971491924,
  622.239932329932,
  26.389542304519857,
  260.2224022579688,
  593.4710391169606,
  75.79227309855965,
  164.7799200896636,
  -96.75628969084129,
  -29.730704743064294,
  31.48810171360832,
  -85.42906574679822,
  -104.48669084401615,
  155.3175332698458,
  -83.12365909428989,
  15.548973287651329,
  -48.18655103962031,
  -90.58208086820655,
  100.27444326335372,
  -74.72356454641007,
  -105.40378624538963,
  228.247547308128,
  139.03129525050983,
  -104.10086407616407,
  118.01272660321736,
  -92.81392793704616,
  -89.69851324383274,
  37.55925422078186,
  -83.96427618762131,
  -82.94382838826384,
  -105.7274161085654,
  132.9472939946152,
  -86.0108517202117,
  141.6377132222893,
  90.11244797474393,
  235.87056847081288,
  -1.6942533901761578,
  47.07961589193912,
  341.1559001847096,
  6.540387152384071,
  127.88486465887718,
  362.58440776466375,
  143.4842199006495,
  100.27994342482421,
  293.25917729264404,
  -4.059474067338556,
  126.01964857937449,
  155.49301544121965,
  -7.1549137238227445,
  95.37692691208997,
  167.60353726562857,
  142.9344416169211,
  97.07298891964888,
  301.47184359847614,
  21.92682030390526,
  103.4434176780464,
  364.25591489031336,
  12.074282646457348,
  9.111705447510126,
  335.7482619584394,
  558.0846936216865,
  383.80113742168595,
  -1266.068700980936,
  121.87279935594492,
  87.05622567137614,
  424.1583950051426,
  474.80887520661133,
  44.6614351866757,
  768.1668484961148,
  540.5722076735109,
  357.84564053367137,
  -344.7648493181733,
  99.34030368557922,
  353.3704009269729,
  -2556.4319056945183,
  354.82018415024737,
  25.84837236653766,
  -2362.0123051582273,
  526.988506731628,
  327.7983735114018,
  -212.92054684562683,
  184.1478039484909,
  307.3847079650642,
  795.0008489111394,
  213.50483290361444,
  251.77175900506413,
  337.34538405154126,
  352.3736828456748,
  -135.2158672828806,
  4205.240943437185,
  118.51090388907237,
  -2111.619165644212,
  6775.060971117897,
  -181.13958892740732,
  -275.5207468239061,
  7298.09116958766,
  73.5251695164942,
  1183.1446014555747,
  5605.990638673315,
  555.0637343742229,
  789.663278577171,
  2243.373680552799,
  641.1042436905611,
  -517.0072456313629,
  2538.969097534542,
  469.12076876639856,
  521.4258555349277,
  5806.446618721296,
  -9.970053776279684,
  652.6453191149387,
  7338.889563988674,
  -153.07262855996265,
  -607.2186351666321,
  6643.070533417764,
  701.8418405506222,
  -558.8660817266608,
  334.61052928996077,
  1315.6636464970525,
  -308.37483445588146,
  406.77209104232395,
  685.8068262976777,
  -561.945662990047,
  421.45898567256376,
  -778.3160374465083,
  642.6702274101968,
  373.94413418976063,
  208.46099675835487,
  -598.1986609584491,
  279.52052138448846,
  624.4951242378595,
  -572.5260088952176,
  287.82095748759355,
  1596.7185240278116,
  265.0589491632835,
  379.5730173127231,
  -973.2505323116261,
  431.8938158540641,
  422.6046207074122,
  1103.8947231354168,
  -431.4780949761,
  403.06574740026906,
  304.7627756849261,
  -484.26520676771713,
  480644.55154731974,
  -428.42305046362605,
  2275.935635510403,
  806649.8268694434,
  -198.21748979587926,
  -639.1887030006158,
  873001.011784057,
  75.39248695577291,
  971.4576004526655,
  658342.5168266114,
  591.5434555432903,
  536.9787538004931,
  231763.66872561013,
  601.84832569519,
  -905.8361126322202,
  269262.6625302704,
  426.9689778877647,
  240.79319322591294,
  683772.1991629605,
  -88.15673904379696,
  385.6846477364217,
  878176.6628631745,
  -161.06435588001034,
  -1005.4467884158885,
  789905.6274629371,
  300.12237083542516,
  107.91779137862446,
  325.38341485443095,
  339.0822730190303,
  86.56831999889766,
  516.825545687632,
  182.7645104202689,
  15.57858261550519,
  555.7893698490975,
  371.8778349487345,
  57.405437482100425,
  429.73411005154986,
  385.6801440819408,
  23.28787302059874,
  179.23152671716906,
  177.03894337757777,
  8.525847201703698,
  201.25229699756335,
  399.4808635364491,
  0.6480580643024112,
  444.667342552379,
  398.2703082139997,
  4.751743497242174,
  558.8287000257529,
  177.5849055246346,
  9.164461837069688,
  506.992744024192,
  270.86648055494015,
  228.46348692705178,
  614.8211872536396,
  270.86645031525313,
  228.42775337546098,
  747.4125231115094,
  300.71333214080624,
  64.549452357176,
  774.3985656989745,
  271.40150732619577,
  269.494455868118,
  687.093669876278,
  306.03178186498445,
  103.61473135483574,
  513.5975224211919,
  276.5820036152918,
  97.54887512931975,
  528.8489372241366,
  305.244436869736,
  95.92874645154603,
  697.4363109519053,
  271.0664028439801,
  253.1110545175173,
  776.503582220061,
  305.3626884176461,
  356.9717362227041,
  740.6024008980404,
  249.10563024552772,
  -22.370514962379993,
  3395.978185825173,
  -1898.4613517818475,
  331.0566223594588,
  5655.5286416726785,
  -723.901360845809,
  -42.20753802925701,
  6115.41031067849,
  172.91192040626584,
  164.02604597243334,
  4627.607085244855,
  1570.8411111996531,
  108.393639573902,
  1670.9787615800903,
  1210.4190170709148,
  -76.35013708107168,
  1930.885195491078,
  597.5124443556921,
  70.46885772957425,
  4803.860829170867,
  -828.03070591913,
  89.02133811639155,
  6151.282873610399,
  -656.7675391557748,
  -89.10468575364574,
  5539.474190209005,
  -204.89127907995623,
  945.2912335855832,
  294.5804352951495,
  60.81435084894332,
  1102.8557142398208,
  358.1091721752975,
  356.77087283275625,
  1122.4629503024435,
  371.0390456687908,
  637.0047418376485,
  999.2563464716482,
  329.2084862345439,
  857.0311063534365,
  750.8658513879934,
  246.0809498078165,
  981.0097980446982,
  415.27617895402125,
  253.3883889538017,
  987.7856357699362,
  45.321682319760214,
  334.1639753642685,
  874.7718232429025,
  -299.4543931860921,
  372.0476262056052,
  658.932914499404,
  -562.3604248306497,
  354.84622547201604,
  449.58418229540143,
  139.60653108844895,
  996.6466992041469,
  431.76789593874867,
  142.44065450258475,
  1211.5819030739158,
  505.9645384402801,
  122.44745148284017,
  1255.3272241965012,
  443.5256570672554,
  140.67654484908562,
  1113.8029272952685,
  219.26204629398825,
  100.04177911741641,
  832.5595897679088,
  213.00794578971968,
  87.6585309438542,
  857.2826678541514,
  437.85143289774487,
  141.5777832589681,
  1130.5687110756262,
  468.11065488877375,
  135.57223855034857,
  1258.7395297757585,
  252.14256450056905,
  39.577542543499284,
  1200.5424562136848,
  75.83013235108407,
  -572.8203197571446,
  -500.2700510359214,
  4.551866388906852,
  2030.1722409291535,
  -384.06633035151094,
  -14.443294549100422,
  -718.9200897423282,
  -360.41562546252106,
  11.179425639218387,
  799.991245102968,
  -436.9300799170504,
  73.85158231078893,
  390.25830527898404,
  -588.9829853972655,
  106.2378015745324,
  -970.3804954367495,
  -575.6165679436904,
  90.2744024426197,
  110.94210518612098,
  -427.86573670853477,
  29.432984669700648,
  247.5812121746355,
  -358.57077828401003,
  -9.39186562627961,
  -1064.3178075548858,
  -390.0347560740553,
  8.952190286226141,
  343.49837336943733,
  765.703849234082,
  8.516089474601234,
  -249.87709641358117,
  930.8342942256861,
  7.858244120240977,
  -443.98850573695154,
  964.4429549439649,
  8.173873265929444,
  -380.4765955730387,
  855.7126506305565,
  8.919647158299393,
  130.8110247685288,
  639.6389845178785,
  8.71522709419904,
  718.8512683392136,
  658.6332340053522,
  8.823287002133894,
  616.0393206396229,
  868.5934690653111,
  8.095146110314088,
  -400.56864120848957,
  967.0645614961028,
  6.324396088579704,
  748.9441116071775,
  922.3529066276096,
  327.1254948498562,
  353.36359683451803,
  13000600.531948203,
  -40.17739414949045,
  -318.2226169075246,
  21818488.813768942,
  -425.10395938984027,
  305.6876883301068,
  23613175.526630815,
  107.41006671531542,
  801.345401095493,
  17807028.29355847,
  910.4203177062155,
  667.6395769708223,
  6268795.9069025535,
  942.6740583926121,
  223.63004172610195,
  7283079.9172562435,
  539.7702448506978,
  576.4919071231625,
  18494857.954175312,
  -277.3052865854702,
  621.0805711817727,
  23753168.08643295,
  -415.62316005540083,
  192.97601196171777,
  21365586.695577107,
  546.3327447096135,
  -81.13422194933526,
  1360281.8670843304,
  -1341.8185886018312,
  185.9721937870215,
  2282995.6701040226,
  -372.52580048141624,
  -96.12626859981046,
  2470793.7175648552,
  162.0583514873624,
  59.73701299361987,
  1863231.904226227,
  1298.1128683893614,
  17.692214780040047,
  655858.2173123857,
  1062.941540706519,
  -121.92991040773705,
  761994.0433315232,
  791.7939883417977,
  -10.969852945667597,
  1935207.1778624295,
  -336.63215677930395,
  3.0513865570285503,
  2485442.697356967,
  -237.9499101886962,
  -131.56929974858375,
  2235603.4802149744,
  873.9329135170325,
  292.95046766880427,
  313.98315877718517,
  1053.801201921963,
  199.03540445158924,
  776.7914732865082,
  241.27508964385737,
  208.15986206720774,
  870.9859001272591,
  530.620705328248,
  322.00557016473147,
  566.2493091374339,
  1150.671065127016,
  104.04775937332573,
  -39.33671243807348,
  -331.83194674957804,
  321.6304454323832,
  13.89815040695927,
  74.19522284328431,
  186.5026145144082,
  602.3501618275147,
  1180.6026925125625,
  53.24659575985997,
  878.3334326174864,
  -578.1373761822293,
  120.6831409921875,
  753.0208312394549,
  -567.0769245899686,
  454.0120414813442,
  141.12661459171045,
  521.7178063821594,
  4.101031151941015,
  213.8415191584019,
  -311.81319591362677,
  5.057744756236673,
  228.6410345165069,
  -446.80369390988824,
  86.32882490261301,
  180.7618339120466,
  536.7750042015593,
  6.808548705338239,
  85.61417042965623,
  -551.9937750908002,
  300.9531272577552,
  93.97825519226798,
  -52.46891083837107,
  66.50275493358001,
  186.43387993161423,
  478.8182118332217,
  0.1500044431155061,
  229.79545440715637,
  -514.8424112028056,
  580.0867713505365,
  210.10675486452135,
  151.02643503087742,
  551.414833996266,
  95331.76055022678,
  -153.8131193309082,
  -268.24312385876937,
  159926.49116509254,
  -547.9529018478958,
  493.2273116737442,
  173073.3241766188,
  39.40798473624747,
  -758.1903986740214,
  130540.86011674123,
  999.9262052557142,
  934.9825767676339,
  46018.46779699352,
  903.6641200594231,
  393.07754435338336,
  53448.52364730807,
  395.47280643497203,
  823.7386122521962,
  135579.5009133204,
  -524.408375252498,
  878.1582125625239,
  174098.82840160961,
  -553.5833368042611,
  355.6648951319229,
  156608.7931647882,
  275.35612324081393,
  358.16720444319446,
  27694.842922047723,
  -213.74438150645688,
  -594.7844711498885,
  46457.13646126129,
  -1072.927798631542,
  290.51716046513695,
  50275.78757607083,
  214.47181705532176,
  993.8339323633692,
  37921.73689668271,
  1997.3019644069705,
  804.1111737227355,
  13371.221394188853,
  1736.2660349181801,
  174.08092305221857,
  15529.367849006176,
  756.5864323028475,
  674.7765880352815,
  39385.268933494386,
  -1079.2745157384052,
  738.0459661994831,
  50573.657249213386,
  -1068.1458230807684,
  130.58418587996363,
  45493.47234866808,
  -729.9111545642514,
  29.704006242646642,
  -32.74782326106993,
  1084.3321082952198,
  41.60341122034404,
  88.41038868377721,
  1103.3456920105564,
  363.8729182502507,
  113.06947101529225,
  -778.3776038968319,
  331.96594323194284,
  33.29272690549799,
  1213.5357080690046,
  1.9453394214162927,
  -125.24314475590892,
  1306.513509506179,
  147.76456856019843,
  -111.30683334311254,
  -296.5922385644203,
  403.17615988286695,
  42.74353974634291,
  1313.097521882427,
  35.28963163201581,
  114.99297556526221,
  1296.150765467841,
  15.43246389891982,
  82.18749165078978,
  97.0028193174748,
  -8.447625817624953,
  579.9231565914964,
  241.03128685264278,
  -26.133058791613344,
  704.9884399966658,
  335.9349781415568,
  -26.843891585839152,
  730.4427205674801,
  263.5208523077683,
  -26.909791207727828,
  648.0933614024992,
  102.06303871512324,
  -9.703210120507539,
  484.4450754056318,
  53.50409729041681,
  12.997878362354427,
  498.83080055365144,
  86.93969468303436,
  -5.63658288960065,
  657.8489410481244,
  447.6743818366572,
  -18.273638343258234,
  732.4282536800242,
  338.89599931475254,
  60.7583444629054,
  698.564868960589,
  340.6073588511056,
  296.63813096931017,
  64.84479857132948,
  533.5584569335705,
  221.87649546093252,
  153.16026614591206,
  219.24770017067024,
  469.0057938154847,
  171.13493208980395,
  417.50458906279266,
  140.95289089871756,
  112.98352539158095,
  378.83067103219287,
  479.89768113526435,
  -2.577520024760232,
  114.05653865141545,
  410.61430507143814,
  7.58103083967789,
  464.2749565607879,
  56.35295858044765,
  119.8724761411928,
  195.79293171041783,
  248.2154447262973,
  172.53702610378429,
  53.488905387280056,
  134.47151549579496,
  148.624229732739,
  -441.4277947596638,
  215.84879093995207,
  757.492547901813,
  -707.1468460785048,
  81.59527888929753,
  920.8521570221935,
  694.2688632686015,
  29.942062569304625,
  954.1004031483192,
  1381.01196383297,
  137.85843937641312,
  846.5361074602556,
  1137.727127853772,
  201.1623361439822,
  632.7795852200996,
  1260.9384967017895,
  182.2510082999405,
  651.5701430240615,
  1221.4803065596043,
  74.71835912411706,
  859.2787937938332,
  -287.19977293481054,
  37.16587717396676,
  956.6938959572706,
  -654.533138234227,
  191.50645880835128,
  912.4617226423269,
  240.15917410713288,
  2.1505560615673076,
  17.31898857223614,
  115.65153299963029,
  21.14797382803625,
  123.05059344590875,
  28.930032851173635,
  16.445522570265137,
  144.56993008658122,
  314.62990664005946,
  6.6168582273672545,
  74.95085061250855,
  -66.36198636611435,
  38.985289560616266,
  -63.39926096257439,
  68.67019722363287,
  22.75119320009959,
  -51.23740624351496,
  302.59026458600476,
  28.02280522464863,
  83.1983279645028,
  -197.00008196553338,
  18.300886367086438,
  146.2485222330443,
  134.37534798322565,
  32.290191194914904,
  117.62003385197146,
  307.058141308148,
  -66.61417991329495,
  -1348.3814595252954,
  107.5771252389049,
  -1363.4951382757472,
  -1021.868479618743,
  -250.3685905500388,
  -158.67976530924113,
  -955.4139626315728,
  81.87017282218909,
  798.4706889402839,
  -1170.4067561732018,
  658.1621750463472,
  540.2751903113506,
  -1597.6499371951572,
  677.815994862588,
  -317.1389432840362,
  -1560.092544301564,
  449.2945854441273,
  364.26252804139307,
  -1144.9374709000904,
  -129.69838212492692,
  450.3664238528246,
  -950.230251247978,
  -221.35049580084086,
  -376.33406475175,
  -1038.6387556180064,
  411.43888513152507,
  544.9341453757709,
  289.4483719624814,
  633.0570509515171,
  436.1093886274497,
  351.8703364231146,
  576.8399472703438,
  480.57132555683506,
  364.5749507965122,
  251.66717680558818,
  551.2028744449306,
  323.4731467531058,
  212.13881733367157,
  545.4176304417226,
  241.79382524670473,
  711.8515847362158,
  295.5782910384566,
  248.97395709049505,
  14.343132839856594,
  50.740437188103584,
  328.3423033195948,
  -76.19467466408264,
  344.19153162461873,
  365.5659602438351,
  231.72880827405692,
  -38.662475124741604,
  348.66423548121435,
  64.2842038657167,
  402.9674702226321,
  237.10132596926667,
  148.00667505957222,
  120.51556038034676,
  288.23421175084917,
  49.60877852313325,
  165.3983363675914,
  298.6411830992706,
  91.29509985531823,
  105.68739639607031,
  264.9726840424378,
  186.5028155361336,
  229.04482288389988,
  198.06515472336451,
  41.518980830653035,
  193.28489355980633,
  203.9467520847672,
  118.3225165376305,
  100.92973896850361,
  268.9612484639234,
  125.79901501990787,
  103.26386156467174,
  299.4529674337798,
  102.431300432194,
  435.7924982799343,
  285.6079375750373,
  -265.64305850834006,
  104.46786694580412,
  -191.46509039344113,
  -185.53554153315042,
  17.592018747184923,
  75.90814141947479,
  399.83416352238993,
  43.240132333646045,
  130.32606679723833,
  21.88267998639114,
  10.009335566341505,
  -45.72610130390094,
  -159.05312994895485,
  11.67372334992588,
  -395.5847504533598,
  47.456456914139864,
  6.301533336845978,
  -364.8299500797226,
  375.0567558395759,
  35.29125673369775,
  -24.869946925640686,
  -181.9362463797238,
  16.70998014636521,
  134.5708771132441,
  -248.85721052801875,
  96.72065385606452,
  62.17538600619531,
  -506.03771123923354,
  506.1504972815218,
  -220.56022348001213,
  1176.7679795414692,
  484.58518325575886,
  106.76201889670708,
  3.2858361832334992,
  339.3647985446269,
  173.38124341429796,
  -714.1527850146431,
  231.52751610410456,
  -42.14440979869622,
  1199.0507748156933,
  452.6804251562959,
  -470.44651310954373,
  540.0224789406889,
  55.33017645961442,
  -432.79603421197373,
  -470.48842294499707,
  1.060784385861524,
  -16.611998898176914,
  1211.2482520684116,
  360.68972838442653,
  178.5778026273424,
  938.0121828653022,
  20.310273895577637,
  89.95017776583842,
  -83.27752517024456,
  316.296595236235,
  624.8778594191133,
  867.3999857371006,
  124.27085972935086,
  935.6640245046018,
  377.46326233243406,
  319.39099408883686,
  998.9176951334447,
  526.3249061657829,
  107.98626871071949,
  794.2802383164388,
  690.9847677272384,
  230.9824692896367,
  387.61564009207285,
  682.8489238672322,
  234.86373024584748,
  423.36404467724236,
  545.6642709081627,
  99.5783143206062,
  818.5227707259129,
  389.9389678319395,
  318.16718703738417,
  1003.851728023281,
  863.1647380393412,
  127.35898598250175,
  919.7015051379046,
  380.3959886645014,
  977.506222649308,
  23.607491330273305,
  430.6341058147244,
  421.07367316281295,
  28.698644460041262,
  429.9654400999692,
  440.8588945183401,
  29.734836412481492,
  368.0773111846637,
  1040.2374105551432,
  26.382561614615014,
  301.5050622284926,
  1213.2063177731766,
  19.720772981114216,
  412.1135170862574,
  730.5801900401719,
  20.306386571210588,
  270.52911464692664,
  -795.4108113512171,
  26.779691405498866,
  136.17023647264074,
  605.0940894250234,
  29.815663424142578,
  133.50375378083717,
  560.845528213865,
  28.437153957687695,
  453.148950155694,
  108.33495281940185,
  370.5574254940488,
  -111.22144714992038,
  83.05971115887431,
  821.5739686282113,
  484.5168534285868,
  28.074376303504444,
  913.3684404307775,
  128.76158379624496,
  79.14317210775262,
  616.396152928904,
  -190.08628183101155,
  17.88970301142959,
  26.239698391280218,
  525.8274781014694,
  17.86307537170744,
  78.11820416109016,
  -115.61830990179448,
  6.845611366371571,
  651.5772014840459,
  -108.0938443176417,
  8.66864384080079,
  920.5287670723194,
  524.9134321866602,
  18.07595102472458,
  798.40897252068,
  374.76547770281894,
  -627.0292085472681,
  648.6928052492491,
  473.4056549988527,
  -394.01684646242006,
  788.5888390759164,
  110.42205983846034,
  312.5155004913599,
  817.0615918560131,
  481.1924310462514,
  735.6386510012339,
  724.9469104537691,
  502.34914428833,
  -241.7489045759744,
  541.8925445245297,
  519.7180798789319,
  469.9238774008827,
  557.9841875219605,
  476.0995367569989,
  -382.54862157984974,
  735.8593464467515,
  435.7813365718673,
  894.6143669041095,
  819.2825775677438,
  237.08457580740065,
  -588.4215552004156,
  781.4035348373314,
  305.8622345882645,
  7.461904478810958,
  -377.4493792953365,
  93.85767826020646,
  19.282290823886708,
  426.33225727174744,
  1278.7742116509494,
  40.16803042596983,
  589.9242848735594,
  -64.96104124171427,
  30.455863622311405,
  60.67347379561449,
  432.5802235693004,
  2.7722440249924922,
  -991.0771284384451,
  917.8251586441775,
  62.42012283431876,
  -898.6215613309906,
  -448.83519143245053,
  58.3679502567948,
  123.37157481712465,
  666.100860837422,
  0.19430658480480645,
  602.6851007547219,
  241.17934446496014,
  21.51843184565855,
  385.0486308375773,
  134.73860598418082,
  69.99037563881775,
  33818854.45562196,
  16.100490781564986,
  -1120.6474295807855,
  56753189.04433366,
  -478.08109822911683,
  -14.533007810720846,
  61420967.11536525,
  103.70721618921957,
  864.2057143242445,
  46319831.893553555,
  956.5841316409674,
  627.1621215234827,
  16310188.579810347,
  776.5831150330933,
  -160.01088429912167,
  18948227.08948272,
  355.89904701971295,
  465.5687782450244,
  48108799.39602791,
  -518.2675629655787,
  544.6188659718146,
  61785072.00123134,
  -455.8975182011187,
  -214.3566197728207,
  55575241.62851506,
  82.01307026953839,
  217.57198973762277,
  735.9378819046069,
  50.80585207300743,
  316.00973716097536,
  894.6490468630254,
  52.77249606884317,
  267.20687082201243,
  926.9512046847491,
  175.62567646864278,
  160.5194571794123,
  822.4476816382158,
  135.390894015478,
  177.6754149463772,
  614.77366206343,
  211.8616996340889,
  440.36429974806265,
  633.0295291981736,
  480.8644530307354,
  207.55695093244054,
  834.8277712062038,
  437.9322602375381,
  177.84624687519317,
  929.470898917836,
  271.14628213252416,
  447.7525872725103,
  886.4973646809599,
  -170.87916002091094,
  312.29493922445425,
  -77.11945251570116,
  257.8322732124141,
  72.32918075563953,
  612.314737457357,
  -454.5700653787045,
  305.86914411605346,
  752.6338638278094,
  90.11441654494917,
  155.67704313968483,
  298.6752416994054,
  -54.396178286432416,
  241.03472513476723,
  -603.4513950844857,
  -242.98496897632066,
  131.27696291489946,
  -524.1487261538207,
  444.8428754927986,
  12.902022528781373,
  352.4537961277336,
  -261.90261838391143,
  364.7895623193537,
  763.5793026885418,
  338.45093882893616,
  22.000050328858293,
  576.9041952716038,
  445.1574460486021,
  371.14639512842103,
  3789.2144271360426,
  -96.35357425375582,
  -172.91992411099773,
  7080.886961422896,
  -640.5087382213998,
  332.5231245406321,
  7750.834319744062,
  81.27742074289989,
  -498.13339623746106,
  5583.42929415175,
  1331.2981295119052,
  625.748071338221,
  1276.266237927124,
  1367.2413565196448,
  266.0464744251817,
  1654.893264278855,
  759.4196499070332,
  551.907399468342,
  5840.192583701252,
  -439.7876749250819,
  588.0296274679272,
  7803.092825338334,
  -632.586275280812,
  241.21299094606084,
  6911.8209202658645,
  1.2897642177338815,
  552.6820237574091,
  178.59580397685022,
  -0.29641415778985003,
  532.2359781145753,
  217.11148417596434,
  -5.636381032279997,
  380.49681296485966,
  224.95050155529475,
  15.993631004123866,
  410.2013917977073,
  199.58981395404402,
  13.888980823995073,
  -135.68444594100083,
  149.19193472669014,
  5.507599047036914,
  574.2895072808508,
  153.6222288430714,
  -1.4267157859724229,
  512.653042323697,
  202.5941871546436,
  -3.0219250323950178,
  -132.17756074874848,
  225.56197546960036,
  -7.315130353929911,
  100.6199283359068,
  215.13325167989822,
  -404.64099804156444,
  480.93743947841176,
  518.3383965994791,
  606.9435624417571,
  526.4333056279695,
  630.1224109704712,
  -19.95967388789009,
  537.3275801354584,
  652.8735821001371,
  472.98451367850157,
  538.7129665287068,
  579.2692876252427,
  1154.843983194843,
  382.69505173601664,
  432.9995806722904,
  -506.2137666551221,
  453.9223610875257,
  445.85761819397163,
  845.9624949423172,
  487.8229462623832,
  587.9888765120404,
  -811.4457384116797,
  227.26290990357603,
  654.6482621387827,
  1068.0204669021455,
  422.92887177189476,
  624.380989070969,
  56.455947696498924,
  87.19040457761683,
  157.4442909211612,
  75.18220844881809,
  156.8757231016773,
  448.35420772580096,
  78.38727486248122,
  52.42378520087824,
  507.5625063164513,
  56.40317718615354,
  77.88421746397815,
  316.0125847767557,
  69.27912357913219,
  158.3244489938656,
  -64.64388493546842,
  77.31616692541715,
  6.092894464460798,
  -31.181760259134638,
  56.407769701223316,
  49.67640179312659,
  338.70469233705825,
  63.452966466924885,
  67.02809720272451,
  512.1809844172986,
  71.33120867359435,
  122.22117272230756,
  433.41256712966634,
  -632.1511857717991,
  362.9930348573795,
  83.13942598922338,
  219.6960555567817,
  437.90704516930475,
  101.0691391853627,
  1513.5929913812079,
  296.07690770155824,
  104.71833693091308,
  217.34636209509648,
  437.8767831037818,
  92.91249959929635,
  1736.5281160912182,
  192.54345576133272,
  69.45141789001093,
  -1017.7099778548873,
  -71.39041609903106,
  71.51379618556773,
  -143.60378845091162,
  -237.7818913310952,
  94.3110871237134,
  1797.5073919615902,
  114.58578111405807,
  105.00298858067603,
  1709.155217817243,
  -26.469106093392497,
  100.1482378509871,
  134.6768031750622,
  406.3532305029807,
  162.17320131231227,
  209.7278648588693,
  291.74725329599414,
  197.1472097689791,
  201.2800776929942,
  312.1277219728805,
  204.26539796400328,
  103.36510122810903,
  425.8795388866834,
  181.23672761344227,
  54.11756703805702,
  433.78921849272336,
  135.47313613113243,
  207.96073428563523,
  296.2694856720242,
  139.49604688049013,
  126.2783969256742,
  -261.80492560395237,
  183.96483661168787,
  -86.0579231183601,
  -128.99542665199894,
  204.82064439193596,
  -6.927874622170194,
  -255.14574074919454,
  195.35088370933286,
  -107.31669196916016,
  306.968004266771,
  -803.2987107569245,
  326.6681071197048,
  304.0006084140043,
  791.6428503507792,
  1442.5588583322478,
  0.17426447354336005,
  1116.258034398011,
  635.6658571293942,
  125.2216717766442,
  66.06719097019504,
  1398.8014586248316,
  324.69888703774143,
  -2020.9184667111697,
  1018.9908096272455,
  41.03373272031408,
  -1837.4591540982788,
  1200.3096486430413,
  13.860573122267937,
  190.47885027212962,
  1042.6103328332883,
  371.2628192242112,
  1141.5792841959471,
  377.18952579685225,
  191.15642034931147,
  709.7238706210065,
  1.5104646606997054,
  71.83955178977638,
  47.547846880043274,
  8.49628301398603,
  18.172040534429748,
  64.0953081283857,
  -13.21115175387467,
  117.53067452339349,
  67.46317897057159,
  13.84898956393624,
  143.99575118328528,
  56.567486796799024,
  4.955023233680433,
  43.279682907273134,
  34.91508576942574,
  -8.435230814789065,
  142.46541503056625,
  36.81846952976925,
  21.498960244125932,
  69.58062049916452,
  57.85825328087694,
  -0.3929638777826341,
  89.26408534514164,
  67.72588602517989,
  -2.0664259946310377,
  103.55931793164964,
  63.24540166432646,
  -1509.1682614815234,
  225.92978534066953,
  1105.4464418567109,
  -763.6729216094102,
  552.727894453431,
  1343.845221020193,
  815.0716806711489,
  641.6164558068941,
  1392.3660354888073,
  2052.461037763601,
  377.03564083472975,
  1235.3921243017553,
  2265.0585447605927,
  45.57554870265017,
  923.4466304634786,
  2097.353435425407,
  -108.49460121461195,
  950.8686233562523,
  2181.679413615638,
  -50.91002897695395,
  1253.9881584227078,
  2246.2281872210388,
  228.62251343577083,
  1396.150848165285,
  1328.3275564009257,
  584.5029853351512,
  1331.6006440186804,
  197.78910677331976,
  643.7805836977238,
  70670.80553644744,
  -476.1098423228151,
  -90.3223092680386,
  118824.1413118033,
  -1144.5554610534032,
  591.6666158381897,
  128624.69095974725,
  81.6686590223265,
  -529.1293853120462,
  96918.07954217138,
  473.5222960691523,
  -675.281629488387,
  33909.30004627088,
  1763.455302695314,
  501.9703794811113,
  39448.172502029745,
  689.8956807751208,
  887.6794826533392,
  100674.22744803858,
  228.8707963797762,
  -726.1747242898876,
  129389.17203761498,
  -1183.997185587359,
  468.4628245750809,
  116350.90201984912,
  540.4566305041661,
  -1141.3451595531878,
  14766.16391642924,
  161.52747969687806,
  2598.5594478007392,
  24718.32964426324,
  -62.351341347732046,
  -1351.2570936683117,
  26743.873518839868,
  70.86916428815067,
  831.0708872661799,
  20190.860183110748,
  441.1144178965146,
  242.37842130370652,
  7168.422469196906,
  706.5197001536029,
  -1712.548149212359,
  8313.177567415016,
  624.8363093083738,
  -158.93503591204222,
  20967.167906252507,
  269.4762328995489,
  37.38409057689404,
  26901.873837202584,
  -31.194085243947256,
  -1847.5145689014098,
  24207.16905856783,
  332.3257396191685,
  318.1122848369887,
  109.15447953785073,
  371.3225281407734,
  257.2833912962616,
  378.4536735751498,
  368.93968969388254,
  1.103433131816729,
  433.26358609349666,
  330.66835826671087,
  281.09148572221636,
  255.9432662668294,
  381.11325875016234,
  319.1093576050652,
  -96.43551003809213,
  379.32346811667105,
  107.85464451434174,
  -65.45917445939185,
  330.24749535411644,
  265.39548722103876,
  276.9496532065398,
  379.36235466191204,
  109.07740088007745,
  437.53897293454526,
  381.1353405420786,
  318.42341352236144,
  364.62199738366337,
  145.2817041976664,
  635.2360849261673,
  463.9385252731971,
  157.00899287903212,
  701.9019716537632,
  563.9907519973326,
  170.72272495351027,
  745.9590483511007,
  584.3541764539841,
  185.82212981574264,
  761.9407082055639,
  518.4746891219994,
  201.48101746449998,
  745.5231613443832,
  387.55606032450544,
  216.67278946569058,
  694.225180159086,
  399.06464044292113,
  230.22563454275002,
  608.0965397460013,
  526.2791528384995,
  240.91033854949572,
  490.29990782794346,
  585.9426029440193,
  247.55906914758728,
  347.4730860195445,
  558.8518951684712,
  76.60842354514912,
  842.8702229956158,
  792.3905785639562,
  558.5042003287315,
  836.7232677888421,
  963.2762401370371,
  1073.9461001338836,
  681.8947349185569,
  998.0562482798135,
  1403.5032123227832,
  367.4364513820161,
  885.5364159340344,
  1363.4601234328547,
  -8.826989997032172,
  661.9320322356598,
  973.5491413282313,
  -297.6352974316337,
  681.5882796945467,
  446.7745376195213,
  -417.41802952551234,
  898.8661636976142,
  7.094458244952818,
  -403.1732789098303,
  1000.7692244973074,
  -244.48046395102017,
  -348.7403859892198,
  954.4992545797783,
  99.36821689636164,
  74.84167283927937,
  -12.081054306109344,
  -159.49852824344254,
  243.19625157243541,
  237.18166525099946,
  225.55761268389335,
  50.52812951605671,
  287.9135952214921,
  67.83200605861094,
  62.65545334702833,
  123.78631177106477,
  -658.018859253395,
  571.5605653386133,
  -202.37467957525664,
  935.4414781628193,
  118.38469589545642,
  -173.70305404045817,
  -74.36499284023779,
  19.740517007951553,
  143.22977559344775,
  -818.5168117470478,
  510.75761069346345,
  291.87088352667297,
  1351.1368877309949,
  539.2611705212197,
  224.37909732706532,
  105.31432424508321,
  -32.80340864899978,
  91.35072732149236,
  61.35091234490881,
  0.2641490758194891,
  111.05127638885531,
  40.87179368609111,
  68.23546654360271,
  115.06088872655882,
  39.273258942686354,
  87.53116048172392,
  102.08904276959723,
  47.892504497313844,
  33.1815549832248,
  76.3108171877898,
  88.75721033005347,
  -28.735369318013795,
  78.57688716685837,
  131.23789027727278,
  -21.899846788860955,
  103.62576239519127,
  128.51192750608246,
  -24.124189321780605,
  115.37365411950823,
  61.669460990906934,
  -0.29531365326808157,
  110.03942183626978,
  105.85787467320706,
  1186.7112647744564,
  311274.41875880765,
  -350.52658846558086,
  -713.0324123248442,
  522788.9741494721,
  -1009.9822553853126,
  1051.848452111034,
  565838.0977042706,
  51.70062909385422,
  -1848.5966175185458,
  426566.13016665797,
  1731.3065067921073,
  2075.716717702744,
  149798.72109331808,
  1467.3118126096317,
  819.7285960094556,
  174128.33660138876,
  537.4189515895096,
  1817.8835371932407,
  443065.09003098536,
  -1072.1836538463247,
  1944.013333907912,
  569196.0971592643,
  -1032.0970756019894,
  733.0162751921233,
  511925.2177598236,
  205.84202873356986,
  -36.000974007067704,
  417.7499552791841,
  -526.8016138517917,
  -26.49303474311258,
  507.84123022768665,
  -988.9051051353629,
  -2.635353398202893,
  526.1773226034768,
  -1031.858684513767,
  17.672251372842126,
  466.856633789057,
  -1014.7274449148824,
  21.074057961143893,
  348.9719392744994,
  -1034.9931613470728,
  5.16788223435228,
  359.3347536731613,
  -675.5301751452256,
  -21.76173501776416,
  473.8841044364365,
  134.45488927587144,
  -35.81649788090406,
  527.6076092880883,
  690.5690440254343,
  -33.4796223291448,
  503.2139852512562,
  32.31734264587466,
  261.8333484473209,
  -683.4235597287773,
  16.848149204206766,
  14.34234379119772,
  473.0967745043582,
  27.875232793449744,
  8.59626501558941,
  708.4809856291338,
  38.41176840885795,
  453.6869432448517,
  -53.03096870616262,
  7.712353896995381,
  303.07899070343245,
  -1566.3411796991672,
  30.703606005994516,
  1.6375826664280737,
  -1433.3115874463424,
  39.43736970464149,
  355.01288603829835,
  37.1821258090015,
  5.771244159978039,
  440.3110379215,
  726.8418716914236,
  34.54429379187718,
  58.930281453765474,
  413.6958734761623,
  36.65480249041855,
  155.3142234258682,
  370.53497261863754,
  482.10063674031096,
  154.9207495444945,
  450.4439413076042,
  850.822227376871,
  152.4513999558137,
  466.7076497785138,
  983.6068324445778,
  149.79022174577338,
  414.09151055982693,
  995.0382808933224,
  149.0889209916602,
  309.5303933122709,
  946.0450321502417,
  150.92163201124956,
  318.7219805307401,
  670.4911315813919,
  154.02725313914425,
  420.32472162543877,
  167.2944713782275,
  155.41553396214638,
  467.9762824398031,
  -197.5537477429246,
  154.65438808573555,
  446.33967733588076,
  44.966988899834135,
  -491.4271030449198,
  -90.94805720099332,
  -86.89453216667961,
  991.947489657932,
  -14.9835032623799,
  -31.948451952021642,
  -574.6853843281417,
  0.47740656601702514,
  12.38395855938057,
  290.90083236232726,
  -49.54152887134412,
  98.81409033475427,
  57.40518511848866,
  -148.94136798014696,
  91.08594125917011,
  -717.985823411805,
  -140.20348993598597,
  64.77263728092865,
  -101.76951280643377,
  -43.61599753270966,
  -21.437599567501394,
  -23.902605794239392,
  1.683417803652928,
  -24.228038892754356,
  -771.5181401027534,
  -18.88517521452126,
  100.13921416789157,
  -633.4243462377203,
  72.2511079691478,
  -559.0760448057969,
  1936.4604547547885,
  485.04498347108176,
  -192.6276283060123,
  -777.6658565608973,
  569.060074140966,
  53.01521255627839,
  721.9262715260952,
  297.25553982678457,
  467.1057562515868,
  317.40477176352306,
  -242.88644327692597,
  355.959074441973,
  -1025.9279086334245,
  -195.4045276399668,
  199.0754340663368,
  41.64122632320277,
  329.45507130379013,
  -220.28673593286067,
  176.54240490298025,
  575.6135787279197,
  -163.57145777907976,
  -1118.6704213491967,
  463.843170223246,
  1.094030686849785,
  989.5712640291656,
  4964.791781963228,
  -12.55538236859286,
  -131.57860567299824,
  8426.551453267188,
  -26.791725470660886,
  909.9808294521548,
  9131.116297666358,
  1.4872199903677261,
  -801.7414681889045,
  6851.717229009443,
  8.568755821438168,
  -1024.9507363788161,
  2321.994660783478,
  37.218063015673145,
  772.9933244741518,
  2720.1860837265062,
  12.221942736934341,
  1362.0629425183533,
  7121.747978294285,
  3.3954741032563374,
  -1102.6766071690993,
  9186.075102123514,
  -27.962203612571265,
  721.8193117071432,
  8248.749440166506,
  382.9419473505367,
  39.58194380178145,
  -1640.1481704601865,
  244.73249674016205,
  127.14955210186588,
  821.1980099224212,
  -17.08111919761052,
  63.7500072772244,
  1322.1507487763397,
  408.30453863402903,
  22.396896132017957,
  -298.525070435879,
  6.244342059904966,
  32.91730006520794,
  -3519.2036848170555,
  205.33235347780786,
  80.57096000982685,
  -3236.085550982894,
  389.19026046855066,
  34.93983416874403,
  -106.53047333903845,
  -95.1371597610896,
  360.8160981426693,
  1361.2270152631072,
  496.10960228708655,
  487.24679017226254,
  694.77897816888,
  266.88513262540164,
  105.70269200589297,
  -57.41529267905426,
  224.65329142262289,
  167.64050321475514,
  107.16428254632446,
  -198.2164002023298,
  171.1840249544057,
  140.6608258711452,
  362.3291243283936,
  2.6819590652581837,
  32.293242298432425,
  137.40026469551566,
  288.73261467037736,
  -183.05960912774103,
  -87.60508970475115,
  2.856066427873202,
  -164.12872383561802,
  416.92155276949103,
  80.74526607182189,
  45.131090743974454,
  78.42556884598316,
  351.08601818938905,
  143.27368682952772,
  116.77849734479383,
  227.15498425782178,
  98.71118858001073,
  3.7619438586689284,
  494.7048240953625,
  86.27899204495164,
  -242.22069829353234,
  55.01959092168536,
  113.58901854451663,
  -467.1818532101503,
  463.4915673033155,
  119.14737221380972,
  26.241065611301067,
  -207.80050336947176,
  101.16505833912763,
  168.01898764583524,
  -295.3372562896487,
  65.42980947151014,
  633.1600446958772,
  409.7687023270799,
  68.57116512442217,
  150.85568024465164,
  -355.01132888101836,
  103.29534686833932,
  22.32479227642581,
  -325.8192806341152,
  119.58094546805702,
  -491.7600749833289,
  389.6996122402424,
  112.18632796212083,
  56.37989791946173,
  -97.04320090041472,
  263.78805529914086,
  20.895339922938547,
  -42.047806841164416,
  320.6761576622002,
  5.52457651455542,
  46.445156841907135,
  332.2544764351193,
  25.372627085820156,
  143.7285285307084,
  294.79644934591556,
  82.29215519245237,
  203.98391056766297,
  220.3582024411458,
  153.84840191000904,
  182.96195492164006,
  226.9017977739618,
  197.66551576518162,
  76.6740767490425,
  299.2339430962265,
  178.5818315254798,
  -54.97925475030259,
  333.15763043498447,
  103.00915535262483,
  -116.53872520334747,
  317.754285527206,
  211.57999803342986,
  38.40037176756886,
  125.71507543163638,
  -163.97969950559477,
  22.50247745199845,
  138.89090863837242,
  136.83410463001007,
  62.8967014120292,
  141.57255894185425,
  261.1829642742058,
  1.125078549535452,
  132.89691857629984,
  -166.94704550661044,
  16.58537636131901,
  115.65630261833176,
  16.199137163950006,
  55.431005082478805,
  117.17186241196526,
  211.94152378587154,
  24.0827168002087,
  133.92468492956806,
  -167.46587863055896,
  6.2580615131347095,
  141.7817381193609,
  -82.4843144855746,
  21.58176045235146,
  138.21417486974715,
  1706.2549133797509,
  145.0268768263048,
  616.8740125867068,
  1294.1956947985639,
  50.173221872878784,
  749.9080574123825,
  315.0927194308336,
  2.772313016312694,
  776.9842036478859,
  -768.4417976586287,
  63.0351894570359,
  689.3878056688532,
  -1047.3461876890851,
  215.31980455912526,
  515.3123722456367,
  -72.27744925908127,
  332.8273166370635,
  530.6147099694593,
  1312.0139012587401,
  289.7306269253139,
  699.7649797697748,
  1665.5323247539495,
  123.3982173409018,
  779.0962486047691,
  646.7742193169142,
  7.55236259261099,
  743.075196894361,
  18.782794870441542,
  275.01321299071867,
  -912.0588081925464,
  31.017785718642752,
  466.2080050395184,
  554.0446740381378,
  5.185532076467439,
  104.35095606100998,
  852.437708191733,
  54.24997577527054,
  559.8329761493079,
  -112.91957517291205,
  54.67926444541433,
  553.9507013953278,
  -2031.3202330422341,
  -0.4282924297656976,
  22.740534661107688,
  -1862.680614119392,
  84.23247395692744,
  268.41594532120916,
  1.4422117291640557,
  79.01010183762236,
  320.3562377856608,
  875.7135280765724,
  -2.5333998288818833,
  2.9084250711934487,
  478.7430426986215,
  65.36622050612509,
  132.47855669790766,
  14.354327332051199,
  -21.51639410413867,
  25.2048767132273,
  34.29468818404729,
  -2.463163606713117,
  96.93576821680404,
  38.353108922323976,
  67.43377743125946,
  17.79238602910179,
  25.22335865933071,
  -33.07134573115785,
  1.2816676194861145,
  -0.8686613380694109,
  10.18422287413847,
  134.3404597325614,
  1.4249931658733592,
  43.84335961510568,
  30.4431671927886,
  26.778784538980638,
  -33.30894373521754,
  62.084982349551964,
  38.66968156078712,
  17.940200583351114,
  149.40860386575162,
  33.27051648003542,
  75.64749146105174,
  -2551.695096907212,
  641.7272449350696,
  -189.97057055373253,
  2561.1932902786907,
  2428.856726375944,
  -49.41549772016212,
  -2838.6693390198184,
  2792.5875235916474,
  22.46317382387473,
  144.8290552468311,
  1615.850354534725,
  179.48998677963843,
  -659.9826147954607,
  -722.6137542043525,
  143.67841355422416,
  -3332.5966008684213,
  -517.0478863316334,
  109.03908262458883,
  -1208.6251954070533,
  1755.2534208257864,
  -46.69343021701809,
  -940.2339161124405,
  2820.9599437005018,
  -29.635021777166216,
  -3517.1115316854857,
  2337.0666399335555,
  1651.4128511604974,
  245.2702676042659,
  -228.2158727620519,
  -272.91203414998677,
  21.888929935913424,
  551.1043892579744,
  -691.2472281002795,
  170.01867170193665,
  709.7178434786234,
  1607.4454023843737,
  255.26348754109335,
  196.5736485886327,
  415.21889759196796,
  21.960664336917233,
  -823.1691741181156,
  103.82035914369689,
  6.357046912644606,
  -733.5272944017232,
  1474.3924313065845,
  244.79509465421086,
  257.36366703808164,
  998.2553156209283,
  133.24532588585404,
  722.090311228161,
  1045.2337061716705,
  95.2018441484089,
  511.0771416746326,
  137.1811567109497,
  -502.3739559989151,
  95160.53659317583,
  51.57395437807975,
  581.8223902975416,
  159947.36107898562,
  -14.627390268098566,
  -563.2273134787036,
  173133.29056200112,
  17.42629581997363,
  69.42840150857481,
  130474.34210340743,
  106.8223784655792,
  -101.23322965542246,
  45700.594396500455,
  178.32303945809554,
  -667.9653973325567,
  53152.74598397548,
  157.80907787739142,
  -217.5737863576859,
  135527.96697075677,
  72.15993155748995,
  -160.66097654193965,
  174161.84446417724,
  -7.720619462886091,
  -707.0920902465616,
  156619.79680250929,
  98.28858855184063,
  2626.163870616613,
  33509156.737986725,
  -353.91602001818296,
  -1555.3241354271038,
  56233224.50794341,
  -950.0376780229753,
  2329.320017200341,
  60858207.404698044,
  51.436725165245804,
  -4054.7919117115753,
  45895522.57700601,
  1614.6516398262393,
  4582.936083383246,
  16161014.005330248,
  1381.1701031197317,
  1818.4056207195774,
  18774866.42130819,
  502.89332506674646,
  4015.4246001990255,
  47668088.44793765,
  -999.3982027230775,
  4293.046385982412,
  61218974.10014278,
  -975.1999748936964,
  1627.5448567940057,
  55066076.76258514,
  75.40614984943535,
  281.9960757292305,
  -265.28862448409416,
  220.72764509178546,
  395.2789023815147,
  420.23703130278005,
  79.00205810711475,
  138.78124598904498,
  559.7606617283387,
  134.37367354051324,
  8.550407724991828,
  108.37561778840737,
  208.2844106126801,
  326.22959994246105,
  -788.6366906789912,
  121.35390520404763,
  0.2714060384256811,
  -709.7836037346551,
  202.07218992807975,
  171.9353896764767,
  161.84929131363614,
  185.14637341350002,
  192.53468446219398,
  570.6440488043003,
  162.86487269746806,
  85.19039833880854,
  385.0272382482669,
  -117.33122281898045,
  91.8737582012138,
  356.98058561767334,
  337.5477309784451,
  440.0204333657862,
  577.8755766261432,
  658.5369278821015,
  37.84478155292166,
  622.8338809990794,
  7.500405709512847,
  43.72377981883815,
  477.3853563803774,
  89.95691816761266,
  144.53345527569664,
  188.3436200999848,
  654.3789952267666,
  43.75243131741985,
  213.7522270347112,
  243.53389851338062,
  347.3267487414976,
  494.6160267904978,
  -90.2180091793063,
  12.253577100211515,
  626.3408040004172,
  671.1666177781099,
  21.27314263672426,
  566.5300247061947,
  -450.04713017547635,
  187.7796412076203,
  -66.69541071773494,
  685.6013676559317,
  129.8383762223401,
  163.64641436061237,
  652.4602466944527,
  35.484607702609594,
  210.5274134924254,
  -406.10790898739947,
  163.89902226342778,
  58.858611666402524,
  350.6951241130357,
  18.138904826898028,
  -242.5443343881195,
  181.18880124352154,
  28.527089839582445,
  -216.04909849651514,
  -302.8700982855556,
  111.45027783302706,
  76.82617196041762,
  23.282833874332994,
  9.943632169079038,
  214.1843141801664,
  -292.2200127799133,
  184.03927969804914,
  151.8156565700843,
  58.802013829910045,
  -990.8693271073325,
  -139.1062885381098,
  -66.19680640480031,
  1708.6175959364434,
  183.59576935051982,
  -28.32996819961815,
  -1142.3850957235616,
  249.2746571971599,
  13.067365551851914,
  432.8331156557204,
  36.79116901557221,
  99.16315261169643,
  7.911150952364068,
  -385.46540949511405,
  102.66216981674758,
  -1403.16727662092,
  -348.34637067723014,
  78.38299859994913,
  -281.75945392491263,
  61.963187515228334,
  -6.875559860119488,
  -140.0550602732198,
  254.39786648417052,
  -20.431763575417534,
  -1500.5868964380177,
  167.02122895132507,
  133.3344063995891,
  -1576.1077364178304,
  23813584.472792,
  79.85030532079446,
  939.8962126526843,
  39962591.85555065,
  -11.13313906808682,
  -1717.3250429106552,
  43249366.19986802,
  15.379302538007579,
  -249.17374102941994,
  32616036.36674062,
  89.61736042591808,
  -645.2139411557006,
  11485013.377910327,
  170.9087802939149,
  -1960.381970278604,
  13342564.692683129,
  151.26247263627118,
  -915.195758655683,
  33875721.8960166,
  80.5538988388926,
  -783.1229521587122,
  43505747.41150536,
  -7.3169788300455,
  -2051.1800201170668,
  39133150.67682471,
  -28.227411372042667,
  14.964834963344458,
  -177.3212283382557,
  213.14685230915532,
  255.6144120445102,
  113.39897440813681,
  293.4389842612211,
  29.993892461437497,
  172.568660885694,
  -39.132039549183645,
  374.0568253830891,
  -18.856343245301986,
  250.47048469964318,
  98.96626671234336,
  -399.2645715621815,
  269.7343144885889,
  28.907114614730716,
  -365.8242688833226,
  -8.696939848251446,
  533.4310835165711,
  3.820965878898046,
  283.9372661981106,
  0.27638675817928515,
  177.18412709119917,
  232.33416793366763,
  174.79643940164527,
  98.46707785684426,
  90.7255757006447,
  21.905897368871667,
  -4.067480970892419,
  506.8500603216644,
  26.569352298068708,
  154.56711482920113,
  539.1555829680032,
  1.5731686505418185,
  186.85368868720596,
  63.31248086385136,
  2.8667320509516774,
  82.40058267846437,
  542.389530416175,
  26.616308571219317,
  -125.17324593061977,
  578.5470638094472,
  13.013819941453978,
  -106.92618621897955,
  167.32335046795347,
  5.7579275936020515,
  94.77469955361462,
  573.3951285149179,
  21.390737691503972,
  189.37216731037205,
  567.2530748538727,
  23.400368192482382,
  146.41936537262328,
  779.904700212931,
  205.84256666729686,
  133.68168796159694,
  -390.55020070520254,
  282.5512869899253,
  140.411881369585,
  350.87429940058564,
  18.77549785506507,
  141.78166382750163,
  487.0546592944475,
  14.006880982757906,
  137.350161342446,
  -345.13505435904983,
  250.97836643786275,
  128.54368375204592,
  43.23362804777972,
  23.890865195839808,
  129.31782914175145,
  42.07662373638743,
  88.60020760477354,
  137.87514266447587,
  -237.47454542089667,
  169.79181792138505,
  141.88851219902048,
  -185.90263259042945,
  134.26219105389677,
  140.0662069004944,
  502.80988882033097,
  -6.26069707275467,
  265773889.5059509,
  -430.3415966562684,
  67.23286772231243,
  446006266.4747433,
  -267.10822872913946,
  -10.385715743234305,
  482688592.42802864,
  107.54562990501287,
  32.49961950182022,
  364014406.114644,
  816.7510344742421,
  20.93111376867747,
  128179818.21760781,
  924.3629034479958,
  -17.485513836558166,
  148911178.410089,
  673.9543394219529,
  13.044827975980276,
  378073234.11524254,
  -31.934750442010113,
  16.902731841965206,
  485549956.85051763,
  -223.87560857076164,
  -20.1377641883642,
  436749217.3165904,
  161.53485988009982,
  514.2031365117466,
  724.6473425727371,
  353.6162581295301,
  759.8130900088896,
  880.9236082082231,
  300.6743421257137,
  991.2859502836224,
  912.7301959657362,
  182.96242845976073,
  -319.55007522288224,
  809.8299347790521,
  226.13245796188647,
  -529.8168698171452,
  605.3419880289841,
  370.3173872461933,
  -155.78301080759587,
  623.317779098899,
  240.68702022637677,
  -562.5339054170654,
  822.0200927079218,
  343.1350963591137,
  830.9049076892646,
  915.2112338019417,
  341.12166785906777,
  -405.6501858624506,
  872.8969867011962,
  -324.9592219028375,
  573.4137696647749,
  455.7272239409281,
  -95.26498597538279,
  1320.1276722170205,
  554.00861479384,
  351.78832644147735,
  1513.6406247648354,
  574.0116246583384,
  681.3059955197718,
  1050.9036763874383,
  509.29814595169853,
  776.8982176056841,
  626.3971367426047,
  380.6966610267266,
  766.0558993942998,
  703.2719393774596,
  392.00154946163053,
  604.0736170321511,
  1232.851335863687,
  516.9644775670216,
  162.18150205071623,
  1534.4502044547758,
  575.5719374051871,
  -257.54727463951974,
  940.2085220612781,
  548.9607111831886,
  400.217399736325,
  -53.46109966965355,
  16526.918179498985,
  59.93740647166979,
  2003.4610308862848,
  27728.33640717788,
  -67.51172393733623,
  -168.91123759568103,
  30008.138080314202,
  56.74544924397665,
  1031.3543283465478,
  22632.553204374388,
  368.2877000023826,
  707.5774707901473,
  7975.464971862129,
  550.4137811273218,
  -367.618864057378,
  9263.916247100233,
  472.17158603906404,
  486.8577952631757,
  23506.307492445365,
  170.5825737630257,
  594.8319813246118,
  30185.97149813374,
  -42.93180463924415,
  -441.8494781202131,
  27153.012034728366,
  395.81777108872797,
  22.68022669571711,
  463.19446803992633,
  464.0034897948352,
  134.84760373305198,
  764.0154914276916,
  412.76491200485873,
  59.1623339068008,
  825.2409772094252,
  424.7627122724226,
  91.35050838202962,
  627.1650777683158,
  447.0079956894791,
  68.08979512317616,
  233.5398963520913,
  380.44074592912096,
  3.3867272925017886,
  268.1420532686725,
  444.2750801101146,
  146.67936395699462,
  650.6302902784126,
  394.39528654261596,
  4.493402197521135,
  830.016803774746,
  346.46165269692466,
  30.783447872088267,
  748.5647991151299,
  111.56312946608892,
  -58.5001162879926,
  162.17320131231227,
  107.92362029259779,
  -76.19155817494865,
  197.1472097689791,
  121.81564553368132,
  57.39129001880082,
  204.26539796400328,
  103.55318092821457,
  -93.51674953071822,
  181.23672761344227,
  -4.311231935207715,
  -27.940941567230055,
  135.47313613113243,
  1.9935549705791686,
  -66.51232842749457,
  139.49604688049013,
  118.32199705320357,
  -10.188381992614666,
  183.96483661168787,
  98.70492348734683,
  -109.198644695935,
  204.82064439193596,
  38.5313350441773,
  280.01932228734756,
  195.35088370933286,
  584.0413944539195,
  283.82128694735457,
  10.538214552453137,
  -198.42288023635194,
  0.0008229650609905548,
  22.238979399632726,
  434.0355502225574,
  252.33158072699177,
  24.620412065869505,
  648.7439775571517,
  44.410025255243454,
  16.916031915993734,
  -254.26684358465036,
  245.57488528196066,
  1.6055471838718902,
  527.7294490904312,
  118.82717257266889,
  2.951436167050556,
  607.9921386781921,
  14.216574131265276,
  17.828737186980813,
  -104.75105591740669,
  474.22624393974695,
  24.806173097337382,
  615.8302009903948,
  7.507192848665596,
  21.63800771407878,
  212.8829308575551,
  -1058.6492121498957,
  3092763.8201906057,
  -344.63752587071366,
  2370.1271263166323,
  5190847.761068505,
  -137.7279303792805,
  -1251.0982578930264,
  5617866.481517179,
  54.63395636873548,
  749.6785878821433,
  4236381.042061552,
  430.1918758836437,
  209.96033037456164,
  1491032.1214511078,
  416.0527443522599,
  -1582.3329690974629,
  1732365.7520891344,
  299.6141131688107,
  -157.9672589291469,
  4400039.768377568,
  -74.59101356595602,
  22.019785224330576,
  5651175.606352518,
  -105.80585973958969,
  -1706.0713300726263,
  5083086.511368064,
  489.65772973810715,
  2911.657504972109,
  1281.9680985165319,
  251.17728446400056,
  -941.0872164893149,
  3063.2956094395404,
  171.58122694407294,
  2638.151138890238,
  3425.8455434979837,
  53.52124550539946,
  -3244.0500057224262,
  2252.9286876489446,
  345.4723661864685,
  -4011.0913737318597,
  -77.94352584309519,
  334.86293446320525,
  2167.404184381492,
  126.9549661526865,
  471.9700877905969,
  4191.69631768567,
  2391.879177621882,
  495.2281021253002,
  4447.491830716869,
  3454.1258516772323,
  208.8682041405259,
  1991.5486516894453,
  2971.803522320033,
  -446.04308233754614,
  61.11835302167021,
  -227.57870581349786,
  -141.21924425746795,
  3.297184508084193,
  313.35603885749214,
  814.8432195465118,
  22.487327468945985,
  423.4513777594154,
  -389.5047956331953,
  11.797217246152258,
  67.27236180167971,
  -405.33987842881277,
  15.390825354630586,
  -640.542320189451,
  814.9595845124244,
  22.832267252022483,
  -578.3209079159841,
  -111.63855889366431,
  5.268708163041371,
  109.46738060340081,
  -436.8445386093998,
  64.52612875608807,
  432.0392433766887,
  813.6806562742738,
  31.30603451331302,
  285.5726871257478,
  273.7934669104948,
  -1102.5318414407375,
  43298.82963858671,
  -1405.506859635436,
  1570.1208495185815,
  73975.80697157551,
  -381.4949819948657,
  -1252.5414685510416,
  80219.42923698618,
  128.5605294098071,
  307.018296511301,
  60020.14326642518,
  1103.734083814029,
  -113.6797341840055,
  19879.22946987221,
  767.6416711510038,
  -1510.7313458865838,
  23407.871090222656,
  489.9704830169394,
  -400.4708703099998,
  62413.06708597524,
  -488.7610040663683,
  -260.1750882556346,
  80706.45611310241,
  -276.38285969172887,
  -1607.1825666107147,
  72400.1839233138,
  4.778212695276766,
  599.8443142289784,
  688.9769950648013,
  -32.32474173858646,
  21.063106480266185,
  1223.9550674537227,
  -77.81626548212647,
  558.7566335409674,
  1332.8380570656761,
  4.073962265367674,
  -324.9010517801553,
  980.5812178449886,
  128.99561201046947,
  870.6911952811921,
  280.56085880795484,
  109.57913268114709,
  488.0383507134327,
  342.09710052158664,
  37.453779477189144,
  792.1390193156313,
  1022.3115929879073,
  -82.99661662692883,
  830.566075005103,
  1341.3313547122498,
  -80.47221206848263,
  461.6203331806778,
  1196.477660797228,
  1180.1131025431773,
  218.91158541633752,
  451.62157327479366,
  918.5730845588793,
  151.3827043296204,
  549.0175461920937,
  851.3008128719099,
  297.35875651397276,
  568.8403487605154,
  599.9488164759522,
  128.47357520457297,
  504.7098743665481,
  1136.9381439754757,
  190.74896276432554,
  377.26696137783716,
  71.01573189696327,
  123.89307230668888,
  388.4700039709852,
  1134.6182467241301,
  252.02926990970403,
  512.3071399312827,
  919.5666745866147,
  290.5070613483366,
  570.386604635771,
  -544.3768101189982,
  267.0261649717486,
  544.0151191905472,
  529.1511352780637,
  -229.68869377904878,
  -1862.620195731266,
  -841.285207487203,
  151.97485706165125,
  -1459.8243592455012,
  -183.1548509731225,
  -251.11055945462624,
  -1377.8441489464633,
  123.16766236493453,
  -28.40032116012975,
  -1643.0654646129833,
  925.6129905083549,
  -88.47737672743064,
  -2170.1249846719707,
  800.0955997609542,
  -287.9809188950206,
  -2123.793100741571,
  689.4299140512255,
  -129.43208952410015,
  -1611.6458191544366,
  -96.2362980613101,
  -109.39739271221856,
  -1371.4493729609778,
  -60.4741650654222,
  -301.7544688624445,
  -1480.512655775562,
  -391.0402158925924,
  230.10744570974506,
  287.3955466294141,
  -118.13334938056778,
  864.2922697704277,
  349.3748021222415,
  709.9337932100937,
  77.5578113926779,
  361.9893128476008,
  608.372901971194,
  670.091024996834,
  321.1790109605306,
  719.2468620766733,
  178.76539387390122,
  240.07897542226002,
  149.64503728475268,
  968.0921378054018,
  247.20818434517238,
  29.7370763041786,
  -506.011374791683,
  326.01363450172533,
  -258.01108545564426,
  -265.9632321678366,
  362.973293859127,
  -103.31995395896178,
  875.6725777132561,
  346.1914394848937,
  -683.7522880419234,
  77.58496835229795,
  -1032.528833627241,
  908.9637689861539,
  89.35142695037479,
  372.4647341667025,
  389.911254185389,
  398.9665018630673,
  658.4201927967058,
  -504.3113471445804,
  52.56732313653703,
  -266.6992071563675,
  1013.949759872187,
  1.7386296113913886,
  -2105.137364780202,
  222.7170085021128,
  417.99408292597946,
  -1943.5269581932716,
  2.859442192165716,
  346.4113234472265,
  -157.10423180417325,
  880.7565195318668,
  169.50808224739504,
  680.7258333055003,
  140.9577364265765,
  413.04233195154256,
  300.301814591995,
  614.1831627911015,
  265.7640910745253,
  44385.197439608855,
  167.8634482785436,
  -525.8379450604099,
  74896.5037513074,
  -231.7491874971588,
  209.56825876821296,
  81106.40733361467,
  109.7922886105672,
  793.8024890464595,
  61016.2076103639,
  789.9270226413059,
  636.2027640157096,
  21092.07482557795,
  1012.8493588999048,
  112.84649944228192,
  24601.660016259164,
  779.1482429858011,
  528.7665487331894,
  63396.2084444206,
  107.04208605719003,
  581.3234305379341,
  81590.80402100383,
  -193.24145120127616,
  76.71444092068504,
  73329.38985558508,
  92.87246970081392,
  61.41867384217704,
  278.57920462902723,
  153.30898408001943,
  321.70934164853213,
  765.9867997183545,
  108.32981065613879,
  271.45483887941566,
  865.1878676722517,
  33.20029141614141,
  58.971676019945875,
  544.2538561311117,
  234.05600728469216,
  563.8757262758991,
  -93.52039541571408,
  90.76497580081426,
  359.03416457513015,
  -37.45598243791988,
  12.769076706284295,
  357.64109583462425,
  582.2735486014202,
  272.96187899731433,
  251.69476914723975,
  872.9259376866144,
  63.34714344916847,
  487.36565519127515,
  740.9526957261495,
  -565.6534777062261,
  327.2802656549789,
  43.10933199441212,
  819.0639430981632,
  342.40936030689767,
  52.40622031833622,
  -959.3367174117595,
  148.2652442873546,
  54.29839692714012,
  -281.9525021090435,
  96.53854905038976,
  48.17685164407959,
  666.6665907087261,
  346.983107477628,
  36.011846313339,
  828.3673968401858,
  342.07468046219856,
  37.08122765177586,
  307.3937448105197,
  86.38319372626614,
  48.902045175258806,
  -944.5002701188951,
  291.81937512025013,
  54.445994078869056,
  910.6206003763681,
  99.18153058057517,
  51.92871592273405,
  90.60845822037172,
  -151.33261417274923,
  651.77204324885,
  87.779211772889,
  -96.4360477963487,
  792.3321405272261,
  89.10747289243534,
  -130.05291833655895,
  820.9400487793803,
  93.12406740939468,
  -153.4947597185464,
  728.3881141426319,
  92.13167298235386,
  -157.46906541607632,
  544.4648192611968,
  84.50900733065818,
  104.13486675478174,
  560.6328466399445,
  87.95136836459268,
  605.7057887664214,
  739.3523496735558,
  88.86351383372575,
  629.0167881337784,
  823.171577144806,
  84.26199423962451,
  142.05877717541887,
  785.1127288318124,
  0.39338457957594297,
  2476.3483826413294,
  2994527.4307217174,
  -10.260851222254539,
  -28.778761192227364,
  5026220.271625656,
  -20.14286764853348,
  2298.5093947981386,
  5439726.547692242,
  1.1478559439498204,
  -1526.2085188424917,
  4101956.3934721025,
  7.25342589305823,
  -2024.9532554817688,
  1443480.419696849,
  27.55539139447598,
  1992.4208634070662,
  1677177.365793044,
  6.750641788986991,
  -2364.9490701073723,
  4260436.355178771,
  1.240278764562662,
  -2198.6260123154348,
  5471981.6491904305,
  -21.170103726606918,
  1878.0762856606552,
  4921868.98458819,
  -84.84381720807457,
  483.9513746754709,
  -12.153047106984978,
  -132.15080780239495,
  123.75259786431307,
  796.2433222724881,
  -221.9140353880113,
  376.06415211491293,
  960.7745769768792,
  -256.2198863102213,
  332.13578471613175,
  428.485190528768,
  -43.585978582198294,
  218.14336831427892,
  -629.3038029719905,
  -30.393465678677273,
  499.4977016846652,
  -536.3174228678108,
  -350.36399131277165,
  170.64466802597082,
  491.5432586991844,
  333.6670867799914,
  501.0646612389117,
  973.6086562334173,
  228.08705859410787,
  397.08583865733306,
  754.7226751142144,
  -93.30313299995115,
  -71.88091942478911,
  67.74323599121905,
  449.2450569499428,
  36.18337452787827,
  82.35263192881405,
  11.337707391066047,
  132.07867353302922,
  85.32605231407733,
  -265.31050804610953,
  32.85458735636453,
  75.70648115498221,
  -234.75341751580186,
  -22.376192384680884,
  56.59004420667557,
  145.5156659155731,
  -86.74173248309798,
  58.270500595647775,
  -229.5107307805012,
  -25.82156764581014,
  76.84607098969241,
  -241.80288587601825,
  64.18473609732007,
  85.55799069536566,
  -252.54636824382618,
  -7.354031286378262,
  81.60226787858208,
  -60.44479185113359,
  370.44286963349737,
  72.37659714188922,
  117.59697679412402,
  392.09325844540706,
  80.16271554897226,
  120.24613392037668,
  125.91540486441188,
  81.74740825581566,
  -63.79508729624179,
  352.4300249702654,
  76.62063091402739,
  128.80118474093854,
  245.69918661164073,
  66.43247240036642,
  128.17387594802065,
  367.01248506767513,
  67.32807633076622,
  -62.58295066648982,
  359.82980620463366,
  77.22797850228247,
  101.17750239565787,
  22.18615381297846,
  81.87102046453202,
  92.72437466869637,
  306.1213595009607,
  79.76280693067751,
  601.9834221799713,
  -5.091705340732489,
  109690.30908521086,
  -149.06221384335095,
  213.2757408731918,
  184112.49028085076,
  -101.67891489285381,
  -17.34814976779157,
  199259.48414891493,
  96.04214541947016,
  110.07472274633523,
  150256.12556485145,
  646.9585554388248,
  75.70184859739656,
  52874.48566276357,
  810.8525127941012,
  -38.443395080721075,
  61434.95116083589,
  718.7939235567935,
  52.269755005716064,
  156061.34581692662,
  185.86412322685592,
  63.732535690023084,
  200441.00871791123,
  -539.5526706208581,
  344.69384663085225,
  180290.03728227384,
  222.32120559716202,
  4036.5020938790108,
  2042104.8876243944,
  114.8420989468764,
  -200.8616645052869,
  3427687.09796063,
  66.30417353550415,
  3735.6916205385687,
  3709691.8028279915,
  24.084773961587203,
  -2733.7289488714346,
  2797353.8303313763,
  149.1969303739302,
  -3577.3439633517646,
  984315.490229525,
  166.95124140862197,
  3217.9500548195424,
  1143693.0913125342,
  228.18054872421226,
  -4152.43890272168,
  2905434.6441308814,
  106.53435130617184,
  -3871.1073547377655,
  3731689.269142139,
  83.8522063859066,
  3024.5388856886702,
  3356521.1795531637,
  -767.3973461111734,
  16.060726692191515,
  1245.0385645052834,
  -1166.0805188289448,
  11.564808844881327,
  1513.5415534795675,
  -891.0402584496544,
  5.742850787221382,
  1568.1894160147847,
  203.57784209678286,
  2.348902021850913,
  1391.3933581968702,
  1456.849598373045,
  4.611760598357515,
  1040.0564185257192,
  1926.6737915944875,
  10.970765444160527,
  1070.9411700381931,
  1423.713139507566,
  16.55285452806651,
  1412.3376380378315,
  551.8418277797965,
  18.647873684213383,
  1572.4521623254325,
  -105.17529853030322,
  18.299929494073886,
  1499.750771768486,
  -876.2902214399396,
  57.93697071343024,
  675.3795345791233,
  -745.3060927347233,
  42.78174854782319,
  821.0307849872675,
  -880.6417582457323,
  56.91310522628032,
  850.6748851918618,
  -481.345850907266,
  74.51681136598982,
  754.7706757572469,
  -867.2176479679742,
  50.650454383711285,
  564.185592242311,
  1400.0220413257591,
  50.02244517944414,
  580.9392332111552,
  464.16472628863266,
  80.33633141323224,
  766.1320410790546,
  1342.636733009155,
  45.63590625261931,
  852.9872405689486,
  -829.7752245083475,
  62.78014085935836,
  813.5498827895002,
  449.2588760660116,
  -2612.693975995468,
  -104.87249266002203,
  -956.395718371263,
  2329.5720548569884,
  1909.3766687039865,
  -249.90291529496824,
  -2890.0915918083842,
  2319.3326684580156,
  122.46557475260798,
  -6.155614633161349,
  993.0483222293614,
  961.5551525964867,
  -784.109889569498,
  -1642.602546285146,
  801.3038345084533,
  -3367.535991741762,
  -1410.9120721098486,
  626.4495606251434,
  -1314.4437016729746,
  1150.167608931494,
  -203.4021018041774,
  -1055.0089160517275,
  2351.310834563838,
  -141.85284656588766,
  -3545.893469101837,
  1805.9213194648014,
  486.2917551085287,
  109.66051394665713,
  -1.550454188244434,
  400.8808405576809,
  102.3287737885231,
  31.258173116032225,
  -348.4693479531235,
  24.899779105634487,
  37.93564572720308,
  550.3660729550309,
  81.21607606516966,
  16.33277273136894,
  299.3719381228702,
  78.58157451248104,
  -26.59741123391983,
  -266.02457169361435,
  101.99988965268572,
  -22.82357502588044,
  515.728641002666,
  22.0210508074558,
  18.891973558456925,
  227.80164482876026,
  58.90640166378069,
  38.456514621560565,
  -7.719537214234919,
  84.9125171254946,
  29.573064808218042,
  105.15171121694513,
  -308.8660254696779,
  441.35744660945744,
  98.65162399877384,
  -382.1113424762668,
  536.5398746877279,
  91.41616241295576,
  -410.01987310090396,
  555.9121590159583,
  83.9481313922356,
  -386.40250728957994,
  493.239195403672,
  76.84437959525974,
  -308.8052690926828,
  368.69271225561357,
  70.7518507295399,
  -179.49276099557363,
  379.6411402443719,
  66.30725413704964,
  -6.099860461362709,
  500.6637958419354,
  64.06403315360453,
  198.22701435042234,
  557.4232727122308,
  64.41335432004598,
  415.35545202857486,
  531.6511392089438,
  114.92061813411661,
  157.04293116779553,
  86002.84391054862,
  -516.189092896006,
  20.875160799029643,
  144355.21915261715,
  -1597.302811759955,
  147.37638050235074,
  156231.55838077154,
  280.20280832931684,
  247.8736870764086,
  117809.37937069923,
  2736.3776539336686,
  220.76410146575486,
  41455.12715768381,
  2254.2354998940255,
  130.73874478091938,
  48167.15154295622,
  794.6271270658566,
  202.28341391812233,
  122361.09211372472,
  -1752.3701384478359,
  211.3240089219317,
  157157.95913791348,
  -1625.2882798314101,
  124.5234729358119,
  141358.139409257,
  275.8010190471498,
  95.24657015598024,
  3280.296093694902,
  -235.07972524899162,
  -25.167972461656504,
  5748.648758244913,
  -750.306312844928,
  86.69834120343562,
  6251.027512448225,
  68.74166360368167,
  -97.14528499581078,
  4625.738266828008,
  382.2202982770458,
  -121.11856694806735,
  1395.891647596556,
  1321.948039703647,
  71.985510919078,
  1679.8157073658922,
  615.5208219013656,
  135.25318863426338,
  4818.2793970031735,
  -654.3279663277173,
  143.24787863636038,
  6290.215013691257,
  -762.5667435396526,
  66.48928288768612,
  5621.869861247101,
  30.401524439207847,
  106.64224892724596,
  -265.5238308587467,
  243.8374977838058,
  0.05306397354212322,
  195.26743477806048,
  30.971235674541703,
  110.02789393740835,
  289.05133579958994,
  2.2589679711728934,
  31.786104461711744,
  -14.357127371438338,
  243.5906162873056,
  2.454685877598479,
  -617.3038346482703,
  91.08688697730928,
  427.80580535632794,
  -564.3009843162234,
  27.428162502234045,
  377.0393623514962,
  21.586387643556392,
  240.85018004023652,
  29.918259363401944,
  296.3668456755714,
  154.30045093188323,
  511.74770146703963,
  171.600391878293,
  178.10421524581744,
  389.0452752767634,
  242.23338930193478,
  73.53659261418471,
  38.557050492532426,
  294.4730475030321,
  192.4764400442357,
  379.56443660378557,
  305.10527797154924,
  -77.6462515811584,
  94.14857237195648,
  270.7080235238758,
  -108.81058410004553,
  326.6499291643348,
  202.35227928447628,
  202.79080622077475,
  371.603397626713,
  208.36118394807386,
  -30.480036474661333,
  61.441920621599365,
  274.7829205085971,
  126.79033784767762,
  46.76558436389837,
  305.93463339554995,
  -28.306607502910282,
  397.6374956429046,
  291.789927565839,
  -1031.074957132146,
  -22.262624769602468,
  1247.0913898383508,
  359.1918097800799,
  663.3560856358425,
  1516.0370877804405,
  -880.6926486273342,
  -163.64015538883154,
  1570.775053963696,
  817.9650566846584,
  -410.64425258414565,
  1393.6874939894453,
  -1041.065417597936,
  -6.107118962462096,
  1041.771268350164,
  -552.6683180673878,
  -311.81986367786413,
  1072.7069427835158,
  1723.5636994686238,
  298.13543142892286,
  1414.6663068557011,
  1741.9441075654474,
  -52.195601049603425,
  1575.0448287101406,
  946.6845999738106,
  616.7657233363686,
  1502.2235677648066,
  147.5645426303879,
  -256.8878177343843,
  5.1320633326681095,
  185.58871689256,
  -61.30557789179392,
  6.238835752182883,
  184.28873806853466,
  253.17184727858682,
  6.464094872278585,
  146.1371980944329,
  436.80953120732534,
  5.7353394814380465,
  116.60195786377074,
  458.81328481574974,
  4.287124561111786,
  118.54637969375882,
  459.47662221951225,
  4.41443186330665,
  152.61773742729034,
  421.93931605795484,
  5.821672044673667,
  189.29015238377647,
  181.24354283392407,
  6.481665961770125,
  174.24221239099776,
  -156.4292179584006,
  6.181989990801673,
  1327.4448932030507,
  126.45724919464148,
  893.0626208883556,
  -323.3896896735905,
  2.5183062569059587,
  901.102771712357,
  1271.6721722360332,
  25.480390620667833,
  902.7391671158902,
  1195.6622655094675,
  4.7868751157492255,
  897.4451218787214,
  -312.6477198339446,
  1.822855405595007,
  886.9245612108858,
  1297.3928321826447,
  165.11546613479157,
  887.8493854047271,
  683.3079286986897,
  73.36103928606593,
  898.0722849857866,
  -218.4649873301546,
  0.38773258661694854,
  902.8668123365002,
  1014.1105794988482,
  226.19967882399348,
  900.6898155461648,
  256.50280834816596,
  433.171952661664,
  253.52392863380462,
  199.74266450243164,
  198.28432983769346,
  308.1984861578344,
  262.01246738467967,
  220.84765176028606,
  319.3262866905621,
  221.40283880090678,
  26.90342852248304,
  283.3257703830395,
  257.6619772099404,
  419.5307062761527,
  211.78395331892222,
  247.8026521205117,
  57.041649550186094,
  218.0729340473485,
  259.8266324089577,
  387.54553215415615,
  287.59059900687913,
  261.790004410018,
  213.31645581614256,
  320.1942985114442,
  212.93528879890897,
  58.40379455466976,
  305.39030554560264,
  -284.56367434307475,
  4.3438934545197725,
  -48.13390475770779,
  -16.98609286382353,
  8.921903593865569,
  78.19116837161083,
  253.01795283499047,
  4.354033051936183,
  103.90185136063135,
  -164.30355382057746,
  10.986750704008173,
  20.72298240970754,
  17.788590764465326,
  9.889006712495707,
  -144.57374209431612,
  -11.058149891904932,
  11.58188970519418,
  -130.04310871739017,
  66.1406810196245,
  10.155665810962148,
  30.57683056483469,
  11.59669183098599,
  9.728278039993953,
  105.90738486132499,
  -213.48370696846223,
  9.33032555633318,
  71.70289233856568,
  -1188.5927658541286,
  418.1756397430147,
  651.77204324885,
  -644.8494229706127,
  1185.0713462633032,
  792.3321405272261,
  313.2636477812719,
  1449.4872610926557,
  820.9400487793803,
  732.8774159554777,
  1399.1377261900154,
  728.3881141426319,
  296.12447406907967,
  1449.5296180122982,
  544.4648192611968,
  -736.8486015149149,
  1121.1046126599535,
  560.6328466399445,
  -1201.2642229233318,
  238.86830493699236,
  739.3523496735558,
  -1092.7921054915348,
  -181.05715239628591,
  823.171577144806,
  -1181.666370616559,
  455.0927059543452,
  785.1127288318124,
  34.101059128548464,
  498.04530608712287,
  -53.68652095798166,
  30.33675573617054,
  0.37254225537270713,
  66.61301079656351,
  34.16424500226727,
  499.60205649803083,
  91.09732771045472,
  31.58447652672663,
  365.10058583801833,
  11.885982418571857,
  35.39661622023714,
  286.5238359650223,
  -145.52630372384544,
  37.79848436069961,
  462.38910922386196,
  -131.68876262421193,
  30.163184690051477,
  221.72953815551804,
  21.26981485719376,
  41.200616942798966,
  511.3614495530352,
  93.00719987656473,
  41.82413421278183,
  198.3501671904723,
  60.43421707545845,
  342.5109705038936,
  42.81294499477663,
  275.2958226779344,
  404.56338736178395,
  0.30526809526293164,
  417.4548437040256,
  241.68905605779986,
  287.21201686052666,
  446.3881776264981,
  238.36074238836076,
  176.41323074968165,
  352.78343007162414,
  441.3712593166684,
  19.941391638779777,
  166.76793882978464,
  70.90968710298802,
  83.35354614465183,
  183.1198835750548,
  112.13209657563624,
  296.27989881436474,
  363.8723878879289,
  456.42084440236533,
  55.009273351238406,
  448.6450904628103,
  -22.54536058909045,
  13.723239452190825,
  410.1533084968342,
  497.21531647881903,
  -2666.501456125433,
  49994192.757668324,
  -1840.8885260352267,
  1843.3161820095802,
  83897938.77459541,
  -322.27118000101905,
  -2919.6267740990133,
  90798298.65081045,
  173.89543000963553,
  -288.03526204240586,
  68474343.65891045,
  1407.5360289944135,
  -997.9185198170394,
  24111193.68252054,
  897.9478891466191,
  -3355.2947779269994,
  28010996.716650292,
  736.9554694808764,
  -1481.8481110193798,
  71118968.01466917,
  -480.468186359587,
  -1245.113875177659,
  91336553.6207193,
  -116.3334324307624,
  -3518.0459718673087,
  82156583.26010552,
  264.79532443102124,
  511.0234590189404,
  -1086.6065555880407,
  172.9322214335842,
  562.9990336663489,
  858.1073384246524,
  418.86389007793014,
  152.75909224761753,
  1253.91096786027,
  243.42087001816094,
  481.1147350659704,
  -26.587813023318812,
  357.12761988592786,
  313.6044769742422,
  -2571.2515825719875,
  255.65383504798905,
  508.26503953765837,
  -2347.5594530769595,
  252.02399648889664,
  493.8229356431092,
  125.10745175717418,
  476.33738519175773,
  16.596657880815485,
  1284.7851939112936,
  66.8797859915671,
  460.8341851399391,
  758.2234417675288,
  387.1529673831963,
  12.784549369503935,
  -742.3326150307244,
  85.85498481705835,
  0.4141551863267807,
  652.7932164217946,
  56.38340719407334,
  3.490708783021347,
  936.7403149170373,
  388.95992293389713,
  14.25165916665216,
  18.118335686969484,
  265.5524422348724,
  191.5541844962424,
  -1807.4078603198943,
  -83.08275343566464,
  246.25189198085826,
  -1646.9324972796285,
  410.9999050034961,
  40.1713710166824,
  126.94358913729212,
  401.29351627415645,
  420.8643515106986,
  958.8892955061624,
  -101.599410403219,
  445.7540371270529,
  581.137120992274,
  1826.0221204520103,
  7.044160728242417,
  167.02826917467547,
  1823.7091696948057,
  300.09202671567596,
  375.74845594242015,
  -575.6234505251964,
  369.3936616941862,
  418.22884738380196,
  1944.5833661031315,
  82.371855195721,
  280.7968346210303,
  1952.1558732848691,
  115.25250733586932,
  7.685864993821738,
  -327.151884065942,
  305.6317552713683,
  31.694056219493092,
  1881.9230282958486,
  254.0585159127817,
  297.0778228395267,
  1861.8495360538122,
  16.180089982926262,
  421.5424835168697,
  -1155.1638290678288,
  394.3328359114888,
  365.02822319787583,
  189.61490051566616,
  141.95251153220522,
  252.497515967271,
  114.88349119670156,
  127.51829304707398,
  306.9507190073978,
  156.91589273932976,
  312.10887760485554,
  318.0334677161064,
  47.611335050216724,
  124.88927173301417,
  282.1787024867519,
  -165.81267945953743,
  229.9211787398019,
  210.92652840669987,
  196.46872557837133,
  144.06625881286936,
  217.19004767468718,
  -162.87282672607435,
  205.8115299219168,
  286.4262645979444,
  -0.21177517983469585,
  317.652913803277,
  318.8979653190902,
  72.3473584971985,
  321.1587936967884,
  304.1539075474423,
  -294.4126692050261,
  180.7041367302716,
  387.9839879497091,
  -656.9687503397226,
  108.9663152719892,
  471.655982865026,
  -204.78395107623032,
  188.52780777498737,
  488.68557234426106,
  -394.3390700883224,
  -0.5921640406129853,
  433.5916647967163,
  778.4974131201814,
  198.86681933347037,
  324.106616820051,
  -306.15650456640947,
  -10.542774677868508,
  333.7310488659827,
  -607.065449404514,
  129.34308078983412,
  440.1184065773292,
  1413.3984909395783,
  84.80212302368386,
  490.0139467098215,
  -664.3081484386328,
  64.87997988923851,
  467.35844330460645,
  121.03467544951471,
  1088.6508424082251,
  627.1381392520431,
  64.14945480389852,
  -284.71712877687355,
  762.3857289167483,
  365.1117980128571,
  -448.7323157095899,
  789.912393392443,
  271.14941217331,
  1230.9891801039535,
  700.8584846317293,
  47.06049784263584,
  -85.69874176631583,
  523.8866213678602,
  360.381376835109,
  -475.5315118581552,
  539.4435736960726,
  330.6538258770439,
  1089.772073926843,
  711.4083238591221,
  97.88975766327513,
  990.2456789796069,
  792.0595805283093,
  37.35135333601821,
  293.6084364266008,
  755.4391768759644,
  207.9400848470167,
  788.3708027322816,
  15208.232134369327,
  -223.2972315324439,
  -578.9297203676936,
  26625.678833721147,
  -789.3688842526576,
  691.3061321010497,
  28949.448338533282,
  55.34952083767766,
  -1396.228154094101,
  21431.619302429357,
  1435.3515370908763,
  1428.2137644330637,
  6491.857188299079,
  1290.526828054905,
  524.2427516590219,
  7805.157295547306,
  559.1264732532752,
  1242.6437599988792,
  22322.22465343121,
  -762.1908842541345,
  1333.4230262258602,
  29130.711418622643,
  -797.7702320209216,
  461.833383994327,
  26039.258862270668,
  -258.8965281885754,
  1567.1306613159747,
  964.8279065416046,
  1376.7343901512154,
  1321.3173321461684,
  1172.901121410382,
  1798.6008263752926,
  805.2187169480628,
  1215.2498359883741,
  1112.953354619523,
  1485.6946026601718,
  1078.2438225103529,
  -714.5944022278111,
  1322.19278136168,
  805.9794174890158,
  -1137.8608660790026,
  804.6684373482706,
  829.9131903016502,
  740.2345804087954,
  1619.5390760433745,
  1094.4743443986495,
  -179.69089938486655,
  -1056.8173805435308,
  1218.5532008127836,
  1188.0158504648236,
  1445.9280130487914,
  1162.2141182707146,
  1726.749385789482,
  197.98175905593743,
  901.19032121652,
  837.5053161272391,
  181.5170710307402,
  1095.5395580833142,
  -647.086760228355,
  214.57096951732296,
  1135.0950595721195,
  1396.9929907232106,
  213.80633356878866,
  1007.125612940521,
  -841.3853729945461,
  210.84449676681822,
  752.8190729312296,
  -197.87777586634752,
  181.88424922780882,
  775.1742351966477,
  -426.3990204743858,
  217.28555738406345,
  1022.2856110446959,
  -941.6457063703504,
  207.83121621678643,
  1138.180542886834,
  848.0383938347195,
  219.42450647566062,
  1085.5574423847738,
  -154.76166569450766,
  19.469370290090353,
  308.9502126266202,
  -443.20586507778864,
  16.597719406425718,
  375.57791228140957,
  980.6646666048439,
  -0.9474176741438773,
  389.1385113111708,
  -643.6860948221754,
  12.301445695674989,
  345.26743678257037,
  -715.2198940450031,
  3.0124556408663103,
  258.0848985789295,
  -342.75078321976355,
  17.87915232536385,
  265.74879817106034,
  -598.8559384725536,
  13.595542907088781,
  350.4646570893548,
  961.0570943730881,
  -1.4866360158660719,
  390.1962908985616,
  -274.11497546414085,
  -6.5652199745831155,
  372.1557974462607,
  -234.11011199788436,
  192.77795132697426,
  -960.5481780973458,
  -416.56462333953255,
  297.93164359591975,
  382.16175594998913,
  1252.9743435612588,
  293.3660943908135,
  655.4407543730464,
  257.7451114104096,
  11.475446224403697,
  -228.66792553165547,
  -503.67237797799726,
  283.8693068920401,
  -1985.6077677895187,
  1273.0597494022077,
  320.4416286831975,
  -1831.161581455429,
  739.7347248851688,
  54.518162318141805,
  -123.93131641100366,
  -163.1731341459465,
  44.08307091280402,
  676.7575815692546,
  1270.2428833673625,
  336.6277247863061,
  313.1978324104978,
  412.05545932038876,
  -223.58432733542355,
  193510.44478788838,
  -901.7842933356899,
  304.7097148320778,
  324971.39207055036,
  -182.26243654066548,
  -253.2362130960442,
  351727.3689901982,
  109.89847315182394,
  55.03658833212852,
  265166.7786393423,
  850.8591672673742,
  -28.121340836795184,
  93149.74791278855,
  663.8212421851812,
  -304.27171591529145,
  108271.13894806046,
  559.3022484611473,
  -84.81035586456781,
  275421.2449995275,
  -168.8604338186156,
  -57.078572363005975,
  353814.4394923335,
  -66.68300006295271,
  -323.3368961538997,
  318219.3285853993,
  178.06855220346375,
  1105.5003861384548,
  -157.8728800369175,
  12.043449531993375,
  -895.9397000434406,
  223.3959860116713,
  -145.06865599992562,
  963.418144911107,
  300.9948561783535,
  44.26304025460625,
  2440.56165240859,
  49.947995420490344,
  353.6896825091051,
  2042.0957657012884,
  -448.94342139807856,
  398.06928461089365,
  718.8725304680962,
  -405.08769289264586,
  257.9488968616281,
  1770.4603502291818,
  79.68845326668783,
  -53.94199978317917,
  1903.3420827753898,
  307.0478705538064,
  -137.32335769004032,
  627.5183562488019,
  203.8133522205398,
  -488.1959184016482,
  70.26428106382919,
  -49.695953058142145,
  724.258450461345,
  77.84866775790125,
  66.56580191830746,
  395.4133642769359,
  9.8170672365464,
  90.22831840770361,
  -438.2453997971618,
  110.48830125231866,
  13.675651216362802,
  839.1799033978155,
  112.47034557487474,
  -138.45319230327163,
  246.89453313738863,
  0.31122863999199524,
  -125.08009941306294,
  -83.66912226277412,
  39.375771114853144,
  22.744521325891718,
  783.6034740430583,
  83.31269756882479,
  92.07408693709135,
  163.93100886616662,
  0.751233899572533,
  60.59439545332759,
  554.5380460773174,
  -284.11892994599776,
  -1913.8369696380732,
  375.93505968754107,
  517.4057541169354,
  -1520.8065183584606,
  -10.064232319431198,
  -329.1066005785129,
  -1440.8138368775858,
  59.28583028717304,
  138.60312174988957,
  -1699.6051250270318,
  324.34379110396384,
  12.436389619080956,
  -2213.8866102263482,
  660.4339102090281,
  -406.53737209612984,
  -2168.677996828868,
  615.0716697215255,
  -73.57185812407211,
  -1668.9472176828122,
  367.23664143425134,
  -31.49735560196453,
  -1434.5740958878687,
  10.549381126590845,
  -435.4629539646235,
  -1540.9932476761144,
  47.076089858155086,
  699.1296394569526,
  23043486.36093219,
  -20.70644290438814,
  -1502.9159630314969,
  38671154.440142624,
  -156.37701365493717,
  542.8064116738639,
  41851821.665491425,
  32.54565449820144,
  2168.0048812090436,
  31561768.21079455,
  299.8731608654703,
  1729.6005244544663,
  11112919.212423872,
  260.2460802154555,
  273.7498465486247,
  12910503.094784532,
  118.3718079220524,
  1430.7389316192669,
  32780787.24206498,
  -156.30139233792897,
  1576.9394783279442,
  42099926.10821351,
  -153.8103789569668,
  173.23918974835894,
  37868490.157123156,
  122.70963269905677,
  14.83765782685807,
  -85.47313097336693,
  117.99595937063557,
  56.44590570334887,
  227.2151772354699,
  105.00695730366785,
  2.2429845518580933,
  290.85598715212524,
  122.20081966383093,
  6.150318136957807,
  84.96606232015212,
  121.96689127475993,
  9.092445355264228,
  -324.18749569690254,
  105.00911992299194,
  2.379138384117269,
  -288.2202957160833,
  118.42544041304403,
  52.40023400420489,
  109.35696930834182,
  122.83614397429108,
  10.910172380339137,
  295.82021841559,
  105.0069230847084,
  0.3465050577235971,
  211.15496048112897,
  296.103887077239,
  1.989227744508682,
  220.67872330472872,
  -114.46709595974056,
  13.274747353051652,
  268.26993734386394,
  -342.8693266625164,
  37.297631598950446,
  277.95607950797915,
  -316.08293394260056,
  33.33326603641984,
  246.619597701836,
  -2.743086964335646,
  7.043579764018318,
  184.34635612780679,
  445.45617717027847,
  5.218604721360094,
  189.82057012218596,
  567.2207841307829,
  10.949793016442186,
  250.3318979209677,
  79.62408511761714,
  4.075935262452376,
  278.7116363561154,
  -506.1355806525056,
  110.40641968947453,
  265.8255696044719,
  214.9854887326518,
  1517.2718319253265,
  829396.3190889887,
  -96.04391892205217,
  -982.2790866210933,
  1391688.3532164164,
  -431.7308223881861,
  1339.8287003417436,
  1506130.4974287718,
  44.21673004383487,
  -2476.375677848747,
  1135888.7531714416,
  843.3229171852444,
  2686.9635241501064,
  400127.99599522445,
  823.5871487292483,
  1034.4214990831724,
  464806.04601548845,
  417.5412393769201,
  2347.724514728461,
  1179749.7238075498,
  -349.3274939873029,
  2513.6773498580965,
  1515057.4308053413,
  -431.82656126060726,
  920.3314437978223,
  1362808.053856792,
  124.49946821732775,
  26.690344159031014,
  -237.2714954538361,
  494.2524463682929,
  187.55365628113344,
  171.53438634625414,
  39.09586709701438,
  21.1022132102334,
  254.7378088390269,
  352.4938380321976,
  29.161184288676708,
  -14.440827090253395,
  398.307291506792,
  60.89642219091003,
  -549.364508870816,
  34.43394446231393,
  23.042716220242554,
  -502.3413151087428,
  481.76733286553656,
  161.84766514687362,
  17.447625331675432,
  189.16635177860465,
  5.666028250781693,
  261.2280001440528,
  65.6949547507569,
  11.64423802404825,
  150.53740340893873,
  -228.01081017966845,
  42.773151567935216,
  139.34641295299323,
  292.7040068967725,
  5.47484279023341,
  245.05582926416216,
  83.58071844517468,
  33.18967411231156,
  266.57064991222614,
  -360.1250018834056,
  26.769343512237132,
  196.96618051901063,
  354.55124604796424,
  1.7836762911051878,
  58.645102742305674,
  -219.35618228769755,
  4.033813977828196,
  70.80440520583169,
  -352.49302599419605,
  2.551021722295218,
  205.21192707663226,
  371.02528161991694,
  1.0938749350461947,
  268.24888979366114,
  -369.79602430381664,
  6.533634763889786,
  239.62640931348596,
  335.4161460357584,
  540.7572151499232,
  513752.5486159053,
  -19.26741511154529,
  -133.58118432519376,
  862132.5001982787,
  -317.30448876492324,
  492.88592896724504,
  933037.5570724226,
  56.22712856345393,
  -536.6642727767643,
  703646.4344713305,
  725.0243972811761,
  856.3211101526718,
  247790.25760226237,
  811.0491387186906,
  410.4920070204001,
  287862.91481048363,
  502.93435897393056,
  764.7999137027315,
  730821.4287788268,
  -140.76350167070194,
  809.5713037949736,
  938568.4279166707,
  -308.4786448061777,
  379.7123558813451,
  844239.0984035978,
  522.7445443734231,
  -247.48052845229967,
  89026290.65374888,
  -34.96684368772736,
  814.8459103550069,
  149400242.70712075,
  -119.8442093422887,
  -307.10638013664175,
  161688029.31658927,
  81.55042206141897,
  312.7876962355263,
  121934741.06196113,
  552.4109719577042,
  145.56857260097166,
  42935249.72923707,
  757.5379373034073,
  -409.73173578190085,
  49879807.456946366,
  631.6602231356181,
  31.574783825931895,
  126644144.67694929,
  172.52579580451837,
  87.33957475205887,
  162646524.57341254,
  -82.36513724333264,
  -448.0691831341438,
  146299331.25364307,
  55.09605639226582,
  19.3743855890005,
  189590.4833540087,
  -3.271952435506698,
  -6.074081975360485,
  318160.1094573879,
  -115.3988228230022,
  17.56779875569468,
  344327.62170871225,
  26.609543536204438,
  36.34979422884809,
  259670.82463902395,
  236.73920917822932,
  31.283269248468162,
  91437.09605974302,
  215.03026922340086,
  14.458382101093862,
  106225.910774334,
  110.15869105298232,
  27.829403650541803,
  269699.7566760333,
  -104.60213781892887,
  29.51900529485068,
  346368.7896727159,
  -111.3804884892595,
  13.296806615752745,
  311556.54926969524,
  143.67608563487298,
  472.543334567187,
  -284.82308951893094,
  -24.98078991505963,
  148.66132325637415,
  706.9678457515952,
  56.15624219228945,
  447.2691778565328,
  908.8250202336616,
  85.6869986438483,
  509.1702544957211,
  255.77930105857513,
  -55.09825813154575,
  3.597645957564964,
  -1041.9820137136344,
  108.91970209340266,
  521.6734545196064,
  -927.9005403372317,
  38.58649730053163,
  389.2562770616313,
  333.1428602926377,
  8.18466226967125,
  318.8753189174636,
  924.5706667399025,
  167.45089546706603,
  386.9556958015745,
  656.0277338981097,
  266.6245363204274,
  -1649.5577518281054,
  12501141.060036922,
  -428.64418621724155,
  1140.2431304198417,
  20978751.756307684,
  -94.79589094362501,
  -1806.1426277731307,
  22704182.47023268,
  62.46086043865088,
  -178.2239598494009,
  17122091.348858953,
  470.4036838215578,
  -617.3621019521264,
  6029113.169623671,
  406.5109451909436,
  -2075.6495300409415,
  7004256.503312558,
  348.4169437264694,
  -916.7239185067476,
  17783378.03130415,
  -51.22587171412192,
  -770.2786666134149,
  22838772.79213817,
  -33.09191285327469,
  -2176.328417941445,
  20543326.88826275,
  -369.2836724329975,
  149.50400262791584,
  -52.97765495825033,
  1150.6972223298192,
  151.7667562607505,
  38.43048952341995,
  -812.0223168325035,
  17.64763234622896,
  57.03460165385151,
  -701.1126742000195,
  97.72482183008131,
  -3.1531812030367945,
  419.58752179169926,
  77.66229540005848,
  -122.7610033203699,
  -778.2759408874347,
  65.33144115777625,
  -112.24671504627142,
  -812.4050878031685,
  36.68912129847281,
  3.977010401461527,
  831.000936898946,
  133.5922901638336,
  58.4857949241421,
  -561.8843820414961,
  130.13138761610412,
  33.735607831497916,
  -671.5894607776022,
  13.31676361521832,
  -279.97665527237865,
  -1237.4704503487646,
  132.35233703661171,
  186.03547201653194,
  1832.9931326088526,
  199.4504555092647,
  280.88196429996697,
  -956.855585697165,
  0.23226416284451545,
  -25.964180373344504,
  -1202.3787680592307,
  35.79731579718299,
  -635.742400261279,
  1131.0972090850735,
  147.99991908387602,
  -582.1390165220542,
  -1202.777682243015,
  35.95974609355305,
  10.386582202916866,
  -956.1833878441471,
  0.2213523784680973,
  288.28036043665975,
  1833.7551847646891,
  199.2695851783617,
  162.10027655852693,
  482.2301346952283,
  138.62112778450182,
  19031464.18091454,
  145.94782406548475,
  -1141.641728415767,
  31937461.31825209,
  -141.28364331234798,
  47.73526154000564,
  34564192.44007465,
  79.39560203193352,
  992.620886137484,
  26066225.90045782,
  552.3561903032979,
  737.7338786590794,
  9178691.221761616,
  741.21862939263,
  -108.69343646579858,
  10663212.925337683,
  594.7602342082204,
  563.9766249403694,
  27072943.988415256,
  130.5166946178256,
  648.9771940910688,
  34769087.707321316,
  -110.16127707228526,
  -167.1300376007785,
  31274586.80067303,
  169.3847058270458,
  -347.33848097382906,
  561.4477285938912,
  391.86016916699265,
  -246.29776234580493,
  682.5286312888074,
  285.82174412919886,
  989.8119568909098,
  707.1719790272772,
  76.45696506124773,
  408.0653522837019,
  627.4461392693223,
  430.4969699160999,
  607.6580983813583,
  469.0114269856294,
  223.3200098268879,
  -424.72680173164656,
  482.9388458457475,
  229.22952501624667,
  984.1008681614136,
  636.8909216872992,
  219.04090862372473,
  976.0934634087969,
  709.0942562176517,
  327.4255684787273,
  951.6999917961515,
  676.309704993703,
  307.36544988911015,
  331.178189173005,
  766.7302619006156,
  260.4422119787744,
  347.1437455640919,
  932.0820613761227,
  250.03406798392407,
  347.9414364544286,
  965.7357739184206,
  294.23677010631195,
  338.0798490844602,
  856.8597185268442,
  331.2534956212992,
  309.38471104846326,
  640.4964094301008,
  319.79297239217254,
  321.93449504090034,
  659.5161203780135,
  204.01238333427585,
  340.9616573285084,
  869.7578034742459,
  166.5602522970813,
  227.51956058105316,
  968.3608946884567,
  253.81345830543114,
  197.24886520104616,
  923.58930462577,
  798.2043143332228,
  138.68378055710883,
  343.6809140795495,
  -489.6372753733465,
  97.33551431422461,
  521.1279561589125,
  873.1644534964377,
  0.12228269191598429,
  557.2433886160264,
  678.442715748825,
  223.41002869244505,
  440.4032088067593,
  -555.0145356424343,
  10.20413128344947,
  208.21323968938657,
  714.5380837342716,
  78.04948630260795,
  228.62421471123085,
  580.2635021045411,
  264.5365975194944,
  454.2447698279553,
  -271.25505167582014,
  196.44432328383073,
  560.0605331359021,
  361.19369767491406,
  250.69075304849034,
  512.0139666575593,
  -10.39455393493779,
  703.126345558162,
  709.2511525747327,
  196.03844908610222,
  694.0546023837678,
  862.2071009516744,
  366.849601516292,
  404.05625189386416,
  893.3379113489004,
  362.25182897236255,
  1.335511268134809,
  792.623916334738,
  236.99145457974586,
  -236.3722025563482,
  592.4806143456489,
  145.24504061651544,
  -295.57891795139966,
  610.074483508979,
  162.4143093350727,
  -288.78339086092615,
  804.5550765739008,
  281.6612328233299,
  -182.5686583950419,
  895.7662359166313,
  386.73071274056946,
  156.68238495101576,
  854.3510167287911,
  153.7393315985231,
  239.78212794403788,
  209470.93361435173,
  54.16940912860123,
  -1117.6545347582878,
  351500.91207208735,
  41.23051008679897,
  143.417692809289,
  380407.9822253422,
  9.453081764593065,
  1145.2606992491837,
  286888.20287683007,
  19.830489457390456,
  875.0091902547335,
  101041.56420987831,
  124.00599722179601,
  -22.440473537960543,
  117378.66573990752,
  152.43871964841975,
  690.7779087909587,
  297967.0948697585,
  149.55716891508064,
  780.9022831386967,
  382662.8463852717,
  49.00189877586416,
  -84.39961297574928,
  344206.00471622235,
  13.839057393030714,
  309.06866425385243,
  794.0121545882879,
  -377.3038267562063,
  525.4004665839542,
  904.0374213168135,
  441.43430350739317,
  3.288451418814134,
  926.4306381467272,
  -59.199395706075336,
  229.73534536691884,
  853.9843927910343,
  -466.8944207096488,
  237.9725514727972,
  710.0160122282223,
  678.5504646879587,
  242.07475333891705,
  722.6717485236928,
  -182.1375751819304,
  101.75472331806259,
  862.5667925056214,
  -406.49579305540976,
  20.16709497013494,
  928.1773963545846,
  628.3228855530739,
  561.9706084555926,
  898.3863317630137,
  -125.38379477924121,
  13.095468873341815,
  -38.53073467947037,
  483.59090924351585,
  0.10619353838194456,
  24.19795799847532,
  89.26362507631127,
  169.10344254093297,
  36.96500013671607,
  -310.961004470206,
  98.9692149082344,
  -4.338769403795286,
  504.33743312846644,
  5.368446535499686,
  -86.41944567199258,
  332.3237441864767,
  350.38941693239406,
  -79.20403219200989,
  -307.1490982033167,
  343.2881839409124,
  0.5543131593578443,
  535.7294548060702,
  40.45223243459819,
  37.96087919305787,
  487.86000337484353,
  320.94282484825965,
  20.97610296048199,
  352.6710657330472,
  -122.01095525303927,
  885795.9267144998,
  -1066.4433617015545,
  206.84399088469831,
  1486358.2620137844,
  -312.7428089484164,
  -140.4687997797044,
  1608589.4821154266,
  118.9767017310657,
  51.426295409062575,
  1213148.620319272,
  978.2523068044999,
  -0.33824125989641374,
  427311.06308441126,
  778.4830440169563,
  -172.23761826169405,
  496391.18232005194,
  543.1265624428333,
  -35.62628446226276,
  1259994.8236352964,
  -314.8698818765747,
  -18.36367416990967,
  1618123.993775392,
  -220.99854520961793,
  -184.1054008222362,
  1455512.333252809,
  751.4983665837751,
  227.32846947247285,
  772.8887378998173,
  -144.72216321292967,
  224.02593083606286,
  939.5686642787422,
  -57.31852410828242,
  226.8293936529899,
  973.4926877651549,
  -554.8741010630168,
  3.6386747383355384,
  863.7421259045698,
  1003.2779679791396,
  -12.899425805268933,
  645.6409589034349,
  -750.3708560475961,
  182.31993963495557,
  664.8134386139815,
  -848.7032852110385,
  168.9124848555344,
  876.7438099278543,
  1754.6982019148002,
  95.19354780528431,
  976.138893842581,
  333.94582812567734,
  232.60548692019265,
  931.0076926147319,
  -328.14289019092394,
  1179.0983505786294,
  234.02208796966582,
  121.47986689310999,
  1452.3268262452655,
  284.49091029953945,
  -224.2614354477751,
  1284.3832945589804,
  294.7627261759035,
  -610.2874973300076,
  542.5044786816734,
  261.5314803535749,
  -330.6175628384468,
  1176.1596421742424,
  195.49287998669743,
  1070.739402793664,
  147.42123733798536,
  201.29809296678323,
  -104.94533195362703,
  -881.7876011475828,
  265.4682452371192,
  630.4695031289536,
  -821.6718528317003,
  295.56396785671774,
  62.681937522372664,
  1439.8135122982264,
  281.8987435805563,
  -340.74924799245446,
  26.036828158923868,
  281.3493881755867,
  325.063632216607,
  94.77562699566596,
  1032.7035327629058,
  -267.6795669768676,
  306.48558113729234,
  1185.6251004725532,
  -118.55304285588323,
  0.31089041610997015,
  690.8952231790382,
  -41.54991514160554,
  5.450158867918702,
  -292.2538537715598,
  -396.8910308829803,
  301.89133865074155,
  -205.82879704465208,
  221.0791282173121,
  60.984010834360134,
  749.5037754488615,
  -294.22959398804414,
  14.75235557435633,
  1197.5535788856414,
  187.84606415320604,
  189.02863672502764,
  994.1126737363329,
  83.35476380810505,
  773.2506570338566,
  426140.7483572673,
  -15.92807552295929,
  -42.4646746994502,
  715071.6389837164,
  -104.12751392878755,
  715.3430217584546,
  773877.1504361212,
  15.112712962334982,
  -530.055260476986,
  583630.3206346558,
  221.0465487861952,
  1154.9734055761032,
  205563.412415325,
  235.36480923297333,
  615.6749835361129,
  238797.89816673065,
  135.42469125028182,
  1044.2645342128512,
  606168.0564382531,
  -62.87142803719536,
  1098.4223715089045,
  778464.2095700065,
  -102.909305399597,
  578.4422924138623,
  700231.6446229857,
  103.81902276976703,
  325.1440175485789,
  196.04481930792178,
  116.10018102490922,
  300.32147174034077,
  238.32352573338613,
  83.1940718538022,
  335.14867396500495,
  246.92842412104196,
  83.82534102458136,
  335.2722989486058,
  219.08996819093338,
  103.19218084897076,
  157.0774713815249,
  163.7681582344702,
  49.55405363468444,
  262.9460636901611,
  168.63129717831401,
  92.2925089350074,
  148.59560028644955,
  222.38787210653408,
  77.81959446483931,
  333.0134845776065,
  247.5996397396188,
  124.35514550877569,
  248.02321596969307,
  236.1520176486239,
  192.56471730759952,
  -391.8545183233501,
  1646982.0025390342,
  158.37782314459437,
  641.2426002399693,
  2764301.698234823,
  2.21991041657283,
  -449.8397979104193,
  2991707.4838148206,
  18.915717467624148,
  152.9982382336849,
  2256007.228573912,
  96.87716788511263,
  -9.619944355754399,
  793991.1667800635,
  222.90100700538898,
  -549.6414740578055,
  922511.6770856768,
  210.62628809562568,
  -120.477257527603,
  2343162.5204679323,
  138.78199151347025,
  -66.24680376261054,
  3009446.0215824475,
  7.469338528705677,
  -586.9240879002532,
  2706914.2103573293,
  10.021945478230771,
  -14.492401230263646,
  4519.760281397297,
  -33.59976417939547,
  18.533528217294595,
  7594.840926441633,
  -8.90550545796107,
  -16.346067955520454,
  8220.705781864846,
  3.529425666747606,
  2.925388805182667,
  6195.915899290843,
  29.094210783852326,
  -2.2731704866656166,
  2172.1639582078333,
  21.911810384302036,
  -19.536516419625507,
  2525.8773450338863,
  15.557985626082914,
  -5.817044279141971,
  6435.784177142684,
  -9.930322859150763,
  -4.083411392388601,
  8269.52568038695,
  -5.885236190622921,
  -20.72836271583194,
  7436.899422394393,
  -235.1674676397618,
  560.1420256813574,
  -144.72878375060347,
  -154.5180553686348,
  219.16360469546538,
  255.54718374958557,
  677.6720480226311,
  287.7693450285912,
  337.0145302832827,
  -293.37647010671424,
  541.5117360401352,
  73.4524248347549,
  -399.3532303662986,
  2.601319258901185,
  -450.30983934955333,
  756.3397117209445,
  0.03254072064692082,
  -404.2678051812021,
  -382.57562260210716,
  460.36869760303654,
  104.675510689261,
  -481.9685329475576,
  108.40578706324527,
  343.3693008957833,
  518.7674364525355,
  291.7020210430662,
  234.9883120846011,
  56.26359743873061,
  214.87127579793224,
  64.1475310318917,
  23.53807371953915,
  48.27913410654004,
  122.79528729354185,
  6.707468965919315,
  203.04489886774073,
  134.73174481466302,
  6.685073898520869,
  -51.30065407843938,
  96.11507188101926,
  41.78763562914537,
  -84.46741530992745,
  19.374312747342742,
  55.83631541710769,
  182.68986654248323,
  26.12031354913897,
  60.94261369171049,
  -107.07729803145384,
  100.6898254950513,
  26.949750377933665,
  -96.01673590452512,
  135.66283503301452,
  10.564002959522519,
  175.0858979597072,
  119.78303626595056,
  66.06608583395878,
  14.891729859987493,
  -343.94176312646493,
  8.018163799002048,
  132.0975662997743,
  179.48692882986398,
  42.965781265280384,
  228.38822384597867,
  286.0192967349292,
  36.55289625288642,
  63.09379505097651,
  -58.632841552923104,
  -13.52201936528676,
  24.08899558319723,
  -743.5408028033025,
  52.51681351517819,
  210.64737451947894,
  -683.3330369705029,
  0.43741072057964914,
  216.9264872095844,
  -17.80336310651455,
  -27.920435849644612,
  18.015865114595456,
  294.32923672497384,
  56.95402550361783,
  192.71620427698764,
  152.60271849141597,
  124.87638307868839,
  525.8819550411988,
  -290.8188447098217,
  182.351581567457,
  575.8976033061351,
  531.8705968728299,
  100.07743695050581,
  159.1999097606629,
  699.3108912417293,
  131.57131285221487,
  495.7590305611182,
  157.61021730932572,
  122.36823044559964,
  327.58310319542494,
  -918.8813026159875,
  155.6621159133136,
  521.8342802566096,
  -824.250851490359,
  128.92482894970252,
  508.32262162224595,
  221.7832008300481,
  78.2772119914234,
  19.291236226140995,
  712.3718869323623,
  213.47824728452352,
  469.14940986469804,
  489.61583260290763,
  174.06300350652157,
  173.32561632515495,
  21.015111789971698,
  175.89037893400626,
  218.42558259252672,
  224.08237259208448,
  191.9448682198276,
  265.1830837048758,
  265.4122356081713,
  145.0994201319795,
  73.70209526843891,
  131.70239752091487,
  224.4346614237728,
  329.5066101547546,
  -134.01170208805013,
  154.71674672898172,
  144.8198833807638,
  -110.65374278133763,
  232.47338386442948,
  321.4564804923661,
  147.54243547737985,
  286.4717875168774,
  320.3766496283964,
  268.63612603897917,
  133.93960160865367,
  65.40130861267284,
  213.6524839823253,
  10.21268786365265,
  984.239604866135,
  1159422.626528451,
  -68.6928697657879,
  -618.7779459177407,
  1946258.0298392691,
  -180.4511819130562,
  870.4413813196629,
  2106401.0253501693,
  8.516836135703265,
  -1576.975292702381,
  1588308.4782677789,
  302.2119517471226,
  1734.3888807739913,
  558732.071389809,
  252.43400311862968,
  674.5769561860561,
  649238.3856967954,
  86.22436473185678,
  1516.8273652319604,
  1649684.7070340666,
  -195.7644438777805,
  1623.2566063173363,
  2118892.803282933,
  -185.47848544097312,
  601.4084683447784,
  1905844.7914948368,
  132.70069460652206,
  2228.928415830994,
  -353.8446135999655,
  -369.0316788737588,
  -962.2440814755594,
  375.45887881231585,
  -968.1875247520409,
  2002.3870650851673,
  523.8925225197886,
  58.991000031799786,
  -2869.7547126324066,
  43.68191889154387,
  1654.997600240228,
  3722.2718523897393,
  -910.6138157460837,
  1447.1055031046478,
  1612.4741995763147,
  -826.7251513167652,
  547.5546962916819,
  3289.1659737107684,
  100.57043433200467,
  -989.7721296431321,
  3501.037682098976,
  535.4709253655037,
  -995.4026202926832,
  1466.8156158918157,
  338.0005797318896,
  204.5452364094253,
  79.04568411421351,
  -352.8161831671703,
  -35.49058347563289,
  42.19123422390449,
  117.92059883075441,
  233.65477573353414,
  65.64727600731109,
  213.7286903948933,
  253.48715025402734,
  37.72686776350133,
  -96.22840782979362,
  -35.49170501649007,
  39.76485623120997,
  -712.1888521049093,
  165.15334387936596,
  75.69091726041407,
  -658.0420115228852,
  242.53773885333257,
  0.00006348899773911398,
  -59.50910376818226,
  -33.93731906556434,
  28.304578658808946,
  221.20209502406863,
  86.42509934339074,
  36.18516357754577,
  93.74273686836082,
  444.74268729731943,
  117.16599286781626,
  140.61853531510621,
  411.3037500799058,
  120.4708918484857,
  170.944099609811,
  372.88978541608196,
  119.59391073069612,
  177.11619950043323,
  352.30484351218047,
  116.78095248863242,
  157.14830179140247,
  351.3560570359276,
  116.58061894519376,
  117.46721297446294,
  370.93590840644976,
  119.41937274060741,
  120.95543305460221,
  412.5958034026903,
  120.4230838496478,
  159.51381402405846,
  448.3368666207234,
  116.42829374806246,
  177.59764735250144,
  458.58928890713173,
  113.18747210512987,
  169.38652574796583,
  89.00596921873777,
  6.091913326169134,
  307.92379996008657,
  272.4584875569964,
  10.0130278530319,
  374.330145130973,
  42.89407558543084,
  21.439336711735052,
  387.8456923367151,
  314.5901386550512,
  243.75348646288973,
  344.1203688862828,
  84.84916119211836,
  7.143566540054181,
  257.22747366670717,
  -36.567623943579974,
  82.65733726993824,
  264.865911798399,
  -18.320194965889385,
  60.89807142331259,
  349.30032268042004,
  -35.12250975526666,
  189.4679539102439,
  388.89995770620754,
  -31.782271210433578,
  75.96223595599314,
  370.91939944810036,
  8.683244463687814,
  269.71496752324526,
  -89.29889714176713,
  581.9896871456934,
  61.902784571794285,
  56.57762725512138,
  -327.01379076541065,
  0.1896114415667114,
  86.26757701251485,
  -236.57941932653387,
  316.8703965108659,
  -9.784964302095416,
  596.2066375485109,
  93.44158551130937,
  -200.66481948454717,
  -377.3070480500233,
  142.33104815687216,
  -183.8852662113702,
  -379.14910602977125,
  134.85299982246514,
  1.5939732690163146,
  596.0155270406499,
  92.89124601103505,
  88.58350883345443,
  -229.6739994311597,
  319.23639541087175,
  49.08515459247471,
  36.34647033740514,
  -11.434226756284872,
  152.93548731350967,
  -121.54927493139937,
  -5.329112450094932,
  185.91730541504992,
  -172.9203784450482,
  -1.1026100143452986,
  192.63002719390184,
  -94.60676012531226,
  -6.967964262702427,
  170.9131165468538,
  91.18519899366999,
  -11.984823638176234,
  127.75631192113121,
  163.80286138020088,
  -11.664792661900368,
  131.55006952653815,
  -62.53974326069732,
  -8.542861811606521,
  173.48582693127528,
  -227.76273653538317,
  27.359250226345715,
  193.15364566074973,
  216.9920215839133,
  44.650519574069094,
  184.22330172588985,
  -323.04993959562637,
  291.8807275130689,
  729.7794059054052,
  -814.364011950433,
  265.9884620786763,
  887.162443960406,
  433.6583835970031,
  297.5498810766259,
  919.1942908380148,
  1336.5001414887556,
  250.79494859567916,
  815.5652742604902,
  -824.7950803110928,
  264.79360378654184,
  609.6291125900959,
  1213.9330212973487,
  219.2656818258683,
  627.7322109622056,
  342.41508047894155,
  190.78212642929043,
  827.8417647525954,
  -838.8275517285751,
  263.0439706389824,
  921.6928997637118,
  -820.0663743439347,
  223.65475226123561,
  879.0789766919979,
  183.38361206669757,
  -3.977718723374686,
  273.02576929794344,
  333.7517214831998,
  -3.3207519512648283,
  331.9060620161294,
  382.8585457502635,
  -2.1383124501719912,
  343.88984720522075,
  172.67672480859108,
  32.86631482206781,
  305.1200604125041,
  89.44261846116342,
  31.20644163381861,
  228.075026651147,
  477.16329653780735,
  2.1273878440886076,
  234.84777512791376,
  266.2189591779576,
  33.13091407074809,
  309.7129527766391,
  -27.409453876604232,
  3.6045769500279743,
  344.82462916617067,
  -60.89056273919624,
  7.02885352416244,
  328.881867510649,
  337.91809702597027,
  305.7375595584523,
  204.371933474357,
  985.4016328570378,
  227.30332697028516,
  585.9575351804452,
  -436.69010540324973,
  25.90330872449954,
  663.6208699057422,
  558.6801673893158,
  354.5501014452791,
  412.36545424191644,
  730.9325430478714,
  346.3602920151065,
  -86.94041210295244,
  -455.719285531089,
  23.739072195946164,
  -43.04825084824428,
  824.0343081820971,
  320.2080635424523,
  442.1306187041244,
  474.58188413529666,
  342.7678744071224,
  669.6789127680684,
  -352.78806782161746,
  98.69417211228328,
  566.3586332936422,
  318.59096284138894,
  -143.72203728456054,
  37037244.945419416,
  -2256.9425171068515,
  677.9030219537514,
  62154900.88054654,
  -786.3367945257871,
  -189.8378940802121,
  67267045.86631867,
  203.03799852612295,
  289.6009004513303,
  50728300.551336214,
  1821.898905636477,
  160.27020007236536,
  17861774.924667403,
  1354.3136004886792,
  -269.2104492865533,
  20750951.559518628,
  710.0975284386483,
  72.10506548320375,
  52687575.63003814,
  -934.3179172674336,
  115.2346986866486,
  67665813.10380307,
  -682.519617517534,
  -298.86141748349206,
  60864814.27324787,
  30.938290331114764,
  5133.610107860303,
  4029.471344305038,
  -163.90240327991563,
  563.26727352581,
  7736.5033607271325,
  -313.8886045591014,
  4809.161448336092,
  8490.98798237314,
  22.6027665628528,
  -2168.6369252860086,
  6050.08909624941,
  154.5572289566793,
  -3078.5446075655705,
  1199.4269532017079,
  459.31382900237134,
  4250.734891201588,
  1625.8310059586292,
  134.61739405375397,
  -3698.831461629246,
  6339.25204459478,
  10.114509669554927,
  -3395.3924137408753,
  8549.840724057029,
  -330.66862490685315,
  4042.125151438633,
  7546.103732291848,
  8.949472315098774,
  -12.094037906286282,
  59.53193465895007,
  7.448546513842881,
  -31.79300149474747,
  72.37049472532144,
  7.2067800331251775,
  107.11783455637705,
  74.98350051843158,
  8.5407045292879,
  -22.457076097964716,
  66.52993798468134,
  7.0446302491187565,
  106.12237821312684,
  49.730644908896714,
  5.451908653278355,
  50.36752380764913,
  51.20740961435714,
  8.729271929283389,
  -18.33202808391593,
  67.53139571821454,
  8.319066124925437,
  102.1793038931552,
  75.18732515653346,
  8.73457306634228,
  -18.20139768770816,
  71.7110838932994,
  1573.4333035101074,
  145.63892126185362,
  -413.5431303906035,
  -120.58099904781864,
  36.76422741187665,
  215.55272781019747,
  -522.9793686784149,
  154.05278956594975,
  343.5913172939245,
  1597.140963545886,
  157.31865406113786,
  -70.63747078907082,
  856.5531919888717,
  82.29717994889623,
  -893.8112254813669,
  -1170.6939312330414,
  494.2363219490281,
  -821.4490170296795,
  1719.9525614050185,
  227.73327326111476,
  -21.565541454945638,
  1588.0535582963084,
  376.46218284035723,
  353.57882640446934,
  -1093.9274074618695,
  383.1198568837345,
  183.24126755817156,
  -341.0798029316145,
  160.27356944845812,
  -406.529616591949,
  -57.088364537271445,
  125.30435822080136,
  233.07336894691275,
  734.2269432318319,
  42.56878020637105,
  363.2504525032897,
  -341.7386534565129,
  197.60332600153464,
  -57.89676393484706,
  -264.7909028833715,
  198.89078536281588,
  -894.8191252173027,
  218.2172736164572,
  22.888873743619513,
  -821.2483268047154,
  -264.05999719402166,
  198.71067719174783,
  -8.00523770858456,
  -341.8914026559794,
  197.45332523099466,
  373.404772487959,
  736.7085835752073,
  43.29867705032331,
  200.22224431318546,
  228.05447944428158,
  129.34193773435183,
  837.3077057728523,
  -361.81231779747486,
  14.748902411220863,
  1323.4814306496444,
  -849.9568119012595,
  121.2069776123035,
  1422.4313715303629,
  75.4704107998677,
  -53.74862735876138,
  1102.309803047188,
  479.1729089564594,
  -76.56290780900274,
  466.1500742514106,
  1406.9445416962053,
  107.20544720054679,
  522.0725604109658,
  522.3311623082575,
  -92.11547267223253,
  1140.2332488309423,
  147.84844163527578,
  -84.50729035560927,
  1430.149852654053,
  -880.8978179686562,
  101.97493733642487,
  1298.510700383095,
  759.2109770995404,
  195.47439276780565,
  51.828220559892465,
  -483.0536835636826,
  1.4649205007428918,
  416.86301630205674,
  -318.30884195181056,
  421.76095395837194,
  491.157799442067,
  720.7333105295023,
  244.19499946773888,
  250.80027828328602,
  -247.76282021494308,
  196.89413926344503,
  -226.84881046417223,
  127.56711863632341,
  421.76417886513525,
  -184.860417698149,
  623.7515395320011,
  346.3411489529671,
  279.2744153605622,
  73.76494767847116,
  439.03441618015415,
  496.9530821491692,
  612.3081986110557,
  65.76470592732127,
  398.1141926697376,
  120.63119031555594,
  170.50905868331296,
  624.8677402191536,
  37.868612388554496,
  -229.22913501058468,
  1161.8091652956975,
  -6.624318461973857,
  142.13164241373025,
  1271.091752052514,
  14.506927198802671,
  437.1545519628941,
  917.542141318914,
  85.50367424232388,
  357.5708387652333,
  214.95272959684507,
  148.1567130976929,
  93.28969962058,
  276.7148073807574,
  136.34586583647476,
  303.318377712919,
  959.4256656251738,
  69.07854428544128,
  329.8582197544964,
  1279.61621983413,
  0.23165209664742292,
  75.04396104417975,
  1134.2309174216048,
  483.54476014656046,
  -770.3611885582129,
  345.9010686218306,
  594.3772199109651,
  504.9260637878741,
  420.4975296971263,
  498.35818923239503,
  1233.903309141187,
  435.67999439157666,
  434.68429238780465,
  1383.2988523233623,
  386.5618810489243,
  453.2611626054818,
  1352.3689975087298,
  288.95219541893437,
  530.7531357434086,
  1099.1734159489238,
  297.5327075868682,
  596.7137401495551,
  440.349142934259,
  392.3806958110051,
  557.5065828213537,
  -427.88096358609346,
  436.8642858233065,
  406.7808057037193,
  -902.948170405773,
  416.6661253800327,
  36.93994435785613,
  31.351110761608282,
  -208.4741506631789,
  62.01078704177732,
  484.2094790838126,
  237.7134504191275,
  24.80720231252234,
  465.48906539718564,
  328.5250975520376,
  28.129933511910245,
  300.06753429879166,
  34.732431705255195,
  62.23408060914486,
  479.122498102716,
  -549.1053381546689,
  26.809086785210354,
  364.5092577370878,
  -497.7822849550872,
  24.548931273005138,
  483.9483037609249,
  69.53680395576347,
  62.09636380032968,
  482.9854219484173,
  335.6087600380164,
  34.88960510713911,
  68.8704753612345,
  214.7964771957623,
  271.66456784543186,
  286.30476396876895,
  940212.5289104565,
  -364.8501113091571,
  45.47631070050692,
  1578402.7568936618,
  -850.206214980298,
  269.20835092702066,
  1708292.3048028867,
  83.25698795392586,
  -98.47793661204128,
  1288075.3199701651,
  545.158547287743,
  -146.42437469850074,
  453001.5560459651,
  1459.4444677231127,
  239.7827675750868,
  526409.8509936171,
  573.6069500767038,
  -179.1096084023146,
  1337856.6455997564,
  138.49799480240648,
  -163.12027035634483,
  1718424.1958861821,
  -881.772783743826,
  228.79034035794507,
  1545624.1939514645,
  -304.923285468603,
  392.15448155870956,
  36.6880530894946,
  1007.2458405814602,
  261.6448324255828,
  1011.8837998005843,
  998.8319246564818,
  374.35434272821254,
  1210.3633895987462,
  -300.159365197356,
  400.5241254613943,
  568.2447886924786,
  866.198761106557,
  3.258383942774799,
  -707.8016737273929,
  774.8353340019523,
  544.8164139503831,
  -595.6290739799907,
  -257.45559744309344,
  461.3572237055089,
  644.313858526143,
  562.1256434905584,
  142.85287452423253,
  1225.8455713328574,
  318.616624890609,
  197.95694374552602,
  961.7960457690797,
  -66.12629809550958,
  387.4464904443635,
  531.6469932269864,
  156.95000267099215,
  159.16472722492725,
  858.8015803740115,
  357.6599376617457,
  334.08179477930935,
  925.3866823666328,
  -177.77368809891294,
  297.9999290763708,
  709.9714219049288,
  217.21894703858962,
  265.41988757188653,
  281.88869594829856,
  319.13327089932636,
  409.3419915356807,
  319.519890181185,
  -154.40624594158828,
  17.043085911868047,
  735.4907550439643,
  288.7210004250194,
  381.9648610356059,
  930.5805798897103,
  250.25286419840407,
  323.625833191787,
  841.9983503080857,
  122.36807190459984,
  -539.8552819141689,
  8965961.66637455,
  117.40159430125242,
  527.9885811045418,
  15046299.804949347,
  0.5394502696365038,
  -599.7908134725038,
  16283818.553004328,
  11.337541967704148,
  23.322818076434366,
  12280213.91081206,
  55.808608731477314,
  -144.76479457210033,
  4324073.824873384,
  144.14066410567335,
  -702.9491763001658,
  5023469.139760128,
  133.54726076129384,
  -259.3506349681374,
  12754503.988507168,
  92.67689773693982,
  -203.29621742973688,
  16380349.839552432,
  1.4994412113146467,
  -741.4857375523342,
  14734003.035669513,
  33.732494569172495,
  1006.8504261468312,
  17460866.55565872,
  -24.787766040222287,
  -475.4523547165445,
  29301849.82333985,
  -86.77332465496796,
  901.6217446905728,
  31711820.85705532,
  7.962131650438714,
  -1361.4929292942775,
  23915113.749953378,
  162.36614891240296,
  1700.5099292490472,
  8421152.80800337,
  154.82197438690943,
  720.5068330629504,
  9783170.516941123,
  73.30891664190595,
  1499.3318202887913,
  24838756.60435084,
  -75.25663332488594,
  1597.7464383625916,
  31899807.9924372,
  -87.76230871858795,
  652.8482768945071,
  28693676.275205538,
  395.4503476043707,
  1.6484435322078332,
  168.75103371668027,
  396.37181083621664,
  1.9017264346562366,
  169.76154938476182,
  -84.42663601050205,
  2.5018396481464378,
  169.96721756570074,
  334.0264167109639,
  0.027732611446626088,
  169.30184252774478,
  349.5026615329168,
  4.872306129961075,
  167.9795798457918,
  -74.30353423725666,
  3.0945148047746596,
  168.09581514517296,
  217.71302539359414,
  2.0305149265063944,
  169.38066668913243,
  204.56937002566383,
  3.2870283810846637,
  169.983260485567,
  -47.10774610544638,
  4.121071241979614,
  169.70964753798023,
  410.59043186637325,
  -1372.4797254224345,
  -967.3975304547963,
  -468.55727137817973,
  796.2179448298169,
  -834.264063142233,
  -108.28965380842828,
  -1494.203558051325,
  -807.1676816519299,
  84.80768804852661,
  -228.71416597628524,
  -894.8295444654785,
  617.4175348765131,
  -570.085434355018,
  -1069.0350725010903,
  584.1320478400517,
  -1703.70918792773,
  -1053.7212986334318,
  516.7477418077302,
  -802.7992736313769,
  -884.4446150230025,
  -2.2812020114176903,
  -688.9576447820119,
  -805.0540582662898,
  -26.86779638106458,
  -1781.973579850037,
  -841.1020301725472,
  -22.449996806944682,
  66.98647146458582,
  -1121.2217971782877,
  627.979401543527,
  0.36291005509562524,
  411.3582495644666,
  161.68294492767734,
  198.6644666857651,
  723.2811225222665,
  76.24338992465036,
  160.79747844447502,
  -285.84772028724564,
  617.7681067788994,
  64.39787041121949,
  -2291.2331555877026,
  52.272221259595796,
  143.41571500049386,
  -2114.947021502398,
  184.33328259792728,
  202.88026690618295,
  -166.3005022086851,
  609.9777523505934,
  9.777031500942911,
  747.6123225769909,
  -38.21731443803753,
  45.56194292402956,
  332.64226595427044,
  2.384457226643428,
  59.733084183169936,
  -36.66594926054776,
  2.3291029068012907,
  36.16265583356517,
  17.272245192751452,
  0.5687802007711813,
  67.5660133868887,
  28.250175260278656,
  2.4578879140971877,
  58.806979356807986,
  -7.265482057311701,
  2.4787897191463406,
  67.82124336683904,
  -77.8437659080906,
  0.5764857050378847,
  67.80366626086666,
  -71.63948587722214,
  2.1579779703658923,
  16.807732375974826,
  -3.0580926235415795,
  2.207599165486909,
  39.564642587712584,
  29.106496600637442,
  0.6270370516706905,
  67.47958554755559,
  14.50188547185257,
  158.7300675087549,
  205.93248961988564,
  112.90539331869842,
  162.82237100266715,
  209.26770605736374,
  137.25438654802343,
  183.29185505904013,
  216.20447267024088,
  142.21008719012886,
  149.22761770544253,
  158.574212691682,
  126.17746859163702,
  197.85325211435094,
  137.26608377064537,
  94.31674034445929,
  150.97795250198035,
  195.9760471561479,
  97.1175009927463,
  165.65777187360263,
  211.09428917361788,
  128.07678498282067,
  222.35852623663754,
  184.32732451084502,
  142.59665115894276,
  210.0034322714808,
  206.17906216661947,
  136.0037797976368,
  192.3937722629346,
  -728.6416625379047,
  1480.7477743371285,
  -6.623316379148974,
  616.9013533962432,
  2443.512084175759,
  -30.768764742272282,
  -804.1637858440589,
  2639.46152912929,
  28.734300070045265,
  -19.005745328773827,
  2005.5284200883416,
  189.3460623238184,
  -230.80554218757652,
  745.7485288644547,
  259.5521845573102,
  -934.1490949749036,
  856.4911935477608,
  227.66847022681742,
  -375.19011245047807,
  2080.62778938468,
  72.43396871362398,
  -304.55840996747054,
  2654.746349702296,
  -13.9732415587724,
  -982.7073183694645,
  2394.062830419123,
  187.37401194905533,
  507.6565822993866,
  -707.2765385301898,
  239.02920043983204,
  0.2980084675891703,
  420.8069867338794,
  348.4806051636193,
  340.91004078009263,
  650.4035124648411,
  182.17363972251962,
  549.7809851250802,
  -92.38419696778975,
  201.32719439147033,
  153.66183771817765,
  -1568.4847609644187,
  317.57696537158307,
  5.104141413239631,
  -1438.7261333372483,
  178.42729190932477,
  544.5958134991124,
  -4.38928440697706,
  182.31977231601417,
  415.24991843604676,
  668.3129365043717,
  261.5743608163001,
  218.491979897375,
  362.8666498005206,
  52.45996115592387,
  27.05932811953528,
  184.75427997605195,
  115.32392912265897,
  26.931676638089108,
  224.59808707858377,
  -38.025510521529014,
  28.690648347788454,
  232.70741540202906,
  -19.54955497645979,
  28.19484725940262,
  206.47222133176967,
  340.80771271488123,
  36.31063536121602,
  154.3364842000243,
  215.7472219875984,
  49.62354082605491,
  158.9195470790394,
  329.973254001476,
  34.61509683217163,
  209.58019360825202,
  -66.72466000809743,
  29.67741942033703,
  233.33997462372452,
  280.0587037145364,
  30.782987054429668,
  222.55163966886022,
  224.5794417668147,
  12.246424190821514,
  -198.60316037909868,
  226.97133382445776,
  145.75099118287085,
  115.80851547921975,
  225.39363195506292,
  204.11762907443418,
  179.80007887823396,
  225.65438553934652,
  172.38941751771128,
  -27.224599081677155,
  227.57239534751346,
  27.59544812927848,
  -438.63318866545706,
  225.1041697191473,
  167.70466978022225,
  -402.46775706784194,
  226.8667140882113,
  219.85772010422346,
  -2.6992626986509682,
  227.76050955823075,
  18.80725849744546,
  184.79167028065936,
  224.98964194051797,
  149.47163752429276,
  99.65978355730928,
  481.44607325776275,
  337.69935729372526,
  9380540.159417547,
  85.30680284607115,
  -2106.325864749616,
  15742102.46703071,
  -520.7969112198208,
  164.19799516873306,
  17036858.193302948,
  147.374592110661,
  1967.9871836767156,
  12848081.219737252,
  1224.5198012461574,
  1481.4072036113414,
  4523958.493125014,
  1237.0637971007495,
  -134.42480836418508,
  5255701.8225095915,
  756.0729424881151,
  1149.7041408029022,
  13344307.878909096,
  -333.6120742651791,
  1311.9704550103365,
  17137854.187278006,
  -485.08666409582304,
  -245.98043647034893,
  15415361.53404937,
  194.14552458171303,
  331.73441568309545,
  800.6018798962251,
  146.57884341951836,
  280.1261329191275,
  973.2583773405297,
  210.05009445831698,
  256.2516213708342,
  1008.3988000754592,
  224.12211012016135,
  301.1341670734874,
  894.7129591043353,
  225.42443061252928,
  292.6786953932826,
  668.7914315334386,
  187.64890430908727,
  247.31709557323103,
  688.6513706758374,
  154.9180739365535,
  317.55471975861815,
  908.1808389690921,
  220.93006312369786,
  309.8458494015105,
  1011.1398900361396,
  225.26463289175115,
  294.65991300401464,
  964.390438565061,
  -23.071074642042902,
  24.386973253692442,
  -42.20999835921241,
  160.80453608439757,
  5.091593243619338,
  25.113682196461852,
  -5.6338730002636055,
  34.947385027349895,
  38.8159327912355,
  -17.655917793967703,
  35.43444270527543,
  -5.513411047747934,
  129.65854917776852,
  1.9264375691443227,
  -93.60664227838484,
  -20.41056503994693,
  34.08641442990945,
  -85.86268697714118,
  -1.2546610999659293,
  33.72283490939377,
  -0.261901517563198,
  165.10861353962736,
  10.863789582800656,
  39.884761752895216,
  -21.443158352797838,
  19.866795066679455,
  21.655820568639143,
  -96.05397693950954,
  147.96204559372842,
  10.796156913017008,
  50.14340933301423,
  495.1851683586956,
  17.433735595961082,
  475.02877461583614,
  317.6953978893223,
  18.78466836888063,
  -93.05367284431605,
  293.4510135479958,
  14.414148140842757,
  -58.21798761190752,
  430.4282034036828,
  5.728857186724592,
  241.1979875512508,
  34.41559969328472,
  6.4923495003496585,
  -43.33398559080365,
  457.47984524202366,
  14.931905153280695,
  -96.28042648901783,
  260.417932847734,
  18.89004639148828,
  525.1101045257495,
  389.2196119717891,
  17.092817980644043,
  156.5819283368359,
  12.405583778245528,
  -272.61740551924925,
  6.347423175387064,
  238.33912045354654,
  121.90487653689634,
  249.8932756634723,
  345.9815606529337,
  202.20118727535686,
  129.31309456848584,
  63.38104271764462,
  -57.57239831975299,
  82.10332738223485,
  2.772268452540203,
  -573.8059484161364,
  232.43206919935318,
  391.75769087105004,
  -528.4257360990019,
  115.21931745386034,
  101.29627161805566,
  -26.79812235938352,
  170.57028366205708,
  154.88553513005508,
  208.46461253079858,
  171.48528808752877,
  158.16784347374147,
  101.6415241892058,
  -32.56538477317952,
  90.10337521545125,
  13.859972414333724,
  1184.0501614462692,
  92.21511514745407,
  428.22305734202774,
  -152.61167536940263,
  121.91544498381754,
  512.5575259872388,
  267.86286301151523,
  25.285219716336215,
  239.7197441795198,
  963.6336316644278,
  198.9882750642588,
  -302.4755540081521,
  -458.1480856735442,
  193.60445738880674,
  -254.813138916156,
  485.9033046363606,
  1.8778227014616675,
  272.041680108959,
  399.83782603089446,
  99.100299403815,
  519.1359433012943,
  -614.7330666362368,
  164.9322495598028,
  406.94064676180346,
  14.520463048611235,
  222.1006982084059,
  20.528253330672438,
  13.037899790492567,
  66.572438558469,
  24.955343008731532,
  9.32778571890055,
  -66.04238855642063,
  25.85637948911434,
  4.690895653248002,
  -117.74933685167144,
  22.941357925752186,
  1.2783073135132774,
  -105.5759101649873,
  17.148498244447143,
  0.19830166986799602,
  -92.7808056434834,
  17.6577274532266,
  1.6870881694491429,
  -109.23189554297187,
  23.286688178694668,
  5.6700685265668564,
  -113.7315807329527,
  25.9266638470805,
  10.701233085022999,
  -31.26550788765246,
  24.727959963206693,
  -18.673949784126535,
  249.07799234766117,
  257.6295792999391,
  -451.76716339187,
  106.43458861273861,
  313.18955475958074,
  717.8792966686797,
  61.512192028998555,
  324.497562588385,
  706.8438763289662,
  59.87992147772684,
  287.91404196818996,
  -461.7253828957138,
  174.6078844215604,
  215.21365296781164,
  740.4859800269946,
  65.0840915509471,
  221.60447953799383,
  928.2218574434696,
  124.07412528302332,
  292.2479366426181,
  678.1053395794554,
  55.93585861754106,
  325.3796312808603,
  899.6073777641668,
  179.63894043792095,
  310.33589753824396,
  -766.636301460832,
  55.49023483202186,
  65.49555705283151,
  792.4763610182493,
  0.10733126113903069,
  461.5446064145767,
  197.6251412601171,
  65.37221626851644,
  542.1516569707145,
  -632.5797543061681,
  5.1179381720346555,
  281.3727699379318,
  1234.9910152827365,
  53.910189169764536,
  -236.85855960511054,
  -74.36576883419036,
  33.0193518312756,
  -191.30272976866672,
  -333.73728631883205,
  7.5476971028489,
  312.266139699911,
  1226.353371105045,
  108.57477025651843,
  548.4393211432871,
  -399.8853802223215,
  3.3416731281852847,
  441.20283663579687,
  13.88833452122052,
  584.1418722422246,
  2087419.2848402443,
  4.045299222160239,
  -394.1780510574325,
  3503261.301172122,
  -2.0389322687533884,
  514.6909362389554,
  3791424.722278395,
  1.8338171176855216,
  -978.9648828384402,
  2859162.1506896005,
  12.044670112446386,
  1041.9571854373944,
  1006528.7666958167,
  18.739304552485642,
  395.15508382103343,
  1169387.0239628083,
  16.237325455945083,
  909.1796215897909,
  2969603.3473180905,
  6.440651853837176,
  974.1332753564291,
  3813902.592467604,
  -1.2541213812022605,
  350.5004327363724,
  3430541.186363715,
  860.2331489843559,
  626.8663597389225,
  903.2431465495873,
  -937.0141179360205,
  440.3226384209933,
  1098.0350923841875,
  -1127.1589612945766,
  320.96278239503283,
  1137.6806975210309,
  -589.2716363990297,
  554.8654671403754,
  1009.4197487330962,
  715.5788403155839,
  640.2068064307452,
  754.5339227556743,
  -1032.438656138265,
  390.40153381695563,
  776.9400079419704,
  1570.1971596652936,
  -144.75654215511668,
  1024.6142798625654,
  1795.612874340615,
  -23.540662625763503,
  1140.773209271542,
  -1123.8131593938033,
  324.01742619337966,
  1088.0302383810945,
  238.24681026815745,
  173.20627437985007,
  78.22686784431889,
  237.72912843531597,
  75.88013056478218,
  515.7564715005338,
  193.53783635963873,
  215.0328608032421,
  604.8059741784464,
  243.0919051352892,
  202.18056861711057,
  316.7141752731386,
  243.11362575862117,
  204.6229230563692,
  -255.79457984849876,
  193.55287121831594,
  215.12350026856603,
  -205.46741909734743,
  237.43134505431036,
  71.65643924035473,
  350.8431899730769,
  237.91298669545853,
  168.91799893232889,
  611.7521825275952,
  194.66543865534527,
  217.9990140634555,
  493.2841881222034,
  319.90635931255486,
  76.80113096884261,
  524.4968725986809,
  499.1952025700361,
  70.72885254656568,
  637.6090138730906,
  663.1607589071718,
  59.25718172571896,
  660.6304959468714,
  785.947541800822,
  42.469016992460936,
  586.1516950029684,
  839.760061188868,
  21.539898488704296,
  438.1441301456245,
  801.0586093829961,
  -1.0644564412042996,
  451.1549364299396,
  658.6400313584522,
  -21.68733530958336,
  594.9748829656488,
  421.71345939568835,
  -36.008635212562424,
  662.4262612929068,
  124.94259599029155,
  -40.03164435211239,
  631.799377059931,
  1013.3052720551461,
  242.42193206874762,
  392.08963861584357,
  1131.8714125933302,
  205.36586510704646,
  476.64705146677227,
  704.9648821576992,
  251.88476640431898,
  493.8568482420839,
  1047.7686848790304,
  240.59296298292247,
  438.17993638186675,
  -14.522889985341749,
  190.2242042554921,
  327.5363164689404,
  708.7997896077034,
  188.1826185159154,
  337.26259435662803,
  -206.43754640996337,
  243.18470080188212,
  444.77574421306815,
  6.299368563832843,
  189.72609662436122,
  495.1992794792376,
  -339.55991597473064,
  205.2478329953643,
  472.3040352972478,
  452.6893125837171,
  136.07465419297336,
  -1005.045892408282,
  -352.37156686131095,
  48.459493058016136,
  351.01203911615295,
  272.3589035369906,
  238.49594456180932,
  627.0077280834594,
  731.5462897009801,
  0.050724906800837744,
  -265.88995392036253,
  -375.6083915234873,
  30.58498975586535,
  -2040.295689583202,
  -77.33653748537168,
  309.08243029022424,
  -1884.3141401351145,
  764.361944988487,
  157.95660802301975,
  -160.11214896220852,
  -416.1543832309799,
  4.287501041161875,
  648.5364677325506,
  -319.0700482363854,
  188.3798854377493,
  281.3625391509018,
  -316.56543206346066,
  21.662970036046453,
  15.33095214483749,
  382.87000678986533,
  5.107679020472943,
  32.86298056104845,
  -522.7529749140778,
  39.1404379792883,
  36.43123833915604,
  367.7173961740435,
  0.5791222054216014,
  24.887256942976403,
  301.0580641447209,
  2.6765552332063685,
  1.946546921423716,
  -760.1953622360932,
  61.99146699989534,
  3.96318123604644,
  1069.7149400859953,
  36.28629043490065,
  26.254823504270743,
  106.70825086184124,
  0.011162706486313567,
  36.709576355931446,
  -669.0896010339522,
  45.01284396266006,
  31.96250501042581,
  269.64262662276064,
  309.95176375051096,
  -283.83591498819635,
  157.30710058383752,
  12.327586186628253,
  551.0035621940108,
  102.1819118119935,
  270.05352002061653,
  720.9167283837382,
  256.4549730127599,
  324.3216197323409,
  171.21585153160257,
  209.64638231897644,
  75.78903098760965,
  -921.1740252081009,
  104.50546451520816,
  249.85085413470892,
  -825.1460074043753,
  211.64068099142835,
  83.67983451060836,
  236.33658519338246,
  255.20313803405008,
  317.344332401417,
  734.1706177163528,
  102.34257601640914,
  268.62552366871864,
  508.1247509092849,
  -286.1510518026298,
  268.0954599955011,
  -1378.0006530593641,
  -752.3224202762008,
  237.9922003708756,
  525.7689351817497,
  1322.5489074408756,
  6.898415932726579,
  913.239254057388,
  -582.7437748369408,
  278.39880594288604,
  -340.299708322281,
  -475.05437384369134,
  282.9438290859253,
  -2831.3877350395564,
  1421.4535881073468,
  5.39895367294281,
  -2612.40525408303,
  -824.376172921312,
  196.08134885973874,
  -191.7982590045125,
  -187.5750934227437,
  252.3380842417472,
  943.4634493991209,
  1270.6660946723596,
  185.99243463240265,
  427.98800946496664,
  -353.0744597244451,
  373.1547969960141,
  245.31262730153566,
  -235.45711118965818,
  591.7995852459476,
  298.2163489543418,
  -56.62813227285699,
  704.9906992684995,
  308.9837348949164,
  -19.518630981921604,
  716.8613670171937,
  274.14922721273865,
  -176.7807132503188,
  641.7865610893691,
  204.92455402114336,
  -341.5592496813532,
  418.21548916068923,
  211.00984306605787,
  -353.3421445337987,
  219.2258988239044,
  278.2759237354013,
  -360.44582514642076,
  283.92966378531116,
  309.823632972612,
  -161.03990234490453,
  652.6409455008574,
  295.49912156031996,
  257.57218247613366,
  4.806531759615414,
  1322.019514495305,
  214.72649080323083,
  1.7499658112924565,
  1607.1240897623106,
  215.2261123953108,
  1.046030535331951,
  1665.1508390989636,
  235.8443545298519,
  3.9053530478494674,
  1477.4234504184408,
  324.4708376437106,
  6.196991219836699,
  1104.3632869423961,
  288.62506650046583,
  5.621278600918641,
  1137.157647987793,
  250.01797932155478,
  -1.5378878877137554,
  1499.6627187079366,
  568.0671843851301,
  -0.03976120790473736,
  1669.6771517519844,
  493.4161574351181,
  5.794824341458419,
  1592.480621630511,
  352.55049511474937,
  91.39173110523416,
  575.817505925362,
  162.3345126923238,
  -85.39987529142158,
  699.9973713949195,
  103.07903414431628,
  -71.4677160752133,
  725.2714446696573,
  334.9909563769213,
  6.909795353534108,
  643.5050898173488,
  222.00552764043266,
  239.07962280862475,
  481.0153757567424,
  317.40379862030096,
  178.84259396668864,
  495.2992550630061,
  13.170071452050706,
  146.40691106564196,
  653.1916034123855,
  -1.040946691827287,
  62.24439773624461,
  727.2429209106081,
  352.6895973788485,
  69.56748637678916,
  693.6192769679477,
  38.80920757814654,
  -102.43584942876953,
  398.2481146150453,
  19.247618434069224,
  761.1110809206725,
  484.1336543693917,
  40.4311883615767,
  -63.926015285708786,
  501.6137620888182,
  4.7257766973880635,
  564.2994476838705,
  445.0623437595924,
  7.234427670530657,
  -103.36676205927643,
  332.6808659422746,
  40.462029736362126,
  -63.110925086813154,
  342.55991259259605,
  9.27616551223075,
  665.9583504772036,
  451.76175066667656,
  21.32678386096772,
  766.652763342343,
  502.9772786333617,
  11.153762195283628,
  -170.26878640993436,
  479.7224232862098,
  639.8031698696407,
  140.14943214443247,
  340566.6776300951,
  99.71146557481774,
  575.5813268377967,
  571537.9929911394,
  -104.32970002491498,
  115.7096774483476,
  618547.1109888448,
  90.27172162468639,
  369.795090673094,
  466463.82066554046,
  584.1351687272436,
  301.25444518665375,
  164237.1847507291,
  874.8794146123073,
  73.64506207233771,
  190804.82821974953,
  753.4556984089452,
  254.5300772180721,
  484480.483655538,
  275.76219387915484,
  277.3872402172337,
  622214.0054475691,
  -64.5063554067371,
  57.93110944113022,
  559674.9034820293,
  -239.54593382663342,
  414.44986892025315,
  -262.83843770167357,
  462.0596177710904,
  395.03909395681546,
  119.72645308043548,
  93.2253453639447,
  73.85446990260081,
  197.5891005024477,
  -20.152999908864587,
  308.1511748375824,
  -54.31112901900386,
  450.18903444906755,
  161.7298274135684,
  -554.898397959564,
  46.16184693604977,
  35.85776337777415,
  -510.8935932669287,
  239.3539482723808,
  26.414362999539065,
  -24.46957619131906,
  308.7909082182108,
  0.22411079826687796,
  203.66269053209513,
  39.76044489610135,
  31.615423264474657,
  100.0772531990698,
  137.44891292584535,
  269.0394131685114,
  7875683.194822406,
  1.2593013914896574,
  -2827.1784358324585,
  13216387.49268457,
  -526.2353904997884,
  49.23889335705101,
  14303370.082434325,
  112.13238770518385,
  2334.3725453838206,
  10786778.071893772,
  1039.1486725321633,
  1717.947802440541,
  3798451.0112994257,
  843.5713494074688,
  -329.07195469725673,
  4412769.405933283,
  379.0689222481104,
  1297.7291670628188,
  11203373.826710358,
  -571.9834203087229,
  1503.2965457499874,
  14388158.96180189,
  -504.76405467859115,
  -470.3964074007174,
  12942079.60718723,
  11.304025843781766,
  35.962557499387955,
  58.15104548590449,
  23.156659344737605,
  5.641315116761826,
  67.73781683977465,
  33.95971717871828,
  26.918273321480378,
  69.68899274699345,
  19.48332510614885,
  14.406259708558972,
  63.37657369705771,
  14.171911844735815,
  29.62180774702385,
  50.832255581037074,
  34.27577418474606,
  28.049451358014814,
  51.9349809257428,
  28.415890254414116,
  0.0008875025665275871,
  64.12437923461916,
  8.5580210275625,
  33.87382392340536,
  69.84119207399479,
  35.4964330223216,
  32.30519006195606,
  67.24542354627603,
  197.73571940296,
  267.7901495494416,
  -386.96118470515654,
  -11.729858306863314,
  110.872436335596,
  130.81964952978146,
  -164.46388679229034,
  244.13584967916182,
  236.20252053890502,
  270.6419828607692,
  161.24090222276047,
  -104.73078026384957,
  -63.49137709400503,
  186.16931165175922,
  -782.2485033082716,
  -125.38063632095017,
  262.9920363595555,
  -722.6903864159523,
  230.19363101902957,
  1.1487332091959104,
  -64.34185673666424,
  -121.43137758308191,
  259.7422210502085,
  244.4227952900005,
  -67.74675798068736,
  192.39422732976044,
  104.22552301225643,
  84.09345631996774,
  111.89856147848232,
  377.7198612843729,
  85.96302155127887,
  156.6890911325693,
  459.1783113606602,
  87.50640196131079,
  374.68708461218586,
  475.7573825997039,
  42.29619187225063,
  -185.82776139473555,
  422.1209858338402,
  -21.558209624769887,
  12.147774719030792,
  315.53236769782745,
  74.87492786646503,
  -17.08900296449798,
  324.9021851393694,
  87.62501386377055,
  218.35840435559803,
  428.47506248798186,
  -27.769852765155335,
  481.64941751358526,
  477.05061478628124,
  -0.18920457258934675,
  729.7080035813095,
  454.9944633230031,
  661.2192753425213,
  19.332228587710887,
  354481.5490133888,
  379.476640410387,
  1902.3638700151198,
  595608.3530720936,
  -9.323943255685776,
  -86.3578505321484,
  644684.396851325,
  73.56077113321135,
  1012.4382610027812,
  485914.21498234494,
  411.132399641049,
  716.0332301638842,
  170399.0926580109,
  778.5757972670517,
  -268.2668992325896,
  198134.87859767256,
  734.9319337437228,
  513.9730127503319,
  504723.0456797414,
  418.9956766911616,
  612.8191507692165,
  648512.5195784724,
  24.75059919517099,
  -336.2221188135818,
  583223.6599550169,
  5.93622619304184,
  395.1147650681083,
  -105.31838202702363,
  -18.01634424738391,
  8.337915820277857,
  530.0682893901244,
  -18.874752071189143,
  1.5737753134765455,
  659.3872351827135,
  14.722308392008026,
  392.05944361472757,
  241.01625493505125,
  -13.211007415726133,
  135.17171258682987,
  -590.3890470927787,
  -18.611567451834304,
  55.172257680310764,
  -517.3032332773652,
  26.278396429486925,
  110.29348990328187,
  290.5788922234294,
  -3.4365310312669646,
  348.44837878690095,
  669.4746170765425,
  -17.430227870014747,
  122.83985255522201,
  497.4337220018119,
  3.8725345936315683,
  -268.6235509449712,
  40.03009399481125,
  8.474863494330037,
  -306.02693802273905,
  48.66291886702649,
  11.066706246276002,
  120.81955141644957,
  50.419940003772965,
  8.110285488776201,
  -321.2635005102739,
  44.73564795521676,
  6.191873183693828,
  -348.9410597867992,
  33.43957157667193,
  10.207632330896796,
  360.1828907576074,
  34.432568533791866,
  6.433555158793309,
  545.9119494283743,
  45.4090419484546,
  8.546821212300665,
  -302.575129844298,
  50.556994501806976,
  9.13954422913347,
  -267.78991814195166,
  48.21952192825305,
  51.55069421099757,
  -52.84885646392579,
  163252.67500974005,
  -231.64112570742668,
  99.02922045627976,
  274041.14756998804,
  -69.27508934753236,
  -61.37341102430604,
  296589.6981171814,
  22.5412687929898,
  27.251249696116247,
  223640.91912911576,
  192.79400432456268,
  3.3443619503740756,
  78673.88152236959,
  143.13893083402778,
  -76.04549400112941,
  91417.40612349613,
  90.19743212484038,
  -12.953036652862238,
  232282.85187377044,
  -80.92427909878243,
  -4.980488012138997,
  298348.57296052144,
  -52.94716069243486,
  -81.52650018264308,
  268350.85843384423,
  50.65007654249911,
  137.0520293195252,
  694.881375243262,
  327.8517387827981,
  84.33367044283855,
  844.7383608455624,
  547.9733176832834,
  153.59287775191177,
  875.2384457065205,
  228.3308725525768,
  184.33084352198657,
  776.5649657867115,
  84.92321529343309,
  161.15116040239724,
  580.4766655745358,
  136.88653845406046,
  173.88157895120173,
  597.7140742917204,
  455.0477439415878,
  177.52306116148264,
  788.2543948488145,
  441.97932029060485,
  91.76230844264865,
  877.617571223675,
  53.280460442545774,
  128.01379347458914,
  837.0414447545465,
  308.0401426683268,
  103.3723577411496,
  626.4913558635902,
  297.84862694675536,
  83.94824643555306,
  707.0019712039189,
  381.81405280445045,
  85.08979951884169,
  723.388131583554,
  301.27197600682416,
  50.04761438865457,
  670.3758375340905,
  293.4737001801091,
  4.356261766398205,
  565.0274638985874,
  364.86212529501154,
  222.95002331612113,
  574.2882559605357,
  295.0925999622509,
  3.7958696505957903,
  676.6559793838982,
  297.1764871610876,
  17.579573044229193,
  724.6663159710762,
  373.9232186501257,
  188.5874335212335,
  702.8668056110708,
  266.48146298413513,
  -3498.803835543,
  4244.588361477617,
  -753.6582948552413,
  1574.7226895904037,
  8129.4229583049655,
  -93.20037884859033,
  -3783.568790130611,
  8920.095374394201,
  76.83095487597095,
  -823.0390279435087,
  6362.1222038999795,
  595.107337959616,
  -1621.6548095690166,
  1278.8048688044953,
  1604.7644519929274,
  4811.171717398351,
  1725.6607926376778,
  359.30431407255713,
  -2166.0736340688395,
  6665.1544466419555,
  -146.42913856218394,
  -1899.7485803030022,
  8981.77090511497,
  -1296.610143960998,
  4628.077285270798,
  7929.891079299946,
  102.43605848647725,
  12.559682565248524,
  41785.32854536533,
  44.42034258346155,
  -0.36693440086949636,
  70123.8126838085,
  -236.86299389900518,
  11.642021965406325,
  75891.48622655035,
  56.90114713847278,
  21.182386654430893,
  57231.98340555156,
  509.4994773089982,
  18.608831779073334,
  20150.994735166045,
  423.46004763148017,
  10.062585483408391,
  23410.64947569419,
  217.08300401659164,
  16.854431537725553,
  59442.49563981593,
  -244.40255602586922,
  17.71266919883675,
  76341.38724691502,
  -219.37277870141952,
  9.472560117902086,
  68668.29872372502,
  176.50462623741586,
  -983.5221857559889,
  335919.32270367624,
  22.685154615205903,
  1891.937283735738,
  563725.9071011032,
  -28.17443591491559,
  -1144.9148740945425,
  610090.9138979563,
  25.073267510775253,
  532.9877242700549,
  460091.44379787997,
  162.49445663936433,
  80.36619950129626,
  162005.86752597013,
  240.11105173868404,
  -1422.6967685482157,
  188209.48551509355,
  207.82150143738053,
  -228.18728031645503,
  477861.2454356946,
  74.97411745913945,
  -77.24554501261508,
  613707.5651720854,
  -16.403078315830342,
  -1526.4669205449356,
  552025.3636927286,
  63.29766224828012,
  1615.7680010739048,
  -478.1130691684022,
  -51.53777841865367,
  -522.1771969125324,
  -30.221515913414134,
  -170.29686073044647,
  1463.9952613109513,
  60.93693310969119,
  15.493871717432015,
  -1800.1254110664036,
  -233.97770172518804,
  315.79852887378854,
  2616.242413481901,
  -820.0450979441445,
  300.68769687730185,
  1202.7707931409054,
  -768.5260464071011,
  140.55916459239296,
  2326.0805264880337,
  -199.04041456272057,
  -148.7332932291537,
  2468.0252511684043,
  68.04764749503737,
  -172.75315915319612,
  1105.1859493893844,
  -53.22600709160475,
  558.6935708307631,
  554.2977184682502,
  210.4145966393925,
  -593.4166356551756,
  74.55990720084822,
  255.7922658394982,
  1036.4701717141993,
  240.43980414596317,
  265.02788976342197,
  468.01581548037774,
  571.3641893783993,
  235.1489187389599,
  856.7882075918538,
  443.68474761956713,
  175.77210700558322,
  204.3891815437911,
  -201.50352596674583,
  180.99170639557263,
  -468.5637107973648,
  -40.94955118995205,
  238.68855383162034,
  685.3758579945352,
  519.6266324189592,
  265.74830443257514,
  211.11576198709648,
  591.491157820053,
  253.4615896228686,
  -575.0814526155852,
  17.22982601296029,
  398.2481146150453,
  -503.06708979880693,
  14.574520955801361,
  484.1336543693917,
  -206.5232556103041,
  12.066079629582939,
  501.6137620888182,
  278.5590380878072,
  11.058769714390273,
  445.0623437595924,
  757.4437989011909,
  12.237222578438217,
  332.6808659422746,
  1036.192784296173,
  14.849840166017001,
  342.55991259259605,
  1090.4188136237613,
  17.439727404283342,
  451.76175066667656,
  1040.9861977827659,
  19.06000731653588,
  502.9772786333617,
  1015.0511142047197,
  19.503881256963602,
  479.7224232862098,
  45.67969760157614,
  58.139147705869675,
  29.724476572628113,
  -192.0764262680101,
  2.7811554290918714,
  430.44280109807465,
  465.7589841297649,
  21.42701473083664,
  512.0001796496653,
  234.9505968908315,
  22.49819940251234,
  248.1468037817192,
  -183.96003042780916,
  0.75887301603316,
  -276.19428585287466,
  368.16684547065347,
  0.9277844761933132,
  -230.10136924609287,
  404.4552612601771,
  0.24285008202034675,
  279.4043952086287,
  -185.31219567695211,
  0.9759684671076343,
  518.3619731105321,
  185.5305028810741,
  33.00548748984035,
  409.8612092049206,
  82.31727261411146,
  91.76958579682609,
  251.47110330073738,
  254.97293556383818,
  96.43868372780611,
  305.70295185696125,
  191.24841118940455,
  96.48951145898917,
  316.74064874165066,
  -20.06927523698812,
  80.54150864650356,
  281.03163459046425,
  -20.627726040150492,
  80.45605482959404,
  210.0691034944775,
  430.32343442330296,
  85.02881662438736,
  216.30716130202583,
  510.959298621815,
  -25.84514742171929,
  285.26193018900966,
  336.1705879674511,
  -47.396232621095095,
  317.60163212673615,
  606.8083636736471,
  28.739853866559184,
  302.917509549282,
  679.7226349493808,
  132.88106448004268,
  -1030.1684277376755,
  -855.3481663528546,
  95.18226396715099,
  877.7823120295376,
  317.81721024437053,
  225.53142156781354,
  1266.1036120980118,
  167.57482440426543,
  258.4800197898536,
  9.811566373618518,
  -695.3701425970085,
  31.6633276121202,
  -2486.7475092399577,
  858.4459312872398,
  86.42250330050975,
  -2267.2840882893815,
  -206.3835248362842,
  310.9426788146624,
  158.6391618097398,
  119.93689573512737,
  68.35376926249059,
  1296.3941872901526,
  1385.3893543989068,
  0.002324132205785645,
  779.786635079565,
  196.71596681988055,
  7.263972199785442,
  -494.12256162644746,
  197.64788933831187,
  114.98460923935647,
  281.8858775748983,
  212.91014748017616,
  51.483506110458855,
  439.82528329117986,
  199.74233797589582,
  12.195570951885422,
  -71.13823859859231,
  198.54143767787534,
  115.36346515992166,
  -1086.5475315435556,
  209.5668056004586,
  115.31034706299695,
  -997.2865966546268,
  204.68285688625448,
  80.91787030996318,
  -10.606555239427466,
  198.8546735322392,
  114.13028273181592,
  452.14517262974425,
  204.2369099929498,
  74.7902917800364,
  242.02873098645637,
  205.59273823269007,
  255.48028260142684,
  1422968.7493918594,
  -647.0754557804723,
  25.399649506007847,
  2388460.7779927915,
  -1360.5018122403628,
  239.1468573648142,
  2584965.389950334,
  102.2014303846928,
  -112.13013116966513,
  1949236.2118009815,
  660.9850914343267,
  -157.9367901416211,
  685887.0926668518,
  2069.374126732334,
  211.03449458152843,
  796943.5151838843,
  658.8130019847665,
  -189.16332986891965,
  2024548.3537942027,
  141.04241114774646,
  -173.887572496947,
  2600293.515713852,
  -1421.956082490767,
  200.53264324688547,
  2338871.4238441125,
  386.14575155408346,
  184.25412587159124,
  443.4102719425247,
  394.88518228525265,
  285.5345285236455,
  539.0354089886011,
  313.612648763877,
  369.8607596870593,
  558.4977969648697,
  217.3103757118386,
  387.8717250005353,
  495.5333311962472,
  186.2454347490517,
  383.7471726667672,
  370.4075620800583,
  237.93920034169614,
  388.0080357673937,
  381.40691298969455,
  347.9660486463068,
  348.8800669637085,
  502.9924646598048,
  401.8146379910321,
  236.36141064004917,
  560.0159390969388,
  356.5845148394679,
  147.38826141123053,
  534.1239352052645,
  537.3381614696552,
  -457.2000403963958,
  300554.5275624447,
  -871.0622039806171,
  1285.6508980876267,
  504908.5417698041,
  -330.21693666771887,
  -555.0221106845324,
  546500.2950667972,
  136.6459761817557,
  461.9750507330932,
  411943.19293119456,
  1071.2257679462682,
  187.63564251297265,
  144545.37276016883,
  1024.3373430933802,
  -723.3890936237949,
  168051.34181280885,
  750.3051654360886,
  0.6176276257961604,
  427883.6026693994,
  -179.35568438332962,
  92.10524823803675,
  549744.6139604384,
  -244.53865859931227,
  -786.2854441768009,
  494412.5632613978,
  142.37550753682052,
  673.3625388042573,
  806.7603558954269,
  354.54012958316457,
  693.7203609828279,
  980.7449802431493,
  483.84871830897674,
  264.74285177926424,
  1016.1557139221936,
  477.6127427167779,
  -51.34264810721962,
  901.5953664820609,
  485.2551921927992,
  29.21985237108518,
  673.9359810067727,
  448.4018956602396,
  483.440184425237,
  693.9486889118053,
  228.08662301966058,
  746.9450565987196,
  915.1668454227005,
  62.0919493869028,
  477.54800600877314,
  1018.9178891902637,
  54.79810480266684,
  446.71314212576567,
  971.808826554023,
  127.7638146833298,
  -765.0756997262774,
  344.874655955297,
  55.12478693660464,
  -860.4370071571341,
  419.24976254668974,
  29.584561622006966,
  -828.9427411661595,
  434.38717541712094,
  81.7995647943805,
  -857.7992227802349,
  385.4148131526367,
  157.74086282628136,
  -629.8770611203204,
  288.094770506712,
  167.81011136590382,
  -565.6615431897699,
  296.6498212142069,
  51.23460130382341,
  -857.8255684430767,
  391.21636140207045,
  -80.24305541154948,
  368.0287846826582,
  435.56795263095245,
  62.760869707115624,
  1330.3378960907344,
  415.4297273818724,
  66.21529623539308,
  123.14315195989425,
  545.100118854293,
  400.9730998710114,
  174.64762151568428,
  937.4237018786611,
  501.7677234842188,
  33.8954337476423,
  1017.2725159136252,
  -179.29890482557175,
  37.152210530657975,
  758.9466658637743,
  528.1077462943707,
  159.71883045626578,
  245.59011982620464,
  81.26714619155413,
  157.35716230371094,
  290.7174251887217,
  -351.78718727686396,
  2.5864400434324892,
  789.5494347285114,
  592.4867893164715,
  142.87028723861084,
  1023.5010346817248,
  -256.6476788877037,
  144.32774036095745,
  917.2732785471853,
  637.2987843135181,
  491.8769303403791,
  -66.7684064092074,
  962.2415565018849,
  429.6664240404922,
  659.5995132865706,
  -265.87681610165066,
  450.43831655730975,
  807.4356859011278,
  292.00910628967836,
  208.6131436817767,
  329.15801302236275,
  975.2480493996212,
  313.92531418098065,
  -621.2965162032195,
  -494.36110698074503,
  514.0698165815065,
  -537.7455181598222,
  -114.7770417044901,
  0.3479073864808129,
  385.81754234723917,
  971.264722402253,
  255.29942171128835,
  818.9674836724832,
  -381.09282972997096,
  140.67263288641362,
  622.2919903397174,
  -57.01061996653954,
  -9.665234166941438,
  280.2106579636788,
  5.24774451703064,
  84.37738242670406,
  340.6404320691854,
  308.2170869411129,
  72.52215996221375,
  352.93958002641074,
  237.90467138944098,
  -48.32681830776649,
  313.1495356865173,
  -74.90100229230165,
  16.313484825012836,
  234.0770010367035,
  230.98130754083044,
  94.55471437748335,
  241.02797973654307,
  257.20607178627984,
  -44.276159840226015,
  317.8632936391822,
  -75.5412364957879,
  21.49118877805757,
  353.89896151264884,
  237.2079207362948,
  93.45547585742823,
  337.53665349777134,
  132.1800403456717,
  -2549.796613630697,
  182831.73462978512,
  -72.7857327044986,
  1139.652228564974,
  307502.23937315395,
  -21.80559766557431,
  -2756.876585874174,
  332876.17145278654,
  22.837474461883204,
  -603.9908072589068,
  250786.7546868961,
  157.1586969816762,
  -1184.7411110724765,
  87655.03771376409,
  343.0180267067846,
  3493.1854286614043,
  101995.35315920007,
  159.07888436080168,
  -1580.6403720244198,
  260511.5400579414,
  29.258380491679894,
  -1386.9698242512952,
  334855.4370697971,
  -181.8045884213031,
  3360.039866638799,
  301098.94485753577,
  289.28688756918217,
  14.466789152152586,
  41.372765434619076,
  26.29458530793761,
  26.537159389009673,
  115.50667712453065,
  25.275898620318486,
  66.22878118589401,
  130.59500009145395,
  290.0200273577456,
  16.440597113784037,
  81.78145284765367,
  43.07065818427208,
  256.5941325332805,
  -15.222985570271895,
  53.57202262648201,
  35.08878976259217,
  -6.69567848167224,
  283.83258372387183,
  4.330283926356458,
  87.56418695452557,
  99.49143538118274,
  380.85568906565413,
  131.77194810144542,
  135.70592422016563,
  299.21754780688406,
  111.6990301504328,
  342.00568704127755,
  436.1391526594181,
  3777.870490713413,
  -29.138002066799174,
  -213.38900583911015,
  6427.378047829442,
  -411.3191402879255,
  390.02914560154204,
  6966.626885693085,
  106.83708959457297,
  869.4071239317412,
  5222.056022454943,
  897.3174361621299,
  740.0928289876483,
  1755.1677009923942,
  941.422862033068,
  310.666658702884,
  2059.929233981465,
  550.5538653886621,
  651.9388780336724,
  5428.7279404435185,
  -252.64221070665883,
  695.063040298007,
  7008.690397191688,
  -400.4415087607023,
  281.019451693561,
  6291.294719663784,
  291.34124750472216,
  644.6400697365016,
  8463586.55910422,
  46.38253906637692,
  -2174.851111869161,
  14203201.690901978,
  -293.98989869930335,
  444.48437735822944,
  15371373.78435148,
  84.8405353092044,
  2525.3825876565434,
  11592118.541903945,
  698.7463990414201,
  1964.0512435416913,
  4081815.4983531423,
  721.7731459404033,
  99.98532980605418,
  4742018.9016746115,
  448.04802114721167,
  1581.389946896771,
  12039830.896835322,
  -172.41688063709273,
  1768.5845952388706,
  15462495.761507388,
  -274.19067102822515,
  -28.708149650253972,
  13908405.049379958,
  270.70841191924967,
  295.3722529368335,
  -34.230853445099775,
  244.27604127505737,
  97.58362003694597,
  139.90847486626532,
  370.7753375395597,
  266.69246854881527,
  175.35069512566812,
  237.8394713516522,
  214.46963885171874,
  60.68848270814606,
  341.57056006918145,
  320.2540459242957,
  -167.17333335217526,
  428.8154664403446,
  87.49683603439072,
  -147.14283051125253,
  220.18787323075912,
  153.27948669465977,
  74.27202916102976,
  425.76427650097395,
  234.823165603309,
  178.11532646974985,
  459.5245124043131,
  3.9377713921647057,
  130.96437531180413,
  184.58037740462856,
  28.53432720037253,
  94.79234574644529,
  198.71670212621342,
  1.3089607509453458,
  251.11310830342939,
  169.0987325883252,
  476.99365166549126,
  282.9287524280935,
  216.26312042076114,
  13.737261083099071,
  179.99919219957766,
  173.40563699342243,
  78.88348285435686,
  -24.54697890130156,
  228.64529118623372,
  226.82162953997147,
  -6.566069540641543,
  258.2336739766093,
  190.11540449670622,
  192.1928210617858,
  159.44343549768251,
  187.7962270156334,
  285.410496696241,
  289.95627580688915,
  0.495058799757345,
  243.0842013569237,
  283.31548904241896,
  418.51541831232527,
  1607513.4837347157,
  -515.2790435899378,
  180.15256283497,
  2697697.509879322,
  -1108.1965326888967,
  401.5940380694701,
  2919580.4283020524,
  101.45737220510765,
  37.67211676704153,
  2201747.6814312576,
  679.9380246236026,
  -9.783446465456109,
  775238.7219324732,
  1822.1843833078876,
  372.4697133617045,
  900637.9321199222,
  670.1768422623841,
  -42.134049277771226,
  2286786.2853177334,
  122.27901635762782,
  -26.308409814880235,
  2936888.1609017067,
  -1156.3607652540031,
  361.58982643577434,
  2641703.757307323,
  112.73065571266456,
  1030.9944517141255,
  209610.61182926144,
  -181.12592238324487,
  -2415.657949557442,
  353235.93429877516,
  -939.9217198204522,
  786.3165813719763,
  382467.7015460366,
  176.71430084957876,
  3330.085067018368,
  287897.46636005596,
  1697.3720789193633,
  2643.892452647197,
  99963.31542755356,
  1367.584865420001,
  365.1879475149688,
  116483.92256237661,
  522.9926152767259,
  2176.112845617603,
  299100.8014050075,
  -1047.6341981638595,
  2404.9466467029647,
  384747.89334506023,
  -934.3694672446302,
  207.868182555296,
  345859.0872926123,
  340.1229278466326,
  -1211.4280359929844,
  151.90907464697605,
  326.5160725791433,
  -1158.2267401877207,
  184.66953826461332,
  353.0992863982952,
  -1152.9477637488394,
  191.33720821944613,
  358.90229783106605,
  -1089.6431170658864,
  169.76604865056618,
  296.63282417929736,
  -444.7104941885299,
  126.89888700890886,
  314.6862242313524,
  1584.208508172122,
  130.66718315387683,
  292.9693422737634,
  771.6734314836426,
  172.32149252234055,
  347.33846796466554,
  -1192.3372028714662,
  191.85731246839572,
  338.2440848989303,
  -1211.05847915969,
  182.98690372772953,
  132.61722756054365,
  22.9211693717383,
  497.81014326880666,
  186.57630719838897,
  287.8692501762922,
  605.1670679617397,
  126.23433387770254,
  360.3072666394322,
  627.0172026110228,
  191.93990415668375,
  120.22037636642142,
  556.3279296994905,
  187.1533161682833,
  285.67371979729353,
  415.8510824278432,
  197.63461992394238,
  213.13485822720656,
  428.19989074074505,
  80.06479131359796,
  90.26331969103424,
  564.7021883333457,
  167.66163594440133,
  49.21705851521,
  628.7215982917022,
  79.38751172657155,
  92.62101418855605,
  599.6530291077622,
  -517.8387696076795,
  212.20019028164432,
  -1555.994072121597,
  1371.4390066422523,
  34.38817563753224,
  643.0849841451055,
  1118.6164012872346,
  105.17195908638914,
  1090.6590332460942,
  -795.2350637075815,
  68.64419320460306,
  -357.3267395123969,
  1555.3789919519472,
  1.663301634272301,
  -3234.828061472217,
  847.253078380382,
  169.53105616484777,
  -2981.877394261627,
  -524.0830809183524,
  10.891447896103188,
  -185.79000048839112,
  1482.0938107248105,
  85.28665105923328,
  1125.571553846828,
  660.4284624623009,
  201.3994044073483,
  530.1364492098403,
  698.6231376543287,
  177.46219982572296,
  4086471.3106104755,
  352.5130312703746,
  0.30004672530300525,
  6858379.79623736,
  208.3761147278361,
  164.8854577353853,
  7422540.643985869,
  76.72986663323314,
  -105.5979236172303,
  5597374.768689803,
  483.2183092811515,
  -140.8690640892873,
  1970324.4773356286,
  525.4568193470348,
  143.23893037485993,
  2289165.2661139746,
  688.9515421438962,
  236.3226872203884,
  5813594.436255834,
  320.9259943830168,
  -153.1511710519119,
  7466547.389369588,
  262.0094636879003,
  135.1525018521492,
  6716009.742948919,
  479.18744743548007,
  339.1490576287368,
  1614.626641064042,
  60.281263539158715,
  -106.58223599306046,
  2695.4953201799094,
  -554.0722724534911,
  307.50659097674793,
  2915.4823051315116,
  151.88855244199132,
  636.4742633080865,
  2203.7832576961614,
  1271.637772153039,
  547.7338026905545,
  789.463456796893,
  1279.951754104643,
  253.04498913926275,
  913.791162419964,
  766.8300770372304,
  487.23915887492126,
  2288.095228200525,
  -367.7385797553312,
  516.8326235783945,
  2932.64214752953,
  -521.5091870832404,
  232.69993133132087,
  2639.980020074779,
  10.546567862509598,
  792.4888040927658,
  312369.7733489615,
  6.085892332095647,
  -17.88471078086637,
  524462.9663006153,
  4.333837074048792,
  734.960384421609,
  567629.8587711771,
  1.0746937339738096,
  -502.2822468382458,
  427976.88676102913,
  6.626211374225029,
  -663.6191778798387,
  150452.32876121555,
  6.318351084549851,
  635.9450351781727,
  174848.5024754173,
  10.449166447531551,
  -773.6030579470379,
  444520.98261080735,
  5.032016630135061,
  -719.799880220441,
  570997.044660697,
  5.232720172910541,
  598.9561671268309,
  513569.4900768454,
  -96.36288168590983,
  10.420921168993734,
  -50.31902226902061,
  470.5691517321479,
  0.4162579971436777,
  32.465418373211676,
  204.21877736228495,
  6.830326207239903,
  49.31436575198691,
  -52.37300567524585,
  10.950385129625992,
  -5.195130809370168,
  342.13664027181994,
  1.5891976520056836,
  -113.51881144599642,
  -51.129846441203654,
  0.13345224251326648,
  -103.99647097559156,
  30.7863386999627,
  10.528481419381812,
  1.2623782780033217,
  186.81893556606659,
  6.632481088680441,
  50.62864932951721,
  -209.61996899702592,
  4.617465658028845,
  28.213465147914977,
  -232.41847677970804,
  10.83303947674736,
  888.8733692181166,
  -797.2733889070041,
  121.79002395725733,
  1080.5663522780753,
  -805.3649797703654,
  125.53097569443545,
  1119.581231878651,
  -193.909913482538,
  7.571508879775223,
  993.3607981850696,
  471.10008625058333,
  -6.27085041761066,
  742.5299739845614,
  -420.9688764790726,
  31.960185032641135,
  764.5795987247118,
  39.25286297875107,
  412.9252076369137,
  1008.3135981374791,
  1252.48103142045,
  97.21973350464823,
  1122.6245445785858,
  1015.6829352642774,
  43.21035005039627,
  1070.7206664068497,
  50.48440666162651,
  277.4192360440952,
  496.783730602273,
  38.450993299318014,
  101.30995468639142,
  603.9193008113031,
  76.76103948690658,
  -96.59847343601425,
  625.724383636567,
  162.53082605910518,
  -239.17181949103616,
  555.1808618032029,
  254.3230044137569,
  -291.8062172357442,
  414.9936575156209,
  310.65579597572355,
  -291.81055686330774,
  427.3170043680837,
  313.8301620048535,
  -291.1238375628573,
  563.5378539244109,
  260.80732761500576,
  -292.97969496064024,
  627.4252650993482,
  164.46043538246306,
  -241.0685326313756,
  598.4166311096019,
  51.58266999206051,
  -401.0048995969703,
  2790259.125704099,
  -332.93547988794484,
  1458.9156429138739,
  4682858.691976393,
  -107.86148111544472,
  -505.3978078040857,
  5068055.599195055,
  29.96352671111744,
  579.9123988399585,
  3821871.5487937243,
  265.53747094714834,
  287.1452495089331,
  1345399.528213201,
  192.87783593115225,
  -685.0742238042358,
  1563097.1692719904,
  107.12053737019733,
  87.56498706215214,
  3969501.692854005,
  -131.33861581773115,
  185.19795222561874,
  5098102.459565138,
  -89.64348538156645,
  -752.195405460913,
  4585651.478065458,
  994.9246043523386,
  1224.9395575042925,
  90.32431465495873,
  1340.757280144825,
  809.5258117501,
  109.80350923841874,
  1069.8798807070334,
  1164.6435974789642,
  113.7680697521031,
  426.458357053336,
  1431.4786744657565,
  100.94197487330962,
  1070.8186355257722,
  1163.81785384327,
  75.45339227556744,
  771.2305767817238,
  -789.6312918206188,
  77.69400079419704,
  -599.6233881035811,
  -267.64678090766813,
  102.46142798625654,
  308.56944281046003,
  -869.7061110553016,
  114.0773209271542,
  1132.5257119814673,
  1105.1514271687854,
  108.80302383810944,
  21.358194058736757,
  300.6468253850096,
  -217.34481323702576,
  52.56238436370931,
  208.00753874050616,
  138.12100148963927,
  27.71478466561659,
  26.140083759096882,
  210.46822955350393,
  21.413456237212962,
  96.71225725414959,
  -23.58858662118171,
  51.24674887388773,
  400.2401851296347,
  -488.71663596196555,
  24.125484272772148,
  2.8090881021428515,
  -447.8289221940432,
  24.224215824074435,
  2.1140229694484276,
  4.139132634277653,
  51.40165656246479,
  400.8331518590941,
  216.11159537254346,
  21.364052086089316,
  101.51572436502204,
  119.8636574080183,
  107.58511634450684,
  -290.8710056759165,
  1851768.8257680358,
  -95.88306958775493,
  827.9607448894106,
  3107524.9079203685,
  -44.53065882765058,
  -353.66836586760314,
  3363106.367245563,
  22.233828245332177,
  299.197974737854,
  2536252.536852392,
  165.3152181387149,
  123.08443939732933,
  893092.06194576,
  178.8631859812223,
  -461.7523804553283,
  1037536.3182488701,
  139.99868304755728,
  3.027302918706283,
  2634206.406554405,
  -1.2457913953896735,
  61.75823191810372,
  3383042.7174020996,
  -31.206678204177067,
  -502.12900271230603,
  3043027.085838454,
  0.5401934596375941,
  1308.1309744822136,
  79043.10404565145,
  -0.2500716876190956,
  -695.7707758807134,
  132492.59227522791,
  -1.1151786322649395,
  1165.8739797029261,
  143371.05696757953,
  0.11189240976829828,
  -1893.5950538968268,
  108177.18874483432,
  2.170686139570419,
  2245.8783162316277,
  38238.378404934774,
  2.1095769281042616,
  921.0275872431969,
  44386.44464712277,
  1.0619347857693366,
  1973.9088037374574,
  112346.45718803832,
  -0.913215346294912,
  2106.953973702373,
  144219.6196209303,
  -1.1157535779655667,
  829.5610522792803,
  129747.33335815232,
  421.25435902594484,
  59.093856566648014,
  -521.6075803405108,
  316.56409837817137,
  47.92289197675814,
  379.39184859315804,
  317.67518094046335,
  31.441184446866245,
  562.7704140414273,
  421.3758348618388,
  57.64027993358767,
  -30.493548271191713,
  330.3302787136914,
  0.4681334986065906,
  -1209.4539137266684,
  321.37889487783127,
  121.73568423575118,
  -1105.8157993734517,
  419.9860319771598,
  71.84527365146918,
  39.787919537498865,
  356.1028103913598,
  54.42440359762794,
  577.0746570081616,
  348.0724707215699,
  110.09570542421366,
  333.11494682122554,
  728.3490334801301,
  573.9630459854147,
  10172509.885289676,
  418.4252427613326,
  33.99151407136151,
  17071026.98021822,
  316.08652160168765,
  535.6304643693004,
  18475068.01283633,
  74.61978052690932,
  -288.77431526486487,
  13932732.630157698,
  469.9168898027823,
  -396.2770263109262,
  4906003.007295131,
  414.83446870588153,
  469.65413514249826,
  5699509.951464858,
  717.6935518333876,
  -469.56195371258025,
  14470843.855942523,
  329.2211797170508,
  -433.7115911752402,
  18584588.686731555,
  377.14008364955686,
  445.00755504225566,
  16716707.113054898,
  6.030145362535029,
  -499.9645805952118,
  450.59516060826,
  5.94172980013164,
  -466.32820037641443,
  547.7697790416571,
  5.872748256429055,
  -249.50609674021683,
  567.5475297860597,
  5.849763095574227,
  -69.32240560256443,
  503.5628064702605,
  5.854234155463201,
  -117.38570704799236,
  376.4095364656148,
  5.897493561886667,
  -357.68079035477723,
  387.58711759832386,
  5.992382073431519,
  -511.0717970789376,
  511.14280552234794,
  6.0721694670783215,
  -440.5728386583752,
  569.090271443417,
  6.077935378644729,
  -427.86460733132765,
  542.7787211923869,
  260.7871139043902,
  230.56171390627512,
  744.149183236876,
  245.59158195014743,
  72.2010810665083,
  904.631184066518,
  245.6694549066721,
  85.77504146812296,
  937.2937564803948,
  266.47896788531614,
  236.85360978420738,
  831.6242248085167,
  282.2066982085183,
  180.64440279814409,
  621.633061361209,
  247.93850082131166,
  147.61835419617705,
  640.0926201794642,
  281.32614957352973,
  188.09333688864166,
  844.1424464776817,
  260.4935259643397,
  -86.88383751396898,
  939.8415644566682,
  251.82034679320628,
  -46.246962665053786,
  896.3885486662425,
  -1148.1161358585337,
  699.2486568967174,
  574.7910932588283,
  -618.7825711660745,
  1100.0271945985373,
  698.749604244483,
  277.90161845106024,
  1302.639212942738,
  723.9786256952016,
  1136.6139078543692,
  1195.463470101358,
  642.3580219210612,
  1612.7183171100178,
  977.3131491170367,
  480.15795084452003,
  1708.2035898775005,
  909.219365253897,
  494.41636869034477,
  1453.1168873561428,
  1069.1029839398232,
  652.0272690034507,
  732.8267928879197,
  1282.3188945499974,
  725.946587718254,
  -301.2180613258223,
  1214.515598237945,
  692.3828789697874,
  140.5448677313293,
  23.883584858287755,
  319.21433929195643,
  125.66849005088547,
  62.12322977648943,
  388.0555837857753,
  89.876122478726,
  70.9982043451413,
  402.066701055728,
  63.91137132148185,
  28.197383154319517,
  356.7381157454465,
  76.50635264042171,
  -24.951528959795574,
  266.6591477011531,
  109.66881916490264,
  -37.70769398624194,
  274.57766189767364,
  131.92288050158672,
  -18.344780422753026,
  362.10800117870207,
  138.73802815960988,
  -0.5946615343256383,
  403.1596228221018,
  138.62054810129507,
  -1.0897633835201859,
  384.519777427864,
  168.2477897628637,
  34.30279309115129,
  -518.877062296356,
  -247.28464065501868,
  213.5643552879726,
  193.82438128316983,
  271.9605741838975,
  126.2118072408831,
  338.87904404938274,
  71.80547199195765,
  0.4473651890192656,
  -130.39992415631258,
  -143.26175533694766,
  194.20989725763468,
  -1062.9718297540705,
  358.3852230297295,
  229.29709494196578,
  -980.9928280616786,
  4.838029099320771,
  8.787837157402663,
  -74.80643324431188,
  62.892357734092954,
  24.520470200889037,
  350.1938732094515,
  372.93988494707855,
  208.0633921565687,
  157.21879238032432,
  593.2964750038338,
  280.2763908743809,
  -1057.3960101589025,
  60.730022784124685,
  250.75902278335232,
  536.8151924835084,
  158.35461195629532,
  362.75013480181804,
  861.2817281705658,
  364.1341142385609,
  22.752946206136613,
  -188.42821000568807,
  94.18425400892409,
  345.08025512191807,
  -2274.458191517341,
  84.03382864938021,
  329.6800351243781,
  -2091.082888917902,
  412.9654621164349,
  59.18121545950925,
  -64.07352151119116,
  180.39207017616184,
  351.825539616563,
  886.591382816935,
  58.40159770339528,
  230.96352032871354,
  454.93372523806244,
  424.2054972336134,
  -3868.128034825231,
  24780.684765979153,
  112.66296136420553,
  1191.9444579439582,
  41757.9216980928,
  -48.61281150139837,
  -4152.137846634693,
  45213.263903548934,
  56.231174221165304,
  -1199.4588492042678,
  34034.58550706421,
  351.4316963238506,
  -1995.9568528859131,
  11819.821751223404,
  578.4300357045399,
  4419.811035310524,
  13772.64077204609,
  490.8266915178035,
  -2538.9319816746347,
  35358.87616986406,
  207.51618769568117,
  -2273.31317155908,
  45482.79406548053,
  -49.366448195300336,
  4237.20213497299,
  40885.941205501294,
  528.5391538276192,
  -324.95496031022554,
  -785.0620284384089,
  -734.2245214206216,
  272.7434706016039,
  -186.96271625332932,
  -190.71033778007325,
  -358.5023490333384,
  -65.23279019344182,
  118.87219260613841,
  -9.730348973582124,
  -459.05187199165545,
  890.0686974283836,
  -103.81311314449391,
  -1241.666556339366,
  818.291557155902,
  -416.2426177494273,
  -1172.8697481280915,
  687.5187779727501,
  -167.94962165596752,
  -412.3977940801031,
  -68.92446460905643,
  -136.57458775010952,
  -55.73738142291976,
  -83.85248025752594,
  -437.8124773429915,
  -217.6821398523058,
  405.14734207721006,
  -2134.397077557679,
  4747.719132237114,
  -752.3339050438742,
  1313.0683579236234,
  8076.875529229692,
  -136.39442209883572,
  -2327.8950977836353,
  8754.451901232444,
  98.8460808467286,
  -316.2126959486819,
  6562.365589284713,
  747.3928848344653,
  -858.8727746424108,
  2206.1547900148703,
  599.1271683260907,
  -2660.9352570667106,
  2589.093424925659,
  530.4059773189331,
  -1228.8058124596032,
  6822.0527662480135,
  -103.59651561749746,
  -1047.8377199677097,
  8807.305499633943,
  -27.63168738649813,
  -2785.3480738839485,
  7905.88425152227,
  198.01411892252375,
  168.44054541258376,
  -163.6250322678856,
  527.0402197501244,
  7.305987983670818,
  146.75893161671385,
  525.5354861993708,
  258.6369033799779,
  209.93074306022078,
  205.46765847188422,
  193.54282905660324,
  5.55811602048661,
  446.5573317807262,
  51.42037975570685,
  -400.58020076622296,
  419.1749547312869,
  161.5663542539792,
  -364.878059666592,
  225.78677968018607,
  236.21306413350214,
  29.769275168396653,
  355.6078450418231,
  186.75044353271878,
  214.85839061449047,
  285.2609242041821,
  2.380094762191476,
  130.81707000502556,
  0.5182699098740144,
  1796.233554843499,
  7904616.7100710375,
  -128.47260114247143,
  58.33060751001517,
  13265066.124029752,
  -244.76124205507472,
  1672.8598163551117,
  14356067.396753235,
  13.697424294313684,
  -980.4939470245172,
  10826474.195051411,
  88.69565185604986,
  -1326.4923327376105,
  3812310.5927883317,
  330.1519703056996,
  1460.5144421257287,
  4428900.183756191,
  77.53999852901865,
  -1562.3604920736957,
  11244610.145895604,
  9.251971643700116,
  -1446.9757967069804,
  14441169.74905872,
  -257.9183249906104,
  1381.1892153937251,
  12989744.094939495,
  155.28520202551445,
  174.74301274118568,
  2.850824759168735,
  21.4245045706907,
  166.1249735593951,
  103.2976410069279,
  114.76748807129258,
  4.92315061094034,
  123.74137545985614,
  145.43341435198744,
  56.92042749599382,
  57.6020702669999,
  21.138440077930127,
  224.27830315206376,
  -73.83288006637642,
  133.5205639303514,
  10.56846482907281,
  -62.27891200113342,
  127.34891706009967,
  1.747335347596234,
  65.43731350456476,
  17.090069494061296,
  236.78657380601055,
  125.33606644267215,
  149.98964380577584,
  91.49884960547837,
  98.13851737207467,
  724.8218943671253,
  101.84321887585138,
  1031.54472986629,
  -790.7054263594935,
  90.04392812579744,
  1254.0059861887594,
  -1097.3422824907452,
  41.37780433168505,
  1299.2830693279957,
  807.4963778567635,
  18.69304902501007,
  1152.8032357690474,
  1981.3913367657256,
  67.66477994889328,
  861.712036783469,
  208.558631853204,
  102.62239655209365,
  887.3008045246366,
  -1257.2686709165168,
  62.36025697579335,
  1170.156080979407,
  -229.3307154988213,
  20.185770206596267,
  1302.8148583157952,
  1324.0491746959428,
  25.145976883360134,
  1242.5799881511361,
  -387.6791474336584,
  4.198563294265938,
  279.46052527464036,
  837.5998798011093,
  202.4215688090093,
  610.0023067088662,
  674.7118193106469,
  11.099881451774621,
  677.2767974062248,
  56.70772262176948,
  195.41987442329906,
  459.6312355265435,
  802.8358836390149,
  99.70639719575493,
  27.116356023009132,
  807.1733487090164,
  106.21225820393008,
  65.13716474132204,
  27.147744566260087,
  181.51567871273818,
  485.4147830242266,
  663.0210350941621,
  8.10923493051115,
  682.5244699357049,
  837.55715170178,
  207.14989125367006,
  593.0251044379894,
  140.43952662591215,
  8.114282652555689,
  165.25243931191312,
  -157.14838699484588,
  7.071976911551877,
  200.89051122028883,
  267.52842164242105,
  8.027717716328276,
  208.14385488737045,
  342.6951310160835,
  7.910872630510409,
  184.6779313023051,
  -199.68518961093974,
  7.826693637150235,
  138.04541086779952,
  425.6597753208502,
  7.559881766623289,
  142.14470599847414,
  -99.4082744471718,
  8.017216077554085,
  187.45783983849208,
  -188.69867753582463,
  7.857278987997673,
  208.70964396899805,
  -166.45733508269564,
  7.909279050507877,
  199.06007770381387,
  -220.351831202911,
  429.838768614189,
  154.6477331999823,
  253.34258942766326,
  36.6441812790448,
  186.48692910705378,
  136.2150666976976,
  35.76270518567566,
  192.9670953346563,
  -232.8835846373998,
  378.6808322341175,
  172.002545398113,
  472.8945263217787,
  348.3409907350425,
  130.34086522720034,
  49.92803406229028,
  0.7241157858117333,
  134.003191883985,
  -151.70031501518326,
  161.0638080987933,
  174.48612679709987,
  528.3289371225954,
  403.4609207474375,
  193.47257356193913,
  -64.54342121365451,
  42.647088857945505,
  184.851612486229,
  415.4275078748609,
  1197.367476996721,
  -634.6128239061596,
  -190.89343033484863,
  -684.5906529028699,
  403.5990205170244,
  -857.4214680077034,
  1063.7672604135255,
  614.9041474104414,
  85.87355206709663,
  -1809.5236182017861,
  -68.7074651644376,
  1669.763477244814,
  2078.0499921337178,
  -1427.2106741731004,
  1621.947394599245,
  833.8205283530762,
  -1307.7896019727148,
  816.6541119796475,
  1822.6306657967232,
  12.277105945430474,
  -702.6456817102571,
  1947.5796256017334,
  631.3867710355717,
  -857.6152540528603,
  747.9200149881166,
  350.27464982381554,
  249.99860806628607,
  7.2248972980824835,
  -30.11629423725475,
  424.0184940270589,
  1.5993762970959402,
  186.00259074110863,
  364.13351913760187,
  7.973047333259487,
  229.9888240515066,
  305.46959691409774,
  6.271908453869601,
  87.68513115728155,
  417.45303700709104,
  3.725494969797196,
  -195.107056533083,
  399.14153285864546,
  6.602810161254451,
  -170.2478246667704,
  373.8770201385106,
  0.6063518355858291,
  104.5432466784349,
  398.89496702939795,
  6.627826835170264,
  233.41992172055728,
  417.5599810831743,
  3.7000951934712796,
  174.90234795511722,
  251.84671495784255,
  147.26043497458926,
  15526.797139624294,
  0.424865043725589,
  -355.68341241595573,
  26595.296038285243,
  -345.0304865104796,
  111.55644885872667,
  28848.044913059082,
  88.04335955035478,
  482.7492934199625,
  21559.980900361596,
  751.2238969276277,
  382.61840891432234,
  7076.817995305486,
  745.4818049488264,
  50.10434092923967,
  8349.980128088951,
  424.87545070827287,
  314.3588782452292,
  22423.366962611854,
  -249.5125578458842,
  347.750859487202,
  29023.768107146847,
  -331.35121243806725,
  27.147860655740132,
  26026.798634349834,
  936.1889368647393,
  12.209937012673777,
  -17.278886842418302,
  358.82150956428853,
  351.9530424772843,
  42.81879550847195,
  -375.42891563456226,
  75.62471739737109,
  55.05035351213783,
  778.2038702356369,
  105.33231781909132,
  15.478975315494043,
  730.9856793562192,
  144.38383830625824,
  -63.1590163104128,
  -373.53929714521087,
  78.3363415878824,
  -56.24623670608368,
  420.9222409341748,
  333.1174089154785,
  20.166828816710805,
  931.0133301009498,
  1.4702922473765057,
  56.004462718513416,
  -392.97222514643795,
  48.884455063336475,
  39.732073748654145,
  -37.69252311794921,
  331.93267154049533,
  686.6700739109931,
  111.3770943924406,
  398.90578254422064,
  834.7562236420697,
  119.23965122887788,
  400.48256516530796,
  864.8958939108747,
  -39.39202017368177,
  330.51108261069527,
  767.3884226164106,
  -96.86237903273047,
  241.51338734095123,
  573.6172662767569,
  -14.674566850004709,
  348.8716544309856,
  590.6509833104298,
  479.8122650319869,
  313.03636892806674,
  778.9397195773366,
  268.6807110200947,
  28.278504936808446,
  867.2469056848428,
  154.41194078528275,
  28.15189403412367,
  827.1502607692638,
  282.5863326349674,
  803.8397706377148,
  7246728.605210319,
  -391.8103079809025,
  -369.5825824383122,
  12161826.650610974,
  -1240.562916814193,
  720.5385122176433,
  13162186.472891746,
  84.5833961325315,
  -1070.991113383831,
  9925835.31890664,
  2214.073489504657,
  1352.9553608342446,
  3494415.2738206214,
  1979.7809603065807,
  577.1641028034917,
  4059777.999842954,
  828.4364204097881,
  1193.698498436651,
  10309232.126897087,
  -1214.9714292156502,
  1271.60559960931,
  13240218.438716564,
  -1261.0484507974675,
  523.6041532372774,
  11909378.64438347,
  66.62913261961829,
  15.826940208577525,
  47.55156564928997,
  125.76879427112945,
  502.92709839702707,
  99.69560953942153,
  168.44453821159152,
  435.9143306468308,
  110.30837982337233,
  78.39361279917563,
  91.76524161216696,
  75.97408271302425,
  176.6739564823751,
  191.20769911645095,
  7.7434500767834695,
  153.35256664890844,
  498.35712780229903,
  13.74135663474916,
  104.15370826608583,
  347.57765204497343,
  80.04152140875846,
  209.94561953301843,
  11.754953466813532,
  111.1362172771155,
  130.41795179871778,
  493.5773159563296,
  97.0174005199654,
  125.41480994560425,
  -11.29506281120042,
  237.10132596926667,
  157.19845354916353,
  -23.499782852649382,
  288.23421175084917,
  202.98186094583605,
  -29.00173635174,
  298.6411830992706,
  281.1211346484839,
  35.74764374204706,
  264.9726840424378,
  305.4324271998416,
  9.729821788738358,
  198.06515472336451,
  198.2789563302,
  -28.86985986642391,
  203.9467520847672,
  202.82384857675436,
  48.99877608244709,
  268.9612484639234,
  242.92484795312535,
  46.39957778897468,
  299.4529674337798,
  305.0668423580098,
  13.381172221421828,
  285.6079375750373,
  220.19339765814652,
  299.28741340782267,
  -91.90102214715128,
  12.432312379690089,
  224.39626480021454,
  707.3915406112699,
  130.67566372421362,
  408.0135868640455,
  870.0699162297522,
  185.02347029534184,
  467.25136989645875,
  343.7749402270781,
  -6.153277629342611,
  1.6851768443109734,
  -702.1016959110416,
  169.26965750002034,
  477.80578718093193,
  -610.1624877820526,
  144.77252524648912,
  446.1247042726735,
  406.12287599182673,
  -2.24793815965225,
  87.49161332752672,
  882.75946369454,
  208.29785704579615,
  387.03613232987215,
  666.3384808356559,
  231.6998954121253,
  57.65133368748186,
  107.38603696670329,
  323.240129298338,
  4.115645849365663,
  223.58145532074826,
  -125.27478202645068,
  71.18533161273288,
  247.23047045347025,
  524.8673843814734,
  68.4514911248387,
  170.72148267655567,
  199.67902862990934,
  19.310998119850744,
  18.679440819699014,
  59.63265457740668,
  43.16226215115788,
  32.04490329168788,
  632.428629576742,
  22.961137178260273,
  179.78517827093805,
  30.03786539671637,
  48.38346531233833,
  249.0751858244053,
  223.13765111585636,
  15.819239992195495,
  217.61345602036843,
  847.4175388383602,
  253.90854330800943,
  -41.630992038509895,
  345.0153966933807,
  291.9661218947598,
  20.369735402844316,
  -867.1264201580759,
  159.0568726461923,
  32.98861626983948,
  1539.5216484978764,
  24.915610861109627,
  -7.835823842908272,
  -21.367525561510092,
  325.57697273031005,
  -88.9639554880901,
  -427.9969027904225,
  295.09552120585835,
  -81.832276738688,
  1611.6301032383408,
  60.67104626294302,
  -2.9995254060246834,
  -480.1024604834396,
  285.15180542804444,
  33.97293816944937,
  25.02996770021477,
  324.23487117374856,
  17.18526992877888,
  -602.1301888417943,
  147.99477485851858,
  150.88266198044244,
  427.38604663276544,
  137.5320936046303,
  183.42177111417675,
  1577.7769716813739,
  153.41450464222328,
  190.0443892449904,
  2101.5911269628323,
  189.02297639562934,
  168.61898075427857,
  1963.0865854584904,
  218.3027522021514,
  126.0414620966865,
  1775.6351333739915,
  229.0807370038548,
  129.78429678121552,
  1912.7926867394028,
  221.77023571628717,
  171.1571581134058,
  2110.670966657415,
  194.01246927076593,
  190.56097927604168,
  1625.7544921507497,
  155.0041191028757,
  181.75050572956917,
  -1151.5945825867605,
  115.89462630705543,
  -219.51618097730483,
  1875.2176835068874,
  111.79758790537159,
  490.4660352885448,
  -596.5595492389656,
  311.6743854002707,
  634.9672592978651,
  -1089.4879273405966,
  273.00352599780814,
  167.47876899785498,
  1589.5282067093935,
  11.304409125577592,
  -761.5350197748097,
  -931.2641127184704,
  318.6915816103782,
  -679.8687991810925,
  -800.6492666616211,
  325.9825816717623,
  222.86014957906764,
  1800.8662382734217,
  6.402182442459832,
  646.2389180774348,
  -1152.8417946609338,
  218.48049269491645,
  454.0001106421343,
  -313.3722298777993,
  137.56840588482538,
  1146.8158654461142,
  -330.8058614583647,
  106.867674572916,
  1546.6511672900388,
  945.3481097671933,
  186.69476683804604,
  1628.0288260467041,
  -346.99372617978577,
  8.838526179814949,
  1364.7568773340133,
  -20.805446396335583,
  435.8991590155839,
  841.5712254387585,
  890.3362587550682,
  240.07057530867309,
  887.5625717196273,
  -131.18667775394636,
  232.24521566193897,
  1395.9455895494907,
  499.81731769785495,
  403.32866289230446,
  1634.3766006629678,
  763.6986097915561,
  346.7371199787698,
  1526.114928981563,
  466.6964568098937,
  266.7680369749435,
  -137.5482277527027,
  156.07453501267733,
  117.08738269253845,
  678.4496096357542,
  339.3516069308615,
  154.17138502751988,
  844.527975530258,
  351.3959369974397,
  262.05812408362783,
  307.2333949770409,
  182.4658757853184,
  0.3132239160739232,
  -760.5021414560211,
  355.4381502186728,
  124.42011888848104,
  -666.6413969677267,
  235.42696554053,
  54.742062816726545,
  370.8844072848411,
  269.3680764435495,
  118.12188383661041,
  857.4827354907039,
  352.33916587285137,
  130.11044568601287,
  636.538537825613,
  530.2522447686216,
  204.94846928993238,
  842.9463501152893,
  953.0908604355449,
  35.44666196573232,
  1010.4696532951335,
  705.3881380160897,
  172.3474390874443,
  1044.565327531723,
  828.0314132831652,
  137.4111155851098,
  934.2594433850535,
  714.5306732548256,
  109.89236661320949,
  715.0547153943127,
  356.03214050318246,
  215.99919035877952,
  734.3242051345325,
  1009.0953951696964,
  70.34298474932143,
  947.326914086532,
  104.95819020899316,
  215.81661513735065,
  1047.2249230368059,
  -56.31362485528257,
  156.44696423830396,
  1001.8653643280047,
  265.2711746768575,
  86.54503914546383,
  24376743.298947472,
  147.7574555404757,
  -659.7229365174564,
  40908053.4872489,
  -910.1100190604118,
  33.56747200746457,
  44272637.137317166,
  205.63754253242678,
  584.3433372029558,
  33387579.64495255,
  1889.3994602872185,
  435.7691516968287,
  11756312.326477349,
  1476.807967959989,
  -57.61515289727353,
  13657838.299397592,
  693.0157562412951,
  334.4856743535544,
  34677086.283385865,
  -1028.923330898271,
  384.03268914279784,
  44535087.778125875,
  -846.7807085506549,
  -91.67797353011372,
  40058976.569796495,
  416.33566014517226,
  0.03214803775444608,
  -1961.1165985040939,
  436.8033375340209,
  40.28236536361209,
  660.4021990224413,
  218.87525601081578,
  91.79761646277296,
  1193.9545420633578,
  498.9207141063007,
  57.314558334936166,
  -532.1870948278466,
  500.1886694682746,
  103.57405333966949,
  -3962.452043206431,
  213.6963586774874,
  98.85317769584671,
  -3660.9099376373906,
  515.8255502297651,
  112.75147414482012,
  -327.69840919539183,
  516.0339889863237,
  94.97225411812269,
  1235.5737047592343,
  215.35552383816025,
  96.58732132838082,
  525.7564223542064,
  -159.9847124141544,
  25.36732266338927,
  -73.57433372089314,
  156.9396732072903,
  82.66057215507234,
  55.534327259155674,
  -118.93755107710328,
  1.367767651594015,
  81.81154817314493,
  -168.28193161728626,
  61.833856030173756,
  -3.2001769425423694,
  329.0784986051963,
  6.111540656077814,
  -172.13923422102536,
  -18.892169507312246,
  18.108080664740193,
  -157.288416627859,
  -157.89314570067347,
  86.1477494071381,
  6.870801916158373,
  386.2950606729157,
  30.007762459828903,
  83.86127384051197,
  131.47278078478433,
  80.84775578897717,
  48.90308130026465,
  -323.0538309744636,
  296.4438315277198,
  247.25679497609755,
  489.9456075906014,
  148.0456590453947,
  392.68371909215296,
  211.4736431480766,
  217.9536347502656,
  422.2821626267046,
  -302.91907321523087,
  432.4554765175841,
  326.52566106028775,
  508.18211131586355,
  236.38905826884908,
  136.23410914904596,
  394.35633415920665,
  419.5895227055373,
  152.96194682305392,
  -85.03935128382238,
  143.1326684160151,
  337.86952805682483,
  508.05936595782373,
  363.14823307931033,
  424.5909566055452,
  488.713011805599,
  420.70454367571267,
  385.21433868391244,
  336.85610096893913,
  444.5723942490233,
  242477.2749495653,
  -205.31544386219161,
  58.84413609418176,
  406692.53424099856,
  -583.2316908069804,
  417.1895433699257,
  440114.92909114616,
  77.06423917552078,
  -171.7233916057423,
  331987.2297043333,
  506.9254910484169,
  -248.51787247722768,
  117111.08673416165,
  1175.5500295460897,
  370.0594021532301,
  136000.06632111943,
  563.2234070460208,
  -300.8689053093501,
  344796.6600868206,
  153.6032720060507,
  -275.259225764342,
  442722.00617945235,
  -597.0811251955824,
  352.4531361750172,
  398258.15217632183,
  105.5664614310954,
  -278.1233784396618,
  95.45637798762684,
  87.56715017806421,
  -119.09199229280014,
  116.04234499060162,
  146.6950488396584,
  -114.37984376681823,
  120.23216462438168,
  127.54613362099555,
  -281.40215070488927,
  106.67731435474766,
  136.50554449344756,
  -233.1698785162069,
  79.74051683667922,
  97.00586184653669,
  399.4285831817751,
  82.10843265750368,
  121.3054628185935,
  466.5975350184074,
  108.2831000309302,
  151.37697166508426,
  30.550664325017983,
  120.55898688892434,
  137.8135231864275,
  -222.83894936748595,
  114.98501382891112,
  524.3261273923156,
  -113.05920198104857,
  419.18054502033857,
  -1389.262260657444,
  53.90699084498608,
  847.8922121712824,
  -135.83233917234833,
  -122.43061653505279,
  935.1470183215133,
  143.42355486698398,
  -25.00166239598898,
  652.861398402056,
  1093.4338022288198,
  -51.28354659000202,
  91.89093876759914,
  3025.0349006023594,
  160.4162541299387,
  141.20380996145937,
  687.2674464555405,
  -69.19998754665194,
  686.3025796797606,
  -235.18269228379506,
  -60.43541717115933,
  941.9532333452659,
  -2428.3675437616503,
  154.39074502723642,
  825.8728333879843,
  48.88826066946727,
  965.0596015298248,
  5734644.455841178,
  -339.4705740195313,
  -163.63185975574578,
  9623615.311347393,
  -763.3467208830726,
  884.9337893304934,
  10415129.57168036,
  43.10270635630681,
  -838.302678558339,
  7854432.877580938,
  237.531420221201,
  -1063.013399126589,
  2765703.2360099386,
  1079.6157985736577,
  747.0248162753917,
  3213034.93600478,
  368.47107607960095,
  1340.0569040959695,
  8157787.764624176,
  125.06384749057217,
  -1141.2621052565596,
  10476870.769533886,
  -793.4396990788686,
  695.5065734331523,
  9423870.986884099,
  210.28557926300596,
  491.03653967791524,
  461.8856999401299,
  343.10897308218466,
  440.81462263240445,
  561.4952176964595,
  34.75903880967573,
  154.8417092392553,
  581.7685385050727,
  55.992162821091796,
  285.2892582486862,
  516.1805533294241,
  243.6569021618804,
  494.57819815781585,
  385.84121050006075,
  414.6011182677639,
  -88.97821722773907,
  397.2988676975985,
  157.61416225030123,
  463.46960999352973,
  523.95048402063,
  94.69336508761168,
  -166.13162574881414,
  583.3499365593113,
  350.64194912239805,
  432.00474208277967,
  556.3790991721505,
  192.16931167218368,
  44.13311961706384,
  -15.355349888550622,
  -225.24855507596266,
  76.83941159554297,
  89.30368659489496,
  338.5857599150612,
  97.98071971939105,
  110.60472559138601,
  118.74989554878354,
  18.128673261492285,
  41.691879831346256,
  -116.96093230286988,
  88.45315502637435,
  -95.25477289491738,
  349.6905193410014,
  67.82778930069102,
  -83.21629113471715,
  70.95956263051198,
  6.691516701450269,
  49.8556926677264,
  74.67147669373219,
  21.255136411597775,
  112.26628967061669,
  269.6692069438374,
  10.405116041571716,
  83.92821598375198,
  63.50387119974587,
  174.34437624152025,
  225.81078663739683,
  56.49008981217176,
  -74.76552363789952,
  274.50877309604687,
  34.83044832994172,
  -111.9044548129697,
  284.4201743802577,
  29.01474755056776,
  -78.87589359449336,
  252.35493718327405,
  42.594521176433986,
  -126.00937122646579,
  188.63348068891858,
  63.89313266479634,
  42.96929065722136,
  194.2350019854926,
  56.156246640419866,
  281.51105828787763,
  256.15356996564134,
  54.14221945944741,
  295.9696329696568,
  285.1933023178855,
  61.527931210938625,
  -14.691774735562944,
  272.0075595952736,
  187.56394375768738,
  5.384569550466048,
  33.871617995609526,
  160.24852029090417,
  3.8155858020051983,
  41.176315964407024,
  111.04598959285111,
  2.5297870492076173,
  42.663026157038665,
  42.861554645408624,
  1.9297376329207463,
  37.85324057749111,
  -33.0303776304372,
  2.388357909688236,
  28.295022103337786,
  -97.15755204650864,
  4.061216318486648,
  29.135250297823887,
  -126.66600926315277,
  6.696488429441932,
  38.423035494846204,
  -104.83888162126044,
  9.564774820488314,
  42.77899534768283,
  -31.920576753609865,
  11.627552533029089,
  40.80113393929104,
  227.33647081324995,
  1823.7456352086454,
  87062.08285393692,
  58.75392660392974,
  -2110.0159731937138,
  146962.50411840304,
  -56.89707687002067,
  1544.4878799379082,
  159153.91397781312,
  34.95313829631286,
  4447.76260697678,
  119712.42253801286,
  236.7964849384359,
  3664.5916201414107,
  41332.547615704774,
  337.910613632968,
  1063.8418909619222,
  48222.637120156185,
  275.6501778719305,
  3130.7015595574394,
  124384.88890550878,
  78.25102589264355,
  3391.8760316574626,
  160104.8914724279,
  -44.43435473856198,
  884.2884055530267,
  143885.91403195457,
  102.7323977114603,
  964.9821082188083,
  678266.7859313601,
  -456.090292709031,
  -441.4410574678428,
  1138632.7271084255,
  -1289.9477673827128,
  865.1401210044563,
  1232330.0627151802,
  61.56479466160718,
  -1282.124894746097,
  929201.6548540131,
  2192.51384675445,
  1623.1329306124621,
  326811.4858660987,
  1836.291578765767,
  693.2965471726558,
  379765.41294294636,
  650.5590159631549,
  1432.2532017719504,
  965111.9929031124,
  -1391.0341795969232,
  1525.629939971547,
  1239638.8201513528,
  -1319.6416427242975,
  629.1014569517694,
  1114987.5296145624,
  -423.9413678162083,
  268.1749848691613,
  -1889.0682291617425,
  -69.37929481147722,
  111.09816210555965,
  706.5208216699256,
  1036.4158916484037,
  231.76526638702458,
  1234.7957365586742,
  -6.565038966071768,
  86.69697139984768,
  -474.27243305612484,
  -460.40853365083126,
  280.5175857882082,
  -3870.6082326940386,
  1057.3495289054335,
  246.1615755628354,
  -3572.0487150898903,
  484.00570781096496,
  1.5205825218139353,
  -271.80636874739247,
  -531.4928395757566,
  201.05171491493147,
  1276.0032392857654,
  1100.577922220174,
  276.2426660577794,
  573.2068420064778,
  21.410359445931853,
  -497.9145156401295,
  232.99567530313217,
  3.304994630130034,
  -469.17925892487733,
  283.2431431491029,
  -13.580020749127208,
  -247.97474447338294,
  293.46990720144777,
  -20.50899027129409,
  82.68801986727914,
  260.38441245728734,
  -18.496197809636854,
  341.48510308005706,
  194.6354550744751,
  -15.96160624285054,
  439.1614361535308,
  200.4152065941219,
  -17.93309396109732,
  367.38230085544654,
  264.3039108281845,
  -20.594109485648858,
  115.45084346460095,
  294.2676346643637,
  -13.777449760736463,
  -243.21191465602243,
  280.662345582396,
  196.40072809481825,
  1034.0764871919353,
  675544.0472124832,
  -301.78475684737214,
  -620.8890919958277,
  1133792.229025943,
  -953.7792677557634,
  916.5904728622676,
  1227058.5414138238,
  61.55471851564769,
  -1610.1381655459681,
  925324.5742936061,
  1692.8940716678728,
  1808.5354008033657,
  325705.4995739955,
  1497.3582080996985,
  714.3787867674974,
  378415.8298404015,
  614.1507477321029,
  1583.9234997035219,
  961069.7188567164,
  -950.0400572922365,
  1693.801729376803,
  1234333.6773586732,
  -969.5862220218371,
  638.8391716214569,
  1110255.8033458006,
  47.36423863412418,
  172.83757931682604,
  418.89232556670214,
  89.84810506298169,
  54.50925061684012,
  739.3757658388284,
  43.693808544233704,
  323.5185924088223,
  804.603102993284,
  63.381875607014734,
  1.7834964562607922,
  593.5804657687066,
  87.55427801693102,
  31.745169116240987,
  174.22695484270753,
  45.04368938701353,
  447.1981034973019,
  211.09079555628483,
  85.63249832156845,
  249.0004391126473,
  618.5794234454734,
  81.96744909179074,
  2.0919446129261132,
  809.6910895660313,
  54.45661677904503,
  290.3449237803736,
  722.9151775090925,
  344.75862342463597,
  912.2651923078796,
  7474590.636901755,
  -15.240238071189708,
  -1522.5655009163438,
  12545569.458843613,
  -454.5988074227795,
  739.4165498274416,
  13577655.375797853,
  116.16450296787784,
  2536.4198052248453,
  10238664.37081012,
  986.6796183699115,
  2051.6703601347936,
  3603273.8776007323,
  999.2192208709823,
  441.91717822491705,
  4186566.903272383,
  573.1040290956146,
  1721.215178625972,
  10634220.487038353,
  -312.09685604893616,
  1882.871039926089,
  13658162.100684533,
  -439.45067463613555,
  330.78122722696486,
  12285115.144118592,
  292.9013056102123,
  -1423.149761831119,
  8322.462675919916,
  -810.9173302391571,
  663.0193849882255,
  14741.518588455672,
  -96.25049922709297,
  -1540.2414650898108,
  16047.975870194634,
  83.20415930595367,
  -322.9095328490935,
  11821.342175782422,
  641.9725369152877,
  -651.2901169530384,
  3421.9889004104416,
  1738.595913489975,
  1993.805786442793,
  4160.345473499955,
  392.17465166884506,
  -875.1481669687175,
  12322.053560264641,
  -152.49891820189794,
  -765.6387148275253,
  16149.884631112089,
  -1400.8693243519017,
  1918.5197002526877,
  14411.824683672045,
  215.0448193489395,
  347.22500466023223,
  -1056.4970569252007,
  118.24059205449817,
  1.9686566244406833,
  585.5317165795908,
  458.0382233083048,
  160.39482689729562,
  919.7304643706474,
  128.8448777436157,
  84.00768945907207,
  -161.46500048519005,
  139.79988762634878,
  134.47892868989635,
  -2310.064412130473,
  456.45125184785513,
  164.89627490086343,
  -2121.188858678496,
  123.24955460568253,
  15.883725897278566,
  -33.38035505694471,
  240.48959831832005,
  378.7305107815134,
  945.7992695000579,
  438.1248324126883,
  214.74112015346074,
  501.19425551360547,
  11.39921962968927,
  75.12165801913189,
  17.449015331071575,
  1.5700870415545864,
  74.30680641391115,
  21.212041557421802,
  84.07860950796159,
  78.1626511730328,
  21.97792256574719,
  -13.126703048231633,
  72.79903684806104,
  19.500154236889358,
  28.881644064970033,
  47.71982491103517,
  14.576223507780071,
  -4.424886208603908,
  50.260974072806576,
  15.00906833524261,
  48.667337858529756,
  77.2302984307166,
  19.79368495189047,
  -28.69960589395663,
  70.64064046873273,
  22.03766427001843,
  249.2216257724564,
  55.41416677757625,
  21.01876596872569,
  48.05608798310828,
  220.2929498774586,
  116.45792721492585,
  105.72011085208888,
  297.42646539960674,
  271.4310984134849,
  23.737311692435064,
  236.96801606634654,
  302.9724700334362,
  56.78758065940206,
  136.9112573836784,
  200.93023266351935,
  84.72431243909486,
  307.9659001899275,
  -1.8526112371487269,
  31.24190554124533,
  40.118292576450386,
  15.973290447789271,
  61.570257329572165,
  95.6683122805129,
  213.01874414647622,
  56.19583171951868,
  67.34294661759169,
  305.43281997702394,
  52.08601743692615,
  39.65932794941625,
  263.4714061089866,
  270.1137828846585,
  182.39838859299527,
  -1277.0047697294285,
  504.195717553753,
  227.07254092501216,
  696.3491688462789,
  528.9624151539194,
  36.76728891587115,
  1097.9818477992255,
  264.417090425285,
  166.3366384852771,
  -201.3749986642413,
  531.6874803633278,
  71.78136307565578,
  -2783.5143495733037,
  517.0759407897676,
  196.29943856864244,
  -2556.527878130672,
  267.75553776738855,
  176.0576026503516,
  -47.445698760799374,
  502.43488433460806,
  2.0755101486425502,
  1129.3107624358927,
  445.5879108690068,
  223.7683891057273,
  594.9942695598248,
  451.8736690211683,
  314.1085994020257,
  12639.578839581869,
  156.82267809295269,
  -56.37682205129377,
  21492.463679620018,
  -4.771003988656332,
  287.8078375727915,
  23294.27317018346,
  57.13084737755369,
  -277.8330049142661,
  17465.082418848364,
  291.26105990464237,
  487.4812306010567,
  5881.056934282813,
  527.5412384014571,
  242.5401397501124,
  6899.366449188485,
  502.77120708491316,
  437.19895531455313,
  18155.64194743269,
  278.30690087999864,
  461.79661628163444,
  23434.821334412925,
  22.79056567367695,
  225.62962118359613,
  21037.764077173506,
  -604.5139812624902,
  656.7216628925432,
  770.83591256675,
  380.85486831356155,
  -322.0501184231508,
  937.073129977869,
  1377.338895091375,
  -68.8801676469455,
  970.9070498162434,
  6.333402887098487,
  787.3894558324796,
  861.4479901119946,
  752.9724719339022,
  -285.3405989856932,
  643.9261090789902,
  -1013.888850683431,
  360.5609170974236,
  663.0476658686588,
  852.2885467191458,
  741.7489196565458,
  874.4151411099848,
  978.2154932198314,
  -236.74852281292857,
  973.5462274578729,
  1500.9516140240992,
  441.3769559949509,
  928.5348966184113,
  418.38725394569417,
  310.2378379192567,
  -718.914516089959,
  257.4160339350413,
  191.4751269380522,
  575.5469178910873,
  360.02199717687995,
  213.0898928574331,
  839.0059980732883,
  492.75988459695196,
  442.03551646408886,
  -13.333409392647066,
  -48.0975261827619,
  7.2495445965616625,
  -1707.1399494039679,
  182.48997074172559,
  23.464916333921593,
  -1558.243581867388,
  519.389375103633,
  472.99682561598627,
  87.6396286364678,
  -270.13175638630156,
  298.36070580282876,
  859.5568333658774,
  -42.995942194093004,
  62.37240367454331,
  509.06112144747317,
  4.108995799891767,
  209.75489416408044,
  2964.7543532158015,
  -10.746513936177209,
  35.588000185309085,
  5038.907285557965,
  -22.13221591929472,
  197.39078553301843,
  5461.055376931759,
  1.8199698823638188,
  -68.51956596489917,
  4095.3273336410234,
  12.198309640293143,
  -103.1943815256756,
  1381.2922070941331,
  34.59566825730299,
  176.1102333957219,
  1619.8731560771341,
  11.636203413555487,
  -126.83230950265894,
  4257.119348001378,
  1.850826439845866,
  -115.26883638953475,
  5493.984573712161,
  -23.173164290523673,
  168.16052114322213,
  4932.375174185195,
  798.4946908121951,
  -82.7555105064601,
  472.1498266054661,
  231.8397864390059,
  -123.14818002548566,
  573.9728892008252,
  -316.88241725849036,
  -89.1924544054572,
  594.6967282496298,
  -524.0245616218521,
  -48.10930547308213,
  527.6512322923003,
  -430.77805043071965,
  -69.9972989717033,
  394.4154596222843,
  48.04090015084415,
  -120.00206257417472,
  406.1277314242118,
  723.347908558467,
  -93.60199928915921,
  535.5938281099774,
  1031.3698555240926,
  -25.724244241941307,
  596.3132684828515,
  961.3782277364446,
  -48.565356035562715,
  568.7430791537539,
  230.56782942751948,
  -172.9883714519283,
  -580.1014966780293,
  -876.9784050858993,
  1835.8170343830946,
  -355.7381646209144,
  -360.4417774544237,
  -285.73783227255853,
  -310.07395590935,
  97.51535546327716,
  886.450420012286,
  -457.80621311110804,
  844.3092003315566,
  570.2475399510051,
  -751.386283711062,
  726.4253762079139,
  -479.7971737941639,
  -725.5787283256792,
  415.1494140030903,
  354.6910680816021,
  -440.30499857861406,
  -341.87008793245764,
  460.1394588732611,
  -306.5119696177834,
  -322.005953167598,
  -552.2913419460594,
  -367.26185658497997,
  292.4216421638829,
  -978.4553601682765,
  36391455.01116903,
  -540.7155382800579,
  1803.4259196593996,
  61071282.60334148,
  -198.22546121045394,
  -1134.5957277003731,
  66094317.28463913,
  78.72996757588109,
  488.70165391417845,
  49843860.47374759,
  624.8804999305195,
  50.810123895903345,
  17550234.503438722,
  580.0024385051383,
  -1403.3375619201179,
  20389049.614833802,
  417.068847710378,
  -247.7018733823649,
  51768983.23491972,
  -127.14458336913788,
  -101.67234584370169,
  66486133.570997216,
  -148.40018162228938,
  -1503.7306456367774,
  59803683.62319243,
  93.79924570762027,
  1178.3546597959953,
  -158.41713029660687,
  28.25185365652915,
  -394.50655377855276,
  67.78570906321112,
  -11.281973759069501,
  1066.6972347713063,
  113.82430892250416,
  12.293821911049243,
  -1334.6780702853894,
  -35.1191736763623,
  77.23153903285035,
  1914.3919538914645,
  -331.10624491606075,
  123.24970621623983,
  874.5174565392601,
  -305.08709886583506,
  108.62751532120532,
  1700.9232559378954,
  -17.47447040333519,
  46.314914518698316,
  1805.350325505214,
  117.41549918307663,
  -5.915468600240395,
  802.7254312272543,
  56.16753679647023,
  185.74036675117821,
  1111.2384513165453,
  13489110.139304202,
  -84.36098830263677,
  -217.20516995145186,
  22637090.926802315,
  -321.13992009734005,
  1016.9322323309725,
  24498960.6901884,
  38.8923980968697,
  -1011.2770456021713,
  18475463.721301436,
  230.21658117427828,
  -1275.7563418567893,
  6505304.3337726295,
  644.6560644279682,
  854.616575790077,
  7557557.47457407,
  338.09137434130673,
  1552.6015622053908,
  19189041.884155523,
  131.96575573605244,
  -1367.8532506191143,
  24644193.78983005,
  -323.5928581239535,
  793.9808011517772,
  22167234.681925893,
  69.04407841430618,
  414.23676807044876,
  798.5490545631578,
  90.05610047837345,
  412.1906826596066,
  970.7628430396566,
  -30.407801812474943,
  406.63934899482877,
  1005.8131621265478,
  94.71108934894214,
  411.5605140493615,
  892.41882331176,
  257.47714901788,
  227.95238366093298,
  667.0765817089939,
  259.09220769048903,
  231.07402540734284,
  686.8855979305147,
  46.30584504256692,
  415.02053306335864,
  905.8521701512226,
  88.80426833869441,
  412.34902268965686,
  1008.5472236514315,
  35.76383585705214,
  132.11242714992906,
  961.9176425687403,
  152.1827367730854,
  48.28705876407963,
  -478.98534917519976,
  142.05333079458228,
  23.405186983860006,
  585.7542135075317,
  164.9408098910972,
  240.78879575387717,
  802.4584724789883,
  138.85813380497004,
  328.2822050127947,
  101.37965766137613,
  144.8970977224655,
  62.51278190301963,
  -1291.8351476143223,
  163.20309701225256,
  403.4126775558131,
  -1169.3627053350826,
  128.3202022985771,
  363.0341087402047,
  184.43349420807425,
  149.71774426201424,
  158.97471395593698,
  819.3622494535567,
  157.7072446502889,
  347.2472038534229,
  531.0673329472701,
  39.883457004427555,
  1158.2282533817845,
  -746.078158106214,
  -2.2633892436992085,
  -2374.235039507832,
  -334.66818979585423,
  -60.96245883314754,
  907.4586674359617,
  -250.93476291770492,
  14.99277939900773,
  3514.5590520991163,
  -521.8280621771452,
  129.4414812491636,
  2811.2823824750308,
  -1060.1591987076613,
  126.46811807521983,
  475.8452444705915,
  -1012.8364680015341,
  69.91950999835738,
  2331.8565226509454,
  -489.73648085594573,
  -46.68151292820973,
  2566.3875714472274,
  -244.4032292045119,
  -58.957865198580805,
  314.6087081836585,
  -355.79892315716694,
  577.7372756059142,
  -523.2181418588161,
  86527608.18732785,
  513.089111877121,
  486.2913411785961,
  145207025.97126883,
  -8.391865404425687,
  -579.8795036687559,
  157149927.49707094,
  56.188227390817474,
  9.194556541028348,
  118512407.00285846,
  288.95155255267457,
  -149.710733666967,
  41730218.6754531,
  693.7228173613757,
  -677.4025116062136,
  48479861.366869226,
  635.7504120677725,
  -258.03695672977,
  123089630.33905478,
  419.57312666137557,
  -205.04469069643324,
  158081520.37290815,
  -1.7395251098059816,
  -713.8338901766161,
  142193148.75268343,
  81.97984829424925,
  -90.30587683325965,
  217.59948530512784,
  -40.41213487140544,
  -81.0050917915633,
  264.5266358925542,
  65.23512728352479,
  -89.95932309177132,
  274.077622584612,
  227.39111195210063,
  -81.29595954243143,
  243.17839401297317,
  45.297322596262575,
  -89.18061216130603,
  181.77408139113973,
  -239.73093940438332,
  47.14532097213463,
  187.17191100420195,
  -11.071546659037807,
  133.73629437842422,
  246.83889469416349,
  -225.29750258653792,
  64.30911375047015,
  274.8226367790533,
  74.59795533184048,
  -90.18744995870021,
  262.11637560999094,
  602.3491127408067,
  -96.33590503466644,
  81294.80233068996,
  184.3438940306609,
  -1473.0361307105175,
  138319.34884585792,
  -86.98173382040522,
  -194.06786059642008,
  149925.4378171523,
  82.34822990385504,
  821.9924322734075,
  112377.56894146693,
  524.5984410810005,
  547.9057484194254,
  37760.784468005666,
  809.9569821096514,
  -362.2797420892008,
  44320.0743886149,
  704.0469499630015,
  361.0600165067408,
  116825.7058675404,
  277.4723141617551,
  452.4633577546768,
  150830.75800074686,
  -51.39896811938178,
  -425.1181518584551,
  135390.46870128936,
  199.330779108331,
  130.0575779675528,
  -25.136918677890936,
  -110.28528397915818,
  157.1905377475834,
  518.6767106338289,
  409.834290279838,
  258.36728478066937,
  629.3579830208964,
  137.92748633476975,
  251.59416616443,
  271.283362633065,
  54.65310522927618,
  25.464507051716282,
  -440.29834825857864,
  389.2957802650005,
  521.5023558666707,
  -377.7457901863194,
  105.28613209989851,
  318.95334088758216,
  313.70294565947387,
  245.88710083994647,
  366.9345051191857,
  637.9915537341462,
  272.9637566697277,
  423.02418332609705,
  490.7454943669321,
  -369.606306978211,
  212.84937487733242,
  569.6590299261602,
  659.1042582877401,
  -2.9543370930824864,
  692.5107684923,
  648.0382274427957,
  257.0669722842447,
  717.514530822923,
  -424.8999814213498,
  92.36558207814087,
  636.6226824396232,
  -122.94920314195286,
  -47.35191128454514,
  475.87082628340823,
  640.0565156273257,
  -9.897401088668516,
  490.00193682703815,
  -370.5779699292377,
  212.212718770256,
  646.205596958777,
  471.6305834612833,
  301.28111228835826,
  719.4649217564839,
  588.8111774297155,
  275.7825125597599,
  686.2008889789857,
  281.96855248999134,
  109.62458215511742,
  11.8025688089573,
  330.97855621215274,
  98.06504123083714,
  844.5072972372459,
  400.0008579713964,
  99.9240701644213,
  1013.985982392341,
  277.21017979946555,
  107.98616951111427,
  465.690732961957,
  267.99543302423467,
  31.78286600452179,
  -623.9058188429527,
  453.2327390316741,
  24.08929364194882,
  -528.1233520666408,
  263.45710701060506,
  99.05809958599805,
  530.6449478990738,
  234.22828385964763,
  0.03568931539337683,
  1027.205980510524,
  454.5826911790556,
  10.561091061787323,
  801.7381303709517,
  414.10402045040104,
  26.47365135896061,
  -1411.5100509178083,
  175.11695442089288,
  76.11203195167327,
  955.4663703550001,
  398.68501237464795,
  197.51964320521927,
  1437.2122257287217,
  288.2755126969576,
  59.28460882890013,
  -121.32573255474345,
  145.58778520917957,
  237.97119459647377,
  -3218.521243489664,
  416.5999435420135,
  227.1089338925405,
  -2946.25805980534,
  185.35704903713494,
  249.9132394351675,
  63.307655451389124,
  178.02717790007387,
  262.14396801365916,
  1474.7902804301432,
  417.45415830899606,
  228.44768189701637,
  833.8943339849451,
  337.45644246445136,
  201.143421882723,
  2028.0326769542169,
  109.15014517718903,
  -1139.739720763741,
  4181.104416292235,
  28.910326880561684,
  105.95412121538943,
  4619.314690558772,
  31.798726811800123,
  1095.5799622024867,
  3201.6224809924183,
  152.71634393354807,
  828.6240867334786,
  384.3218666446554,
  352.8036444140314,
  -57.88145611647866,
  631.980508777513,
  360.9239682444181,
  646.6394487385465,
  3369.57046994639,
  253.01517197607,
  735.6647842292505,
  4653.496800219762,
  46.7289940656795,
  -119.08502302148582,
  4070.5188973788768,
  293.8358191568159,
  0.008634502121168453,
  -527.8926873320348,
  -171.87269783107718,
  103.69035351181262,
  472.04537448411344,
  678.0098161100719,
  170.80916486643022,
  675.5607169188834,
  113.26801276668455,
  18.00809866280821,
  17.150514237254864,
  65.0566022358831,
  28.459594568936872,
  -1291.2713392447367,
  715.0136098513449,
  151.50953031887846,
  -1176.2527367143407,
  -118.26916534804488,
  84.1754490198755,
  95.14958110169087,
  259.4584428058649,
  0.5802424606452092,
  691.4357069894452,
  443.2733404387876,
  152.3758363121499,
  420.68681200483627,
  16.137258379712193,
  0.8229924635714099,
  63.53923558021879,
  420.4625156156924,
  426.86700003500545,
  255.66437635104106,
  435.52262940178036,
  419.52433428149345,
  294.7672121239745,
  28.297229869270495,
  8.668898474291325,
  168.2622237595936,
  481.2661782988424,
  335.91241834653584,
  -83.13408005873973,
  370.56500827312556,
  409.1768972836529,
  -61.0347460637121,
  27.36473133719676,
  164.6069994094495,
  183.248733698124,
  509.09939360444787,
  122.21268019889514,
  297.8173857482313,
  318.3188988073574,
  344.9937205826035,
  245.79649410621818,
  110.88534376871948,
  1564.5692185282426,
  21413.1692654384,
  -262.1656153136537,
  -96.74353985919117,
  36124.82246560656,
  -608.0142289540951,
  1446.6326179170205,
  39119.0550617494,
  45.527533678723586,
  -1089.7866144579832,
  29432.152507293475,
  275.5442378318904,
  -1420.536690835128,
  10181.911634386797,
  944.6505195308808,
  1243.645402817873,
  11874.130239329043,
  313.1665147603659,
  -1646.0100309912184,
  30579.71880711225,
  105.69472972033613,
  -1535.7103926658845,
  39352.616876618245,
  -630.6453851356945,
  1167.8160756198088,
  35369.20630405954,
  20.49722865512466,
  1097.710690889311,
  496187.0658420935,
  -95.40097634811556,
  -36.98493148558447,
  833052.104424338,
  -211.85144456282018,
  1017.1586432657037,
  901613.5546774163,
  13.288010219570673,
  -715.244713629641,
  679804.4378942709,
  77.6389959955688,
  -941.1508001690609,
  239015.55807652997,
  307.98827686001613,
  878.516052815337,
  277763.7040453967,
  109.75757385406237,
  1474.702820465208,
  706081.2240993532,
  32.022037082342784,
  -1019.8157563130958,
  906961.6150691767,
  -220.4313033364965,
  826.7237547156122,
  815750.1286402706,
  528.0549757351139,
  9.106213173680885,
  -770.0300357533565,
  -464.0793419717445,
  84.80825574833841,
  442.8076191009752,
  627.1959911721551,
  0.17163088589097697,
  689.6539789616576,
  910.6339381644071,
  148.13503825401358,
  -108.9401706621558,
  -476.4795480041985,
  102.30002301045033,
  -1695.9417589955633,
  172.39276830329726,
  180.16417922137083,
  -1556.4342259947475,
  1018.3460042301075,
  472.3877550734417,
  -14.334105597615771,
  -510.55295583165434,
  173.0409451402372,
  708.9089573080624,
  -214.21908003607342,
  444.3415757128588,
  380.51416228333795,
  293.44921553809274,
  665.2638364964544,
  643.5607419165809,
  342.2108487616841,
  695.0404904788704,
  782.3500033237335,
  219.12344731693992,
  560.886084681362,
  810.5974969837346,
  243.29979832181374,
  604.5365539305812,
  719.2115709723311,
  588.5983523675784,
  412.28857533133043,
  537.605419963418,
  590.0971113489712,
  -160.02944991020314,
  553.5697556586539,
  532.9319017224091,
  568.8067846526048,
  730.0376744020779,
  196.02878565399413,
  506.710297310588,
  812.8009116059737,
  545.9215274597801,
  541.3662203157294,
  775.2215448465298,
  67.34761308123943,
  0.025659356384096554,
  -1216.655865754095,
  -43.16409419003992,
  168.20522241598553,
  514.5003756299101,
  75.00684442497446,
  22.85919017081426,
  866.8390541211113,
  84.79286292326347,
  232.14647687009602,
  -273.0424798341167,
  -43.0144934998423,
  189.05654783959324,
  -2538.265441648968,
  45.447577374887764,
  110.35852824572308,
  -2339.1379364071768,
  74.81658707641594,
  549.4844501719415,
  -138.00554446709057,
  -41.631414008198774,
  273.6949202346844,
  894.3228445597379,
  11.368856655368031,
  420.2357745655403,
  425.5851723991941,
  371.5215393270013,
  22.959671596528636,
  595.3193465895007,
  395.36782238676204,
  50.50683051729181,
  723.7049472532144,
  344.9857870253498,
  4.091067154847579,
  749.8350051843158,
  321.2307365766434,
  -7.638371960221505,
  665.2993798468134,
  406.42493916889026,
  122.1215245952663,
  497.30644908896716,
  214.7642589310253,
  224.1675219804164,
  512.0740961435714,
  296.2652775357581,
  213.43368975105426,
  675.3139571821454,
  373.00176352581,
  24.274195270861426,
  751.8732515653346,
  354.8937107360679,
  10.254827550174852,
  717.110838932994,
  370.9211676963687,
  -265.3686990919406,
  -1063.4305753209562,
  -9.83214584363364,
  3054.33778946762,
  -755.2826310180479,
  -86.54225982976538,
  -451.6959140529385,
  -692.5659120530015,
  57.30957133779458,
  1485.4359433286083,
  -895.4662297945902,
  387.4571431219889,
  962.8861982953233,
  -1298.6787084747025,
  540.8253536102461,
  -772.3940032474372,
  -1263.2337671530754,
  448.18709273412253,
  606.6624365325513,
  -871.4294888906917,
  126.04175296857383,
  780.9240678993393,
  -687.6737634861314,
  -62.27865648511255,
  -892.1962298332107,
  -771.1096467650009,
  410.5808862512095,
  31.07873208210251,
  44.97769047909752,
  -100.5615327319855,
  49.927046009285846,
  136.42196414681067,
  -415.20296758228096,
  76.11784379706002,
  155.0334295763616,
  653.7034214495897,
  96.65396562031012,
  94.8218574213022,
  187.46412433642797,
  3.7116965454307405,
  -24.833239840734553,
  -405.4961803762984,
  61.66531564126253,
  -14.314795780745039,
  640.0373784258236,
  70.28098503475582,
  101.95486724315367,
  488.6230614511709,
  20.582633289692936,
  156.48519643264876,
  -400.9936648735717,
  57.52677907207139,
  131.72522679689385,
  635.3027153027997,
  328.52429505403256,
  509.76094766979924,
  -819.9394197086453,
  555.4171580146123,
  1213.8553728761513,
  1309.4204386861556,
  67.84006969458093,
  1357.1582668494275,
  -428.89517583983775,
  2.206320719702262,
  893.5465983775514,
  -1165.9614309339295,
  509.35169272045437,
  -27.762998720490476,
  1419.600046222694,
  110.19435943077139,
  53.22597442609548,
  -1081.4724580897866,
  231.68785007548536,
  948.4687083038401,
  -972.1641359574569,
  132.69339060456502,
  1368.3364512147548,
  1404.0218033527017,
  103.488229114488,
  1177.6918554452886,
  118.7457066878344,
  131.3211613846687,
  -366.5621995286329,
  310.22100428991484,
  9.537135462880457,
  268.2126585251297,
  -114.19856064033777,
  116.24533381157316,
  397.4070831989514,
  160.21780092822917,
  153.58478907694143,
  -20.56104793637857,
  311.0857962257887,
  86.93514689701479,
  -851.1657904040975,
  -169.47977122045134,
  5.5651249229266,
  -778.1503508656049,
  219.52594316795987,
  166.957093846437,
  28.953865524632995,
  263.59096154670453,
  153.4028291940583,
  407.48475196009747,
  -131.71259901736096,
  23.568600549500808,
  235.60951493799934,
  240.01745319637882,
  128.43100411604894,
  269.94653129834256,
  433.53778161301324,
  -54.31045611530999,
  328.1627605648196,
  194.10715221917906,
  130.04837333863367,
  340.01139028185355,
  -69.51324798871954,
  -62.19851550323605,
  301.6788567236413,
  50.37485033888288,
  -77.18955426833007,
  225.50275191447994,
  528.019119187046,
  70.46379054471157,
  232.19911600992978,
  437.2720088517293,
  -53.42453417319906,
  306.2199495498349,
  366.8966484203248,
  115.98225538872813,
  340.9356295891086,
  565.2067001557994,
  11.641077405767408,
  325.172673516168,
  216.64219909841975,
  283.77445955011535,
  44.5218253478871,
  804.9786234487111,
  270.51029876064956,
  358.0232959279127,
  144.85077638238218,
  300.8656498214383,
  421.8296071138438,
  -14.127724910632992,
  241.96181419546195,
  215.40425471683204,
  811.913304483018,
  262.3056153384232,
  -194.81332862091114,
  416.41888024260834,
  168.8719813282463,
  -158.75259404716456,
  -82.81281640380996,
  35.143222109639524,
  239.8585915399126,
  832.0042896998078,
  225.32614282417734,
  426.80674812148294,
  649.6366478038392,
  19.057382068246795,
  341.9213137362499,
  201.23867822572953,
  606.5466860983039,
  628.1645519185766,
  249.70790715873844,
  669.3543708192431,
  763.6334960671849,
  311.88274917771713,
  653.820660807722,
  791.2052123668989,
  372.05381038661176,
  520.952346079933,
  702.0055525280169,
  409.1671983132354,
  285.5279135054992,
  524.7440462800826,
  410.84878276789794,
  18.97160236857114,
  540.3264600687339,
  382.66097636868244,
  -197.10810978384347,
  712.5726582680568,
  342.94504501478167,
  -324.0196283055978,
  793.3559137206634,
  309.98017015145797,
  -375.86350143136644,
  756.6755748741248,
  87.02388559042788,
  260.22671512287593,
  300132.88834844774,
  52.50050660847451,
  12.426851861394335,
  503643.7486192734,
  38.182918485655506,
  242.6354016525882,
  545063.8965252213,
  8.606586283883829,
  -135.6945279666878,
  411061.96993042843,
  52.06718296021529,
  -185.02890121229908,
  144767.41913031394,
  48.76980505465882,
  212.35801776358315,
  168176.40378841857,
  85.33088883047711,
  -218.6602945653617,
  426936.61037472996,
  43.10113971293454,
  -202.20810327458227,
  548294.8295293945,
  45.912617731760896,
  201.04738596591204,
  493191.07596728235,
  -352.0776201423913,
  41.90985103247115,
  -2168.552778400722,
  1332.7779418595567,
  413.91131684766856,
  698.470656155205,
  1148.6875833773242,
  415.42845122792255,
  1281.9900543391307,
  -734.5291965223228,
  71.05950210328871,
  -605.8043528568835,
  1412.9854991454831,
  263.93886967274557,
  -4357.312830696676,
  931.601677063856,
  342.1307803774047,
  -4027.5313757677704,
  -623.8695233612884,
  377.62667105806605,
  -382.16534848928194,
  1238.4479978299037,
  44.90517562681663,
  1327.5068421219437,
  774.1248410579545,
  272.949598272994,
  551.2153332347489,
  -40.54643682177925,
  88.315763596506,
  1245.0385645052834,
  -359.2126535410017,
  355.59051545807654,
  1513.5415534795675,
  1746.8643490357408,
  298.3106231840283,
  1568.1894160147847,
  1469.5067408670268,
  123.87438992019283,
  1391.3933581968702,
  -860.7811157688411,
  140.71756193390587,
  1040.0564185257192,
  1160.025397610689,
  353.88220914985595,
  1070.9411700381931,
  -1160.0591311324208,
  247.19392878231417,
  1412.3376380378315,
  -1164.67505597235,
  243.6334433368743,
  1572.4521623254325,
  1170.366987887435,
  353.32351192718386,
  1499.750771768486,
  368.50625882104066,
  267.42297730517146,
  13.396792077813213,
  384.9838930977527,
  176.2607695431717,
  157.09228386473882,
  327.6016304524855,
  237.68086307563914,
  186.33833252922673,
  350.93284927499604,
  115.45107419364466,
  91.72189428701358,
  384.9918853235296,
  5.559264023479244,
  -96.30407340079745,
  326.4498307824257,
  193.78655257348024,
  -79.77539498922495,
  336.82730373443866,
  4.333448586550219,
  102.93070281226319,
  370.6900248367123,
  106.27953319970082,
  188.61963833446708,
  326.40649989706253,
  111.70966419868157,
  149.7118328400771,
  927.8096373976665,
  253.55972060795256,
  -835.7993662369778,
  -529.4334147994352,
  324.4160346641475,
  618.767063547501,
  -482.50764279127463,
  140.46745447711186,
  914.8119850839888,
  901.4854274497307,
  231.26107544325214,
  -42.948714722613275,
  -245.46967603465077,
  176.19292924620896,
  -1946.253106011218,
  -65.07433374458572,
  1.1591027774422002,
  -1778.9405449336105,
  821.8814909305703,
  170.4212552096133,
  70.51313711394937,
  135.70108583847679,
  21.173447475066382,
  937.9046430310831,
  505.31004825313556,
  189.19345560019673,
  544.0579953391543,
  -219.3300933053016,
  3.032800222142612,
  -156.89371706472085,
  1057.9115037953363,
  189.00065861252023,
  1193.3775208218958,
  -43.537850694576775,
  420.89800444321645,
  1468.1954559040003,
  -312.2341913123281,
  152.2826875697913,
  579.1080280313316,
  1045.932330511934,
  2.2323434024391986,
  -1187.7258022263122,
  -181.33568118941673,
  399.020093584625,
  -1032.409871420928,
  -251.0046223998869,
  340.1374535977269,
  684.4344483275596,
  882.2849919817119,
  106.80118592542622,
  1489.6323261588263,
  -292.00618146864497,
  266.01580644084515,
  1124.0252355323287,
  1360.8435103926759,
  95.6018734260406,
  559.394903260824,
  864.8117933254205,
  5.1842055920817245,
  680.0330969879343,
  547.9154910812076,
  -12.773557330996937,
  704.5863410783658,
  957.2381128784416,
  14.12314145880174,
  625.152003476747,
  1412.703946991619,
  126.19487232159946,
  467.29657716118464,
  1411.37748175897,
  184.0138378801808,
  481.17307310042486,
  1180.179501218717,
  46.20171759385532,
  634.5622528694297,
  -651.5627606487103,
  85.78702726027842,
  706.5015898329436,
  613.3714405184131,
  319.45854445057125,
  673.8369089973824,
  28.953601043274716,
  252.84295476075533,
  -808.3063255972623,
  436.0555073458043,
  89.8020298764718,
  467.86323691779137,
  184.76696654703238,
  136.90418827490768,
  727.5994100247156,
  60.332999762773625,
  246.57236050962538,
  -112.69569663975214,
  386.1426253996767,
  0.2629990951893717,
  -1782.5672697955076,
  -5.054022543836055,
  0.338416650840216,
  -1635.7749380727687,
  121.33603287443923,
  213.21570340551148,
  -13.149495891898582,
  287.28761920761383,
  56.05685154587127,
  747.8598440524834,
  -114.76782288054011,
  124.00705788842498,
  402.3169428888001,
  514.6088448824191,
  32.78554917801509,
  625.0853139189758,
  -138.47127553523683,
  31.93224708686324,
  759.8901946158752,
  178.93393540582684,
  79.50351602734162,
  787.3267554435316,
  253.38572391190246,
  78.859679216898,
  698.564348839154,
  -161.6638489661275,
  44.79103887803039,
  522.1717715434155,
  502.0366869874852,
  29.699538012003742,
  537.67780095075,
  280.7864343215322,
  78.20357894074465,
  709.0796550412526,
  530.8784618491796,
  49.656875064031624,
  789.4669141436013,
  163.5803960214239,
  79.43584329800672,
  752.9663808796438,
  483.0489805299693,
  -72.92265926963782,
  229.91643730353132,
  246.8976656999235,
  -312.43121987909694,
  279.49984169779316,
  335.80227305636697,
  -284.93360696810004,
  289.59145027808063,
  504.4791100462918,
  198.78161902530212,
  256.9432087684245,
  493.09129474782867,
  260.96514040000454,
  192.063180337808,
  39.69006865616191,
  -172.65084083473823,
  197.7665474761379,
  501.3869444620262,
  5.39390559927584,
  260.8109076013803,
  140.0419368575824,
  -282.3906417180705,
  290.37863508730163,
  423.04168894573434,
  425.0795379547875,
  276.95315158791493,
  192.84351644569608,
  1112.970995037093,
  2447.004683936079,
  62.23725924224657,
  -1404.6217598031135,
  4818.744616134375,
  -9.885718663401875,
  934.2470734092954,
  5301.45997911483,
  23.1654496657345,
  2792.332068313777,
  3739.7854823659413,
  136.31553180669502,
  2291.1055582867193,
  636.356903571909,
  235.76233573955832,
  626.6354334704934,
  909.1680135635813,
  217.74490154142939,
  1949.4179111409787,
  3924.790442793782,
  110.62466811283275,
  2116.568598997552,
  5339.113659188992,
  1.35207486169368,
  511.72187261662805,
  4696.927917536899,
  480.4813153744478,
  980.1769138331559,
  57.47910932588283,
  506.9915185488889,
  -423.56636060434334,
  69.87496042444829,
  9.261037636820987,
  -432.36385390282794,
  72.39786256952016,
  174.85284693189863,
  1235.570257684792,
  64.23580219210612,
  555.9627939280042,
  -157.0195444207488,
  48.015795084452,
  -41.326686729653886,
  -162.044795600658,
  49.441636869034475,
  413.23520136741524,
  1139.8726749777343,
  65.20272690034507,
  300.33723146593195,
  -796.3933888195561,
  72.59465877182541,
  23.983850031062644,
  949.4175200432693,
  69.23828789697873,
  252.18289363288824,
  96.30470216680163,
  105872.60029983724,
  117.45641245178754,
  -58.5204239014773,
  177704.8449898399,
  -527.7967139390486,
  85.31366573160413,
  192324.71439394302,
  130.11516603908967,
  199.58085331727898,
  145026.70205553801,
  1155.8678065097952,
  168.7567824048937,
  51034.00158131006,
  970.1527157495334,
  66.39638419668107,
  59296.557749898704,
  510.7486670701373,
  147.7439188495764,
  150629.89716386484,
  -533.8007285622642,
  158.02323279740867,
  193465.12119986938,
  -485.5404253734446,
  59.329511879086404,
  174015.41564634873,
  147.92242619520943,
  449.00453558055545,
  -313.743213626252,
  97.59928885095417,
  175.5853926799296,
  298.5238141522399,
  138.18711053369748,
  550.450268374709,
  423.137266303008,
  148.50614049020686,
  280.9948378886966,
  19.989438203796926,
  76.19709837580405,
  545.7129326995453,
  -781.1637430810832,
  121.90822210028529,
  331.5085417999322,
  -710.7372830835343,
  147.09312204386322,
  165.90530781359905,
  67.7486531614176,
  72.12492786914805,
  378.5602245150606,
  432.8576013494231,
  99.92616615590794,
  33.003008136736355,
  267.07671197568067,
  -72.82937648674286,
  16.404533995458706,
  585.0552199241645,
  -61.71437200457993,
  600.9569512306919,
  711.2272757488487,
  -29.936599864955056,
  880.7631659273688,
  736.9068154397587,
  -48.678535572534,
  744.067712700187,
  653.8287008839372,
  -75.48075933717232,
  161.8710116043729,
  488.73219996674356,
  -49.562010932720455,
  -337.03209964300424,
  503.24523241695806,
  -63.08409746692662,
  -182.65816914721825,
  663.670613092798,
  -26.951204120123535,
  897.9707276773041,
  738.9099196417943,
  190.92481413129423,
  379.44249280067277,
  704.7468589513907,
  28.805313348145503,
  -932.4133168482487,
  7788710.455612877,
  -29.430144121976355,
  604.4546408089323,
  13071102.166143319,
  -8.325636707952967,
  -1018.6740532416375,
  14146216.514616689,
  5.850774945469988,
  -121.87311869322573,
  10668020.484697413,
  42.60922837744427,
  -363.7890718629632,
  3755995.61372002,
  42.30455520739762,
  -1167.1421841030403,
  4363606.560601918,
  36.3806293968903,
  -528.7039181290252,
  11080067.630383085,
  0.4691182553522566,
  -448.02897941994274,
  14230079.624898918,
  -3.2577133836292056,
  -1222.6049799647162,
  12799789.316812884,
  558.2931613541186,
  205.40277343233146,
  -221.25435130936492,
  221.906601235194,
  243.15816630275566,
  1313.7792792528132,
  498.54994032185107,
  75.89205560089036,
  1626.2015250920645,
  387.63266769640416,
  240.16792043048144,
  615.4571175975667,
  153.58374605956135,
  108.50464995771974,
  -1393.1388392454476,
  530.9294466050758,
  41.51801343262579,
  -1216.5704798975216,
  228.09182736995024,
  61.72929894780785,
  735.1957247788098,
  159.81389674994384,
  0.26657922952793456,
  1650.5716781782398,
  539.3303824391213,
  33.5543264541533,
  1234.937275299258,
  8.013715663888778,
  83.35386478217274,
  -62.71487415292891,
  8.492319113351597,
  41.63299768996819,
  68.12565875482707,
  5.149738585517199,
  224.70538194943748,
  94.75536400947676,
  6.538628384616935,
  190.98127681722463,
  8.603286115469082,
  9.005819493604122,
  3.142498060722559,
  -162.60193060245797,
  2.2986400509692624,
  179.16190236490542,
  -147.55190318171017,
  4.444329490245351,
  240.4666423283814,
  18.809357735859987,
  9.166121876191735,
  1.9334696950850372,
  96.83258482949944,
  0.8609166397547812,
  15.90504752554979,
  61.4054608338078,
  34.48236451405012,
  1084.4367577535118,
  635.1535418801423,
  2.894203702294419,
  -445.8254034075328,
  1102.6979372976841,
  -22.783299460596844,
  975.8034396620664,
  1197.8562889700238,
  5.269484104007443,
  -1360.533506255432,
  890.0012208366907,
  58.92577915934518,
  1800.5393678483376,
  278.2180236592089,
  70.16496961629272,
  788.8286193595977,
  331.9976576539114,
  47.66796414033582,
  1592.8522125854515,
  926.4715063002021,
  -3.8417709215129747,
  1694.4510006925173,
  1205.2790113547678,
  -21.399217146177584,
  718.9809946232588,
  1078.6840418767272,
  -58.95693756570758,
  341.7943667688145,
  -206.2688280517078,
  122.7561470797816,
  297.5995313040406,
  557.72172827542,
  94.58422498241544,
  381.73652826311604,
  713.2151589439625,
  -58.365103461598665,
  354.49541128389757,
  210.16482388162814,
  90.63784130975543,
  373.4989238221307,
  -789.5190344732628,
  123.94247087798743,
  274.875415204136,
  -701.6404652991223,
  -59.047158802080176,
  339.13347034467097,
  269.759065527481,
  40.0859372561686,
  166.18233736188597,
  725.3442526936971,
  113.39745200296008,
  20.001520170570473,
  518.48184110737,
  332.06543684506494,
  446.64618714703636,
  465.8270826085703,
  -50.60519341174478,
  51.00989662642226,
  755.166552579435,
  -363.72716262094866,
  418.55996500321714,
  814.0552213476433,
  59.110132456636336,
  -185.48011789848783,
  623.539362074013,
  353.5150528333625,
  -264.2471848740537,
  244.93782659772612,
  870.2789565669058,
  370.2192125473756,
  278.2193094852665,
  517.9051330576428,
  578.0926867719369,
  646.108968659233,
  -190.02782437259827,
  604.360190908337,
  818.6487670763322,
  -358.64680702862495,
  352.1607021471791,
  740.3055728711222,
  1198.9981335819039,
  106.39035992901869,
  -1074.5391869183693,
  19.239225522480524,
  235.16219205668264,
  595.8415300087279,
  -839.5636169751133,
  15.036867242566032,
  935.8106906829595,
  1239.0528369010215,
  83.98033336757487,
  -164.05313927260565,
  644.3840327595871,
  183.09290468416577,
  -2349.751151100237,
  -801.5649301880745,
  60.08500164608961,
  -2157.614394743821,
  1298.8618532105631,
  40.606996148944134,
  -33.75693173348688,
  1082.6925161914291,
  57.72440730121631,
  962.3296105119675,
  -245.6811401445609,
  225.58253617810425,
  510.04786369037,
  13.864596332476816,
  24.838931962174534,
  51.08060719339512,
  -6.870226455827229,
  -23.390174016941124,
  99.2034775940894,
  -32.63134646446303,
  21.415147499568942,
  108.99782668682556,
  6.993247879286963,
  57.01017293216346,
  77.31127522523263,
  62.921204412635845,
  47.40825998370826,
  14.34235976041955,
  59.37302535188982,
  15.522282438492102,
  19.877727914309183,
  28.97830788313322,
  40.862606516019966,
  81.06504671311355,
  -28.414365375020246,
  44.06468446274827,
  109.76182409721558,
  -32.56362278963436,
  13.320902451914279,
  96.7318030569013,
  541.3949500479509,
  -447.68004290032275,
  13082523.453532249,
  -361.3710984175167,
  375.03970986430653,
  21954723.713434152,
  -150.8740044066452,
  -493.85734223516545,
  23760464.431778543,
  100.98350965476104,
  -13.779766621257394,
  17918555.423190314,
  721.52539284925,
  -143.28278097587224,
  6309255.65572267,
  800.652936019686,
  -573.3356495986186,
  7329786.9408407705,
  675.0016320319585,
  -231.56538253005004,
  18610621.629821014,
  68.43090472513762,
  -188.3782854874272,
  23901319.24709997,
  -78.37904738877671,
  -603.0261233127773,
  21499032.037342507,
  -18.49106495225456,
  455.19369107658554,
  613.794774587106,
  -5.950449925855308,
  650.2620370839218,
  746.1647559610728,
  2.9806212693280543,
  692.7527560511621,
  773.1057467245188,
  -3.672044450064192,
  666.3761276105295,
  685.9466019799904,
  -17.886673208978458,
  472.0010699590575,
  512.7400975089696,
  -22.294940716300793,
  256.50197803408867,
  527.9660508514753,
  -19.557345541095774,
  421.1512307436808,
  696.2719765429706,
  13.598548870959686,
  677.7437161268468,
  775.207249027707,
  28.89228724193796,
  -83.74085640979399,
  739.3660028998801,
  13.440062494768199,
  663.963848111527,
  470.09700127239887,
  831.7412298821621,
  221.54731137459936,
  571.477354899952,
  722.7737573782348,
  -84.77234655943465,
  592.1110903007184,
  719.6223992000965,
  467.2919710077616,
  525.357096499725,
  -366.1302932327653,
  450.514508771818,
  392.7006097978396,
  -461.9712043016152,
  237.88562290726298,
  404.36195867888915,
  812.2512742795054,
  313.18897287762877,
  533.2651592921079,
  496.0550849007217,
  620.6922582111395,
  593.7206020981434,
  -185.9296709207481,
  593.5740241789454,
  566.2702831574333,
  -226.1971752254641,
  126.6677475474319,
  -1710.8595557161862,
  908.1203123649201,
  299.20569241924886,
  577.9187259963742,
  -516.9580824790859,
  165.27238812441348,
  1043.7490744421357,
  -559.5565112992051,
  341.15523402258975,
  -463.2992417492222,
  940.9551261770076,
  326.25266996091057,
  -3458.172260312534,
  -652.8631410571827,
  374.04182236567635,
  -3194.90387448235,
  -646.0497254672742,
  327.3234475140097,
  -284.7656134673626,
  934.0491736203581,
  320.5567619171651,
  1080.0856575600053,
  -456.7279979977566,
  271.33488667341226,
  460.3630824307631,
  44.56568747564696,
  7.0228272809065935,
  -282.5148862326089,
  210.85475442613102,
  20.78501774116492,
  128.10608182069393,
  65.08708455833175,
  56.78690616387664,
  211.6789250950902,
  127.14453748335835,
  49.09860719911146,
  -58.69485616718377,
  191.5046244685985,
  55.89060437663851,
  -595.9935835734171,
  58.62100577361195,
  58.46278643140019,
  -548.7616081954731,
  189.55804764135422,
  56.9139805094405,
  -26.66481994178229,
  130.72816042573203,
  50.7158226350616,
  218.19793266118987,
  64.51369865328759,
  56.950500596732994,
  107.01587288838881,
  630.1181296923419,
  -864.6233765440059,
  9898570.461233806,
  -820.3519851175993,
  352.9836389552172,
  16611552.575077474,
  -1548.6882943602957,
  1247.3324384665507,
  17977832.053604387,
  126.83895273742633,
  -222.4605760896605,
  13557662.362147424,
  896.5500798348813,
  -414.1221695746866,
  4773705.800044147,
  2364.4177605637724,
  1129.706303563929,
  5545871.448127867,
  760.7458087575826,
  -544.778464914227,
  14081301.136139536,
  22.082488747519108,
  -480.86251764124756,
  18084407.17907523,
  -1633.7491395924035,
  1085.7650599431533,
  16266762.10806603,
  306.36984933751233,
  176.66168895326223,
  340.8251183327484,
  113.11709474670118,
  -656.5726785751834,
  520.874110727815,
  -303.1766283776168,
  117.51037724351994,
  557.5191127950076,
  92.16322801954306,
  732.4709472430895,
  438.96567623499885,
  759.1478434244781,
  566.5826584132348,
  203.37104758445696,
  744.6917212728474,
  15.701778630412662,
  224.08131383302197,
  471.8174133735944,
  453.4961038009363,
  453.0101995239616,
  -200.59116785940546,
  508.8170834988381,
  560.3775658088822,
  -270.99847733122596,
  -22.33055523869092,
  511.6264805211422,
  228.85325627804974,
  -94.37662445199967,
  1007.9372385360167,
  216.2161541804223,
  -37.0347374255809,
  1225.3073417287183,
  209.00851105364382,
  96.83412535018634,
  1269.548232915514,
  438.4046830729788,
  -242.02024882680013,
  1126.4206741544324,
  539.2839084107977,
  -20.354924123659984,
  841.9912638023548,
  217.5801953337852,
  -44.967556120811636,
  866.994417953426,
  271.5011873569818,
  -193.31552424620025,
  1143.3763895739082,
  310.007962599578,
  365.32739494096074,
  1272.9991948916527,
  499.5220703725774,
  287.78786933521485,
  1214.1428341934486,
  314.33804747298797,
  12.315025277384336,
  44.79970946376204,
  341.85099153541404,
  21.130414164894113,
  270.6955337848796,
  65.10997971553087,
  107.06494048232199,
  316.6716475031608,
  428.0660319776973,
  59.08423293510116,
  167.93031925922512,
  248.19127287395037,
  0.5031758300837836,
  -127.65502191205925,
  211.2424351863458,
  110.63060291653599,
  -101.6711904898646,
  546.5342100239454,
  117.4277578483378,
  185.55107416240165,
  187.91123282742174,
  4.321173966270109,
  320.2579636011457,
  417.9767444981918,
  19.026576865838834,
  259.0931303458784,
  5.322563485131951,
  3.0767892582751983,
  325.37281529115813,
  157.463780975041,
  2.5897870596104187,
  395.5421866883948,
  106.47877864400888,
  2.6978553718694536,
  409.8236149024623,
  -18.1557970789666,
  8.7969181796595,
  363.6205231231721,
  -199.15883239257874,
  6.2035149244396965,
  271.80369717448724,
  247.21547285547882,
  2.514087703850922,
  279.8749801336416,
  423.05432667727393,
  9.222301384704581,
  369.0940076323105,
  649.0683136345235,
  7.637719331278524,
  410.93762197622596,
  194.82793912911765,
  2.541118245082095,
  391.93816541682605,
  207.5078560607279,
  1.859159352506481,
  132.9128603307577,
  2163.2801324677757,
  317.76333896903367,
  612.768766112662,
  -1426.333084851867,
  334.7328208817769,
  710.4328542334584,
  -752.1671465143729,
  95.94789763612324,
  394.47125996230255,
  2166.8835355058836,
  301.1596162023767,
  -233.421584227559,
  -1162.0723540123006,
  219.35858939550567,
  -178.22580980254267,
  -1376.3166019627279,
  307.22542219132987,
  431.90189122800086,
  2167.065209031277,
  306.5354147864249,
  718.0510338292552,
  -329.19892114710547,
  22.818370190095777,
  588.1225300514116,
  -357.01737150206725,
  138.46996490711524,
  625.0853139189758,
  -365.56836005578225,
  236.8986148597967,
  759.8901946158752,
  -356.0623862240956,
  136.53373487686986,
  787.3267554435316,
  -237.7382478494294,
  23.397936581264503,
  698.564348839154,
  -371.12132375386,
  207.3442155206558,
  522.1717715434155,
  361.2716496172804,
  501.75669179281795,
  537.67780095075,
  853.5364612639706,
  420.3896579922539,
  709.0796550412526,
  82.28083289253692,
  479.368143990023,
  789.4669141436013,
  -304.0883321982012,
  71.147538199301,
  752.9663808796438,
  299.67562941277123,
  -145.71283368098733,
  1416.3805022300721,
  -679.2527180532335,
  220.30294343575548,
  2461.6778513120166,
  -58.930568442096245,
  -166.25642710316976,
  2674.4250764333297,
  75.44553998069674,
  47.322943422674044,
  1986.1480063300082,
  564.1977443375397,
  -10.291020844847168,
  618.3733939289872,
  1558.219392448822,
  453.78775920317145,
  738.6094814540149,
  382.2749090186354,
  -49.566636757991006,
  2067.6852744245707,
  -90.57847798474398,
  -30.35333984570437,
  2691.0201893419444,
  -1216.890173309439,
  440.5789091993453,
  2407.9895567443095,
  1445.3168803359736,
  242.47678185621845,
  397.2217019485117,
  1312.0785016924983,
  311.39498909393876,
  482.88588721895513,
  1128.722423416464,
  344.63889131568817,
  500.3209431143625,
  1244.8786477652602,
  325.938085723279,
  443.9152758633048,
  1439.695552120963,
  255.96326303677367,
  331.8234410300522,
  1390.2121741651035,
  194.8782511927095,
  341.6770262199347,
  1436.0927195683878,
  221.8842154015387,
  450.5974162577418,
  1040.9067988130164,
  355.4073357272804,
  501.68094544100774,
  -495.8549757773684,
  340.21105087053473,
  478.48602528804946,
  5.5746992170239515,
  6.854454344090661,
  -5.95801764041687,
  -7.094052259813743,
  -5.665932417504369,
  -2.8664982099055383,
  -31.721076523227957,
  5.965632028397831,
  -2.237287602198977,
  6.060898218077867,
  15.206182442039701,
  -4.2729016192713765,
  57.51039595035861,
  12.713503771655605,
  -8.318163758806731,
  48.35989930146849,
  4.4358307144252835,
  -7.9625594887310935,
  19.530879701176477,
  11.014237086962925,
  -4.031751052070053,
  -33.572733802931765,
  11.845503881565408,
  -2.1882067219560772,
  -31.71421447282726,
  3.864347410274184,
  -3.0252840386392057,
  15.763799891194754,
  223.37589749032824,
  -728.6417777358394,
  10.507302311442814,
  6.386567900066893,
  352.8105217004032,
  10.372223231072677,
  560.5563838139444,
  572.9162896985641,
  12.576980882229488,
  49.15029055166204,
  -139.16704311215065,
  14.668974265610025,
  144.44247566152717,
  -1554.2505128929972,
  4.402248200900831,
  350.48973905469694,
  -1429.8556759182743,
  7.034824321841326,
  18.176575596586304,
  -54.809547947680414,
  16.731563423302987,
  319.61263835414127,
  590.0853976372646,
  -5.816270172080902,
  3.4319284850625422,
  297.2652458379407,
  227.36464673976528,
  3602.9908413365783,
  1268.2876782297164,
  -34.09697764461859,
  162.17211506625205,
  3105.3079286682687,
  -217.63503320452855,
  3358.7271036104894,
  3479.19289175146,
  40.717236131121126,
  -1894.5635536522668,
  2269.60509665872,
  258.1258818014118,
  -2579.594744057665,
  -134.14122798583122,
  555.2225814421158,
  2938.3112563352543,
  77.16336186218432,
  323.2974207683,
  -3046.582604812343,
  2412.899837419998,
  116.96453422432839,
  -2818.1361192637446,
  3508.3573763818035,
  -215.34144448139313,
  2781.257764928351,
  3010.955365334008,
  97.71120611404527,
  1854.1794912104917,
  191737747.3937151,
  -239.69306894940627,
  -955.3413545771857,
  321763589.03124183,
  -667.5431553575171,
  1654.7315930193338,
  348227481.8429306,
  39.88665478367294,
  -2634.7212333897273,
  262611838.21904197,
  1151.9092930540087,
  3168.9249393093455,
  92472647.39063144,
  1003.6310613685513,
  1311.4507692429536,
  107428964.35572831,
  385.0530970021082,
  2787.616816477134,
  272754360.74445695,
  -683.7906368898986,
  2974.1495037109285,
  350291768.6460183,
  -683.6609256292089,
  1183.212378001172,
  315085235.07446516,
  24.832321562957347,
  23.185707334988507,
  -737.4349712346399,
  64.81301189870699,
  16.03105310066084,
  432.0399018126017,
  211.94445037897964,
  215.2656845154362,
  670.0607236470934,
  2.889223403273263,
  151.74288797598155,
  -99.98115954274697,
  90.424663442407,
  70.57706876379552,
  -1630.2424221392596,
  164.11639765414685,
  12.226598074375744,
  -1495.7227246411976,
  5.174328411279092,
  293.1583504693687,
  -8.757560499608221,
  106.07915806652336,
  114.85720988723196,
  688.627275623,
  91.54663488431291,
  85.95254287709542,
  371.97363308166473,
  25.715016535041876,
  991.4641395731438,
  536.8138245970842,
  26.732953807156534,
  -96.09990971835094,
  652.5822196783296,
  22.193264134346414,
  -875.5419127652845,
  676.14432364034,
  17.426966608533824,
  -193.26122473650656,
  599.9165097584197,
  17.81509333386299,
  851.2706175672046,
  448.4332290922928,
  19.790209966174814,
  1251.3146551719997,
  461.7495729018756,
  19.717667582918004,
  1243.0125700517008,
  608.9468958728655,
  17.633639217107216,
  781.9085026010687,
  677.9822596011551,
  17.848588740800587,
  -370.92522246025123,
  646.636153037855,
  121.1971630750065,
  69.29802531160144,
  -205.2528740362139,
  462.87697076720247,
  9.884926455906538,
  282.827940610384,
  -292.53845168485435,
  1.7540071464728086,
  382.16602755972076,
  -93.13851075199472,
  86.28600664318078,
  60.788733937341846,
  406.0339836636695,
  71.73255361029716,
  -577.8664273523582,
  -309.8341198280578,
  0.6649350754784322,
  -521.7245768055482,
  -238.16906801254066,
  53.42287387829887,
  98.8609401575187,
  178.98597626352608,
  76.7853239652953,
  389.9147855898667,
  -304.5693510748226,
  14.9141398047827,
  257.75925888780284,
  154.16682535148885,
  780.0450374599682,
  1102903.8085489664,
  -116.70963666268477,
  -2578.6869044847012,
  1851313.765332702,
  -848.1551271853095,
  541.6086409431666,
  2003636.1085384334,
  167.14128124899514,
  3020.4882815186697,
  1510844.83460698,
  1580.1590938959607,
  2351.799715371212,
  531548.2359348533,
  1291.6524427286477,
  131.22255336403555,
  617634.6353191851,
  531.4856227953223,
  1895.9526716307475,
  1569223.7287508429,
  -924.3045978838065,
  2118.9491643488577,
  2015517.8451042688,
  -834.8239748609628,
  -22.084150693019637,
  1812874.124925597,
  308.13382201745617,
  367.83687794189603,
  -866.1293546714676,
  748.1691758224667,
  260.1397605220258,
  723.8206937992753,
  880.5707593624021,
  19.402672648081932,
  1047.4199655191633,
  -165.92846569159997,
  541.6357682555149,
  0.5157885084859459,
  507.9470705377264,
  508.0861340755755,
  -2079.9384604131506,
  884.1413536530446,
  3.256549071458778,
  -1897.053300170231,
  -435.33356789200684,
  173.55209715477912,
  124.53809036640278,
  153.5569953433872,
  517.3669218421182,
  1072.661970195252,
  868.7105760849225,
  28.571582048287468,
  642.1580868623988,
  -1172.227047005157,
  1.4029118873775275,
  -637.4853809931953,
  -889.50713630152,
  33.66298534668117,
  538.5029306505427,
  331.0427329610954,
  114.96612472674025,
  777.8494192808216,
  -1078.4894924516434,
  7.656937052359702,
  3.5187560252593286,
  -1129.8923772287642,
  1.8405243197722783,
  -1535.265359862276,
  685.6453149188713,
  123.99699142574677,
  -1399.9964493542848,
  -749.7096639059248,
  52.573436269456266,
  95.25042867015978,
  -1171.1316282317225,
  4.940052469918783,
  796.519378434625,
  1533.3099434125554,
  59.92265072644573,
  478.1021203555954,
  308.52597925764627,
  1.2259755430208497,
  -76.13950796242791,
  -225.6367341759202,
  5.454784395028865,
  169.93417888022444,
  230.6727623608282,
  0.6051665598613809,
  220.0170515643692,
  362.29773970467386,
  15.011127868898335,
  57.98958984897018,
  -226.72814512389738,
  7.282001048787887,
  -263.998542943007,
  69.47823170675527,
  11.346657965173634,
  -235.69373821466365,
  280.746691062594,
  21.304982917413053,
  77.1842966878697,
  -221.66997141861304,
  11.72982449582399,
  223.92371087100523,
  -73.88737905627238,
  21.00463872138674,
  157.29540523732442,
  334.9712018845155,
  -1095.8960410495545,
  90266485.43878129,
  -464.5474031648765,
  1134.342628972859,
  151480403.514015,
  -143.68727792199866,
  -1221.074023354811,
  163939146.68479523,
  77.0152887330726,
  80.3260829959414,
  123632781.97491619,
  583.5383800642203,
  -270.7322567699201,
  43534192.666873276,
  552.3773334177504,
  -1436.5247815434407,
  50575368.09691514,
  443.5493610302443,
  -510.04980228245347,
  128407706.21403587,
  -55.58472415372023,
  -392.97769656627827,
  164910977.21983805,
  -82.55528274336586,
  -1517.0100772788362,
  148336349.94097853,
  258.86217988860454,
  19.91466660096401,
  -1892.0529695243213,
  -63.03023738537627,
  155.21108781694633,
  971.3297523608935,
  550.1863783075889,
  6.073136484735386,
  1554.1081637635552,
  -1.856833624628905,
  68.74157024170957,
  -331.2890125849027,
  134.23410503663663,
  1.0981277645871046,
  -4078.033607337819,
  536.06526975269,
  3.4551898348988743,
  -3748.670928030715,
  -96.93065513975131,
  269.51428237756414,
  -107.93399799814935,
  454.9206975797647,
  134.20233841009852,
  1599.567151688853,
  472.49019501359726,
  0.6691074957694525,
  824.2614227916328,
  4.075529774863995,
  308.51982499169264,
  313.0558632927547,
  9.176853689277486,
  -168.82393782646176,
  380.56898088315586,
  6.571319064890766,
  -66.16493687227847,
  394.30978720899367,
  7.58681737379159,
  537.8726868149072,
  349.8557083677208,
  12.002258800711672,
  677.115941874154,
  261.51459822781896,
  15.452106256609937,
  -326.830364600558,
  269.2803436617056,
  92.95353112206254,
  122.94813536409208,
  355.12199472509366,
  67.4281690192683,
  939.8206914283505,
  395.38162366797764,
  93.2312442255315,
  197.72185210942433,
  377.10138943890206,
  108.11706151726764,
  56.210070974699754,
  4452.285026945244,
  -28.040669093260362,
  -26.837434698557423,
  7556.957849961095,
  -224.41591355319144,
  50.314528152376425,
  8188.845540661051,
  50.460752981957874,
  111.60693688649607,
  6144.570659325596,
  448.8547220709627,
  95.07304300908814,
  2082.097267556196,
  421.5436249015024,
  40.16738288280757,
  2439.21451616738,
  214.18676849332098,
  83.80183690942688,
  6386.747242417936,
  -193.5755148517925,
  89.31561497038076,
  8238.135243813465,
  -220.51233668574923,
  36.376744155158725,
  7397.4964400523995,
  228.3020729823163,
  118.1692820757076,
  67632378.91819936,
  68.5145411192086,
  -758.8341190457651,
  113496803.46720771,
  -145.466409781118,
  55.910806463240206,
  122831495.70875709,
  52.437028118138215,
  703.1746885867843,
  92632020.14489852,
  407.34681978884146,
  528.5724407923949,
  32618287.626001656,
  452.5475608509523,
  -51.24570402965807,
  37893876.40387705,
  315.7608632830571,
  409.54555366305726,
  96209624.05228409,
  -39.203543464149675,
  467.7724934523295,
  123559638.09288146,
  -127.62336548197663,
  -91.27584135431599,
  111141126.64708742,
  215.85778588965263,
  -4038.5125346229943,
  339093.94067377766,
  -230.81525472154448,
  2568.148097915277,
  568821.4157846433,
  -64.35676535475048,
  -4409.3286534864,
  615577.3775278608,
  44.450169972137246,
  -554.17675186406,
  464313.09504363826,
  324.99166904202366,
  -1594.1207471997907,
  163714.02770304293,
  319.1822146235005,
  -5047.560812899647,
  190138.597542996,
  273.6680538031811,
  -2303.0537541758736,
  482232.73364527914,
  -0.5649121298598061,
  -1956.249763015674,
  619224.52481186,
  -25.634182682887513,
  -5285.983292959955,
  557022.2120797071,
  -735.3254187761149,
  343.048715296213,
  506.02144460107564,
  1420.2158883523666,
  -86.2924913294849,
  615.1492051652323,
  1418.265334212355,
  303.2071189198594,
  637.3597544066685,
  -181.16354090217294,
  -345.2590534832139,
  565.5044728697914,
  691.4512406496765,
  -365.99059658914166,
  422.71048172562206,
  -305.37979600132417,
  -317.6509477518948,
  435.26298172203565,
  981.7396642084359,
  -307.1747990828993,
  574.0168636048236,
  1475.059664230652,
  -19.174427211061698,
  639.0922638305344,
  1510.8765531779177,
  145.38792645869265,
  609.544213093045,
  377.2233079008522,
  56.55211387519245,
  12275591.85137418,
  -329.3226155172615,
  1156.4920337696735,
  20600463.451047223,
  -193.692435103094,
  -5.184892876651247,
  22294807.489972766,
  80.46985787187617,
  636.6575915045066,
  16813287.577345368,
  609.4657849957748,
  463.5177893341536,
  5920168.948917242,
  683.1206310294791,
  -111.44387443256937,
  6877743.356976358,
  503.5471539729944,
  345.48785586620227,
  17462660.014835533,
  -22.306051874749983,
  403.2270944123763,
  22426972.930043604,
  -158.53073063370294,
  -151.13872455503815,
  20172883.52933966,
  417.79372172013825,
  -2834.1932892143072,
  6959.255262368703,
  -259.49453902436346,
  845.8988505747748,
  12103.85077008434,
  -610.3827776860384,
  3548.9762354911395,
  13150.919740075837,
  71.79060019152016,
  -893.3221835661079,
  9763.455755758736,
  488.48655498411847,
  -1472.5996636605428,
  3031.7376157425188,
  1133.7832798993697,
  3193.463324528296,
  3623.498454215736,
  496.038010948911,
  -1867.494896171882,
  10164.75426045609,
  95.88607981343233,
  -1674.3155105636279,
  13232.595201507624,
  -632.7515455716581,
  3060.6554290390654,
  11839.615374010178,
  94.38187812394534,
  1140.159143530978,
  9229.161382875356,
  -848.1288041209384,
  -184.3931424457237,
  15567.633856726621,
  -1865.1795095350544,
  1046.1291704562236,
  16857.6901565001,
  103.38971878377899,
  -976.1389879480244,
  12684.116706740115,
  577.4170957716187,
  -1239.843559853896,
  4390.207094560647,
  2610.0487925959787,
  884.2889760520084,
  5119.294499030107,
  872.0447421605213,
  1580.2293942470774,
  13178.542268867797,
  277.366913254761,
  -1331.6706943137713,
  16958.31957688856,
  -1942.0232795221323,
  823.8308183829097,
  15242.078857869783,
  465.73406928512304,
  591.3413467238499,
  -202.47417060432545,
  -82.32985022299522,
  581.9617827630761,
  98.8878360231997,
  -103.1707119636354,
  19.494361857501076,
  160.22342701394132,
  439.029831974249,
  236.24996434096929,
  -38.20868337476506,
  72.80544319379067,
  301.1705627594199,
  -432.5417429289452,
  -80.29547119611294,
  2.3826470987966673,
  -397.87735902190775,
  281.7473491913423,
  2.562517587191678,
  -14.701272063060511,
  271.7704004601168,
  6.219448988400586,
  165.00784221478608,
  -79.68871589122179,
  2.1652374936418255,
  83.40935786811391,
  291.81683299470484,
  284.4358997315239,
  448642.43570845446,
  81.99328300893731,
  -75.04768301634016,
  752878.0827090801,
  -114.06814803022957,
  258.9161584842624,
  814798.5398299336,
  53.05700588454707,
  524.2295415698045,
  614474.2781043225,
  383.91191280320567,
  452.66010237185543,
  216381.05178902933,
  486.12135577866445,
  214.99271844117075,
  251375.97826916244,
  372.03295551079566,
  403.87099645292176,
  638205.844567396,
  44.82279494347392,
  427.73821167822564,
  819628.5768689015,
  -95.20687807646397,
  198.58437023527102,
  737252.0093735722,
  -446.8433583981895,
  464.8904033193229,
  57.829704747514285,
  -504.97868554339175,
  80.89132031601696,
  530.4711555730942,
  472.8888482102247,
  170.3963951454698,
  626.6669004764618,
  655.944573264081,
  116.47115532762271,
  315.4556711843165,
  -517.9111210889437,
  77.40117621508247,
  -302.9970377748973,
  -592.7607435591863,
  500.7202954988318,
  -248.63111127624936,
  1708.4153836237956,
  38.37640672915293,
  352.32354683942543,
  -688.8241614181729,
  36.48472406597318,
  634.17054357728,
  -1249.18634139856,
  493.4951374805496,
  506.1954664984794,
  78.93268647875723,
  506.1553402266715,
  62717.49242808639,
  -509.461749663105,
  -85.93295154344446,
  105559.37393981818,
  -1253.843181143846,
  464.12298958075644,
  114278.89419747691,
  64.55083475119221,
  -439.8513661976989,
  86069.61507655878,
  2085.6074684805053,
  783.2294141366425,
  30010.888886633566,
  1766.778678133846,
  391.7787829691794,
  34938.80745421202,
  606.1821868804429,
  702.871200947269,
  89411.44884430489,
  -1340.581826746013,
  742.1817546700373,
  114959.0507687426,
  -1294.589523623204,
  364.75337394844814,
  103358.94020059863,
  59.3142115956658,
  132.06808771374352,
  355.1387826206332,
  61.239554371456194,
  3.453208840752609,
  431.7274340510555,
  64.93733920222496,
  -82.9664220795359,
  447.3153651616781,
  67.64251098914882,
  -106.21405626702136,
  396.8854921155128,
  67.23654911283985,
  -104.27962213864481,
  296.6690196289356,
  63.81592449484291,
  -65.2118458730811,
  305.4786849408202,
  60.170335985388114,
  54.15834895750362,
  402.85970549141774,
  59.168797072999666,
  189.54812714192835,
  448.5312845544927,
  59.251731558491755,
  220.92480695385646,
  427.7937073634758,
  -192.3422318960508,
  20.52310740355003,
  465.99135060626435,
  -130.92790141940512,
  -20.284933399840583,
  566.4862862982058,
  -73.45363659573522,
  -44.04871571512487,
  586.9398144028955,
  -88.42408905099768,
  327.8264252766859,
  520.7688249145747,
  -36.47173927021555,
  343.5181830700782,
  389.2709101489502,
  -43.75347749672454,
  -52.71199888079599,
  400.8304131882438,
  -150.0605994705266,
  298.7547396173694,
  528.607821656369,
  311.943218702629,
  -17.142250749269692,
  588.5352693287274,
  -159.89244202526365,
  292.68390693712337,
  561.324691164792,
  218.17672159152113,
  -81.8015207029614,
  18.475427997605195,
  189.25534535440653,
  -3.604737065811001,
  22.45980870785838,
  205.05096885995826,
  -64.91732905659156,
  23.270741540202906,
  253.2844335547485,
  -45.64748502782177,
  20.647222133176967,
  227.28493767727278,
  -83.9672886824624,
  15.433648420002429,
  243.42500724528526,
  164.6411369750008,
  15.89195470790394,
  197.95200976167808,
  -46.43044355875823,
  20.9580193608252,
  223.68115360802696,
  -83.96208530228452,
  23.33399746237245,
  187.89451239951396,
  86.05571758488762,
  22.255163966886023,
  89.95180416821991,
  473.5587928038219,
  -182.87761096444194,
  637.6914240936954,
  288.1383269342056,
  565.423867961998,
  -199.31172881574713,
  356.3211099896284,
  717.7241328919666,
  -203.1600017051639,
  351.6122167733191,
  225.0042863126025,
  637.8620282748434,
  287.7174044968185,
  -754.1503687686909,
  94.73173416922879,
  472.1669257802402,
  -668.0764471287598,
  -362.22150029969225,
  36.32214041542156,
  283.3747187607185,
  657.4392160452757,
  231.8148370006594,
  729.6041472662251,
  383.24747500610215,
  249.4468475891836,
  526.9897991667998,
  192.1522268797404,
  100.93645403692841,
  30.79237999600866,
  650.7892559950551,
  145.28639159316447,
  37.4330145130973,
  768.3902758368305,
  202.82490884214573,
  38.78456923367151,
  674.3396503338764,
  152.4600471519425,
  34.41203688862828,
  182.2203166721994,
  101.22229439789004,
  25.722747366670717,
  -137.71237155279806,
  141.18943653409528,
  26.4865911798399,
  192.30074624924285,
  100.93253255097616,
  34.930032268042,
  662.5045070822364,
  313.2742958807055,
  38.88999577062075,
  -177.31636734931953,
  152.7810320801998,
  37.091939944810036,
  458.84069563856804,
  342.8423105511427,
  531.6817612644162,
  765.9311467309719,
  309.22156136844757,
  646.3433839261467,
  948.5744079265891,
  245.44307807479376,
  669.6802287680614,
  860.1462562290045,
  167.2960866268006,
  594.1811702769817,
  450.10631319796687,
  111.66484312484464,
  444.14610453118104,
  -120.26603363234176,
  118.24631493920208,
  457.3351410385689,
  -503.3977336504405,
  194.72772953081522,
  603.1252238281919,
  -403.13856681185564,
  295.9290611674588,
  671.500593639385,
  142.33141361817616,
  349.1609337539389,
  640.4541630470533,
  549.0799289045485,
  222.3180082269906,
  532.6645191400903,
  -368.9841224490608,
  123.30913770015269,
  1169.6831881555102,
  1027.9734104031425,
  106.11167659039728,
  1299.3342910713736,
  380.305114974076,
  365.15151784906897,
  879.8887203960775,
  7.238269076932738,
  51.09775579848903,
  46.34794477848259,
  998.6606247110452,
  423.6478490179194,
  119.62148030412412,
  282.9476765544641,
  438.29502782170084,
  929.5786598591112,
  507.48385688158135,
  429.8256667999749,
  1309.4475825156605,
  726.0304372276946,
  551.3859515703109,
  1136.9647985247836,
  325.39508173928004,
  -608.7242383369102,
  33466.256828384605,
  -469.5747180820606,
  125.78865388498747,
  56244.93117270859,
  -874.4978317522023,
  665.2982945344589,
  60881.028033523515,
  66.44799348815229,
  -221.3440328724664,
  45882.38745310055,
  468.105347968523,
  -336.9625448936258,
  16076.42602051838,
  1293.994698310007,
  594.3411536438201,
  18696.559597412717,
  389.43569402387544,
  -415.7800386787591,
  47659.21284970478,
  5.649454375610617,
  -377.22319177087155,
  61242.66166149035,
  -923.6026847443691,
  567.8339066183992,
  55074.97873847155,
  115.61085444296542,
  -404.19114797910913,
  42429298.061012045,
  -495.6870270188683,
  1227.3399024068283,
  71202952.43394528,
  -171.1576457781493,
  -495.76509820285685,
  77059195.28179869,
  50.67530088337455,
  456.2741211984743,
  58113154.19084824,
  436.7953589226011,
  199.45740040366243,
  20462744.006736636,
  346.0653805531332,
  -653.3780956541145,
  23772454.5198623,
  206.86669577195386,
  24.384655206432427,
  60357611.3998201,
  -182.85407415055772,
  110.02875158833587,
  77516005.0532304,
  -142.0563464146769,
  -712.2571119929581,
  69725087.37179793,
  579.106103196189,
  170.13020752005713,
  87489.52690944588,
  69.89129115441733,
  44.846821320485546,
  146993.95015040055,
  -255.60363771522816,
  161.23633933849783,
  159104.76334444113,
  87.10586313539244,
  -30.040823043684,
  119924.01719365221,
  550.1895010057499,
  -54.98344106975506,
  42062.306833414106,
  1011.9939337582513,
  145.92861023423984,
  48906.8463773146,
  729.5606551017424,
  -71.98690017754073,
  124565.59417160139,
  286.4596344006961,
  -63.66895274938993,
  160049.45398496836,
  -233.71582559941282,
  140.21014762890223,
  143937.69921295418,
  992.1193322093263,
  -31.268696383061652,
  236.07491330273305,
  560.598887129792,
  -65.733979834467,
  286.9864446004126,
  1046.1506588501138,
  -23.197388403719906,
  297.3483641248149,
  1220.2818343202407,
  43.05531226968967,
  263.82561614615014,
  492.2306387827374,
  -68.29321725429355,
  197.20772981114214,
  -522.1231644209577,
  119.97840899359213,
  203.0638657121059,
  276.19063179724907,
  152.71810359352395,
  267.7969140549887,
  -595.0418186139086,
  -31.005901142510922,
  298.15663424142576,
  1219.592413795339,
  34.84482047081244,
  284.37153957687696,
  199.55298775919036,
  5.717998365583952,
  -25.77381437975431,
  230.07082589473507,
  219.79042119606018,
  138.2867525418502,
  196.19568674756607,
  23.45717708201545,
  171.67766317130452,
  236.80624006259933,
  211.0118420666695,
  63.651821127922815,
  214.0510834097526,
  109.30778833718928,
  -151.02190642775471,
  218.04740189734926,
  134.96438339741653,
  -132.1507204431002,
  230.22313204278294,
  156.8370316628694,
  76.44918490252867,
  190.8312043979771,
  9.278006546808996,
  174.28228436766227,
  232.49976919731637,
  237.3053562467167,
  129.86031574702997,
  63.56790941116542,
  304.71736071565977,
  231.96926263659856,
  65.77915788462127,
  87.62225849755013,
  281.9953759986663,
  2.828413733639916,
  288.04931578963595,
  292.17708822699205,
  65.72465523038957,
  84.38257978205107,
  259.2373445609997,
  9.709125371532075,
  -100.56247495379796,
  193.77803016225272,
  14.042854356940829,
  454.789767526994,
  199.53232022146057,
  14.242567953168084,
  456.43968961918614,
  263.13957641924975,
  61.433344318419984,
  350.7529374070039,
  292.97130147200966,
  65.81631602849532,
  89.92598215320093,
  279.4259475842356,
  23.461405413454095,
  71.44612829482219,
  8.99887001358455,
  12.303964674651326,
  11.504890989579735,
  29.22682484985543,
  56.10673166459423,
  9.911850257561728,
  33.34377900177733,
  36.82729197043075,
  38.485649878217004,
  20.024662196287952,
  28.526778741305804,
  64.51891601489842,
  -6.443675363493632,
  53.42855737842232,
  0.5882943814382031,
  -4.1169401524245055,
  47.171642792948404,
  7.079688893787068,
  21.602521527834405,
  46.58156066437349,
  60.00317533618322,
  33.66491747468468,
  47.41110195618503,
  6.5245169290374605,
  28.18788181732426,
  327.10714417502487,
  84.62080193029637,
  205.75706923797878,
  305.21498261090375,
  92.38565946684014,
  459.1961681778327,
  183.69050464790087,
  252.0214329147929,
  510.77810807661336,
  400.9945550916426,
  285.044614524361,
  343.90088350395865,
  369.34548658774963,
  0.03629287329295039,
  12.275087624754113,
  179.34945606465072,
  217.08584840908603,
  41.42710423434334,
  425.0668757214505,
  220.62574720074775,
  363.67012119890967,
  416.6759959262269,
  119.34805875087797,
  514.801700469781,
  178.73909563472625,
  209.47031694783846,
  446.17909412631263,
  101.87625455479252,
  -20.581167280631405,
  7130.480520504514,
  -244.47431863914915,
  71.37957504005678,
  12015.151768244317,
  -86.86710358585424,
  -25.742704621781925,
  13009.318886815128,
  31.269281513906066,
  27.91869110454825,
  9793.002287748803,
  254.8897423479819,
  13.443296180823605,
  3401.395795632878,
  224.3303804813434,
  -34.626512405628766,
  3963.2586571335332,
  153.42884185206435,
  3.5753751230848696,
  10174.025686909397,
  -70.32958038439887,
  8.402678089093639,
  13086.86779760965,
  -67.45116568657767,
  -37.9452099249626,
  11764.26653540087,
  1530.9145385256875,
  -342.082434154519,
  1252.2234531710187,
  -318.73439345719225,
  -425.41997607269684,
  1522.2759235326234,
  -1545.7127993978243,
  112.72537192330007,
  1577.2391488359747,
  -1265.1845066106152,
  605.3279356063488,
  1399.4228334708832,
  -1088.5627300410308,
  689.6465799909774,
  1046.0583929112759,
  -1536.2318252078699,
  362.9542383889642,
  1077.1213746468225,
  -909.4961804548207,
  -297.0095827610695,
  1420.4879789003746,
  1225.7559399016145,
  -405.9817101258768,
  1581.5264946719105,
  2223.041142923992,
  -22.099443776908544,
  1508.4055577556082,
  -85.45818932092482,
  8.116461481908743,
  -283.54809552535534,
  -1255.4077475198637,
  58.67071766751272,
  102.82729285440175,
  -10.741273075493439,
  10.28219270822629,
  181.46548303555645,
  -691.5905601562174,
  0.18177367651715315,
  -72.94377238598824,
  -175.76889020834835,
  65.62250290859022,
  -578.5170884826572,
  834.9246086207266,
  43.68829066350255,
  -534.0739785335634,
  -1053.2487108791256,
  7.82163378020411,
  -42.804985891284126,
  1168.78727961926,
  12.80895559864366,
  187.59956842370292,
  1699.464846304184,
  73.05652951722166,
  82.98237917193282,
  402.4114791183547,
  2420.7920701592643,
  64723747.73479064,
  -130.02675811970272,
  -203.349080118911,
  108615976.75040974,
  -543.9537381891257,
  2234.5042774330877,
  117549272.08083738,
  79.18665953015659,
  -1771.9189853924859,
  88648390.61040516,
  490.4690746239993,
  -2294.3581718111404,
  31215281.665871777,
  1195.038894133795,
  1913.8740400302963,
  36264017.21870329,
  620.3820808244589,
  -2650.5065654276773,
  92072155.57800761,
  235.6172283401424,
  -2476.2818035163436,
  118246103.94113503,
  -545.9657911206625,
  1794.0971606355336,
  106361595.33186556,
  63.121871169770145,
  2.4498772001385873,
  -1029.3866373473463,
  610.8021418648461,
  371.9366084465645,
  586.6621857573043,
  171.9816067839918,
  513.7937529544573,
  915.5732875390479,
  86.34902617654049,
  46.07811133256956,
  -148.51565336114862,
  613.3478618170707,
  17.083232751260084,
  -2263.1202245718328,
  325.18377500340483,
  489.5030175937386,
  -2077.2330338024467,
  102.05683813901106,
  86.14085040583407,
  -22.457545341345543,
  491.2543597670224,
  159.47310268626026,
  941.2296356669844,
  498.7955464923177,
  142.87388251910045,
  503.6591002459515,
  1760.73387326788,
  172.89123670802275,
  852.9489258894398,
  1746.9659210383197,
  75.8994772495755,
  1036.894502012795,
  1487.66960657511,
  -31.418635311640458,
  1074.332567772701,
  940.4719784688048,
  -114.30530569405965,
  953.2134218150034,
  217.15699734473964,
  -138.11578132503013,
  712.5201020567788,
  -458.8520399235722,
  -93.66483051408184,
  733.6785756815652,
  -902.1486746876142,
  -5.336767784497312,
  967.5618938247635,
  -1080.5261259358472,
  87.50983413207672,
  1077.2528828461948,
  -1094.2152280439998,
  155.03053458733285,
  1027.446736471238,
  521.9850634340416,
  -380.69510238831674,
  43716.81509228544,
  -863.133666361369,
  343.168118513958,
  73307.64733773237,
  -170.31898894781904,
  -421.32382014641234,
  79330.20872160858,
  122.206440779936,
  1.0684938816401228,
  59846.09605481326,
  917.0261924867538,
  -112.8736702298659,
  21126.40625488541,
  771.5659700670753,
  -491.25215645612684,
  24530.11324689755,
  677.7174311094831,
  -190.54839251032337,
  62154.29632343279,
  -99.24441483651123,
  -152.55057969297167,
  79799.99198720697,
  -42.1327480295966,
  -517.3750760294431,
  71787.8105951132,
  133.05946065979433,
  20.500693209698404,
  -178.31589722779137,
  141.9478735512062,
  17.623415867798013,
  147.99958364474048,
  142.09489703291584,
  20.903658198819933,
  214.41390405866852,
  161.97181373452767,
  7.213929077114443,
  -0.4488460492872659,
  109.23169346626703,
  20.37942098201301,
  -427.4335990125237,
  146.42889359053243,
  21.655260482811293,
  -389.89892358890353,
  177.54752293802443,
  0.008631113975077653,
  25.00503352926301,
  84.744903021958,
  5.356914874564201,
  219.59447995285262,
  155.20383138153716,
  21.831155843685636,
  131.23945154024955,
  322.6158090633471,
  -1942.866545814044,
  -2011.6043230887742,
  -1510.0220149160093,
  3728.577103493807,
  -1670.3882995096737,
  -471.0324911335324,
  -2261.191163856463,
  -1600.9413022058554,
  146.57681010966792,
  1048.2382113849592,
  -1825.6153293499901,
  1262.4245020819774,
  155.50524142813936,
  -2272.0974856529956,
  946.834600015331,
  -2809.077294023502,
  -2232.848864471634,
  579.5262270824046,
  -453.0735586387425,
  -1798.9991493537773,
  -544.2017530072927,
  -155.36199108328367,
  -1595.5241656920234,
  -371.8497697170965,
  -3013.749477990514,
  -1687.913749470133,
  -179.91801755028905,
  817.6296573579339,
  12.316951998403464,
  -284.2898978612227,
  688.3947682138532,
  14.97320580523892,
  856.2163572242328,
  -9.771412986800357,
  15.513827693468604,
  811.5949221635019,
  -151.46562826791143,
  13.764814755451312,
  809.3476647240416,
  -156.90647910849867,
  10.289098946668286,
  509.8566894745117,
  -512.9486413660269,
  10.59463647193596,
  553.353014476126,
  -485.122642231863,
  13.9720129072168,
  744.1081400901861,
  685.5426054066004,
  15.555998308248302,
  135.19317119713202,
  985.2256317502821,
  14.836775977924015,
  589.5253593257582,
  -31.705978255955927,
  215.5466599720606,
  14.144331379462017,
  -95.34890053504498,
  262.0311015916811,
  -94.70470643654733,
  -61.83483573491645,
  271.4919846357006,
  534.207126222592,
  -61.1933040484773,
  240.88425822039795,
  628.079065075689,
  1.8197952409832254,
  180.05923156669502,
  626.3097847785857,
  -0.2383450278549475,
  185.40613825887928,
  -202.1516190534324,
  19.02301815756453,
  244.51022587629402,
  -212.82796698474135,
  54.541455449322235,
  272.2299703943453,
  170.4921270717063,
  -115.0241248478649,
  259.6435796136703,
  361.2002242697276,
  189.74394758017235,
  62.882949005320526,
  140.64554786252077,
  -140.75087981707026,
  94.42563581211792,
  -936.9970557035929,
  166.2821182129813,
  100.84545415080456,
  218.90943992126276,
  410.2006306490146,
  80.07614092367682,
  1977.0822641639543,
  344.4025508762488,
  38.80244377028248,
  1626.38184782474,
  125.90066428183933,
  42.43066425224155,
  808.9682816278,
  299.5477983551771,
  82.53659345696553,
  -986.2324186249764,
  321.4903613953172,
  101.34622500749867,
  -874.0441045249111,
  110.81548524047624,
  92.80554841571575,
  148.56795959659345,
  -42.99756123206407,
  172.4373279776485,
  145.0655962110474,
  53.30771554536875,
  209.62488127334487,
  146.52942917899273,
  -1.7159645656485054,
  217.19358770856047,
  153.11682276615602,
  -78.98784739622258,
  192.70740657631836,
  150.92432546923467,
  -68.79989818653405,
  144.047385253356,
  146.74275378490108,
  268.2989678403706,
  148.32491060710345,
  163.34946220921034,
  178.63909890430102,
  195.60818070103522,
  163.51802607636256,
  158.63132646491485,
  217.78397631547622,
  146.45150888120963,
  260.57511463848584,
  207.7148636909362,
  -516.5628786660864,
  971.110171226535,
  528.6025232648153,
  -856.1634449394476,
  307.9692425157465,
  642.600082474837,
  1068.6473649045274,
  1130.361970127269,
  665.8017718446943,
  691.254508111987,
  1262.66142216456,
  590.7399665881188,
  -676.4476509914607,
  799.2674701907185,
  441.5738297945139,
  -24.14724736386995,
  -692.3843425049297,
  454.6864819205849,
  -149.9233179511083,
  1190.543155114196,
  599.6322206013876,
  1629.7650468937045,
  424.22400544440006,
  667.611594062323,
  -691.7470214827199,
  778.0342608785596,
  636.7449690525723,
  20.100414843413038,
  55.588836265707194,
  -31.380645538685886,
  20.129309875722665,
  107.80827689899644,
  99.99855076267234,
  15.371041197986965,
  29.49011741102283,
  126.73788907280041,
  20.463455332847904,
  48.73316488680314,
  40.23112773618565,
  23.678790485625548,
  112.44937095961484,
  -131.67893159427268,
  11.191476812455658,
  7.765272789361653,
  -116.56694402505943,
  21.51201506525599,
  29.291849723159324,
  50.47921720114056,
  25.045735049492517,
  50.165826476013955,
  128.82366169853123,
  10.003842797942944,
  92.83279149504436,
  93.2506861504729,
  205.39693177920108,
  16.9985953029146,
  440.7089149846807,
  216.9960346058284,
  0.12279175266055908,
  559.8794251613843,
  184.6482794516783,
  12.36156939696557,
  584.1339546296279,
  216.44875781512317,
  15.321966375504282,
  505.6660147088221,
  187.73930092891115,
  10.317639754132161,
  349.73105657491914,
  164.9304435048788,
  3.57896850986542,
  363.43873114674574,
  222.54333549206106,
  12.517557215411284,
  514.9617790631254,
  160.13663430508734,
  16.815987596120976,
  586.0259024792006,
  149.86417468394376,
  0.3724312607036744,
  553.7586199572287,
  1049.6017560344226,
  212.11250703190265,
  -430.333376933533,
  -433.2533337224237,
  209.75712621695737,
  282.7372624334215,
  -684.0026649930475,
  8.723559398569861,
  427.86706686087666,
  1125.8052856610109,
  192.14858072117016,
  -41.65499867505587,
  -837.4182879102075,
  186.339642672298,
  -974.7099980312493,
  -869.9304839193308,
  135.16722148874499,
  -892.6885293249974,
  1135.8572986005665,
  188.70029402815277,
  13.967290947594309,
  -788.7972898020615,
  38.41155395198045,
  439.1877573634456,
  -620.9883875221109,
  229.66423319202036,
  246.11271099115527,
  55.69475279174479,
  1211.170902512243,
  672.8701214741401,
  3.9692569072698305,
  -1826.7729187344364,
  926.9951999881833,
  -50.18976635474529,
  995.5072562079363,
  978.7167559024707,
  14.76945478386795,
  3237.6323253911437,
  811.3878474028566,
  119.69478958700533,
  2632.8093347568292,
  478.86444526163876,
  130.7098569982819,
  624.3166102629149,
  508.09536717046655,
  82.78637852513036,
  2220.4996494643783,
  831.2105941787378,
  -23.161732169604974,
  2422.1980371065756,
  982.7512388891109,
  -47.53378090181566,
  485.65203017851127,
  913.9428928295682,
  777.6067404241147,
  29.86981370180182,
  -6.079844308712014,
  -246.80893676531474,
  4.894880191777375,
  285.25414067859526,
  -402.6278518543502,
  38.98698251941953,
  344.54874899652464,
  782.5520524133792,
  33.24638927894351,
  152.71959934384586,
  99.61931257170221,
  18.249376360981397,
  -228.49176481510108,
  -441.2476851857682,
  97.23417668194072,
  -194.98086138775201,
  795.6666026170495,
  47.946417366521985,
  175.44478587553485,
  433.07402642553126,
  73.49317895009482,
  349.17395959255947,
  -182.00432763465193,
  61.76453800313267,
  270.29071920113734,
  470.08209221388177,
  104.61950587257017,
  -273.3129017340789,
  905.8719480435248,
  0.004653008673130898,
  91.0269918393888,
  -222.47212238431666,
  0.1132102850704797,
  165.18034296653585,
  11.796398556921531,
  18.179350455756285,
  -74.71961917413489,
  892.9590187615439,
  0.19959260462589157,
  -551.4594264187934,
  221.0924536300822,
  55.3126169419881,
  -509.55096527992896,
  -370.8034594728281,
  17.764019424598267,
  -46.299687174943266,
  925.7559066732135,
  0.3003669308579191,
  170.96459342529266,
  649.4531688747888,
  132.07022465170294,
  72.31385959417717,
  -5.2328097372273135,
  460.95533510772026,
  186.8071053091192,
  -1.6273637835775947,
  566.3382907143862,
  227.09362137945695,
  -7.975943816460216,
  318.3496220820192,
  235.2930533509405,
  -8.386250271405622,
  283.5363822193237,
  208.7663571243449,
  15.27580264232309,
  686.3542964867969,
  156.051334024469,
  32.20736617336745,
  118.9400777194486,
  160.68531982436204,
  24.94478336543912,
  559.0047942249427,
  211.9088624261215,
  -7.894940541626802,
  324.4336119197036,
  235.93264100843257,
  -1.567077868677469,
  567.6978362360248,
  225.0244356651809,
  79.8631712068337,
  175.4743871678068,
  319.91987614871766,
  -60.48265838778771,
  192.73641042595236,
  389.5657224968807,
  -41.924813390057764,
  11.517561466422848,
  403.7405987316768,
  173.46008818078326,
  227.65380200263579,
  357.88222253711336,
  -75.73765396653755,
  213.64825680733347,
  266.7504306332462,
  -109.58793564936957,
  34.50236960548244,
  274.7614947430203,
  205.08026146840567,
  70.0269191010658,
  363.31487005157453,
  -100.47688273230798,
  236.199153725604,
  404.8462943356874,
  -132.6053332718021,
  150.72103051285532,
  385.98859038472006,
  420.63313187111737,
  31.353747504632267,
  -119.37588630698048,
  1130.9455122846848,
  11.565362776899647,
  887.4257759074517,
  -1049.5171698845254,
  228.75353145053774,
  1092.3380528511996,
  865.5366235744444,
  0.05027457328375817,
  429.40850572022447,
  652.2349762707862,
  8.42796976797925,
  -887.994388785819,
  -986.9534680574131,
  203.82001176885245,
  -772.1862956296696,
  1341.3736024341079,
  43.171845237125396,
  507.9429601719918,
  256.29933572478444,
  54.463815885431224,
  1108.3220092591098,
  -368.2693877766443,
  39.26719863657594,
  835.7146869434362,
  218.06053775531785,
  -4106.491827656454,
  375758972.3652225,
  -673.5080365570201,
  1835.57997074776,
  630577581.6550432,
  -84.68255713658712,
  -4440.006158851207,
  682440290.4654063,
  66.03747283207757,
  -972.658482421006,
  514654725.94270164,
  516.3086299020105,
  -1907.990601066565,
  181223836.77029553,
  319.7583841118025,
  -5014.036145590065,
  210534532.56081447,
  298.93882430580504,
  -2545.6093712760494,
  534531570.82267356,
  -141.06959454570375,
  -2233.69169757301,
  686485783.9281944,
  -1146.0741127011484,
  5411.643315177284,
  617489653.546452,
  -631.8366976064872,
  397.74752833007506,
  -1896.8661053275634,
  -379.0728269575036,
  270.42364298568515,
  653.2508399137575,
  849.282642886132,
  121.23142885479024,
  1172.2709104338048,
  -671.4484941442431,
  485.4793803493661,
  -506.8561064222692,
  -610.2429275823677,
  474.12397393058177,
  -3843.6915240363314,
  229.41788601486408,
  45.31240752885935,
  -3550.3624684366164,
  -630.2894311941939,
  489.5819199914643,
  -307.9370436127763,
  -672.3759643227215,
  495.1644745984111,
  1212.7564992221237,
  762.8774203411704,
  69.09226106745314,
  522.2723868846142,
  69.5389613174122,
  209.17021369741377,
  16.42260266453795,
  121.71123824686323,
  393.54863008625244,
  19.964274406985226,
  257.6378163944789,
  450.8110080860971,
  20.685103591291472,
  305.89996435786446,
  437.64089329409546,
  18.35308634060175,
  224.01167021666507,
  450.3117902343582,
  13.718798595557715,
  84.29799929432895,
  331.75540640607676,
  14.12618196258128,
  92.36674222718764,
  134.2556686962261,
  18.629350542955734,
  116.46762718347763,
  96.68217423818396,
  20.7413310776644,
  74.37283397345229,
  300.579824307002,
  19.782367970565353,
  5.389800434484291,
  -1588.9420100752377,
  2341383.6383207226,
  -3.3204792842818893,
  2889.1879711606844,
  3930540.2373043625,
  -1.9201780056723319,
  -1840.2887753728796,
  4253978.019877834,
  1.0243436280724625,
  772.8121954637309,
  3207596.290464232,
  7.437257691772041,
  67.9168416168641,
  1128180.2724972945,
  8.608555267927205,
  -2272.895613687102,
  1310974.1656361106,
  6.853856994744706,
  -412.6124801999322,
  3331556.700169064,
  0.5407707005194666,
  -177.54162719171234,
  4279207.427770971,
  -1.3526075635525237,
  -2434.5032571765014,
  3848918.383316708,
  491.5712573921985,
  -194.8153802512107,
  1641.3033856187847,
  -1182.5962045445985,
  115.73420354369215,
  2645.0398522065243,
  -215.33412595443338,
  -212.24578840783755,
  2849.3282761723563,
  135.71573192218796,
  -31.032330489538985,
  2188.4170101238747,
  1054.7026331587122,
  -79.91544903977137,
  875.0249329837364,
  781.1213619518469,
  -242.24622924993935,
  990.4804497844824,
  670.3210189089544,
  -113.23922068479794,
  2266.712367367757,
  -231.86739733678928,
  -96.93751531449985,
  2865.2635696160323,
  -63.29276489259763,
  -253.45340426138569,
  2593.486197034777,
  95.78962571143231,
  268.4265006027111,
  496274.5349243048,
  26.7813166378182,
  64.49245858608923,
  832845.4998146531,
  -16.365702048070773,
  253.94922199101097,
  901347.0978524868,
  12.764980824357707,
  -57.408301567060306,
  679731.6141817091,
  86.73999441631415,
  363.8596253847345,
  239327.53064256214,
  132.33881846322555,
  229.0315759644743,
  278041.8505712225,
  112.93688064851236,
  336.1817005672224,
  705985.4614924408,
  41.92452851592827,
  349.7215057382192,
  906690.489538137,
  -11.060468563470678,
  219.72316541936257,
  815558.6281681875,
  4.660134425440447,
  811.8484989870436,
  768.7830872336829,
  -307.6257895771936,
  -56.1854322318772,
  934.5775956769959,
  1206.8613012831315,
  376.6479618065632,
  968.321411867332,
  -473.9269904837107,
  310.3396603999056,
  859.1538543194193,
  -271.0136071708571,
  -87.62062473456496,
  642.2112592545456,
  498.4571204246183,
  862.4572801412642,
  661.2818931233361,
  793.7634339025614,
  -212.42133543267937,
  872.0864722921153,
  -223.69455315839184,
  -122.47072553581819,
  970.9535610731648,
  332.0523469686099,
  868.4656977110677,
  926.0621006220906,
  -9.021007467938958,
  22.19898264649059,
  216.57307263859423,
  -159.20860948937343,
  20.177024541793436,
  263.27886874211765,
  17.228274973209196,
  22.332821946312208,
  272.7848036101563,
  421.6384928307269,
  10.414944521872686,
  242.03132611668556,
  42.20416929825068,
  22.40946707140932,
  180.91665647891736,
  82.7097883549225,
  22.431363303972933,
  186.28902463154063,
  -136.02184132388763,
  4.33893390165753,
  245.67456028522875,
  389.79718356506163,
  17.044273655607604,
  273.52630358669927,
  10.381310293980391,
  22.30324752017476,
  260.8799776118306,
  1593.8587277545194,
  146.91360284280756,
  380.79909928397376,
  1009.5508396079601,
  428.7789820433259,
  462.9216128119699,
  -1031.5681718563073,
  207.0730191376884,
  479.635839523071,
  276.7386274590567,
  475.39552669286394,
  425.5621895227031,
  890.7004076656076,
  -65.75683229210867,
  318.1046424344945,
  1527.9404151020342,
  90.69764467603474,
  327.5508442573534,
  937.4030850188235,
  -60.296496748878354,
  431.96806571478606,
  678.529253627916,
  462.5393096326459,
  480.9396143633433,
  1385.2891230869539,
  348.19858363138053,
  458.7036573174841,
  291.98637702084494,
  1484.4288836819198,
  2049937.4584774051,
  -413.1441586018698,
  236.4511542643443,
  3440852.389351935,
  -940.4226714985289,
  1395.8349387411215,
  3723942.4518908397,
  91.84349841873703,
  -509.52255549915105,
  2808093.1442980426,
  607.579535321089,
  -757.9819303145852,
  988076.9239081424,
  1605.17337316679,
  1243.3509934266185,
  1148067.9250480367,
  625.7698360185447,
  -927.3574471590639,
  2916589.9310879954,
  138.2510466010087,
  -844.5003863811592,
  3746024.5803344,
  -977.0489897864054,
  1186.388021763318,
  3369412.5731187845,
  138.4374410553497,
  466.0283579016579,
  630.2173772516438,
  140.0959373675817,
  -10.293196911953089,
  766.129030368058,
  103.90751157189753,
  -398.31587813076214,
  793.7908503158103,
  69.28104708560895,
  -522.7935310992767,
  704.2996883205922,
  73.43248203517663,
  -514.0292142398212,
  526.4588961045273,
  114.50449923689526,
  -329.9033646069771,
  542.0922328140566,
  144.21884777648532,
  163.78702969310154,
  714.9013270859263,
  127.75014453678554,
  626.544440654918,
  795.9485801053714,
  116.94103335411283,
  729.1644782792265,
  759.1483708704454,
  84.73286852203432,
  323.50325892481135,
  -293.63658865986093,
  210.03808011205265,
  338.17669596651837,
  206.89090678837672,
  -142.43714813106166,
  51.574201635679316,
  308.7622411479792,
  -23.29337172481405,
  336.6574596856002,
  -20.81058171991812,
  60.086586617607,
  251.5305028536681,
  -675.7522609311393,
  -116.1108244690439,
  151.28390276575277,
  -618.1787218761968,
  -96.93356018354746,
  207.89388202248855,
  18.232514123486045,
  -5.018522382639617,
  135.87016891077002,
  316.70860235144403,
  -57.83414160163659,
  292.27953755356634,
  181.18294183614248,
  57.64763114511886,
  -197.08604928206375,
  423427.29792218475,
  -152.3825187864023,
  518.2428859439005,
  710635.5366895883,
  -45.536515155047624,
  -237.2357579207645,
  769090.4403429932,
  18.049449741773277,
  180.17658672729914,
  579977.8923565475,
  146.55494322102686,
  67.57779101886345,
  204165.07909008104,
  120.58215877337885,
  -306.33964510569496,
  237201.4155590062,
  86.07578808854888,
  -9.18115290647438,
  602381.2545997527,
  -42.020716806467334,
  28.36866893649001,
  773650.1507017876,
  -31.737184772926312,
  -332.15457768381174,
  695884.0207321821,
  5.832321691118126,
  -622.4167059472944,
  59337410.918088935,
  -8.662209982592948,
  1224.7047836708618,
  99577113.70194452,
  -3.2601957666108916,
  -726.0912338133109,
  107767017.8612638,
  1.423478025774207,
  351.7504049955389,
  81271145.88930744,
  11.039178423403797,
  60.997934326254565,
  28617378.110541508,
  10.696704803493118,
  -904.5312056216842,
  33245979.178122967,
  8.004161550131826,
  -137.20891550584315,
  84409999.57224692,
  -1.5404704609392894,
  -40.24781210023943,
  108405862.3122649,
  -2.338682889816524,
  -971.190492517469,
  97510332.39969204,
  -252.99888549723863,
  287.4464330249307,
  79.58597960494033,
  413.2881621223128,
  92.14024238474548,
  278.95503525496645,
  218.58659587205003,
  0.00009649572717762567,
  319.5322101629978,
  -173.46658150381217,
  314.88174227369325,
  188.25745890434072,
  547.891670188019,
  265.6628512387812,
  -72.61752853915532,
  113.66735271314062,
  24.9349397400521,
  -49.684957968712304,
  82.55766181979966,
  59.84121502378902,
  203.80902244228815,
  604.7506155373767,
  356.75595678484916,
  322.69738798718527,
  53.848661730833186,
  60.2957065506226,
  268.7150929104986,
  86.45374836876113,
  -178.3689258231904,
  431.0933199441212,
  101.19824412278678,
  614.485578001205,
  524.0622031833622,
  16.706281886926142,
  925.9782394139459,
  542.9839692714012,
  81.08426654661433,
  -212.75439334279895,
  481.7685164407959,
  -45.44201436988712,
  685.003995801823,
  360.11846313339004,
  12.453900935607297,
  -352.55195933771665,
  370.81227651775856,
  108.48887581779871,
  503.4760999671821,
  489.02045175258803,
  88.10461198295695,
  -166.60610147612925,
  544.4599407886906,
  -60.926431094456206,
  97.68701488079708,
  519.2871592273406,
  -498.8129378587073,
  0.22262238038516102,
  -258.80359133400384,
  767.3498658981872,
  0.04421249894339496,
  545.2646316843533,
  -211.37097507321624,
  131.75271417293982,
  708.9149876386856,
  -405.3821501372338,
  81.92519871930146,
  179.47547342934283,
  749.3325977811822,
  2.8114894572321703,
  -872.650128007244,
  122.06670395794193,
  188.9122780608592,
  -780.1615960848793,
  -44.729168066356806,
  188.28579849878406,
  242.19592931124745,
  692.122911595276,
  25.005429205213417,
  721.680353358725,
  416.4398800539302,
  138.70565533720918,
  503.9662856703155,
  75.14794491854205,
  7.445210454299215,
  -181.07005994284205,
  -67.37291788001735,
  111.79468327425019,
  322.2353940249308,
  229.88969139376042,
  185.40842734482254,
  424.67212058327226,
  29.42327607075719,
  1.837750879756726,
  93.27014818928687,
  -13.60675124254594,
  28.73267257872395,
  -565.3064978002013,
  236.19869621301595,
  142.88339788102886,
  -507.41342204693166,
  -26.705525772643327,
  43.6651186079774,
  132.52993562648678,
  41.16367315851449,
  0.08351805882095675,
  432.66258458229845,
  217.76744225895766,
  171.24806259357985,
  296.3847482791172,
  -244.06958911443508,
  -40.51054733304355,
  372.5877979517048,
  -18.683329669271814,
  -69.34503472264237,
  452.9394756084773,
  -143.89890710427096,
  -56.6047710220283,
  469.2932877274253,
  197.9408722674173,
  141.9473291166151,
  416.3856463524022,
  -379.82986680852,
  59.23528992876375,
  311.24524313671566,
  33.81384432704391,
  -72.9505065638937,
  320.4877532760628,
  890.9316165697803,
  54.060263300862474,
  422.65339044330824,
  885.8039835016741,
  57.904287615708405,
  470.5689488245111,
  134.091505457281,
  -77.50429281570126,
  448.8124733322015,
  -224.16024447511734,
  33.146392696531905,
  -550.8985591970713,
  750.8671005007759,
  285.82103944555456,
  558.2702725963214,
  439.37580700162016,
  430.71397241132934,
  784.0171295670577,
  -110.96819197274453,
  111.182024676414,
  53.683818698943846,
  884.4771276089026,
  73.1205289776448,
  -1397.6668140429463,
  313.3470781301537,
  390.8612209782933,
  -1270.0838627835064,
  227.55957125014368,
  406.43583825431733,
  140.2033114341928,
  885.1319996162824,
  14.606649167268614,
  801.6262644361877,
  245.51683528501127,
  351.36561927048024,
  501.30142730177977,
  182.7306631573536,
  -1822.8939971152545,
  1901.8284772412055,
  79.85893121971864,
  808.2562314490647,
  3099.4966366935423,
  -19.621745964940487,
  -1970.5741899039576,
  3343.255580273968,
  22.724603385123444,
  -435.2321508189666,
  2554.649799853808,
  138.07694519191935,
  -849.3973445850115,
  987.4975402420364,
  201.76806469617574,
  2486.6910552484487,
  1125.260191005787,
  209.8569176741865,
  -1131.7350257662026,
  2648.0725851419884,
  99.34267341705667,
  -993.6178359541545,
  3362.2697281148867,
  27.376659257463103,
  2391.737583623779,
  3037.982311611292,
  354.9620556966463,
  67.72168711895381,
  -16.72294226679775,
  164.21667201247254,
  37.788933852624666,
  65.57922099955914,
  449.22535616440564,
  51.245097617655816,
  82.33001145337286,
  494.1875260951281,
  38.716120988043805,
  28.13807090565745,
  42.633423660395835,
  0.36102903596729163,
  -79.55454838613987,
  483.8497767789431,
  39.92223095996661,
  -70.08768222151798,
  561.9106666594353,
  5.174868302832799,
  34.55796047765835,
  44.33460310469499,
  30.06359732668831,
  83.63663840811259,
  529.1399789242782,
  20.647699452706192,
  61.35203838125011,
  49.873384162915386,
  28.666710340762382,
  -35.2645592914803,
  35.86865784927252,
  1.072984081682126,
  22.394286031034387,
  26.328498786005003,
  29.781152945667692,
  34.12947253737873,
  47.14142195611388,
  13.303927484390874,
  -3.836051013384523,
  44.29310311130697,
  5.128014002621164,
  -79.28281731558289,
  35.901648985839714,
  47.703001355330116,
  -72.65056671351384,
  40.97628223481877,
  0.7407595542109924,
  0.661563692339012,
  48.729303122474654,
  20.74036336686956,
  35.04486283196607,
  18.307125977779382,
  11.717491711447868,
  19.43282719367309,
  88.40455037402657,
  244.65434373045457,
  -1152.902218711219,
  756.495379762626,
  248.2959096553982,
  1165.8466009124622,
  14.541488764585779,
  431.15330339516885,
  1637.776791457301,
  -137.11532193198877,
  23.820524389226165,
  110.99434502921856,
  797.1263374951734,
  189.48091252025415,
  -2923.0952092986176,
  -201.34737458070958,
  172.64258204074665,
  -2656.3794405561753,
  -220.89932830597957,
  80.94350279298305,
  291.86579210182,
  802.2891250223132,
  181.29852634683758,
  1674.589186037817,
  -185.28920276344866,
  0.20416408658792307,
  1046.7516182591385,
  1137.9012694847238,
  331.65483484844486,
  1008.9636512025504,
  1253.5249999979922,
  229.17574153964438,
  1226.555108879155,
  1233.2238477115282,
  113.14241677976838,
  1270.8410518899698,
  1051.0507755966164,
  2.4106632717297884,
  1127.56774205072,
  712.4715126409073,
  -78.88977252406806,
  842.8486887145771,
  266.4799528000815,
  -106.6569732518696,
  867.8773043260874,
  -192.57854765088393,
  -64.82698689355314,
  1144.540723982843,
  -540.2131435681692,
  45.89645203246798,
  1274.2955280840067,
  -656.36794230129,
  202.19853559729737,
  1215.379232191609,
  131.95938959547553,
  4.472509786197158,
  832.4206725587674,
  166.17498320534864,
  -6.765961373084124,
  1011.9391590040636,
  101.77787567501647,
  21.403356225552454,
  1048.4761882835865,
  101.18476800786581,
  21.898706361281203,
  930.2720638892512,
  361.507750678994,
  -24.959427428115703,
  695.3716038123316,
  566.8896658489678,
  23.737202424484042,
  716.0208482283387,
  415.3247370562914,
  -21.3798340080036,
  944.2752056460688,
  97.69933892167268,
  25.100064166568796,
  1051.3262189991144,
  210.9907127213031,
  -16.172848660673104,
  1002.7187765080314,
  170.6063990839714,
  -912.6374653065066,
  10094.485042552753,
  -245.8844145255248,
  2197.8880619638608,
  17264.08362227769,
  -102.37798293179728,
  -1087.2238513495686,
  18723.29731339613,
  41.830719527025295,
  727.8456774895593,
  14002.468059783272,
  326.06979297793293,
  238.22277655048975,
  4621.027527989265,
  323.7970900901447,
  -1387.7141496407164,
  5445.715817028008,
  236.2807485863737,
  -95.55465473803685,
  14561.724698134893,
  -46.57382390285747,
  67.7264228686916,
  18837.121669733082,
  -78.36902819601741,
  -1499.9674121815967,
  16895.840537361655,
  159.32455839269699,
  62.043432470623046,
  280.2106579636788,
  156.96197528932586,
  67.70522952675279,
  340.6404320691854,
  172.15907357741136,
  52.39977055397951,
  352.93958002641074,
  188.26695386339014,
  144.6737038462786,
  313.1495356865173,
  168.30692123563114,
  182.7467111834991,
  234.0770010367035,
  156.1055685695975,
  70.23282054943613,
  241.02797973654307,
  189.22228796340693,
  98.59323758865348,
  317.8632936391822,
  157.85521171520114,
  65.35808440016235,
  353.89896151264884,
  178.90107422463765,
  58.80672523973918,
  337.53665349777134,
  130.52214833911853,
  374.65294133727014,
  260.70881729954,
  98.76528056450589,
  362.86369037432576,
  316.93285621089046,
  134.06344516008716,
  373.2367845587489,
  328.37601951175213,
  167.09715522962546,
  89.48254242714748,
  291.35524565705276,
  143.99297142867113,
  366.2085994305114,
  217.78592770447872,
  142.79690940995124,
  367.30600771120686,
  224.2531386559778,
  61.33285478774648,
  177.92299263494903,
  295.7409398694223,
  184.511725866353,
  175.7699864681642,
  329.2686308579224,
  125.41746740428268,
  375.73647458846244,
  314.045091532725,
  244.3596814235328,
  148.28320246092764,
  403.72306189890816,
  243.57510762527528,
  116.53568592109033,
  530.9729423012935,
  305.08324926744183,
  276.26319622063806,
  556.871849417439,
  242.82316955843493,
  20.436643734534726,
  473.08404020576,
  248.24252272896868,
  251.6987647739686,
  306.5772027031953,
  320.5569815926449,
  12.975555370535346,
  321.21421270905455,
  249.00898657919424,
  33.24393727764917,
  483.01002693334794,
  253.557200969897,
  333.72406643001705,
  558.8920651337995,
  316.195840472292,
  127.61009014472661,
  524.4371665540872,
  1181.6761617462053,
  225.51064876397544,
  -1132.9726363811615,
  -244.37974415313693,
  295.15285382941545,
  660.7391832979206,
  2196.3889872585187,
  225.61150771726355,
  1025.8096703121469,
  -70.63649733836502,
  3.8504626289917496,
  -155.26164584751257,
  37.96183441921903,
  232.1495678213589,
  -2502.338763258585,
  1800.6550559750397,
  31.610795089282675,
  -2296.0157571445575,
  -1137.5022983666024,
  160.96808856714804,
  -15.345131514046003,
  515.0245899650191,
  123.00174892871445,
  1054.2865914477784,
  1155.7824656473267,
  15.433943285321021,
  568.6110164857806,
  177.16037424581683,
  -165.4374256246585,
  288.4219592959478,
  350.6438334514294,
  62.60951021252279,
  350.62256927267805,
  -89.96513256133267,
  499.7205941057465,
  363.2821318220565,
  108.1609562758317,
  -174.41125824982697,
  322.3260788568182,
  -119.17121445970452,
  126.75745295641079,
  240.93640033448236,
  377.36001142822215,
  218.91583011451823,
  248.09107071783373,
  352.9799352100471,
  70.6354749465647,
  327.17796891066007,
  -89.22395289609162,
  20.35197330360984,
  364.26962705148105,
  -63.340308099293566,
  557.9211111599304,
  347.427837483054,
  1788.86540611947,
  8.862381071815156,
  425.9612566114531,
  1463.709829245664,
  4.025384756839348,
  517.8233674311792,
  483.90145847497934,
  1.2531682764062309,
  536.5198743991226,
  -566.9013396344708,
  3.3132534415334014,
  476.0331769593579,
  -1002.9516178680558,
  8.023170511834387,
  355.83133857227824,
  -941.4812347854108,
  11.466844553369507,
  366.39784465445194,
  -882.4609665574128,
  12.285368308810966,
  483.19877970791435,
  -991.6185994097045,
  10.384788687504761,
  537.9782748269204,
  -893.1282467921312,
  5.844291135903946,
  513.1051692365388,
  344.0698367934817,
  -47.5221412759766,
  872.4507665535787,
  425.30655813486874,
  -45.822224106129426,
  1060.6020778710902,
  622.4689426852674,
  -35.07228387673311,
  1098.8961282873595,
  631.2315580470672,
  -34.3112057895736,
  975.0077118444678,
  92.5905056212448,
  -44.34299820038898,
  728.8111753890036,
  823.2622071421766,
  28.072595775437847,
  750.4534167621305,
  -218.8630215495939,
  -14.048884008999089,
  989.6842475945234,
  834.5100024635487,
  21.454538770961506,
  1101.8832135009213,
  468.43443250103826,
  -44.34201905589602,
  1050.9382984362844,
  0.11465337715753765,
  641.7386071835655,
  616882.1848233339,
  -1.1467959196523718,
  -103.51381675534086,
  1035249.2396126485,
  -2.6542657748217824,
  588.8331340672676,
  1120398.6280299965,
  0.13627464636230102,
  -548.9854804647541,
  844924.42831922,
  0.6909592798862154,
  -697.3574801942266,
  297489.9239570048,
  3.6847253841974146,
  497.77459417614654,
  345612.89859328006,
  1.2225850999756789,
  889.34183472074,
  877558.6895064783,
  -2.8498772243012698,
  938.8214239230347,
  1127040.6122630676,
  -2.752734453613048,
  463.75812761095386,
  1013761.1781584794,
  260.06684592452996,
  1044.7388978699491,
  590.1872832568326,
  -7.034502055522154,
  1246.7677854582128,
  717.4661115010315,
  266.8729143723752,
  1024.284485803607,
  743.3709103120373,
  -218.3177600981549,
  459.6052640804064,
  659.5640403653754,
  357.1212431885943,
  518.6758503782567,
  493.01932452785536,
  288.04582264489443,
  951.8181338468321,
  507.65966428026474,
  219.41763859729414,
  -679.3474019607834,
  669.4922851374718,
  -205.9387001605948,
  -141.32304421711973,
  745.3915856035644,
  116.03632720288225,
  1272.3433417645886,
  710.9288489421924,
  3.1838120587776473,
  89.15795838213536,
  113.91026263845953,
  731.6761136973546,
  29.166341551461358,
  190.03654008831765,
  -391.22147546853023,
  85.78407090144216,
  205.53036517119634,
  -309.05545406132063,
  23.441540606796764,
  155.4049427284065,
  755.2490267637182,
  17.92581113928297,
  55.79348793617818,
  -498.545261614404,
  10.159736324130158,
  64.54996834479552,
  -491.83657345199094,
  5.137266689331817,
  161.34308913136223,
  756.3951874416966,
  17.33283204707775,
  206.7389439269948,
  -341.8134081827753,
  16.41191520961563,
  186.12656173463617,
  289.5656632128462,
  -2116.227426556991,
  104040089.78075482,
  -302.82513362376415,
  870.801450711166,
  174594332.20967445,
  -43.336992419200556,
  -2283.8822399049477,
  188954092.43529072,
  56.0977066475166,
  -540.8760985440964,
  142497581.94572917,
  396.12364196708046,
  -1011.0595872358697,
  50177151.13604765,
  970.5565870682806,
  2776.2545232393713,
  58292704.16542836,
  352.0841302400599,
  -1331.585111652359,
  148001087.89567548,
  24.11096381626396,
  -1174.786754060717,
  190074209.71131557,
  -626.2981122082019,
  2668.458032312849,
  170970543.29080644,
  106.4858731879278,
  -357.71024993129595,
  141.64494798163983,
  65.32475607850145,
  -124.84482604141823,
  172.19186676024756,
  51.764483880074636,
  208.0668112092321,
  178.40901847488894,
  64.34455201865127,
  451.87836433755115,
  158.29536968769008,
  71.19059209716848,
  513.8674133290124,
  118.3246378866853,
  58.710962747412836,
  383.4019899767387,
  121.83831942726354,
  53.23693138577485,
  62.397000384364915,
  160.6781484329932,
  86.74834315300596,
  -276.13342467235947,
  178.89398054485545,
  133.2861779059216,
  -421.5073184399222,
  170.62292374612616,
  1503.3341851661821,
  222.62202039304051,
  -381.3584839548398,
  -300.5554602126348,
  96.91099015959529,
  137.55287942540912,
  847.9780050292636,
  222.80940222335602,
  243.16584471229473,
  1613.2548858214811,
  19.503236481485004,
  -98.51185412082333,
  -394.1336274191797,
  69.13807465565044,
  -777.5088778301651,
  1480.2388109665144,
  6.713804981828815,
  -717.8207210009948,
  1234.51661112875,
  80.84549242367848,
  -58.03474491317991,
  -365.12953548762346,
  77.50813681183118,
  251.4040677140287,
  1614.4777330793809,
  101.9966581438421,
  110.90068695964062,
  486.3628997690247,
  137.0123283615781,
  381.82551195050735,
  625.8981595736532,
  105.21328561261734,
  464.1693799624065,
  694.1657278756326,
  56.93692705044051,
  480.9286584975267,
  624.108167730338,
  3.1701268408016077,
  426.70925741899066,
  414.09263535029044,
  -37.53420993685384,
  318.9620673467169,
  141.94589780438264,
  -52.59842345014542,
  328.43373063001474,
  -93.90574632475077,
  -45.01987727182609,
  433.1324001237208,
  -241.71969995913048,
  -28.873462110908065,
  482.23594755569735,
  -303.4195067172128,
  -18.08814314770646,
  459.9400553156445,
  89.9967189914162,
  468.5828771080286,
  647.6663925827155,
  157.6574200653323,
  447.57954241506314,
  787.3410719254798,
  -24.80566576002262,
  432.1677918428021,
  815.7687728815574,
  12.846646312414691,
  454.8905387848164,
  723.7998425574815,
  215.3931318933208,
  10.690253607127659,
  541.0351196123074,
  -89.83271440332274,
  57.51980190721028,
  557.1013011492992,
  274.12088449772284,
  141.9022208291127,
  734.6950120378168,
  -60.59608716423352,
  396.8328820985499,
  817.9862443753898,
  268.3747922051143,
  116.56130831311229,
  780.1671368391711,
  -265.45064723505794,
  159.74026681086795,
  69.7960613242863,
  682.6730719726759,
  74.87241390077367,
  84.84816622968721,
  669.307937593436,
  150.37821056523347,
  87.91169026298876,
  22.122807117275755,
  45.1614533800999,
  78.00061694755743,
  -133.60338424475327,
  52.04986673691851,
  58.304894031120284,
  -106.68056920672518,
  172.55271489600992,
  60.03627334097044,
  -394.8657234234762,
  84.66929288573084,
  79.17473980756188,
  596.1498171227015,
  160.1070520238933,
  88.15065708007371,
  -244.56967196857727,
  61.02970485788835,
  84.07506387490275,
  105.42285128872899,
  -464.0993597237783,
  606.6098859213706,
  84.9367974259209,
  -792.8561878798331,
  737.4303859080168,
  103.73022890126734,
  -513.4187915091039,
  764.0560139033288,
  54.32463928104018,
  1050.4215108515293,
  677.9171267059771,
  114.74061600415178,
  138.86395672415318,
  506.73812312341306,
  100.79266662238176,
  -585.6394238328267,
  521.785846242846,
  79.78410288275099,
  -813.0809885844151,
  688.1216356804274,
  48.09525393676671,
  889.8078571079847,
  766.1329166812288,
  82.60237261801808,
  -804.4765579774896,
  730.7112169127578,
  153.91222546703352,
  395.6256127044068,
  26.686729329874172,
  108.09445169771982,
  379.8166728098404,
  32.44194591135099,
  97.78889093872488,
  372.3934959811059,
  33.613293335848645,
  298.24347971512225,
  84.9081923753173,
  29.823765303477842,
  303.8033185010669,
  155.1282943525431,
  22.293047717781285,
  64.14239530624458,
  335.0020987187254,
  22.95504568919458,
  278.0937526242429,
  13.072879068270936,
  30.272694632303068,
  16.221394709558496,
  122.83039085361247,
  33.70466300120465,
  217.1632663629955,
  375.50040745844717,
  32.146347952168696,
  123.64217878052641,
  758.6997339714799,
  3197040.146754131,
  -381.3581681146958,
  191.1731753369848,
  5365157.563529916,
  -842.3445385634752,
  718.4110208775655,
  5806430.053660451,
  60.248880046983516,
  -148.06356130850827,
  4378831.002951069,
  371.0482088778771,
  -261.05219133421144,
  1541843.0760469055,
  1274.924950131692,
  649.0678854261525,
  1791232.3581654753,
  401.21208234744955,
  -338.0768865076958,
  4547952.613397513,
  119.55998694590542,
  -300.39706141675174,
  5840851.028096221,
  -876.9106946498075,
  623.1635775882557,
  5253799.272387719,
  126.83578821416356,
  522.0854686723003,
  -251.29786100769468,
  -245.47845992513334,
  14.852301106679874,
  236.8193517708209,
  381.74747978326536,
  110.30505416645147,
  336.1648467572791,
  312.0032223919714,
  537.1720759188923,
  14.763586749052749,
  -259.80711587296526,
  51.101814969634205,
  -623.9392016018077,
  458.7428493653838,
  51.8357298974864,
  -567.7931643334118,
  440.9960036957216,
  195.12449493816592,
  52.83863216540935,
  -261.7791934176024,
  59.75786831619246,
  343.91418264319907,
  380.47088005910905,
  414.11638154720885,
  211.7488005767159,
  541.1236269124906,
  2575.5853612582923,
  2700.0117228623994,
  240.52977089355716,
  -836.0412899402913,
  5275.438555696319,
  108.73578134358692,
  2333.393969080268,
  5799.609895717038,
  62.96835101911162,
  -2875.3275122275004,
  4103.81755842159,
  401.57071056594543,
  -3554.546864367747,
  733.8640794996275,
  478.39848885138304,
  1916.5449505023125,
  1030.1044233203493,
  554.9147459557063,
  3709.0667735346187,
  4304.710891128441,
  458.6134697737115,
  3935.575107879495,
  5840.497303607522,
  146.56917184106405,
  1760.8239086302644,
  5143.16014270675,
  541.6237937220365,
  -4649.73152016924,
  -880.1666324425919,
  -235.31007621668311,
  958.9115292891515,
  656.6540081214406,
  -650.248061506934,
  5078.535606943003,
  969.4399604404737,
  87.7237996035233,
  -1691.7476374036255,
  -42.48110555163049,
  584.425616270823,
  -2574.5952643181163,
  -2053.4153701639993,
  1318.3130531968627,
  4536.716287935741,
  -1876.6414586914268,
  635.6396320710219,
  -3176.4351957541644,
  77.3968953760305,
  160.0537052229503,
  -2882.020225358178,
  993.8384840499024,
  -666.8553473622836,
  4334.310464479491,
  577.7202202181237,
  300.03032920124093,
  -1652.1045692809635,
  362116.62690458103,
  114.7767969096491,
  928.284459851684,
  607813.792914665,
  -31.884359617503804,
  -1796.9356569000443,
  657820.0330861572,
  38.01683439582672,
  -291.21404868051974,
  496040.49188418966,
  232.77105227112492,
  -697.3890023720202,
  174545.03769345387,
  389.9961983481187,
  -2046.2124631096058,
  202806.53283929478,
  345.03832990866823,
  -974.2797124202327,
  515205.8286303637,
  158.4632160271373,
  -838.8271345109339,
  661720.714758071,
  19.04347849393298,
  2481.216658336302,
  595194.3580382774,
  -25.72851738476158,
  738.3244101540897,
  909.4016225487891,
  43.07269910601132,
  686.5117760792049,
  1105.5216952868068,
  -29.607534574190424,
  556.5294784381804,
  1145.4376113677654,
  -31.731154853264364,
  288.13316392369273,
  1016.3021561108219,
  -31.31367943844524,
  399.90023933759585,
  759.6784722290084,
  37.549797285535035,
  861.9125906849922,
  782.2373261779384,
  34.922486254821486,
  921.0483816997902,
  1031.6002863161739,
  13.812390405912272,
  1145.2742487026194,
  1148.5512084256663,
  3.963412735460908,
  1150.207649288574,
  1095.4486263700564,
  291.53776316528166,
  -229.73739851917742,
  74.92812465695441,
  69.89134172092862,
  -236.15741828516673,
  91.08700198187009,
  -233.29542468874143,
  -13.010986841082854,
  94.37578513526735,
  -241.44033651345518,
  4.571637676384881,
  83.73595642899548,
  12.015445387981913,
  511.5611662210236,
  62.59201859223207,
  -231.19718927379375,
  308.1802657098373,
  64.45070520427709,
  601.2672345208869,
  195.14707529945008,
  84.99641185223554,
  -51.29043904727652,
  484.78360227105213,
  94.63232304184383,
  45.58891094641753,
  -230.55551974442847,
  90.25705386570442,
  -40.26446143837872,
  6.66834120287307,
  136.51288464897172,
  173.3671444498722,
  7.601655827202112,
  165.9530310080647,
  103.40786671169994,
  10.980354737460154,
  171.94492360261037,
  152.16293056426753,
  9.48491632747745,
  152.56003020625204,
  173.09079668721773,
  7.651095687864941,
  114.0375133255735,
  70.11798573397755,
  11.239816335201066,
  117.42388756395688,
  174.2231773850006,
  5.568987371746449,
  154.85647638831955,
  138.58196982055446,
  2.903576208390259,
  172.41231458308533,
  53.790588613923944,
  1.8002344436004538,
  164.4409337553245,
  152.22416836960218,
  273.4397765629776,
  675.3795345791233,
  758.2169103053237,
  263.806173614514,
  821.0307849872675,
  671.0770530415539,
  267.36609250852814,
  850.6748851918618,
  -64.07410059030366,
  268.6098403599716,
  754.7706757572469,
  -350.9885373384684,
  254.85905041158324,
  564.185592242311,
  765.2192067698536,
  263.4853873306698,
  580.9392332111552,
  1693.7680498087125,
  26.628708617707566,
  766.1320410790546,
  671.759301854592,
  -108.34126406306254,
  852.9872405689486,
  1286.5550883584476,
  -62.53977131107439,
  813.5498827895002,
  104.38721696774884,
  -337.45228871414076,
  2550766.30452088,
  96.6740211025512,
  430.32132182506024,
  4280715.353448922,
  -2.7664325942855896,
  -380.5455920122861,
  4632808.334536013,
  10.068952572893991,
  67.46953383026275,
  3493721.6776436325,
  51.749580963435896,
  -53.38449522717565,
  1230078.3306579934,
  127.47668098630177,
  -454.7158629932974,
  1429066.9777098908,
  115.15764041207343,
  -135.77105701238105,
  3628664.4472931144,
  76.31673065558617,
  -95.46825242588767,
  4660272.959619321,
  -2.423926714957119,
  -482.4234294222516,
  4191862.1537277657,
  197.879277536577,
  1562.5075485438028,
  24520.92421705831,
  -764.6512446690213,
  -104.21078939671187,
  41137.86040882088,
  -1663.1727418843034,
  1444.1872058144488,
  44519.87134371924,
  112.5603429863607,
  -1100.485027611328,
  33578.43332495354,
  688.0842153698297,
  -1432.3112986068961,
  11835.124132653262,
  2463.47648850354,
  1240.539510902609,
  13746.499298873016,
  739.746694798202,
  -1658.5182839307154,
  34874.619125451325,
  221.60035323992543,
  -1547.8597526355936,
  44783.6813806812,
  -1733.4342327872714,
  1164.4634502351246,
  40284.38559052189,
  17.625798014199617,
  449.0638537272928,
  2292.7888093357674,
  3.461367939133428,
  -3881.2556731426985,
  5149.615733508619,
  -21.866973023757012,
  141.65444994046229,
  5731.059856851538,
  5.947369719712372,
  3337.604915141774,
  3849.979351970406,
  50.22567708672421,
  2475.483374800356,
  111.81303753445422,
  48.87449209654789,
  -387.4449004443634,
  440.4216314435308,
  28.91641686074137,
  1887.7724800654319,
  4072.8229887792327,
  -15.963553401794144,
  2175.2756460017517,
  5776.4147651067415,
  -20.384084720438537,
  -585.0989632434936,
  5002.884121141424,
  427.4996407403786,
  490.01377670637737,
  125031009.99224913,
  138.90699400519554,
  -391.8850427180703,
  209820302.86391503,
  -22.24926313393098,
  427.40777532532053,
  227077293.70416552,
  51.476480016626596,
  1078.2846736029176,
  171247700.21567413,
  303.3264659244877,
  902.707798984388,
  60300664.62321328,
  522.9792261357361,
  319.6531189847775,
  70053614.67886643,
  482.8946929547836,
  783.0165057637445,
  177861595.59242728,
  244.41091035821566,
  841.5684673561393,
  228423406.26236024,
  2.845752342100212,
  279.3995341037254,
  205465376.93218887,
  1475.0045689509295,
  -319.7675590513279,
  43.10933199441212,
  583.5179253914423,
  -737.3839947447506,
  52.40622031833622,
  1436.1149153475321,
  -359.5189185683388,
  54.29839692714012,
  1560.3872619595484,
  572.5627833741048,
  48.17685164407959,
  1116.1799500749994,
  -579.8036873765203,
  36.011846313339,
  237.0207214231283,
  1113.3552937448117,
  37.08122765177586,
  1528.0139608349737,
  -257.23942551172826,
  48.902045175258806,
  -111.03357921340165,
  1067.6196468891376,
  54.445994078869056,
  1627.3786433114346,
  -92.54077331034881,
  51.92871592273405
];
